(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    119608,       2382]*)
(*NotebookOutlinePosition[    120337,       2407]*)
(*  CellTagsIndexPosition[    120293,       2403]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.1. Two-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.1.7. Visualization of the Wave Functions and Probability Densities of the \
Two-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial wave functions, radial probability densities and \
probability densities of the two-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["In this file we will present visualizations in \
individual scales for states defined by given quantum numbers.",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the two-dimensional quantum rotator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 1, 2, 3, 4\)]],
  ",\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" to find radial functions of the ",
  "two",
  "-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell[TextData[{
  "and \"",
  StyleBox["Graphics`FilledPlot`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool in this part to give vivid presentation of functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input"],

Cell[TextData[{
  "Determine parameter ",
  StyleBox["r0",
    FontSlant->"Italic"],
  " of the two-dimensional quantum rotator:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(r0 = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized radial wave functions of the two-dimensional quantum rotator for \
given quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Rotat[1, 0, 
          r0] = \(2.724107444910865`\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 1, 
          r0] = \(3.7929945592877274`\ BesselJ[\@2, \(4.381447479827306`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 2, 
          r0] = \(4.430540052964394`\ BesselJ[\@6, \(5.70058432040823`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 3, 
          r0] = \(4.9917511617183115`\ BesselJ[2\ \@3, \(6.944557309670949`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 0, 
          r0] = \(4.15621461613164`\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\
\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 1, 
          r0] = \(4.924605606199757`\ BesselJ[\@2, \(7.604863775917667`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 2, 
          r0] = \(5.42167030668399`\ BesselJ[\@6, \(9.027112035039801`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 3, 
          r0] = \(5.8724331687105735`\ BesselJ[2\ \@3, \(10.370311238377235`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 0, 
          r0] = \(5.209805047808564`\ BesselJ[0, \(8.653727913113732`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 1, 
          r0] = \(5.8412881505895395`\ BesselJ[\@2, \(10.779896986906524`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 2, 
          r0] = \(6.264432018983282`\ BesselJ[\@6, \(12.252431949142155`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 3, 
          r0] = \(6.65486004162976`\ BesselJ[2\ \@3, \(13.649287690577403`\ r\
\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 0, 
          r0] = \(6.0836900469025705`\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 1, 
          r0] = \(6.632499631049359`\ BesselJ[\@2, \(13.939757650233451`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 2, 
          r0] = \(7.007547679056817`\ BesselJ[\@6, \(15.442468814142474`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 3, 
          r0] = \(7.357475297013236`\ BesselJ[2\ \@3, \(16.87362244717725`\ r\
\)\/r0]\)\/r0;\)\)}], "Input"],

Cell["\<\
Radial probability densities of the two-dimensional quantum rotator for given \
quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_Rotat[1, 0, 
          r0] = \(7.420761371418802`\ r\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 1, 
          r0] = \(12.32930608758591`\ r\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 2, 
          r0] = \(17.33479971146061`\ r\ BesselJ[2, \(5.135622301840683`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(\(RR\_Rotat[1, 3, 
          r0] = \(22.480251104858397`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[2, 0, 
          r0] = \(17.274119935346278`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 1, 
          r0] = \(22.205083619652548`\ r\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 2, 
          r0] = \(27.155981240648163`\ r\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 3, 
          r0] = \(32.14982441291802`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\
\/r0]\^2\)\/r0\^2;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(RR\_Rotat[3, 0, 
          r0] = \(27.14206863617159`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 1, 
          r0] = \(32.075685466503465`\ r\ BesselJ[1, \(10.173468135156398`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 2, 
          r0] = \(37.016603769213035`\ r\ BesselJ[2, \(11.619841172201633`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 3, 
          r0] = \(41.97647135298122`\ r\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\^2\)\/r0\^2;\)\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[4, 0, 
          r0] = \(37.0112845867814`\ r\ BesselJ[0, \(11.791534439057065`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 1, 
          r0] = \(41.94560493951443`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 2, 
          r0] = \(46.88333516609999`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 3, 
          r0] = \(51.83115454957805`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2;\)\)}], "Input"],

Cell["\<\
Normalized probability densities of the two-dimensional quantum rotator for \
given quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_Rotat[1, 0, 
          r0] = \(1.1810508537666946`\ r\ BesselJ[0, \(2.4048255576957467`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[1, 1, 
          r0] = \(1.9622700087322944`\ r\ BesselJ[1, \(3.8317059702075125`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[1, 2, 
          r0] = \(2.7589190615869175`\ r\ BesselJ[2, \(5.135622301840683`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[1, 3, 
          r0] = \(3.5778430852852554`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 0, 
          r0] = \(2.7492615752726115`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 1, 
          r0] = \(3.534048819836579`\ r\ BesselJ[1, \(7.015586669815615`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 2, 
          r0] = \(4.322008648959936`\ r\ BesselJ[2, \(8.417244140695804`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[2, 3, 
          r0] = \(5.116803474852396`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\
\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 0, 
          r0] = \(4.319794389186207`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 1, 
          r0] = \(5.105003895054893`\ r\ BesselJ[1, \(10.173468135156398`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 2, 
          r0] = \(5.891375466344339`\ r\ BesselJ[2, \(11.619841172201633`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[3, 3, 
          r0] = \(6.6807629093823016`\ r\ BesselJ[3, \(13.015200721731633`\ r\
\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 0, 
          r0] = \(5.890528892167137`\ r\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 1, 
          r0] = \(6.675850367103544`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 2, 
          r0] = \(7.4617145403189`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 3, 
          r0] = \(8.249184452725327`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial wave functions, radial probability densities \
and probability densities of the two-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the two-dimensional \
quantum rotator.
We will obtain two-dimensional plots for radial  functions and radial \
probability densities and present density and surface (three-dimensional) \
plots for probability densities of the two-dimensional quantum rotator.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(IS2dHorz = 325;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 325;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dAllHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dAllVert = 600;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(\(VP3 = 1.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(WP2 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(\(WP3 = 3.000;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(AR = 3/4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\n", 
    \(\(x2dMax = r0;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-r0\);\)\), "\n", 
    \(\(x3dMax = r0;\)\), "\n", 
    \(\(y3dMin = \(-r0\);\)\), "\n", 
    \(\(y3dMax = r0;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 1, m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\n", 
    \(\(\(PR2dMax = 2.8;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\n", 
    \(\(\(PR2dMax = 2.41;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.385;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\n", 
    \(\(\(PR2dMax = 2.75;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.435;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\n", 
    \(\(\(PR2dMax = 3.15;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-1.75\);\)\), "\n", 
    \(\(\(PR2dMax = 4.35;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.32;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6)",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-1.7\);\)\), "\n", 
    \(\(\(PR2dMax = 2.725;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.3775;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7)",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-1.75\);\)\), "\n", 
    \(\(\(PR2dMax = 2.6;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.415;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8)",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-1.7\);\)\), "\n", 
    \(\(\(PR2dMax = 2.85;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.46;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\  = 3, m\_azm\  = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2.175\);\)\), "\n", 
    \(\(\(PR2dMax = 5.4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.32;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\  = 3, m\_azm\  = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2.05\);\)\), "\n", 
    \(\(\(PR2dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.385;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2. \);\)\), "\n", 
    \(\(\(PR2dMax = 3. ;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.42;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2. \);\)\), "\n", 
    \(\(\(PR2dMax = 2.84;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13). ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 0\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2.575\);\)\), "\n", 
    \(\(\(PR2dMax = 6.25;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=4, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=4, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=4, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=4, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=4, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2.25\);\)\), "\n", 
    \(\(\(PR2dMax = 3.68;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.375;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=4, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=4, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=4, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=4, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=4, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2.25\);\)\), "\n", 
    \(\(\(PR2dMax = 3.35;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.425;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=4, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=4, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=4, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=4, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=4, \!\(m\_azm\)=2\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2.25\);\)\), "\n", 
    \(\(\(PR2dMax = 3.15;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.4375;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, m\_azm, r0], 
            RR\_Rotat[n\_rad, m\_azm, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=4, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=4, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=4, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=4, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=4, \!\(m\_azm\)=3\>\""]\
\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 246, 8, 93, "Subtitle"],
Cell[2519, 82, 189, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2733, 91, 206, 5, 119, "Section"],
Cell[2942, 98, 216, 4, 56, "Text"],
Cell[3161, 104, 160, 5, 56, "Text"],
Cell[3324, 111, 145, 6, 72, "NumberedEquation"],
Cell[3472, 119, 270, 9, 57, "Text"],
Cell[3745, 130, 62, 1, 63, "Input"],
Cell[3810, 133, 285, 9, 57, "Text"],
Cell[4098, 144, 56, 1, 63, "Input"],
Cell[4157, 147, 188, 7, 56, "Text"],
Cell[4348, 156, 54, 1, 63, "Input"],
Cell[4405, 159, 175, 5, 56, "Text"],
Cell[4583, 166, 2317, 48, 1142, "Input"],
Cell[6903, 216, 171, 5, 56, "Text"],
Cell[7077, 223, 2333, 50, 1255, "Input"],
Cell[9413, 275, 175, 5, 56, "Text"],
Cell[9591, 282, 2699, 51, 1205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12327, 338, 216, 5, 119, "Section"],
Cell[12546, 345, 514, 9, 176, "Text"],
Cell[13063, 356, 666, 17, 452, "Text"],
Cell[13732, 375, 1195, 26, 738, "Input"],

Cell[CellGroupData[{
Cell[14952, 405, 93, 4, 89, "Subsection"],
Cell[15048, 411, 6371, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21456, 527, 185, 10, 89, "Subsection"],
Cell[21644, 539, 6374, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28055, 655, 185, 10, 89, "Subsection"],
Cell[28243, 667, 6374, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34654, 783, 185, 10, 89, "Subsection"],
Cell[34842, 795, 6374, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41253, 911, 185, 10, 89, "Subsection"],
Cell[41441, 923, 6373, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47851, 1039, 110, 4, 89, "Subsection"],
Cell[47964, 1045, 6375, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54376, 1161, 110, 4, 89, "Subsection"],
Cell[54489, 1167, 6373, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60899, 1283, 110, 4, 89, "Subsection"],
Cell[61012, 1289, 6372, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67421, 1405, 97, 4, 89, "Subsection"],
Cell[67521, 1411, 6373, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73931, 1527, 98, 4, 89, "Subsection"],
Cell[74032, 1533, 6374, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80443, 1649, 112, 4, 89, "Subsection"],
Cell[80558, 1655, 6371, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86966, 1771, 112, 4, 89, "Subsection"],
Cell[87081, 1777, 6373, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93491, 1893, 113, 4, 89, "Subsection"],
Cell[93607, 1899, 6375, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100019, 2015, 112, 4, 89, "Subsection"],
Cell[100134, 2021, 6374, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106545, 2137, 112, 4, 89, "Subsection"],
Cell[106660, 2143, 6374, 111, 2233, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113071, 2259, 112, 4, 89, "Subsection"],
Cell[113186, 2265, 6375, 111, 2233, "Input"],
Cell[119564, 2378, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

