(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12266,        451]*)
(*NotebookOutlinePosition[     12974,        475]*)
(*  CellTagsIndexPosition[     12930,        471]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.2. Three-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.2.1. Schrodinger Equation for Three-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Three-Dimensional Quantum Rotator", "Section"],

Cell["\<\
Three-Dimensional quantum Rotator is particle moving in field with potential \
energy:\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(V[r]\), "=", 
      TagBox[
        StyleBox[
          RowBox[{"{", 
            StyleBox[GridBox[{
                  {\(0, \ \((\(\[VerticalSeparator]\)\(r\)\(\
\[VerticalSeparator]\)\(\(<\)\(r0\)\))\)\)},
                  {\(\[Infinity], \ \((\(\[VerticalSeparator]\)\(r\)\(\
\[VerticalSeparator]\)\(\(>\)\(r0\)\))\)\)}
                  }],
              ShowAutoStyles->True]}],
          ShowAutoStyles->False],
        (#&)]}]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  StyleBox["r0",
    FontSlant->"Italic"],
  " is parameter of rotator (radius of potential ",
  "well",
  ")"
}], "Text"],

Cell["\<\
Three-dimensional Schrodinger equation in the centrosymmetrical field is\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"\[CapitalDelta]\[Psi]", "[", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "]"}], "+", 
        RowBox[{\(\(2\ m\_0\)\/\[HBar]\^2\), \((E - V[r])\), 
          RowBox[{"\[Psi]", "[", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "]"}]}]}], "=", "0"}]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      RowBox[{
        StyleBox["V",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  " potential energy of particle (",
  Cell[BoxData[
      RowBox[{
        StyleBox["V",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  " depends only upon the spherical coordinate ",
  StyleBox["r",
    FontSlant->"Italic"],
  "), ",
  Cell[BoxData[
      StyleBox[\(m\_0\),
        FontSlant->"Italic"]]],
  " is mass of particle, ",
  StyleBox["En",
    FontSlant->"Italic"],
  " is total energy of particle, ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Psi]",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  "is wave function of particle."
}], "Text"],

Cell[TextData[{
  "We consider Schrodinger equation for ",
  Cell[BoxData[
      RowBox[{"|", 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Italic"], 
        StyleBox["|",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        RowBox[{
          StyleBox["<",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["r0",
            FontWeight->"Bold",
            FontSlant->"Italic"]}]}]]],
  ": "
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"\[CapitalDelta]\[Psi]", "[", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "]"}], "+", 
        RowBox[{\(\(2\ m\_0\ E\)\/\[HBar]\^2\), 
          RowBox[{"\[Psi]", "[", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "]"}]}]}], "=", "0"}]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Psi]",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  " is function of spherical coordinates:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Psi]", "[", 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], "]"}], 
      "=", \(\[Psi][r, \[Theta], \[CurlyPhi]]\)}]], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox["\[CapitalDelta]",
        FontSlant->"Italic"]]],
  " is ",
  "the Laplacian in the spherical coordinates",
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta] = \[CapitalDelta]\_r + 
        1\/r\^2\ \[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\)\)], \
"NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(\[CapitalDelta]\_r\)],
    FontSlant->"Italic"],
  " is ",
  "the radial ",
  "operator",
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]\_r = \(1\/r\^2\) \((\[PartialD]\_r\((r\^2\ \
\[PartialD]\_r)\))\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(\[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\)\)],
    FontSlant->"Italic"],
  " is ",
  "the angular operator",
  ":"
}], "Text"],

Cell[BoxData[{
    \(\[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\) = \[CapitalDelta]\_\[Theta] \
+ \(1\/Sin[\[Theta]]\^2\) \[CapitalDelta]\_\[CurlyPhi]\), "\n", 
    \(\[CapitalDelta]\_\[Theta] = \(1\/Sin[\[Theta]]\) \((\[PartialD]\_\
\[Theta]\ \((Sin[\[Theta]]\ \[PartialD]\_\[Theta])\))\), \ \[CapitalDelta]\_\
\[CurlyPhi] = \[PartialD]\_\(\[CurlyPhi], \[CurlyPhi]\)\)}], \
"NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Separation of variables", "Section"],

Cell[TextData[{
  "We will try to solve Schrodinger equation (3) by a value of wave function \
",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[Psi]",
            FontSlant->"Italic"], 
          StyleBox["[",
            FontSlant->"Italic"], 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontSlant->"Italic"]}], 
        StyleBox["=",
          FontSlant->"Italic"], 
        StyleBox[\(\[Psi][r, \[Theta], \[CurlyPhi]]\),
          FontSlant->"Italic"]}]]],
  " which is the product of separate functions of ",
  Cell[BoxData[
      StyleBox[\(r, \[Theta], \[CurlyPhi]\),
        FontSlant->"Italic"]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][r, \[Theta], \[CurlyPhi]] = 
      R[r]\ Y[\[Theta], \[CurlyPhi]]\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox[\(R[r]\),
        FontSlant->"Italic"]]],
  "is the radial wave function and ",
  Cell[BoxData[
      StyleBox[\(Y[\[Theta], \[CurlyPhi]]\),
        FontSlant->"Italic"]]],
  "is the angular wave function."
}], "Text"],

Cell["\<\
Separated equations for the radial and angular wave functions are\
\>", "Text"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta]\_r\) 
          R[r] + \(\(2\ m\_0\)\/\[HBar]\^2\) \((E - 
              V[r] - \[CapitalLambda]\/r\^2)\) R[r] = 
      0\)\(,\)\)\)], "NumberedEquation"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\)\) 
          Y[\[Theta], \[CurlyPhi]] + \[CapitalLambda]\ Y[\[Theta], \
\[CurlyPhi]] = 0\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(\[CapitalLambda]\)],
    FontSlant->"Italic"],
  " is constant."
}], "Text"],

Cell["\<\
Solutions of the equation (9) for the angular wave function are Spherical \
Harmonics\
\>", "Text"],

Cell[BoxData[
    \(Y[\[Theta], \[CurlyPhi]] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\)], "NumberedEquation"],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(\[CapitalLambda]\)],
    FontSlant->"Italic"],
  " is equal to"
}], "Text"],

Cell[BoxData[
    \(\(\(\[CapitalLambda] = 
      l\_orb\ \((l\_orb + 1)\)\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontSlant->"Italic"]]],
  " is orbital quantum number, ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontSlant->"Italic"]]],
  " is azimuthal quantum number:"
}], "Text"],

Cell[BoxData[{
    \(l\_orb\  = 0, 1, 2, 3,  ... \), "\[IndentingNewLine]", 
    \(m\_azm\  = \(-l\_orb\), \(-\((l\_orb - 1)\)\),  ... , \((l\_orb - 1)\), 
    l\_orb\)}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Radial equation for three-dimensional quantum rotator", "Section"],

Cell["Radial equation for three-dimensional quantum rotator is:", "Text"],

Cell[BoxData[
    \(\(1\/r\^2\) \((\[PartialD]\_r\((r\^2\ \[PartialD]\_r)\))\) 
          R[r] + \(\(2\ m\_0\)\/\[HBar]\^2\) \((E - \(l\_orb\ \((l\_orb + \
1)\)\)\/r\^2)\) R[r] = 0\)], "NumberedEquation"],

Cell[TextData[{
  "or in the \"",
  StyleBox["InputForm",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{\(D[R[r], {r, 2}]\), "+", \(\((2/r)\)*D[R[r], r]\), "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"2", "*", 
              SubscriptBox["m", 
                StyleBox["0",
                  "TI"]], "*", \(En/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
        "-", \(\((\(l\_orb\) \((l\_orb + 1)\)/r^2)\)*R[r]\)}], "\[Equal]", 
      "0"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(\(R[r]\ l\_orb\ \((1 + l\_orb)\)\)\/r\^2\)\), 
        "+", \(\(2\ En\ R[r]\ m\_0\)\/\[HBar]\^2\), "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 248, 8, 93, "Subtitle"],
Cell[2521, 82, 145, 4, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2691, 90, 55, 0, 85, "Section"],
Cell[2749, 92, 110, 3, 56, "Text"],
Cell[2862, 97, 484, 13, 70, "NumberedEquation"],
Cell[3349, 112, 150, 7, 56, "Text"],
Cell[3502, 121, 96, 2, 56, "Text"],
Cell[3601, 125, 425, 11, 68, "NumberedEquation"],
Cell[4029, 138, 1245, 48, 80, "Text"],
Cell[5277, 188, 486, 18, 56, "Text"],
Cell[5766, 208, 412, 11, 68, "NumberedEquation"],
Cell[6181, 221, 370, 14, 56, "Text"],
Cell[6554, 237, 219, 6, 53, "NumberedEquation"],
Cell[6776, 245, 173, 7, 56, "Text"],
Cell[6952, 254, 145, 3, 68, "NumberedEquation"],
Cell[7100, 259, 147, 8, 56, "Text"],
Cell[7250, 269, 125, 2, 68, "NumberedEquation"],
Cell[7378, 273, 166, 7, 56, "Text"],
Cell[7547, 282, 392, 6, 119, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7976, 293, 45, 0, 85, "Section"],
Cell[8024, 295, 729, 24, 80, "Text"],
Cell[8756, 321, 116, 2, 53, "NumberedEquation"],
Cell[8875, 325, 277, 10, 56, "Text"],
Cell[9155, 337, 89, 2, 56, "Text"],
Cell[9247, 341, 196, 4, 68, "NumberedEquation"],
Cell[9446, 347, 190, 3, 53, "NumberedEquation"],
Cell[9639, 352, 128, 6, 56, "Text"],
Cell[9770, 360, 109, 3, 56, "Text"],
Cell[9882, 365, 144, 3, 53, "NumberedEquation"],
Cell[10029, 370, 125, 6, 56, "Text"],
Cell[10157, 378, 107, 2, 53, "NumberedEquation"],
Cell[10267, 382, 245, 9, 56, "Text"],
Cell[10515, 393, 191, 3, 78, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10743, 401, 75, 0, 85, "Section"],
Cell[10821, 403, 73, 0, 56, "Text"],
Cell[10897, 405, 204, 3, 68, "NumberedEquation"],
Cell[11104, 410, 175, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[11304, 421, 408, 10, 88, "Input"],
Cell[11715, 433, 495, 12, 85, "Output"]
}, Open  ]],
Cell[12225, 448, 25, 0, 55, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

