(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     45286,       1153]*)
(*NotebookOutlinePosition[     46015,       1178]*)
(*  CellTagsIndexPosition[     45971,       1174]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.2. Three-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.2.4. Calculation of Radial Functions of the Three-Dimensional Quantum \
Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Zeros of the Bessel functions and radial functions of the \
three-dimensional quantum rotator\
\>", "Section"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" to find radial functions of the three-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
We consider states of he three-dimensional quantum rotator defining by \
quantum numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = \ 1, 2, 3, 4\)],
    TextAlignment->Center],
  ",\n ",
  Cell[BoxData[
      \(l\_orb = 0, \ 1, 2, 3\)],
    TextAlignment->Center],
  "."
}], "NumberedEquation"],

Cell["Determine energy levels by the formulas:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    RowBox[{\(En[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{\(\[HBar]\^2\/\(2\ m\_0\)\), " ", 
        SuperscriptBox[
          StyleBox[\(k\_\(n\_rad, l\_orb\)\),
            FontSlant->"Italic"], "2"]}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{\(C[1]\), " ", \(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(k\_\(n\_rad, l\_orb\)\),
                FontSlant->"Italic"], " ", "r"}]}], 
          "]"}]}]}]}], "NumberedEquation",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(l\_orb = 0\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(l\_orb = 0;\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 0\) = 
        BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 0\) = 
        BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 0\) = 
        BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
    RowBox[{\(k\_\(4, 0\) = BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 0]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 0]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 0]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 0]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.4501581580785532`\ \@r\ C[1, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"],

Cell[BoxData[
    \({\(0.3183098861837907`\ \@r\ C[2, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"],

Cell[BoxData[
    \({\(0.2598989337427179`\ \@r\ C[3, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"],

Cell[BoxData[
    \({\(0.22507907903899615`\ \@r\ C[4, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(l\_orb = 1\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(l\_orb = 1;\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 1\) = 
        BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 1\) = 
        BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 1\) = 
        BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
    RowBox[{\(k\_\(4, 1\) = BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 1]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 1]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 1]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 1]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.3764021226965972`\ C[1, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r\_0.`] + \
0.22254815844566583`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(4.493409457909065`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"],

Cell[BoxData[
    \({\(0.28706730919827866`\ C[2, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r\_0.`] + \
0.12944561822807846`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(7.725251836937706`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"],

Cell[BoxData[
    \({\(0.2416265857850596`\ C[3, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r\_0.`] + \
0.09170844119562539`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(10.90412165949781`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"],

Cell[BoxData[
    \({\(0.21274127679590746`\ C[4, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r\_0.`] + \
0.07109243667446236`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(14.06619391285005`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(l\_orb = 2\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(l\_orb = 2;\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 2\) = 
        BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 2\) = 
        BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 2\) = 
        BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
    RowBox[{\(k\_\(4, 2\) = BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 2]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 2]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 2]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 2]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[1, 
            2]\ \((0.3323521174464318`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r\_0.`] + 
              0.1729961674523217`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r\_0.`]\ r\_0.` - 
              0.030016030571366766`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r\_0.`]\ \
r\_0.`\%2)\))\)}\)], "Output"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[2, 
            2]\ \((0.2645686853222971`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r\_0.`] + 
              0.08726828665822337`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r\_0.`]\ r\_0.` - 
              0.00959518174141225`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r\_0.`]\ \
r\_0.`\%2)\))\)}\)], "Output"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[3, 
            2]\ \((0.22729133392011303`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r\_0.`] + 
              0.05533370673337756`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r\_0.`]\ r\_0.` - 
              0.004490300397068933`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r\_0.`]\ r\_0.`\%2)\))\)}\
\)], "Output"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[4, 
            2]\ \((0.2025674811476966`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r\_0.`] + 
              0.0391697063093515`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r\_0.`]\ r\_0.` - 
              0.002524699232190157`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r\_0.`]\ r\_0.`\%2)\))\)}\
\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(l\_orb = 3\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(l\_orb = 3;\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        l\_orb + 1\/2, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 3\) = 
        BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 3\) = 
        BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 3\) = 
        BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
    RowBox[{\(k\_\(4, 3\) = BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 3]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 3]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 3]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 3]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.3018323092198434`\ C[1, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(6.987932000503647`\ r\)\/r\_0.`] + 
              0.8586231233457278`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r\_0.`]\ r\_0.` - 
              0.3071806949766553`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.04395874129206117`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r\_0.`]\ \
r\_0.`\%3)\))\)}\)], "Output"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.24721012729596964`\ C[2, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(10.417118547512036`\ r\)\/r\_0.`] + 
              0.5759750138806864`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(10.417118547512036`\ r\)\/r\_0.`]\ r\_0.` - 
              0.13822800692285703`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(10.417118547512036`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.013269313034348695`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(10.417118547512036`\ r\)\/r\_0.`]\ r\_0.`\%3)\))\)}\
\)], "Output"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.215581313417243`\ C[3, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(13.698023153276466`\ r\)\/r\_0.`] + 
              0.43801940855712773`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(13.698023153276466`\ r\)\/r\_0.`]\ r\_0.` - 
              0.07994208428030666`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(13.698023153276466`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.005836030745880664`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(13.698023153276466`\ r\)\/r\_0.`]\ r\_0.`\%3)\))\)}\
\)], "Output"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.19395162042753517`\ C[4, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(16.92362128522231`\ r\)\/r\_0.`] + 
              0.3545340503004043`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\)\/r\_0.`]\ r\_0.` - 
              0.052372663676004017`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.0030946487630124277`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\)\/r\_0.`]\ \
r\_0.`\%3)\))\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. List of radial functions of the three-dimensional quantum rotator\
\>", "Section"],

Cell["\<\
Thus radial functions of the three-dimensional quantum rotator for given \
quantum numbers are:\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(R[1, 0, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[1, 0]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(0 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[0 + 1\/2, {1, 1}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[2, 0, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[2, 0]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(0 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[0 + 1\/2, {2, 2}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[3, 0, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[3, 0]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(0 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[0 + 1\/2, {3, 3}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(R[4, 0, r\_0]\), "=", 
          RowBox[{"FullSimplify", "[", 
            RowBox[{\(C[4, 0]\), " ", \(\@r\), "  ", 
              RowBox[{"BesselJ", "[", 
                RowBox[{\(0 + 1\/2\), ",", 
                  RowBox[{
                    StyleBox[\(BesselJZeros[0 + 1\/2, {4, 4}]\/r\_0\),
                      FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
        ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[1, 1, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[1, 1]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(1 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[1 + 1\/2, {1, 1}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[2, 1, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[2, 1]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(1 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[1 + 1\/2, {2, 2}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[3, 1, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[3, 1]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(1 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[1 + 1\/2, {3, 3}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(R[4, 1, r\_0]\), "=", 
          RowBox[{"FullSimplify", "[", 
            RowBox[{\(C[4, 1]\), " ", \(\@r\), "  ", 
              RowBox[{"BesselJ", "[", 
                RowBox[{\(1 + 1\/2\), ",", 
                  RowBox[{
                    StyleBox[\(BesselJZeros[l\_orb + 1\/2, {4, 4}]\/r\_0\),
                      FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
        ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[1, 2, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[1, 2]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(2 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[2 + 1\/2, {1, 1}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[2, 2, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[2, 2]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(2 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[2 + 1\/2, {2, 2}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[3, 2, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[3, 2]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(2 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[2 + 1\/2, {3, 3}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(R[4, 2, r\_0]\), "=", 
          RowBox[{"FullSimplify", "[", 
            RowBox[{\(C[4, 2]\), " ", \(\@r\), "  ", 
              RowBox[{"BesselJ", "[", 
                RowBox[{\(2 + 1\/2\), ",", 
                  RowBox[{
                    StyleBox[\(BesselJZeros[2 + 1\/2, {4, 4}]\/r\_0\),
                      FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
        ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[1, 3, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[1, 3]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(3 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[3 + 1\/2, {1, 1}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[2, 3, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[2, 3]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(3 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[3 + 1\/2, {2, 2}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[3, 3, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[3, 3]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(3 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[3 + 1\/2, {3, 3}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[4, 3, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[4, 3]\), " ", \(\@r\), "  ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{\(3 + 1\/2\), ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[3 + 1\/2, {4, 4}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      ";"}]}], "Input"],

Cell["We can calculate radial functions by the general formula:", "Text"],

Cell[BoxData[
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              
              StyleBox[\(BesselJZeros[
                      l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                FontSlant->"Italic"], " ", "r"}]}], 
          "]"}]}]}]], "NumberedEquation"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 1\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.4501581580785532`\ \@r\ C[1, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\n", \(l\_orb = 1;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.3764021226965972`\ C[1, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r\_0.`] + \
0.22254815844566583`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(4.493409457909065`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\n", \(l\_orb = 2;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[1, 
            2]\ \((0.3323521174464318`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r\_0.`] + 
              0.1729961674523217`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r\_0.`]\ r\_0.` - 
              0.030016030571366766`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r\_0.`]\ \
r\_0.`\%2)\))\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\n", \(l\_orb = 3;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.3018323092198434`\ C[1, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(6.987932000503647`\ r\)\/r\_0.`] + 
              0.8586231233457278`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r\_0.`]\ r\_0.` - 
              0.3071806949766553`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.04395874129206117`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r\_0.`]\ \
r\_0.`\%3)\))\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 2\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.3183098861837907`\ \@r\ C[2, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\n", \(l\_orb = 1;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.28706730919827866`\ C[2, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r\_0.`] + \
0.12944561822807846`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(7.725251836937706`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\n", \(l\_orb = 2;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[2, 
            2]\ \((0.2645686853222971`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r\_0.`] + 
              0.08726828665822337`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r\_0.`]\ r\_0.` - 
              0.00959518174141225`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r\_0.`]\ \
r\_0.`\%2)\))\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\n", \(l\_orb = 3;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.24721012729596964`\ C[2, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(10.417118547512036`\ r\)\/r\_0.`] + 
              0.5759750138806864`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(10.417118547512036`\ r\)\/r\_0.`]\ r\_0.` - 
              0.13822800692285703`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(10.417118547512036`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.013269313034348695`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(10.417118547512036`\ r\)\/r\_0.`]\ r\_0.`\%3)\))\)}\
\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 3\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.2598989337427179`\ \@r\ C[3, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\n", \(l\_orb = 1;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.2416265857850596`\ C[3, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r\_0.`] + \
0.09170844119562539`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(10.90412165949781`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\n", \(l\_orb = 2;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[3, 
            2]\ \((0.22729133392011303`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r\_0.`] + 
              0.05533370673337756`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r\_0.`]\ r\_0.` - 
              0.004490300397068933`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r\_0.`]\ r\_0.`\%2)\))\)}\
\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\n", \(l\_orb = 3;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.215581313417243`\ C[3, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(13.698023153276466`\ r\)\/r\_0.`] + 
              0.43801940855712773`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(13.698023153276466`\ r\)\/r\_0.`]\ r\_0.` - 
              0.07994208428030666`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(13.698023153276466`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.005836030745880664`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(13.698023153276466`\ r\)\/r\_0.`]\ r\_0.`\%3)\))\)}\
\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 4\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.22507907903899615`\ \@r\ C[4, 0]\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ \
r\)\/r\_0.`]\)\/\@\(r\/r\_0.`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\n", \(l\_orb = 1;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(0.21274127679590746`\ C[4, 1]\ \((r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r\_0.`] + \
0.07109243667446236`\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(14.06619391285005`\ r\)\/r\_0.`]\ r\_0.`)\)\)\/\(\@r\ \
\@\(r\/r\_0.`\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\n", \(l\_orb = 2;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r\_0.`\)\)\)\((C[4, 
            2]\ \((0.2025674811476966`\ r\^2\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r\_0.`] + 
              0.0391697063093515`\ r\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r\_0.`]\ r\_0.` - 
              0.002524699232190157`\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r\_0.`]\ r\_0.`\%2)\))\)}\
\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\n", \(l\_orb = 3;\), "\n", 
    RowBox[{\(R[n\_rad, l\_orb, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(l\_orb + 1\/2\), ",", 
              RowBox[{
                
                StyleBox[\(BesselJZeros[
                        l\_orb + 1\/2, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r\_0.`\)\)\)\((0.19395162042753517`\ C[4, 
            3]\ \((r\^3\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) \
- \(16.92362128522231`\ r\)\/r\_0.`] + 
              0.3545340503004043`\ r\^2\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\)\/r\_0.`]\ r\_0.` - 
              0.052372663676004017`\ r\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\)\/r\_0.`]\ r\_0.`\%2 - 
              0.0030946487630124277`\ Sin[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\)\/r\_0.`]\ \
r\_0.`\%3)\))\)}\)], "Output"]
}, Open  ]],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 248, 8, 93, "Subtitle"],
Cell[2521, 82, 161, 5, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2707, 91, 123, 3, 85, "Section"],
Cell[2833, 96, 260, 7, 57, "Text"],
Cell[3096, 105, 62, 1, 63, "Input"],
Cell[3161, 108, 113, 3, 56, "Text"],
Cell[3277, 113, 211, 9, 74, "NumberedEquation"],
Cell[3491, 124, 103, 2, 56, "Text"],
Cell[3597, 128, 609, 14, 117, "NumberedEquation"],

Cell[CellGroupData[{
Cell[4231, 146, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[4337, 154, 2365, 47, 941, "Input"],
Cell[6705, 203, 186, 3, 144, "Output"],
Cell[6894, 208, 185, 3, 144, "Output"],
Cell[7082, 213, 185, 3, 144, "Output"],
Cell[7270, 218, 187, 3, 144, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7506, 227, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7612, 235, 2365, 47, 941, "Input"],
Cell[9980, 284, 322, 5, 140, "Output"],
Cell[10305, 291, 323, 5, 140, "Output"],
Cell[10631, 298, 322, 5, 140, "Output"],
Cell[10956, 305, 323, 5, 140, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11328, 316, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[11434, 324, 2365, 47, 941, "Input"],
Cell[13802, 373, 506, 8, 241, "Output"],
Cell[14311, 383, 503, 8, 241, "Output"],
Cell[14817, 393, 511, 8, 241, "Output"],
Cell[15331, 403, 509, 8, 241, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15889, 417, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[15995, 425, 2365, 47, 941, "Input"],
Cell[18363, 474, 654, 10, 241, "Output"],
Cell[19020, 486, 661, 10, 241, "Output"],
Cell[19684, 498, 660, 10, 241, "Output"],
Cell[20347, 510, 659, 10, 296, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21067, 527, 95, 2, 85, "Section"],
Cell[21165, 531, 119, 3, 56, "Text"],
Cell[21287, 536, 7125, 166, 1713, "Input"],
Cell[28415, 704, 73, 0, 56, "Text"],
Cell[28491, 706, 428, 10, 110, "NumberedEquation"],

Cell[CellGroupData[{
Cell[28944, 720, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[29050, 728, 565, 12, 206, "Input"],
Cell[29618, 742, 186, 3, 144, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29841, 750, 522, 11, 206, "Input"],
Cell[30366, 763, 322, 5, 140, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30725, 773, 522, 11, 206, "Input"],
Cell[31250, 786, 506, 8, 241, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31793, 799, 522, 11, 206, "Input"],
Cell[32318, 812, 654, 10, 241, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33021, 828, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[33127, 836, 565, 12, 206, "Input"],
Cell[33695, 850, 185, 3, 144, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33917, 858, 522, 11, 206, "Input"],
Cell[34442, 871, 323, 5, 140, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34802, 881, 522, 11, 206, "Input"],
Cell[35327, 894, 503, 8, 241, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35867, 907, 522, 11, 206, "Input"],
Cell[36392, 920, 661, 10, 241, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37102, 936, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[37208, 944, 565, 12, 206, "Input"],
Cell[37776, 958, 185, 3, 144, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37998, 966, 522, 11, 206, "Input"],
Cell[38523, 979, 322, 5, 140, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38882, 989, 522, 11, 206, "Input"],
Cell[39407, 1002, 511, 8, 186, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39955, 1015, 522, 11, 206, "Input"],
Cell[40480, 1028, 660, 10, 241, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41189, 1044, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[41295, 1052, 565, 12, 206, "Input"],
Cell[41863, 1066, 187, 3, 144, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42087, 1074, 522, 11, 206, "Input"],
Cell[42612, 1087, 323, 5, 140, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42972, 1097, 522, 11, 206, "Input"],
Cell[43497, 1110, 509, 8, 186, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44043, 1123, 522, 11, 206, "Input"],
Cell[44568, 1136, 659, 10, 296, "Output"]
}, Open  ]],
Cell[45242, 1149, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

