(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     80351,       1778]*)
(*NotebookOutlinePosition[     81080,       1803]*)
(*  CellTagsIndexPosition[     81036,       1799]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.2. Three-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.2.7. Comparative visualization of the Radial Wave Functions and Radial \
Probability Densities of the Three-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["In this file we will present visualizations in ",
    FontWeight->"Bold"],
  "unified",
  StyleBox[" scales for all states defined by given quantum numbers.",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the quantum rotator defined by quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 1, 2, 3, 4\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["Graphics`FilledPlot`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool in this part to give vivid presentation of functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input"],

Cell["\<\
Determine parameter r0 of the three-dimensional quantum rotator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(r0 = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the  \
quantum rotator for given quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Rotat[1, 0, 
          r0] = \(2.6599473004202467`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((6.28886519074513`\ \
\((0.3764021226965972`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\
\)\/r0] + 
                  0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((6.733287171946806`\ \((\((0.3323521174464318`\ r\^2 - 
                        0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 
                  0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_Rotat[1, 3, 
          r0] = \(1\/r\^3\) \((7.180760624824514`\ \((r\ \
\((\(-0.09271705851256021`\) + 
                        0.3018323092198434`\ r\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 
                        6.987932000503647`\ r] + \
\((\(-0.013268168394580504`\) + 
                        0.2591602000689954`\ r\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 
                        6.987932000503647`\ \
r])\))\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 0, 
          r0] = \(2.4973939813378445`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((8.429256550635898`\ \
\((0.28706730919827866`\ r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(7.725251836937706`\ r\)\/r0] + 
                  0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((8.88380479563113`\ \((\((0.2645686853222971`\ r\^2 - 
                        0.00959518174141225`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\
\/r0] + 0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_Rotat[2, 3, 
          r0] = \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((9.281141096227815`\ \((\((0.24721012729596964`\ r\^3 - 
                        0.034171363187267656`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + r0\ \((0.14238685650074237`\ r\^2 - 
                        0.0032803085643514102`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0])\))\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 0, 
          r0] = \(2.4704375261515574`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((10.07467750670633`\ \
\((0.2416265857850596`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\
\)\/r0] + 
                  0.022159197533768875`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((10.527024024151833`\ \((\((0.22729133392011303`\ r\^2 - 
                        0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 
                  0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_Rotat[3, 3, 
          
          r0] = \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((10.91398256569498`\ \((\((0.215581313417243`\ r\^3 - 
                        0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + r0\ \((0.09442879939898956`\ r\^2 - 
                        0.0012581391733403658`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0])\))\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 0, 
          r0] = \(2.4612069656404953`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((11.470756268503296`\ \
\((0.21274127679590746`\ r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(14.06619391285005`\ r\)\/r0] + 
                  0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((11.911247130504961`\ \((\((0.2025674811476966`\ r\^2 - 
                        0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 
                  0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 3, 
          r0] = \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((12.290823460947369`\ \((\((0.19395162042753517`\ r\^3 - 
                        0.01015776298606729`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0] + r0\ \((0.06876245355250067`\ r\^2 - 
                        0.0006002121422403276`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0])\))\);\)\)}], "Input"],

Cell["\<\
Radial probability densities of the three-dimensional quantum rotator are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_Rotat[1, 0, 
          r0] = \(7.075319641012959`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[1, 1, 
          r0] = \(1\/r0\^3\) \((39.549825387365786`\ \((0.3764021226965972`\ \
r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\
\ r\)\/r0] + 0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[1, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((45.33715613990341`\ \
\((\((0.3323521174464318`\ r\^2 - 0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(\(RR\_Rotat[1, 3, 
          r0] = \(1\/r\^4\) \((51.56332315103015`\ \((r\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ r\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ r] \
+ \((\(-0.013268168394580504`\) + 0.2591602000689954`\ r\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ r])\
\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(RR\_Rotat[2, 0, 
          r0] = \(6.23697669802249`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[2, 1, 
          r0] = \(1\/r0\^3\) \((71.0523659964382`\ \((0.28706730919827866`\ r\
\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
r\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[2, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((78.92198764687868`\ \
\((\((0.2645686853222971`\ r\^2 - 0.00959518174141225`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\
\/r0] + 0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(\(RR\_Rotat[2, 3, 
          r0] = \(1\/\(r\^4\ r0\^3\)\) \((86.13958004808885`\ \
\((\((0.24721012729596964`\ r\^3 - 0.034171363187267656`\ r\ r0\^2)\)\ Cos[\(\
\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + r0\ \((0.14238685650074237`\ r\^2 - 0.0032803085643514102`\ r0\^2)\
\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ r\)\/r0])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[3, 0, 
          r0] = \(6.103061570617827`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[3, 1, 
          r0] = \(1\/r0\^3\) \((101.49912686413447`\ \((0.2416265857850596`\ \
r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\
\ r\)\/r0] + 0.022159197533768875`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[3, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((110.81823480506986`\ \
\((\((0.22729133392011303`\ r\^2 - 0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(\(RR\_Rotat[3, 3, 
          r0] = \(1\/\(r\^4\ r0\^3\)\) \((119.11501544429397`\ \
\((\((0.215581313417243`\ r\^3 - 0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + r0\ \((0.09442879939898956`\ r\^2 - 0.0012581391733403658`\ r0\^2)\
\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ r\)\/r0])\)\^2)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[4, 0, 
          r0] = \(6.057539727717295`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[4, 1, 
          r0] = \(1\/r0\^3\) \((131.57824937140765`\ \((0.21274127679590746`\ \
r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\
\ r\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[4, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((141.87780820396267`\ \
\((\((0.2025674811476966`\ r\^2 - 0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[4, 3, 
          r0] = \(1\/\(r\^4\ r0\^3\)\) \((151.06434134817425`\ \
\((\((0.19395162042753517`\ r\^3 - 0.01015776298606729`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0] + r0\ \((0.06876245355250067`\ r\^2 - 0.0006002121422403276`\ \
r0\^2)\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ r\)\/r0])\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial wave functions, radial probability densities \
and probability densities of the three-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the three-dimensional \
quantum rotator.
We will obtain three-dimensional plots for radial  functions and radial \
probability densities and present density and surface (three-dimensional) \
plots for probability densities of the three-dimensional quantum rotator.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 1;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-2.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(IS2dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(\(ISAll3dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 1.25;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=4,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=4,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=4,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=4,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=4,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=4,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=4,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=4,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=4,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Rotat[n\_rad, l\_orb, r0], 
            RR\_Rotat[n\_rad, l\_orb, r0]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=4,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy\_Rotat[n\_rad, l\_orb, r0] = 
        FullSimplify[
          ReplaceAll[
            RR\_Rotat[n\_rad, l\_orb, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(RRxy2\_Rotat[n\_rad, l\_orb, r0] = 
        If[y < 0, 0, 
          RRxy\_Rotat[n\_rad, l\_orb, r0]];\)\), "\[IndentingNewLine]", 
    \(\(RRxy2RRR\_Rotat[n\_rad, l\_orb, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, RRxy2\_Rotat[n\_rad, l\_orb, r0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDenRRxy2\_Rotat[n\_rad, l\_orb, r0, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2RRR\_Rotat[n\_rad, l\_orb, r0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=4,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[n\_rad, l\_orb, r0, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Rotat[n\_rad, 
              l\_orb, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=4,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparative visualization of the wave functions and probability densities \
of the three-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations in unified scales for all states defined by \
given quantum numbers.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{Grph2dRR\_Rotat[1, 0, r0, x2dMin, x2dMax, PR2dMin, 
              PR2dMax, IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[1, 1, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[1, 2, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[1, 3, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert]}, {Grph2dRR\_Rotat[2, 0, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[2, 1, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[2, 2, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[2, 3, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert]}, {Grph2dRR\_Rotat[3, 0, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[3, 1, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[3, 2, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[3, 3, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert]}, \[IndentingNewLine]{Grph2dRR\_Rotat[4, 0, 
              r0, x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[4, 1, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[4, 2, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert], 
            Grph2dRR\_Rotat[4, 3, r0, x2dMin, x2dMax, PR2dMin, PR2dMax, 
              IS2dHorz, IS2dVert]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \[IndentingNewLine]ImageSize \[Rule] {1100, 
          700}, \[IndentingNewLine]PlotLabel \[Rule] "\<Radial function of \
the quantum rotator\>"]\)], "Input"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{Grph3dDenRRxy2\_Rotat[1, 0, r0, x3dMin, x3dMax, y3dMin, 
              y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
              VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[1, 1, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[1, 2, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[1, 3, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDenRRxy2\_Rotat[2, 0, r0, x3dMin, x3dMax, y3dMin, 
              y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
              VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[2, 1, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[2, 2, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[2, 3, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDenRRxy2\_Rotat[3, 0, r0, x3dMin, x3dMax, y3dMin, 
              y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
              VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[3, 1, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[3, 2, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[3, 3, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph3dDenRRxy2\_Rotat[4, 0, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[4, 1, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[4, 2, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d], 
            Grph3dDenRRxy2\_Rotat[4, 3, r0, x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]ImageSize \[Rule] {1100, 
          800}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \[IndentingNewLine]PlotLabel \[Rule] "\<Radial function of \
the quantum rotator\>"]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 248, 8, 93, "Subtitle"],
Cell[2521, 82, 217, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2763, 91, 185, 5, 119, "Section"],
Cell[2951, 98, 269, 8, 56, "Text"],
Cell[3223, 108, 142, 4, 56, "Text"],
Cell[3368, 114, 195, 8, 72, "NumberedEquation"],
Cell[3566, 124, 293, 9, 57, "Text"],
Cell[3862, 135, 56, 1, 63, "Input"],
Cell[3921, 138, 135, 4, 56, "Text"],
Cell[4059, 144, 54, 1, 63, "Input"],
Cell[4116, 147, 193, 5, 56, "Text"],
Cell[4312, 154, 6393, 123, 3993, "Input"],
Cell[10708, 279, 145, 4, 56, "Text"],
Cell[10856, 285, 5419, 91, 3838, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16312, 381, 218, 5, 119, "Section"],
Cell[16533, 388, 520, 9, 176, "Text"],
Cell[17056, 399, 666, 17, 452, "Text"],
Cell[17725, 418, 1250, 26, 713, "Input"],

Cell[CellGroupData[{
Cell[19000, 448, 185, 10, 89, "Subsection"],
Cell[19188, 460, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22497, 524, 197, 12, 89, "Subsection"],
Cell[22697, 538, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26006, 602, 185, 10, 89, "Subsection"],
Cell[26194, 614, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29503, 678, 197, 12, 89, "Subsection"],
Cell[29703, 692, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33012, 756, 197, 12, 89, "Subsection"],
Cell[33212, 770, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36521, 834, 185, 10, 89, "Subsection"],
Cell[36709, 846, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40018, 910, 185, 10, 89, "Subsection"],
Cell[40206, 922, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43515, 986, 185, 10, 89, "Subsection"],
Cell[43703, 998, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47012, 1062, 185, 10, 89, "Subsection"],
Cell[47200, 1074, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50509, 1138, 186, 10, 89, "Subsection"],
Cell[50698, 1150, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54007, 1214, 198, 12, 89, "Subsection"],
Cell[54208, 1228, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57517, 1292, 198, 12, 89, "Subsection"],
Cell[57718, 1306, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61027, 1370, 186, 10, 89, "Subsection"],
Cell[61216, 1382, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64525, 1446, 198, 12, 89, "Subsection"],
Cell[64726, 1460, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68035, 1524, 198, 12, 89, "Subsection"],
Cell[68236, 1538, 3272, 59, 1108, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71545, 1602, 198, 12, 89, "Subsection"],
Cell[71746, 1616, 3272, 59, 1108, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75067, 1681, 193, 5, 119, "Section"],
Cell[75263, 1688, 169, 5, 56, "Text"],
Cell[75435, 1695, 2011, 34, 588, "Input"],
Cell[77449, 1731, 2867, 42, 963, "Input"],
Cell[80319, 1775, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

