(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    422014,       7419]*)
(*NotebookOutlinePosition[    422743,       7444]*)
(*  CellTagsIndexPosition[    422699,       7440]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.2. Three-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "1.2.9. Visualization of the Wave Functions and Probability Densities of \
the Three-Dimensional Quantum Rotator (",
  StyleBox["beginning",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial and angular wave functions and probability densities of \
the three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" for the three-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 1, 2, 3, 4\)],
    FontSlant->"Italic"],
  ", \n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "."
}], "NumberedEquation"],

Cell["In this file we present states for radial quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[Cell[BoxData[
    \(n\_rad = 1, 2\)],
  FontSlant->"Italic"]], "NumberedEquation"],

Cell["and next file presents states for radial quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 3, 4. \)],
    FontSlant->"Italic"],
  " "
}], "NumberedEquation"],

Cell[TextData[{
  "Determine parameter ",
  StyleBox["r0",
    FontSlant->"Italic"],
  " of the three-dimensional quantum oscillator:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(r0 = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator for given quantum numbers in the \
Cartesian rectangular coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Radial probability densities:", "Text"],

Cell[BoxData[{
    \(\(RR\_\(Rotat, Cart\)[1, 0, 
          r0] = \(1\/r0\^3\) \((7.075319641012959`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(3.1415926535897913`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[1, 1, 
          r0] = \(1\/r0\^3\) \((39.549825387365786`\ \((0.3764021226965972`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[1, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((45.33715613990341`\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[1, 3, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^2\) \((51.56332315103015`\ \((\
\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 0, 
          r0] = \(6.23697669802249`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 1, 
          r0] = \(1\/r0\^3\) \((71.0523659964382`\ \((0.28706730919827866`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((78.92198764687868`\ \
\((\((\(-0.00959518174141225`\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[2, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((86.13958004808885`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 0, 
          r0] = \(6.103061570617827`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 1, 
          
          r0] = \(1\/r0\^3\) \((101.49912686413447`\ \((0.2416265857850596`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(10.90412165949781`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((110.81823480506986`\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((119.11501544429397`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 0, 
          r0] = \(1\/r0\^3\) \((6.057539727717295`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(12.566370614390479`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 1, 
          r0] = \(1\/r0\^3\) \((131.57824937140765`\ \((0.21274127679590746`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((141.87780820396267`\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((151.06434134817425`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\)}], "Input"],

Cell["Angular probability densities:", "Text"],

Cell[BoxData[{
    \(\(YY[0, 0] = 1\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[1, 
          0] = \(3\ Cos[\[Theta]]\^2\)\/\(4\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[1, 
          1] = \(3\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          0] = \(5\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(64\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          1] = \(15\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), \
"\[IndentingNewLine]", 
    \(\(YY[2, 
          2] = \(15\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[3, 
          0] = \(7\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(256\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          1] = \(21\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(1024\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          2] = \(105\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(32\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 3] = \(35\ Sin[\[Theta]]\^6\)\/\(64\ \[Pi]\);\)\)}], "Input"],

Cell["Probability densities:", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.5630360474111934`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(3.1415926535897913`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((9.441825313230899`\ z\^2\ \
\((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((4.720912656615449`\ \((x\^2 + 
                  y\^2)\)\ \((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((4.509770315871688`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((27.05862189523013`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((6.764655473807532`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\
\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 0, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((7.180738041514811`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 1, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((5.385553531136108`\ \
\((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
6.987932000503647`\ \@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) \
+ 0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 2, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((53.85553531136109`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 3, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((8.975922551893515`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\
\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4963228357196234`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(6.283185307179585`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((16.962502900061462`\ z\^2\ \
\((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((8.481251450030731`\ \((x\^2 + 
                  y\^2)\)\ \((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((7.850515282898902`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.00959518174141225`\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((47.10309169739341`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 2, 
          
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.775772924348352`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\
\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((11.995847465449176`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + \
0.24721012729596964`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((8.996885599086882`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + \
0.14238685650074237`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((89.96885599086882`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((14.994809331811469`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4856662084790068`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(9.424777960902889`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((24.231131639907577`\ z\^2\ \
\((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((12.115565819953789`\ \((x\^2 + 
                  y\^2)\)\ \((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.023293658715744`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((66.13976195229446`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((16.534940488073616`\ \((x\^2 + y\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((16.58802556637349`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + \
0.215581313417243`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\
\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0012581391733403658`\)\ r0\^2 + \
0.09442879939898956`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((12.441019174780115`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((124.41019174780115`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((20.73503195796686`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4820436953208706`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(12.566370614390479`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((31.4119931862564`\ z\^2\ \
\((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((15.7059965931282`\ \((x\^2 + 
                  y\^2)\)\ \((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((14.112846556690327`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((84.67707934014196`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((21.16926983503549`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\
\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((21.037307069172908`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + \
0.19395162042753517`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0006002121422403276`\)\ r0\^2 + \
0.06876245355250067`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((15.777980301879683`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((157.77980301879683`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((26.29663383646614`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial probability densities, angular probability \
densities and probability densities of the three-dimensional quantum \
rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the two-dimensional \
quantum rotator.\nWe will obtain three-dimensional plots for radial and \
angular probability densities (product of these functions gives probability \
density), three-dimensional plots for probability densities (surface and \
density plots) for four cross-sectional profiles (defined by coordinate \
planes ",
  StyleBox["y0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y3",
    FontSlant->"Italic"],
  ") of the three-dimensional quantum rotator.\nIn this file we will present \
visualizations in individual scales for states defined by given quantum \
numbers."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-r0\) - 0.1;\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = r0 + 0.1;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-r0\) - 0.1;\)\), "\[IndentingNewLine]", 
    \(\(z3dMax = r0 + 0.1;\)\[IndentingNewLine]\), "\n", 
    \(\(ISAll3dHorz = 750;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 550;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ISProf3dHorz = 750;\)\), "\[IndentingNewLine]", 
    \(\(ISProf3dVert = 600;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.25\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-0.75\);\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.2;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.09\), 
                0.09}, {\(-0.09\), 0.09}, {\(-0.09\), 
                0.09}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,0,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,0,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,0,0], y=0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.65;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
                0.1}, {\(-0.1\), 0.1}, {\(-0.26\), 
                0.26}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,1,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,1,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,1,0], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.35;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,1,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,1,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,1,1], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        1.2;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,2,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,0], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.5;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.12\), 
                0.12}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,2,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,1], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.5;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.15\), 
                0.15}, {\(-0.15\), 0.15}, {\(-0.15\), 
                0.15}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,2,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,2], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        1.85;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.55\), 
                0.55}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,0], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.75;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,1], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.6;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.135\), 
                0.135}, {\(-0.135\), 0.135}, {\(-0.135\), 
                0.135}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,2], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3.4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.6;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.175\), 
                0.175}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,3], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,3], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,3], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.35;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.09\), 
                0.09}, {\(-0.09\), 0.09}, {\(-0.09\), 
                0.09}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,0,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,0,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,0,0], y=0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        1;\)\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
                0.1}, {\(-0.1\), 0.1}, {\(-0.26\), 
                0.26}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,1,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,1,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,1,0], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,1,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,1,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,1,1], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        1.725;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,2,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,2,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,2,0], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.7;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.12\), 
                0.12}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,2,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,2,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,2,1], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.61;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.15\), 
                0.15}, {\(-0.15\), 0.15}, {\(-0.15\), 
                0.15}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,2,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,2,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,2,2], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        2.5;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.55\), 
                0.55}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,3,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,3,0], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,3,0], y= y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.75;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,3,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][2,3,1], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,3,1], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.75;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.135\), 
                0.135}, {\(-0.135\), 0.135}, {\(-0.135\), 
                0.135}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,2], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,2], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.7;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, r0] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.175\), 
                0.175}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        ReplaceAll[
          RR\_\(Rotat, Cart\)[n\_rad, l\_orb, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(RRy2\_Rotat[n\_rad, l\_orb, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, 
          RRy\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0], 
          0];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, y0] = 
        If[z < 0, 0, 
          RRy2\_Rotat[n\_rad, l\_orb, r0, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Rotat[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(Rotat, Cart\)[n\_rad, l\_orb, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0]];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            Anglar3dPlot[l\_orb, m\_azm, r0], 
            Radial3dhf\_Rotat[n\_rad, l\_orb, y0]}, {WFunktion3d\_Rotat[
              n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,3], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y1}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y1] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y1\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y1], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y2}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\
\[Psi][1,3,3], y=y2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y2] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y2\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y2], 0];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y3}];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.9] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y3] = 
        If[\@\(x\^2 + z\^2\) < \@\(r0\^2 - y3\^2\), \[Psi]\[Psi]hf\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y3], 0];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y3] = 
        Plot3D[\[Psi]\[Psi]2hf\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3d\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}, {WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y1], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, y2], 
            WFunktion3dhf\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,3], y=y0, y1, y2, y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 248, 8, 93, "Subtitle"],
Cell[2521, 82, 318, 10, 125, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2864, 96, 193, 5, 119, "Section"],
Cell[3060, 103, 236, 7, 57, "Text"],
Cell[3299, 112, 62, 1, 63, "Input"],
Cell[3364, 115, 165, 5, 56, "Text"],
Cell[3532, 122, 203, 9, 74, "NumberedEquation"],
Cell[3738, 133, 121, 2, 56, "Text"],
Cell[3862, 137, 96, 2, 50, "NumberedEquation"],
Cell[3961, 141, 120, 2, 56, "Text"],
Cell[4084, 145, 115, 5, 52, "NumberedEquation"],
Cell[4202, 152, 193, 7, 56, "Text"],
Cell[4398, 161, 54, 1, 63, "Input"],
Cell[4455, 164, 256, 6, 80, "Text"],
Cell[4714, 172, 45, 0, 56, "Text"],
Cell[4762, 174, 7480, 124, 5476, "Input"],
Cell[12245, 300, 46, 0, 56, "Text"],
Cell[12294, 302, 1079, 26, 588, "Input"],
Cell[13376, 330, 38, 0, 56, "Text"],
Cell[13417, 332, 22740, 356, 15083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36194, 693, 228, 6, 119, "Section"],
Cell[36425, 701, 842, 22, 200, "Text"],
Cell[37270, 725, 666, 17, 452, "Text"],
Cell[37939, 744, 771, 13, 463, "Input"],

Cell[CellGroupData[{
Cell[38735, 761, 202, 11, 89, "Subsection"],
Cell[38940, 774, 18920, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57897, 1094, 202, 11, 89, "Subsection"],
Cell[58102, 1107, 18920, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77059, 1427, 202, 11, 89, "Subsection"],
Cell[77264, 1440, 18930, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96231, 1760, 202, 11, 89, "Subsection"],
Cell[96436, 1773, 18918, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115391, 2093, 202, 11, 89, "Subsection"],
Cell[115596, 2106, 18919, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134552, 2426, 202, 11, 89, "Subsection"],
Cell[134757, 2439, 18920, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153714, 2759, 202, 11, 89, "Subsection"],
Cell[153919, 2772, 18924, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172880, 3092, 202, 11, 89, "Subsection"],
Cell[173085, 3105, 18925, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192047, 3425, 202, 11, 89, "Subsection"],
Cell[192252, 3438, 18928, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[211217, 3758, 203, 11, 89, "Subsection"],
Cell[211423, 3771, 18927, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230387, 4091, 203, 11, 89, "Subsection"],
Cell[230593, 4104, 18919, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[249549, 4424, 203, 11, 89, "Subsection"],
Cell[249755, 4437, 18901, 313, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268693, 4755, 203, 11, 89, "Subsection"],
Cell[268899, 4768, 18909, 314, 6548, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[287845, 5087, 203, 11, 89, "Subsection"],
Cell[288051, 5100, 18920, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[307008, 5420, 203, 11, 89, "Subsection"],
Cell[307214, 5433, 18919, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[326170, 5753, 203, 11, 89, "Subsection"],
Cell[326376, 5766, 18921, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[345334, 6086, 203, 11, 89, "Subsection"],
Cell[345540, 6099, 18920, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[364497, 6419, 203, 11, 89, "Subsection"],
Cell[364703, 6432, 18924, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[383664, 6752, 203, 11, 89, "Subsection"],
Cell[383870, 6765, 18929, 315, 6573, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[402836, 7085, 203, 11, 89, "Subsection"],
Cell[403042, 7098, 18925, 315, 6573, "Input"],
Cell[421970, 7415, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

