(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    153874,       3285]*)
(*NotebookOutlinePosition[    154603,       3310]*)
(*  CellTagsIndexPosition[    154559,       3306]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.2. Three-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.2.11. Comparative visualization of the Wave Functions and Probability \
Densities of the Three-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Probability densities of the three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" for the three-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 1, 2, 3, 4\)],
    FontSlant->"Italic"],
  ", \n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "."
}], "NumberedEquation"],

Cell[TextData[{
  "Determine parameter ",
  StyleBox["r0",
    FontSlant->"Italic"],
  " of the three-dimensional quantum oscillator:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(r0 = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Probability densities of the three-dimensional quantum oscillator for given \
quantum numbers in the Cartesian rectangular coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.5630360474111934`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(3.1415926535897913`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((9.441825313230899`\ z\^2\ \
\((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((4.720912656615449`\ \((x\^2 + 
                  y\^2)\)\ \((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((4.509770315871688`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((27.05862189523013`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((6.764655473807532`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\
\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 0, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((7.180738041514811`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 1, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((5.385553531136108`\ \
\((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
6.987932000503647`\ \@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) \
+ 0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 2, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((53.85553531136109`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 3, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((8.975922551893515`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\
\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4963228357196234`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(6.283185307179585`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((16.962502900061462`\ z\^2\ \
\((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((8.481251450030731`\ \((x\^2 + 
                  y\^2)\)\ \((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((7.850515282898902`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.00959518174141225`\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((47.10309169739341`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 2, 
          
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.775772924348352`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\
\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((11.995847465449176`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + \
0.24721012729596964`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((8.996885599086882`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + \
0.14238685650074237`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((89.96885599086882`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((14.994809331811469`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4856662084790068`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(9.424777960902889`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((24.231131639907577`\ z\^2\ \
\((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((12.115565819953789`\ \((x\^2 + 
                  y\^2)\)\ \((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.023293658715744`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((66.13976195229446`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((16.534940488073616`\ \((x\^2 + y\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((16.58802556637349`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + \
0.215581313417243`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\
\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0012581391733403658`\)\ r0\^2 + \
0.09442879939898956`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((12.441019174780115`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((124.41019174780115`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((20.73503195796686`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4820436953208706`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(12.566370614390479`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((31.4119931862564`\ z\^2\ \
\((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((15.7059965931282`\ \((x\^2 + 
                  y\^2)\)\ \((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((14.112846556690327`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((84.67707934014196`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((21.16926983503549`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\
\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((21.037307069172908`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + \
0.19395162042753517`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0006002121422403276`\)\ r0\^2 + \
0.06876245355250067`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((15.777980301879683`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((157.77980301879683`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((26.29663383646614`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial probability densities, angular probability \
densities and probability densities of the three-dimensional quantum \
rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the two-dimensional \
quantum rotator.\nWe will obtain three-dimensional plots probability \
densities (surface and density plots) for four cross-sectional profile \
(defined by coordinate plane ",
  StyleBox["y0",
    FontSlant->"Italic"],
  ") of the three-dimensional quantum rotator.\nIn this file we will present \
visualizations in individual scales for states defined by given quantum \
numbers."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-r0\) - 0.1;\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = r0 + 0.1;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-r0\) - 0.1;\)\), "\[IndentingNewLine]", 
    \(\(z3dMax = r0 + 0.1;\)\n\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 300;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(IS3dVert = 265;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VP1 = 0;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = 0;\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 3;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.35;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,0], y=1\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,3], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.35;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.725;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.7;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.61;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 2.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.9;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.7;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,3], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "21) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "22) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "23) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,0], y=1\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "24) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "25) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "26) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "27) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 2.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "28) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "29) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "30) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,3], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,3], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "31) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,0,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "32) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.15;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,1,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "33) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,1,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,1,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "34) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.95;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,2,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "35) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,2,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "36) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,2,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "37) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 2.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,0], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "38) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,1], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "39) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,2], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "40) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][4,3,3], y=y0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][4,3,3], y=0\>"]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparative visualization of the wave functions and probability densities \
of the three-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations in unified scales for all states defined by \
given quantum numbers.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3dVW\_Rotat[1, 0, 0, r0, y0], 
            WFunktion3dVW\_Rotat[2, 0, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 0, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 0, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 1, 0, r0, y0], WFunktion3dVW\_Rotat[2, 1, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 1, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 1, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 1, 1, r0, y0], WFunktion3dVW\_Rotat[2, 1, 1, r0, y0], 
            WFunktion3dVW\_Rotat[3, 1, 1, r0, y0], 
            WFunktion3dVW\_Rotat[4, 1, 1, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 2, 0, r0, y0], WFunktion3dVW\_Rotat[2, 2, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 2, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 2, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 2, 1, r0, y0], WFunktion3dVW\_Rotat[2, 2, 1, r0, y0], 
            WFunktion3dVW\_Rotat[3, 2, 1, r0, y0], 
            WFunktion3dVW\_Rotat[4, 2, 1, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 2, 2, r0, y0], WFunktion3dVW\_Rotat[2, 2, 2, r0, y0], 
            WFunktion3dVW\_Rotat[3, 2, 2, r0, y0], 
            WFunktion3dVW\_Rotat[4, 2, 2, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 0, r0, y0], WFunktion3dVW\_Rotat[2, 3, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 1, r0, y0], WFunktion3dVW\_Rotat[2, 3, 1, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 1, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 1, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 2, r0, y0], WFunktion3dVW\_Rotat[2, 3, 2, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 2, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 2, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 3, r0, y0], WFunktion3dVW\_Rotat[2, 3, 3, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 3, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 3, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {750, 
          1800}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, \
y=0\>"]\)], "Input"],

Cell["", "Text"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[1, 0, 0, r0, y0], 
            WFunktion3dDen\_Rotat[2, 0, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 0, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 0, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 1, 0, r0, y0], WFunktion3dDen\_Rotat[2, 1, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 1, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 1, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 1, 1, r0, y0], WFunktion3dDen\_Rotat[2, 1, 1, r0, y0], 
            WFunktion3dDen\_Rotat[3, 1, 1, r0, y0], 
            WFunktion3dDen\_Rotat[4, 1, 1, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 2, 0, r0, y0], WFunktion3dDen\_Rotat[2, 2, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 2, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 2, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 2, 1, r0, y0], WFunktion3dDen\_Rotat[2, 2, 1, r0, y0], 
            WFunktion3dDen\_Rotat[3, 2, 1, r0, y0], 
            WFunktion3dDen\_Rotat[4, 2, 1, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 2, 2, r0, y0], WFunktion3dDen\_Rotat[2, 2, 2, r0, y0], 
            WFunktion3dDen\_Rotat[3, 2, 2, r0, y0], 
            WFunktion3dDen\_Rotat[4, 2, 2, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 0, r0, y0], WFunktion3dDen\_Rotat[2, 3, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 0, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 1, r0, y0], WFunktion3dDen\_Rotat[2, 3, 1, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 1, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 1, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 2, r0, y0], WFunktion3dDen\_Rotat[2, 3, 2, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 2, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 2, r0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 3, r0, y0], WFunktion3dDen\_Rotat[2, 3, 3, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 3, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 3, r0, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {750, 
          1800}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, \
y=0\>"]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 248, 8, 93, "Subtitle"],
Cell[2521, 82, 204, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2750, 91, 142, 4, 85, "Section"],
Cell[2895, 97, 236, 7, 57, "Text"],
Cell[3134, 106, 62, 1, 63, "Input"],
Cell[3199, 109, 165, 5, 56, "Text"],
Cell[3367, 116, 203, 9, 74, "NumberedEquation"],
Cell[3573, 127, 193, 7, 56, "Text"],
Cell[3769, 136, 54, 1, 63, "Input"],
Cell[3826, 139, 210, 5, 80, "Text"],
Cell[4039, 146, 22740, 356, 15083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26816, 507, 228, 6, 119, "Section"],
Cell[27047, 515, 554, 11, 176, "Text"],
Cell[27604, 528, 666, 17, 452, "Text"],
Cell[28273, 547, 762, 13, 488, "Input"],

Cell[CellGroupData[{
Cell[29060, 564, 202, 11, 89, "Subsection"],
Cell[29265, 577, 2722, 47, 1028, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32024, 629, 202, 11, 89, "Subsection"],
Cell[32229, 642, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34997, 694, 202, 11, 89, "Subsection"],
Cell[35202, 707, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37970, 759, 202, 11, 89, "Subsection"],
Cell[38175, 772, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40942, 824, 202, 11, 89, "Subsection"],
Cell[41147, 837, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43914, 889, 202, 11, 89, "Subsection"],
Cell[44119, 902, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46886, 954, 202, 11, 89, "Subsection"],
Cell[47091, 967, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49859, 1019, 202, 11, 89, "Subsection"],
Cell[50064, 1032, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52832, 1084, 202, 11, 89, "Subsection"],
Cell[53037, 1097, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55804, 1149, 203, 11, 89, "Subsection"],
Cell[56010, 1162, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58777, 1214, 203, 11, 89, "Subsection"],
Cell[58983, 1227, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61751, 1279, 203, 11, 89, "Subsection"],
Cell[61957, 1292, 2728, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64722, 1344, 203, 11, 89, "Subsection"],
Cell[64928, 1357, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67695, 1409, 203, 11, 89, "Subsection"],
Cell[67901, 1422, 2732, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70670, 1474, 203, 11, 89, "Subsection"],
Cell[70876, 1487, 2862, 50, 1128, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73775, 1542, 203, 11, 89, "Subsection"],
Cell[73981, 1555, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76749, 1607, 203, 11, 89, "Subsection"],
Cell[76955, 1620, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79722, 1672, 203, 11, 89, "Subsection"],
Cell[79928, 1685, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82695, 1737, 203, 11, 89, "Subsection"],
Cell[82901, 1750, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85669, 1802, 203, 11, 89, "Subsection"],
Cell[85875, 1815, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88642, 1867, 203, 11, 89, "Subsection"],
Cell[88848, 1880, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91615, 1932, 203, 11, 89, "Subsection"],
Cell[91821, 1945, 2728, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94586, 1997, 203, 11, 89, "Subsection"],
Cell[94792, 2010, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97559, 2062, 203, 11, 89, "Subsection"],
Cell[97765, 2075, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100533, 2127, 203, 11, 89, "Subsection"],
Cell[100739, 2140, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103507, 2192, 203, 11, 89, "Subsection"],
Cell[103713, 2205, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106481, 2257, 203, 11, 89, "Subsection"],
Cell[106687, 2270, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109454, 2322, 203, 11, 89, "Subsection"],
Cell[109660, 2335, 2728, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112425, 2387, 203, 11, 89, "Subsection"],
Cell[112631, 2400, 2728, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115396, 2452, 203, 11, 89, "Subsection"],
Cell[115602, 2465, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118370, 2517, 203, 11, 89, "Subsection"],
Cell[118576, 2530, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121343, 2582, 203, 11, 89, "Subsection"],
Cell[121549, 2595, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[124317, 2647, 203, 11, 89, "Subsection"],
Cell[124523, 2660, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127291, 2712, 203, 11, 89, "Subsection"],
Cell[127497, 2725, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130265, 2777, 203, 11, 89, "Subsection"],
Cell[130471, 2790, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133239, 2842, 203, 11, 89, "Subsection"],
Cell[133445, 2855, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136213, 2907, 203, 11, 89, "Subsection"],
Cell[136419, 2920, 2730, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139186, 2972, 203, 11, 89, "Subsection"],
Cell[139392, 2985, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142160, 3037, 203, 11, 89, "Subsection"],
Cell[142366, 3050, 2731, 47, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145134, 3102, 203, 11, 89, "Subsection"],
Cell[145340, 3115, 2731, 47, 1053, "Input"],
Cell[148074, 3164, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148139, 3170, 193, 5, 119, "Section"],
Cell[148335, 3177, 169, 5, 56, "Text"],
Cell[148507, 3184, 2635, 46, 888, "Input"],
Cell[151145, 3232, 16, 0, 56, "Text"],
Cell[151164, 3234, 2675, 46, 888, "Input"],
Cell[153842, 3282, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

