(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28924,        886]*)
(*NotebookOutlinePosition[     29735,        912]*)
(*  CellTagsIndexPosition[     29691,        908]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.1. One-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.1.1. Schrodinger Equation for One-Dimensional Quantum Oscillator:
General Solutions, Radial Wave Functions  and Energy Levels\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Schrodinger Equation of the one-dimensional quantum oscillator\
\>", "Section"],

Cell[TextData[{
  "Consider equation (",
  StyleBox["DifEqnQntOsc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") of the one-dimensional quantum oscillator:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["DifEqnQntOsc",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0, 0]], 
      "=", \(D[\[Psi][x], {x, 
              2}] + \(\(\(2\)\(\ \)\(m\_0\)\(\ \)\)\/\[HBar]\^2\) 
            En\ \[Psi][x] - \(\(2\ m\_0\)\/\[HBar]\^2\) 
            V[x]\ \[Psi][x] \[Equal] 0\)}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(2\ En\ m\_0\ \[Psi][x]\)\/\[HBar]\^2\), 
        "-", \(\(2\ m\_0\ V[x]\ \[Psi][x]\)\/\[HBar]\^2\), "+", 
        RowBox[{
          SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  StyleBox["V",
    FontSlant->"Italic"],
  "[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] is the one-dimensional potential energy of oscillator:"
}], "Text"],

Cell[BoxData[
    \(\(\(V[x] = 1\/2\ x\^2\ \[Omega]\^2\ m\_0\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "\[Psi]",
  "[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] is wave function of one-dimensional oscillator, ",
  Cell[BoxData[
      \(m\_0\)],
    FontSlant->"Italic"],
  " is mass of oscillating particle, \[Omega] is frequency of oscillations, \
",
  StyleBox["En",
    FontSlant->"Italic"],
  " is total energy of oscillator ."
}], "Text"],

Cell[TextData[{
  "Substitute expression for potential energy ",
  StyleBox["V",
    FontSlant->"Italic"],
  "[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] to equation (",
  StyleBox["DifEqnQntOsc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") and use extra denotations:"
}], "Text"],

Cell[BoxData[
    \(k = \@\(2\ \(m\_0\) En\)\/\[HBar], \ \[Lambda] = \(\(\ \)\(\(m\_0\) \
\[Omega]\)\)\/\[HBar]\)], "NumberedEquation",
  TextAlignment->Center],

Cell["and we will have", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{
          StyleBox["DifEqnQntOsc",
            FontWeight->"Bold",
            FontSlant->"Italic",
            FontColor->RGBColor[0.996109, 0, 0]], "1"}]], "=", 
      RowBox[{"Simplify", "[", 
        RowBox[{"ReplaceAll", "[", 
          RowBox[{
            StyleBox["DifEqnQntOsc",
              FontWeight->"Bold",
              FontSlant->"Italic",
              FontColor->RGBColor[0.996109, 0, 0]], 
            ",", \({V[x] \[Rule] 1\/2\ x\^2\ \[Omega]\^2\ m\_0, 
              En \[Rule] \(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\)}\)}], "]"}], 
        "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\((k\^2 - \(x\^2\ \[Omega]\^2\ m\_0\%2\)\/\[HBar]\^2)\)\ \
\[Psi][x]\), "+", 
        RowBox[{
          SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RadDifEqnQntOsc2", "=", 
      RowBox[{"Simplify", "[", 
        RowBox[{"ReplaceAll", "[", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["DifEqnQntOsc",
                  FontWeight->"Bold",
                  FontSlant->"Italic",
                  FontColor->RGBColor[0.996109, 0, 0]], "1"}]], 
            ",", \({m\_0 \[Rule] \(\[Lambda]\ \[HBar]\)\/\[Omega]}\)}], "]"}],
         "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\((k\^2 - x\^2\ \[Lambda]\^2)\)\ \[Psi][x]\), "+", 
        RowBox[{
          SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "To solve this equation we will use \"",
  StyleBox["Dsolve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        StyleBox[
          RowBox[{
            RowBox[{\(\((k\^2 - x\^2\ \[Lambda]\^2)\)\ \[Psi][x]\), "+", 
              RowBox[{
                SuperscriptBox["\[Psi]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}],
          FontWeight->"Bold",
          FontSlant->"Italic",
          FontColor->RGBColor[0.996109, 0, 0]], ",", \(\[Psi][x]\), ",", 
        "x"}], "]"}]], "Input"],

Cell[BoxData[
    \({{\[Psi][
            x] \[Rule] \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ C[
                1]\ HermiteH[\(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\), 
                x\ \@\[Lambda]] + \[ExponentialE]\^\(-\(\(x\^2\ \
\[Lambda]\)\/2\)\)\ C[
                2]\ Hypergeometric1F1[\(-\(\(k\^2 - \[Lambda]\)\/\(4\ \
\[Lambda]\)\)\), 1\/2, x\^2\ \[Lambda]]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "General solution for \[Psi][",
  StyleBox["x",
    FontSlant->"Italic"],
  "] is superposition of two independent fundamental solutions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]1[
        x] = \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
HermiteH[\(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\), 
          x\ \@\[Lambda]]\), "\[IndentingNewLine]", 
    \(\[Psi]2[
        x] = \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
Hypergeometric1F1[\(-\(\(k\^2 - \[Lambda]\)\/\(4\ \[Lambda]\)\)\), 1\/2, 
          x\^2\ \[Lambda]]\)}], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ HermiteH[\(k\^2 - \
\[Lambda]\)\/\(2\ \[Lambda]\), x\ \@\[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ Hypergeometric1F1[\(-\
\(\(k\^2 - \[Lambda]\)\/\(4\ \[Lambda]\)\)\), 1\/2, 
        x\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where HermiteH[...] is Hermite function ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\_n\)(x)\)], "InlineFormula"],
  ", Hypergeometric1F1[...] are the Kummer confluent hypergeometric function \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Null]\_1\) \(\(F\_1\)(a; b; z)\)\)], 
    "InlineFormula"],
  " and C[1] and C[2] are constants.\nAs a result we have solution of the \
equation ",
  "as superposition of two components",
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][x] = C[1] \[Psi]1[x] + C[2] \[Psi]2[x]\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Now we analyze asymptotic behavior of functions \[Psi]1[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] and \[Psi]2[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] at infinity."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(HermiteHAsymptot[x] = 
      Series[HermiteH[\(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\), 
          x\ \@\[Lambda]], {x, Infinity, 2}]\), "\[IndentingNewLine]", 
    \(Hypergeometric1F1Asymptot[x] = 
      Series[Hypergeometric1F1[\(-\(\(k\^2 - \[Lambda]\)\/\(4\ \
\[Lambda]\)\)\), 1\/2, x\^2\ \[Lambda]], {x, Infinity, 2}]\)}], "Input"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \\!\\(HypergeometricU[\\(\\(\\(\\(1\\/2\\\\ \\(\\((1 - \
\\(k\\^2 - \[Lambda]\\)\\/\\(2\\\\ \[Lambda]\\))\\)\\)\\)\\), 3\\/2, \
\\*InterpretationBox[\\(\[Lambda]\\/\\((\\(\[LeftSkeleton] 1 \[RightSkeleton]\
\\))\\)\\^2 + \\*InterpretationBox[\\(\\(O[\\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)]\\)\\^1\\), SeriesData[x, DirectedInfinity[1], List[], \
-2, 1, 1]]\\), SeriesData[x, DirectedInfinity[1], List[\\\\[Lambda]], -2, 1, \
1]]\\)\\)]\\).\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \\!\\(HypergeometricU[\\(\\(\\(\\(1\\/2\\\\ \\(\\((1 - \
\\(k\\^2 - \[Lambda]\\)\\/\\(2\\\\ \[Lambda]\\))\\)\\)\\)\\), 3\\/2, \
\\*InterpretationBox[\\(\[Lambda]\\/\\((\\(\[LeftSkeleton] 1 \[RightSkeleton]\
\\))\\)\\^2 + \\*InterpretationBox[\\(\\(O[\\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)]\\)\\^1\\), SeriesData[x, DirectedInfinity[1], List[], \
-2, 1, 1]]\\), SeriesData[x, DirectedInfinity[1], List[\\\\[Lambda]], -2, 1, \
1]]\\)\\)]\\).\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \\!\\(HypergeometricU[\\(\\(\\(\\(1\\/2\\\\ \\(\\((1 - \
\\(k\\^2 - \[Lambda]\\)\\/\\(2\\\\ \[Lambda]\\))\\)\\)\\)\\), 3\\/2, \
\\*InterpretationBox[\\(\[Lambda]\\/\\((\\(\[LeftSkeleton] 1 \[RightSkeleton]\
\\))\\)\\^2 + \\*InterpretationBox[\\(\\(O[\\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)]\\)\\^1\\), SeriesData[x, DirectedInfinity[1], List[], \
-2, 1, 1]]\\), SeriesData[x, DirectedInfinity[1], List[\\\\[Lambda]], -2, 1, \
1]]\\)\\)]\\).\"\>"}]], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Series :: \"esss\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    RowBox[{
      RowBox[{"HypergeometricU", "[", 
        RowBox[{\(1\/2\ \((1 - \(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\))\)\), 
          ",", \(3\/2\), ",", 
          InterpretationBox[
            RowBox[{\(\[Lambda]\/\((1\/x)\)\^2\), "+", 
              InterpretationBox[\(O[1\/x]\^1\),
                SeriesData[ x, 
                  DirectedInfinity[ 1], {}, -2, 1, 1]]}],
            SeriesData[ x, 
              DirectedInfinity[ 1], {\[Lambda]}, -2, 1, 1]]}], "]"}], " ", 
      RowBox[{"(", 
        InterpretationBox[
          
          RowBox[{\(\(2\^\(\(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\)\)\ \@\
\[Lambda]\)\/\(1\/x\)\), "+", 
            InterpretationBox[\(O[1\/x]\^2\),
              SeriesData[ x, 
                DirectedInfinity[ 1], {}, -1, 2, 1]]}],
          SeriesData[ x, 
            DirectedInfinity[ 1], {
            Times[ 
              Power[ 2, 
                Times[ 
                  Rational[ 1, 2], 
                  Plus[ 
                    Power[ k, 2], 
                    Times[ -1, \[Lambda]]], 
                  Power[ \[Lambda], -1]]], 
              Power[ \[Lambda], 
                Rational[ 1, 2]]]}, -1, 2, 1]], ")"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \\!\\(HypergeometricU[\\(\\(\\(\\(-\\(\\(\\(k\\^2 - \
\[Lambda]\\)\\/\\(4\\\\ \[Lambda]\\)\\)\\)\\)\\), 1\\/2, \
\\*InterpretationBox[\\(\[Lambda]\\/\\((\\(\[LeftSkeleton] 1 \[RightSkeleton]\
\\))\\)\\^2 + \\*InterpretationBox[\\(\\(O[\\(\\(1\\/x\\)\\)]\\)\\^1\\), \
SeriesData[x, DirectedInfinity[1], List[], -2, 1, 1]]\\), SeriesData[x, \
DirectedInfinity[1], List[\\\\[Lambda]], -2, 1, 1]]\\)\\)]\\).\"\>"}]], \
"Message"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \
\\!\\(\[ExponentialE]\\^\\*InterpretationBox[\\(\[Lambda]\\/\\((\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\))\\)\\^2 + \\*InterpretationBox[\\(\\(O[\
\\(\\(\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)]\\)\\^1\\), SeriesData[x, \
DirectedInfinity[1], List[], -2, 1, 1]]\\), SeriesData[x, \
DirectedInfinity[1], List[\\\\[Lambda]], -2, 1, 1]]\\).\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(Series::"esss"\), \(\(:\)\(\ \)\), "\<\"Essential singularity \
encountered in \
\\!\\(\[ExponentialE]\\^\\*InterpretationBox[\\(\[Lambda]\\/\\((\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\))\\)\\^2 + \\*InterpretationBox[\\(\\(O[\
\\(\\(\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)]\\)\\^1\\), SeriesData[x, \
DirectedInfinity[1], List[], -2, 1, 1]]\\), SeriesData[x, \
DirectedInfinity[1], List[\\\\[Lambda]], -2, 1, 1]]\\).\"\>"}]], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Series :: \"esss\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    RowBox[{\(\@\[Pi]\), " ", 
      RowBox[{"(", 
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                InterpretationBox[
                  RowBox[{\(\[Lambda]\/\((1\/x)\)\^2\), "+", 
                    InterpretationBox[\(O[1\/x]\^1\),
                      SeriesData[ x, 
                        DirectedInfinity[ 1], {}, -2, 1, 1]]}],
                  SeriesData[ x, 
                    DirectedInfinity[ 1], {\[Lambda]}, -2, 1, 1]]], " ", 
              RowBox[{"HypergeometricU", "[", 
                
                RowBox[{\(1\/2 + \(k\^2 - \[Lambda]\)\/\(4\ \[Lambda]\)\), 
                  ",", \(1\/2\), ",", 
                  InterpretationBox[
                    RowBox[{\(-\(\[Lambda]\/\((1\/x)\)\^2\)\), "+", 
                      InterpretationBox[\(O[1\/x]\^1\),
                        SeriesData[ x, 
                          DirectedInfinity[ 1], {}, -2, 1, 1]]}],
                    SeriesData[ x, 
                      DirectedInfinity[ 1], {
                      Times[ -1, \[Lambda]]}, -2, 1, 1]]}], 
                "]"}]}], \(Gamma[\(-\(\(k\^2 - \[Lambda]\)\/\(4\ \
\[Lambda]\)\)\)]\)], "+", 
          FractionBox[
            
            RowBox[{\(\[ExponentialE]\^\(-\(\(\[ImaginaryI]\ \[Pi]\ \((k\^2 - \
\[Lambda])\)\)\/\(4\ \[Lambda]\)\)\)\), " ", 
              RowBox[{"HypergeometricU", "[", 
                
                RowBox[{\(-\(\(k\^2 - \[Lambda]\)\/\(4\ \[Lambda]\)\)\), 
                  ",", \(1\/2\), ",", 
                  InterpretationBox[
                    RowBox[{\(\[Lambda]\/\((1\/x)\)\^2\), "+", 
                      InterpretationBox[\(O[1\/x]\^1\),
                        SeriesData[ x, 
                          DirectedInfinity[ 1], {}, -2, 1, 1]]}],
                    SeriesData[ x, 
                      DirectedInfinity[ 1], {\[Lambda]}, -2, 1, 1]]}], 
                "]"}]}], \(Gamma[
              1\/2 + \(k\^2 - \[Lambda]\)\/\(4\ \[Lambda]\)]\)]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "That is Hermite and Hypergeometric functions and consequently \[Psi]1[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] and \[Psi]1[",
  StyleBox["x",
    FontSlant->"Italic"],
  "] are divergent function at infinity."
}], "Text"],

Cell["\<\
Next consideration deal with properties of the special functions HermiteH and \
Hypergeometric1F1.
Note that:
1) special functions HermiteH and Hypergeometric1F1 are polynomial with \
finitesimal norm if conditions take place:\
\>", "Text"],

Cell[BoxData[{
    \(HermiteH[\(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\), 
        x\ \@\[Lambda]] \[Rule] 
      HermiteH[n\_1, x\ \@\[Lambda]]\), "\[IndentingNewLine]", 
    \(\(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\) = 
      n\_1\), "\[IndentingNewLine]", 
    \(Hypergeometric1F1[\(-\(\(k\^2 - \[Lambda]\)\/\(4\ \[Lambda]\)\)\), 
        1\/2, x\^2\ \[Lambda]] \[Rule] 
      Hypergeometric1F1[\(-n\_2\), 1\/2, 
        x\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(\(k\^2 - \[Lambda]\)\/\(4\ \[Lambda]\) = n\_2\)}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(n\_1\)],
    TextAlignment->Center,
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(n\_1\)],
    TextAlignment->Center,
    FontSlant->"Italic"],
  " are integer numbers:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(n\_1 = 0, 1, 2, 3,  ... \), "\[IndentingNewLine]", 
    \(n\_2 = 0, 1, 2, 3,  ... \)}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "2) polynomials of ",
  Cell[BoxData[
      StyleBox[\(HermiteH[n\_1, x\ \@\[Lambda]]\),
        FontSlant->"Italic"]],
    TextAlignment->Center],
  " and ",
  Cell[BoxData[
      StyleBox[\(Hypergeometric1F1[\(-n\_2\), 1\/2, x\^2\ \[Lambda]]\),
        FontSlant->"Italic"]],
    TextAlignment->Center],
  " are identical ",
  "accurate to constant factor"
}], "Text"],

Cell[BoxData[
    StyleBox[\(\(2\^\(2  n\)\ \@\[Pi]\)\/Gamma[1\/2\ \((1 - 2  n)\)]\),
      FontSlant->"Italic"]], "NumberedEquation",
  TextAlignment->Center],

Cell["if", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(n\_2\  = n\), "\[IndentingNewLine]", 
    \(n\_1 = \(2\ n\_2\  = 2  n\)\)}], "NumberedEquation",
  TextAlignment->Center],

Cell["\<\
This fact can be illustrated by the expansions of Hermite and Hypergeometric \
functions:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[
      TableForm[Table[HermiteH[2  n, x\ \@\[Lambda]], {n, 6}]]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\(-2\) + 4\ x\^2\ \[Lambda]\)},
          {\(12 - 48\ x\^2\ \[Lambda] + 16\ x\^4\ \[Lambda]\^2\)},
          {\(\(-120\) + 720\ x\^2\ \[Lambda] - 480\ x\^4\ \[Lambda]\^2 + 
              64\ x\^6\ \[Lambda]\^3\)},
          {\(1680 - 13440\ x\^2\ \[Lambda] + 13440\ x\^4\ \[Lambda]\^2 - 
              3584\ x\^6\ \[Lambda]\^3 + 256\ x\^8\ \[Lambda]\^4\)},
          {\(\(-30240\) + 302400\ x\^2\ \[Lambda] - 
              403200\ x\^4\ \[Lambda]\^2 + 161280\ x\^6\ \[Lambda]\^3 - 
              23040\ x\^8\ \[Lambda]\^4 + 1024\ x\^10\ \[Lambda]\^5\)},
          {\(665280 - 7983360\ x\^2\ \[Lambda] + 
              13305600\ x\^4\ \[Lambda]\^2 - 7096320\ x\^6\ \[Lambda]\^3 + 
              1520640\ x\^8\ \[Lambda]\^4 - 135168\ x\^10\ \[Lambda]\^5 + 
              4096\ x\^12\ \[Lambda]\^6\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ -2, 
          Times[ 4, 
            Power[ x, 2], \[Lambda]]], 
        Plus[ 12, 
          Times[ -48, 
            Power[ x, 2], \[Lambda]], 
          Times[ 16, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]]], 
        Plus[ -120, 
          Times[ 720, 
            Power[ x, 2], \[Lambda]], 
          Times[ -480, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ 64, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]]], 
        Plus[ 1680, 
          Times[ -13440, 
            Power[ x, 2], \[Lambda]], 
          Times[ 13440, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ -3584, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]], 
          Times[ 256, 
            Power[ x, 8], 
            Power[ \[Lambda], 4]]], 
        Plus[ -30240, 
          Times[ 302400, 
            Power[ x, 2], \[Lambda]], 
          Times[ -403200, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ 161280, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]], 
          Times[ -23040, 
            Power[ x, 8], 
            Power[ \[Lambda], 4]], 
          Times[ 1024, 
            Power[ x, 10], 
            Power[ \[Lambda], 5]]], 
        Plus[ 665280, 
          Times[ -7983360, 
            Power[ x, 2], \[Lambda]], 
          Times[ 13305600, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ -7096320, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]], 
          Times[ 1520640, 
            Power[ x, 8], 
            Power[ \[Lambda], 4]], 
          Times[ -135168, 
            Power[ x, 10], 
            Power[ \[Lambda], 5]], 
          Times[ 4096, 
            Power[ x, 12], 
            Power[ \[Lambda], 6]]]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExpandAll[
      TableForm[
        Table[\(\(2\^\(2  n\)\ \@\[Pi]\)\/Gamma[1\/2\ \((1 - 2  n)\)]\) 
            Hypergeometric1F1[\(-n\), 1\/2, x\^2\ \[Lambda]], {n, 
            6}]]]\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\(-2\) + 4\ x\^2\ \[Lambda]\)},
          {\(12 - 48\ x\^2\ \[Lambda] + 16\ x\^4\ \[Lambda]\^2\)},
          {\(\(-120\) + 720\ x\^2\ \[Lambda] - 480\ x\^4\ \[Lambda]\^2 + 
              64\ x\^6\ \[Lambda]\^3\)},
          {\(1680 - 13440\ x\^2\ \[Lambda] + 13440\ x\^4\ \[Lambda]\^2 - 
              3584\ x\^6\ \[Lambda]\^3 + 256\ x\^8\ \[Lambda]\^4\)},
          {\(\(-30240\) + 302400\ x\^2\ \[Lambda] - 
              403200\ x\^4\ \[Lambda]\^2 + 161280\ x\^6\ \[Lambda]\^3 - 
              23040\ x\^8\ \[Lambda]\^4 + 1024\ x\^10\ \[Lambda]\^5\)},
          {\(665280 - 7983360\ x\^2\ \[Lambda] + 
              13305600\ x\^4\ \[Lambda]\^2 - 7096320\ x\^6\ \[Lambda]\^3 + 
              1520640\ x\^8\ \[Lambda]\^4 - 135168\ x\^10\ \[Lambda]\^5 + 
              4096\ x\^12\ \[Lambda]\^6\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ -2, 
          Times[ 4, 
            Power[ x, 2], \[Lambda]]], 
        Plus[ 12, 
          Times[ -48, 
            Power[ x, 2], \[Lambda]], 
          Times[ 16, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]]], 
        Plus[ -120, 
          Times[ 720, 
            Power[ x, 2], \[Lambda]], 
          Times[ -480, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ 64, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]]], 
        Plus[ 1680, 
          Times[ -13440, 
            Power[ x, 2], \[Lambda]], 
          Times[ 13440, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ -3584, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]], 
          Times[ 256, 
            Power[ x, 8], 
            Power[ \[Lambda], 4]]], 
        Plus[ -30240, 
          Times[ 302400, 
            Power[ x, 2], \[Lambda]], 
          Times[ -403200, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ 161280, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]], 
          Times[ -23040, 
            Power[ x, 8], 
            Power[ \[Lambda], 4]], 
          Times[ 1024, 
            Power[ x, 10], 
            Power[ \[Lambda], 5]]], 
        Plus[ 665280, 
          Times[ -7983360, 
            Power[ x, 2], \[Lambda]], 
          Times[ 13305600, 
            Power[ x, 4], 
            Power[ \[Lambda], 2]], 
          Times[ -7096320, 
            Power[ x, 6], 
            Power[ \[Lambda], 3]], 
          Times[ 1520640, 
            Power[ x, 8], 
            Power[ \[Lambda], 4]], 
          Times[ -135168, 
            Power[ x, 10], 
            Power[ \[Lambda], 5]], 
          Times[ 4096, 
            Power[ x, 12], 
            Power[ \[Lambda], 6]]]}]]], "Output"]
}, Open  ]],

Cell["\<\
This implies that solution with Hypergeometric1F1 function corresponds to \
even states of the quantum oscillator and solution with HermiteH function \
corresponds to even and uneven states of the quantum oscillator.\
\>", "Text"],

Cell["Therefore we will consider wave function in the form:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][x] = 
      C[1] \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ HermiteH[n, 
          x\ \@\[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ C[1]\ HermiteH[n, 
        x\ \@\[Lambda]]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Energy levels of quantum oscillator of the one-dimensional quantum \
oscillator\
\>", "Section"],

Cell[TextData[{
  "Condition (6) give us possibility to obtain energy levels of the ",
  "one-dimensional quantum oscillator",
  ".\nTo obtain energy levels we will use expressions (2) and \"",
  StyleBox["Solve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" Tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Lambda] = \((m\_0*\[Omega])\)/\[HBar];\)\), "\n", 
    \(Solve[{\(k\^2 - \[Lambda]\)\/\(2\ \[Lambda]\) == n, 
        En == \(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\)}, {En, k}]\)}], "Input"],

Cell[BoxData[
    \({{En \[Rule] 1\/2\ \((1 + 2\ n)\)\ \[Omega]\ \[HBar], 
        k \[Rule] \(-\(\(\@\(1 + 2\ n\)\ \@\[Omega]\ \
\@m\_0\)\/\@\[HBar]\)\)}, {En \[Rule] 
          1\/2\ \((1 + 2\ n)\)\ \[Omega]\ \[HBar], 
        k \[Rule] \(\@\(1 + 2\ n\)\ \@\[Omega]\ \@m\_0\)\/\@\[HBar]}}\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "As a result we have quantified energy levels depending on quantum number \
",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(En[n, l] = 1\/2\ \((1 + 2\ n)\)\ \[Omega]\ \[HBar]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \((1 + 2\ n)\)\ \[Omega]\ \[HBar]\)], "Output"]
}, Open  ]],

Cell["where", "Text"],

Cell[BoxData[
    \(n = \ 0, 1, 2, 3,  ... \)], "NumberedEquation",
  TextAlignment->Center],

Cell["\<\
Returning to denotations (2) using definition (7) we can write down the \
radial function in the forms:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][n, x] = 
      C[1] \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ HermiteH[n, 
          x\ \@\[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(x\^2\ \[Omega]\ m\_0\)\/\(2\ \[HBar]\)\)\)\ C[
        1]\ HermiteH[n, x\ \@\(\(\[Omega]\ m\_0\)\/\[HBar]\)]\)], "Output"]
}, Open  ]],

Cell["\<\
Using denotations (2) we can write down the radial function in the forms:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[\[Lambda]]\), "\[IndentingNewLine]", 
    \(\[Psi][n, \[Lambda], x] = 
      C[1] \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ HermiteH[n, 
          x\ \@\[Lambda]]\), "\[IndentingNewLine]", 
    \(\[Psi][n, \[Omega], x] = 
      Simplify[ReplaceAll[\[Psi][n, \[Lambda], 
            x], {\[Lambda] \[Rule] \(\[Omega]\ m\_0\)\/\[HBar]}]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ C[1]\ HermiteH[n, 
        x\ \@\[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(x\^2\ \[Omega]\ m\_0\)\/\(2\ \[HBar]\)\)\)\ C[
        1]\ HermiteH[n, x\ \@\(\(\[Omega]\ m\_0\)\/\[HBar]\)]\)], "Output"]
}, Open  ]],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[]}, "Classroom1.nb", \
CharacterEncoding -> "WindowsCyrillic"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 207, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2757, 91, 92, 2, 85, "Section"],
Cell[2852, 95, 226, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[3103, 106, 370, 9, 85, "Input"],
Cell[3476, 117, 310, 7, 85, "Output"]
}, Open  ]],
Cell[3801, 127, 191, 8, 56, "Text"],
Cell[3995, 137, 93, 1, 68, "NumberedEquation"],
Cell[4091, 140, 364, 14, 80, "Text"],
Cell[4458, 156, 346, 13, 57, "Text"],
Cell[4807, 171, 160, 3, 75, "NumberedEquation"],
Cell[4970, 176, 32, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[5027, 180, 634, 17, 91, "Input"],
Cell[5664, 199, 280, 7, 96, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5981, 211, 473, 12, 85, "Input"],
Cell[6457, 225, 254, 6, 64, "Output"]
}, Open  ]],
Cell[6726, 234, 202, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[6953, 245, 494, 12, 64, "Input"],
Cell[7450, 259, 392, 7, 144, "Output"]
}, Open  ]],
Cell[7857, 269, 168, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[8050, 278, 439, 10, 144, "Input"],
Cell[8492, 290, 150, 2, 88, "Output"],
Cell[8645, 294, 184, 3, 88, "Output"]
}, Open  ]],
Cell[8844, 300, 469, 13, 116, "Text"],
Cell[9316, 315, 114, 2, 53, "NumberedEquation"],
Cell[9433, 319, 212, 8, 56, "Text"],

Cell[CellGroupData[{
Cell[9670, 331, 354, 6, 169, "Input"],
Cell[10027, 339, 576, 8, 73, "Message"],
Cell[10606, 349, 576, 8, 73, "Message"],
Cell[11185, 359, 576, 8, 73, "Message"],
Cell[11764, 369, 164, 3, 30, "Message"],
Cell[11931, 374, 1211, 31, 113, "Output"],
Cell[13145, 407, 532, 8, 73, "Message"],
Cell[13680, 417, 467, 7, 42, "Message"],
Cell[14150, 426, 467, 7, 42, "Message"],
Cell[14620, 435, 164, 3, 30, "Message"],
Cell[14787, 440, 2059, 45, 303, "Output"]
}, Open  ]],
Cell[16861, 488, 249, 8, 56, "Text"],
Cell[17113, 498, 250, 6, 128, "Text"],
Cell[17366, 506, 563, 11, 212, "NumberedEquation"],
Cell[17932, 519, 295, 14, 56, "Text"],
Cell[18230, 535, 153, 3, 78, "NumberedEquation"],
Cell[18386, 540, 388, 13, 84, "Text"],
Cell[18777, 555, 159, 3, 88, "NumberedEquation"],
Cell[18939, 560, 65, 2, 56, "Text"],
Cell[19007, 564, 142, 3, 78, "NumberedEquation"],
Cell[19152, 569, 160, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[19337, 578, 104, 2, 71, "Input"],
Cell[19444, 582, 2860, 83, 210, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22341, 670, 218, 5, 139, "Input"],
Cell[22562, 677, 2860, 83, 210, "Output"]
}, Open  ]],
Cell[25437, 763, 240, 4, 80, "Text"],
Cell[25680, 769, 69, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[25774, 773, 145, 3, 75, "Input"],
Cell[25922, 778, 126, 2, 75, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26097, 786, 109, 3, 85, "Section"],
Cell[26209, 791, 336, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[26570, 804, 207, 3, 119, "Input"],
Cell[26780, 809, 306, 6, 180, "Output"]
}, Open  ]],
Cell[27101, 818, 170, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[27296, 829, 83, 1, 85, "Input"],
Cell[27382, 832, 73, 1, 85, "Output"]
}, Open  ]],
Cell[27470, 836, 21, 0, 56, "Text"],
Cell[27494, 838, 92, 2, 53, "NumberedEquation"],
Cell[27589, 842, 127, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[27741, 849, 148, 3, 75, "Input"],
Cell[27892, 854, 166, 2, 98, "Output"]
}, Open  ]],
Cell[28073, 859, 97, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[28195, 865, 384, 7, 148, "Input"],
Cell[28582, 874, 126, 2, 75, "Output"],
Cell[28711, 878, 166, 2, 98, "Output"]
}, Open  ]],
Cell[28892, 883, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

