(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44921,       1321]*)
(*NotebookOutlinePosition[     45732,       1347]*)
(*  CellTagsIndexPosition[     45688,       1343]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.1. One-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.1.2. Probability Density and Normalization of the Wave Functions of the \
One-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Probability density of the one-dimensional quantum oscillator\
\>", "Section"],

Cell["Consider wave function of quantum oscillator:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][n, \[Lambda], x] = 
      C[n, \[Lambda]] \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
HermiteH[n, x\ \@\[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ C[
        n, \[Lambda]]\ HermiteH[n, x\ \@\[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(C[n, \[Lambda]]\)],
    FontSlant->"Italic"],
  "is constant."
}], "Text"],

Cell["Define probability density. ", "Text"],

Cell[BoxData[
    \(\[Psi]\[Psi][n, \[Lambda], 
        x] = \(\(|\)\(\[Psi][n, \[Lambda], 
          x]\)\( | \^2\)\)\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(\[Psi][n, \[Lambda], x]\)],
    FontSlant->"Italic"],
  "is real function we have"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]\[Psi][n, \[Lambda], x] = \[Psi][n, \[Lambda], x]\^2\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ C[n, \[Lambda]]\^2\ \
HermiteH[n, x\ \@\[Lambda]]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Dimensionless form of the wave functions of the one-dimensional quantum \
oscillator\
\>", "Section"],

Cell["\<\
Transform wave function of the one-dimensional quantum oscillator to the \
dimensionless form using new dimensionless variable \[Xi] :\
\>", "Text"],

Cell[BoxData[
    \(\[Xi] = x \@ \[Lambda], x = \[Xi]\/\@\[Lambda]\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][n, \[Lambda], \[Xi]] = 
      FullSimplify[
        ReplaceAll[\[Psi][n, \[Lambda], 
            x], {x \[Rule] \[Xi]\/\@\[Lambda]}]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ C[n, \[Lambda]]\ HermiteH[
        n, \[Xi]]\)], "Output"]
}, Open  ]],

Cell["\<\
Transform probability density of the one-dimensional quantum oscillator to \
the dimensionless form too:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]\[Psi][n, \[Lambda], \[Xi]] = 
      FullSimplify[
        ReplaceAll[\[Psi]\[Psi][n, \[Lambda], 
            x], {x \[Rule] \[Xi]\/\@\[Lambda]}]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ C[n, \[Lambda]]\^2\ HermiteH[n, \
\[Xi]]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Normalization procedure for the wave functions of the one-dimensional \
quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider normalization procedure for wave functions.
This implies the integral condition:\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\(|\)\(\[Psi][n, \[Lambda], 
            x]\)\( | \^2\)\(\[DifferentialD]x\)\) = 1\)], "NumberedEquation"],

Cell["or for dimensionless functions:", "Text"],

Cell[BoxData[
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][n, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) = 1\)], "NumberedEquation"],

Cell[TextData[{
  "Normalize radial wave functions for different values of quantum number ",
  Cell[BoxData[
      StyleBox["n",
        FontSlant->"Italic"]]],
  " :"
}], "Text"],

Cell[TextData[Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["n",
          FontSlant->"Italic"], "=", "0"}], ",", "1", ",", "2", ",", "3", ",",
       "6", ",", "7", ",", "8", ",", "9", ",", "10"}]]]], "NumberedEquation"],

Cell[TextData[{
  "We will obtain values for constants ",
  Cell[BoxData[
      \(C[n, \[Lambda]]\)],
    FontSlant->"Italic"],
  " and normalized radial wave functions ",
  Cell[BoxData[
      \(\[Psi][n, \[Lambda], \[Xi]]\)],
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][0, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][0, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][0, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][0, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[0, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ C[0, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ C[0, \[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(\@\[Pi]\ C[0, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            0, \[Lambda]] \[Rule] \
\(-\(\[Lambda]\^\(1/4\)\/\[Pi]\^\(1/4\)\)\)}, {C[
            0, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\[Pi]\^\(1/4\)}}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          0, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\[Pi]\^\(1/4\)\) \
\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][0, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            0, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][1, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][1, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][1, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][1, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[1, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \[Xi]\ C[
        1, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(4\ \[ExponentialE]\^\(-\[Xi]\^2\)\ \[Xi]\^2\ C[1, \[Lambda]]\^2\)], \
"Output"],

Cell[BoxData[
    \(\(2\ \@\[Pi]\ C[1, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            1, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(\@2\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            1, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(\@2\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          1, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(\@2\ \
\[Pi]\^\(1/4\)\)\) 
          2\ \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \[Xi];\)\), "\
\[IndentingNewLine]", 
    \(\[Psi][1, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            1, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@2\ \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\
\(3/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][2, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][2, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][2, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][2, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[2, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-2\) + 4\ \[Xi]\^2)\)\ C[
        2, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((\(-2\) + 4\ \[Xi]\^2)\)\^2\ C[2, \
\[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(8\ \@\[Pi]\ C[2, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            2, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(2\ \@2\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            2, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(2\ \@2\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          2, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(2\ \@2\ \[Pi]\^\(1/4\
\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-2\) + 
              4\ \[Xi]\^2)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][2, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            2, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-1\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@2\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4)  ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][3, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][3, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][3, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][3, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[3, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-12\)\ \[Xi] + 
          8\ \[Xi]\^3)\)\ C[3, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((\(-12\)\ \[Xi] + 8\ \[Xi]\^3)\)\^2\ \
C[3, \[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(48\ \@\[Pi]\ C[3, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            3, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(4\ \@3\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            3, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(4\ \@3\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          3, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(4\ \@3\ \[Pi]\^\(1/4\
\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-12\)\ \[Xi] + 
              8\ \[Xi]\^3)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][3, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            3, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((\(-3\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@3\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5)  ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  4"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][4, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 4}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][4, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 4}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][4, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][4, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[4, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((12 - 48\ \[Xi]\^2 + 
          16\ \[Xi]\^4)\)\ C[4, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((12 - 48\ \[Xi]\^2 + 16\ \
\[Xi]\^4)\)\^2\ C[4, \[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(384\ \@\[Pi]\ C[4, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            4, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(8\ \@6\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            4, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(8\ \@6\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          4, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(8\ \@6\ \[Pi]\^\(1/4\
\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((12 - 48\ \[Xi]\^2 + 
              16\ \[Xi]\^4)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\[Psi][4, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            4, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((3 + 4\ x\^2\ \[Lambda]\ \((\(-3\) + x\^2\ \[Lambda])\))\)\)\/\(2\ \@6\ \
\[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6)  ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  5"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][5, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 5}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][5, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 5}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][5, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][5, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[5, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((120\ \[Xi] - 160\ \[Xi]\^3 + 
          32\ \[Xi]\^5)\)\ C[5, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((120\ \[Xi] - 160\ \[Xi]\^3 + 32\ \
\[Xi]\^5)\)\^2\ C[5, \[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(3840\ \@\[Pi]\ C[5, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            5, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(16\ \@15\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            5, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(16\ \@15\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          5, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(16\ \@15\ \
\[Pi]\^\(1/4\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((120\ \[Xi] - 
              160\ \[Xi]\^3 + 32\ \[Xi]\^5)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\[Psi][5, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            5, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((15 + 4\ x\^2\ \[Lambda]\ \((\(-5\) + x\^2\ \[Lambda])\))\)\)\/\(2\ \
\@15\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  6"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][6, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 6}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][6, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 6}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][6, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][6, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[6, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-120\) + 720\ \[Xi]\^2 - 
          480\ \[Xi]\^4 + 64\ \[Xi]\^6)\)\ C[6, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((\(-120\) + 720\ \[Xi]\^2 - 480\ \
\[Xi]\^4 + 64\ \[Xi]\^6)\)\^2\ C[6, \[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(46080\ \@\[Pi]\ C[6, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            6, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(96\ \@5\ \[Pi]\^\
\(1/4\)\)\)\)}, {C[
            6, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(96\ \@5\ \[Pi]\^\(1/4\
\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          6, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(96\ \@5\ \
\[Pi]\^\(1/4\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-120\) + 
              720\ \[Xi]\^2 - 480\ \[Xi]\^4 + 
              64\ \[Xi]\^6)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][6, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            6, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-15\) + 90\ x\^2\ \[Lambda] - 60\ x\^4\ \[Lambda]\^2 + 8\ x\^6\ \
\[Lambda]\^3)\)\)\/\(12\ \@5\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  7"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][7, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 7}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][7, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 7}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][7, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][7, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[7, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-1680\)\ \[Xi] + 
          3360\ \[Xi]\^3 - 1344\ \[Xi]\^5 + 128\ \[Xi]\^7)\)\ C[
        7, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((\(-1680\)\ \[Xi] + 3360\ \[Xi]\^3 - \
1344\ \[Xi]\^5 + 128\ \[Xi]\^7)\)\^2\ C[7, \[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(645120\ \@\[Pi]\ C[7, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            7, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(96\ \@70\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            7, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(96\ \@70\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          7, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(96\ \@70\ \
\[Pi]\^\(1/4\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-1680\)\ \[Xi] \
+ 3360\ \[Xi]\^3 - 1344\ \[Xi]\^5 + 
              128\ \[Xi]\^7)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][7, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            7, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((\(-105\) + 210\ x\^2\ \[Lambda] - 84\ x\^4\ \[Lambda]\^2 + 8\ x\^6\ \
\[Lambda]\^3)\)\)\/\(6\ \@70\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  8"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][8, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 8}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][8, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 8}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][8, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][8, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[8, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((1680 - 13440\ \[Xi]\^2 + 
          13440\ \[Xi]\^4 - 3584\ \[Xi]\^6 + 256\ \[Xi]\^8)\)\ C[
        8, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((1680 - 13440\ \[Xi]\^2 + 13440\ \
\[Xi]\^4 - 3584\ \[Xi]\^6 + 256\ \[Xi]\^8)\)\^2\ C[8, \[Lambda]]\^2\)], \
"Output"],

Cell[BoxData[
    \(\(10321920\ \@\[Pi]\ C[8, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            8, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(384\ \@70\ \[Pi]\
\^\(1/4\)\)\)\)}, {C[
            8, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(384\ \@70\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          8, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(384\ \@70\ \
\[Pi]\^\(1/4\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((1680 - 
              13440\ \[Xi]\^2 + 13440\ \[Xi]\^4 - 3584\ \[Xi]\^6 + 
              256\ \[Xi]\^8)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][8, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            8, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((105 + 8\ x\^2\ \[Lambda]\ \((\(-105\) + x\^2\ \[Lambda]\ \((105 + 2\ x\^2\ \
\[Lambda]\ \((\(-14\) + x\^2\ \[Lambda])\))\))\))\)\)\/\(24\ \@70\ \
\[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  9"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][9, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 9}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][9, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 9}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][9, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), "\[IndentingNewLine]", \

    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][9, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[9, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((30240\ \[Xi] - 
          80640\ \[Xi]\^3 + 48384\ \[Xi]\^5 - 9216\ \[Xi]\^7 + 
          512\ \[Xi]\^9)\)\ C[9, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((30240\ \[Xi] - 80640\ \[Xi]\^3 + \
48384\ \[Xi]\^5 - 9216\ \[Xi]\^7 + 512\ \[Xi]\^9)\)\^2\ C[9, \
\[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(185794560\ \@\[Pi]\ C[9, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            9, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(2304\ \@35\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            9, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(2304\ \@35\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          9, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(2304\ \@35\ \
\[Pi]\^\(1/4\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((30240\ \[Xi] - 
              80640\ \[Xi]\^3 + 48384\ \[Xi]\^5 - 9216\ \[Xi]\^7 + 
              512\ \[Xi]\^9)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][9, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            9, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((945 + 8\ x\^2\ \[Lambda]\ \((\(-315\) + x\^2\ \[Lambda]\ \((189 + 2\ x\
\^2\ \[Lambda]\ \((\(-18\) + x\^2\ \[Lambda])\))\))\))\)\)\/\(72\ \@35\ \[Pi]\
\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " =  10"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][10, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 10}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi][10, \[Lambda], \[Xi]] = 
      ReplaceAll[\[Psi]\[Psi][
          n, \[Lambda], \[Xi]], {n \[Rule] 10}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Psi]\
\[Psi][10, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\)\), \
"\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[Psi]\[Psi][10, \[Lambda], \[Xi]] \[DifferentialD]\[Xi]\) \[Equal] 1, 
      C[10, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-30240\) + 
          302400\ \[Xi]\^2 - 403200\ \[Xi]\^4 + 161280\ \[Xi]\^6 - 
          23040\ \[Xi]\^8 + 1024\ \[Xi]\^10)\)\ C[10, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Xi]\^2\)\ \((\(-30240\) + 302400\ \[Xi]\^2 - \
403200\ \[Xi]\^4 + 161280\ \[Xi]\^6 - 23040\ \[Xi]\^8 + 1024\ \[Xi]\^10)\)\^2\
\ C[10, \[Lambda]]\^2\)], "Output"],

Cell[BoxData[
    \(\(3715891200\ \@\[Pi]\ C[10, \[Lambda]]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \({{C[
            10, \[Lambda]] \[Rule] \(-\(\[Lambda]\^\(1/4\)\/\(23040\ \@7\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[
            10, \[Lambda]] \[Rule] \[Lambda]\^\(1/4\)\/\(23040\ \@7\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][
          10, \[Lambda], \[Xi]] = \(\[Lambda]\^\(1/4\)\/\(23040\ \@7\ \[Pi]\^\
\(1/4\)\)\) \[ExponentialE]\^\(-\(\[Xi]\^2\/2\)\)\ \((\(-30240\) + 
              302400\ \[Xi]\^2 - 403200\ \[Xi]\^4 + 161280\ \[Xi]\^6 - 
              23040\ \[Xi]\^8 + 
              1024\ \[Xi]\^10)\);\)\), "\[IndentingNewLine]", 
    \(\[Psi][10, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi][
            10, \[Lambda], \[Xi]], {\[Xi] \[Rule] 
              x\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-945\) + 2\ x\^2\ \[Lambda]\ \((4725 + 4\ x\^2\ \[Lambda]\ \((\(-1575\) \
+ 2\ x\^2\ \[Lambda]\ \((315 + x\^2\ \[Lambda]\ \((\(-45\) + 2\ x\^2\ \
\[Lambda])\))\))\))\))\)\)\/\(720\ \@7\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Normalized wave functions and probability densities of the one-dimensional \
quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["Resulting normalized wave functions are:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Psi][0, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][1, \[Lambda], 
          x] = \(\@2\ \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \
\[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][2, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\ \((\(-1\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@2\ \
\[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][3, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \
\[Lambda]\^\(3/4\)\ \((\(-3\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@3\ \
\[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][4, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\ \((3 + 4\ x\^2\ \[Lambda]\ \((\(-3\) + x\^2\ \
\[Lambda])\))\)\)\/\(2\ \@6\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][5, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \
\[Lambda]\^\(3/4\)\ \((15 + 4\ x\^2\ \[Lambda]\ \((\(-5\) + x\^2\ \
\[Lambda])\))\)\)\/\(2\ \@15\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][6, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\ \((\(-15\) + 90\ x\^2\ \[Lambda] - 60\ x\^4\ \[Lambda]\^2 \
+ 8\ x\^6\ \[Lambda]\^3)\)\)\/\(12\ \@5\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi][7, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \
\[Lambda]\^\(3/4\)\ \((\(-105\) + 210\ x\^2\ \[Lambda] - 84\ x\^4\ \
\[Lambda]\^2 + 8\ x\^6\ \[Lambda]\^3)\)\)\/\(6\ \@70\ \[Pi]\^\(1/4\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi][8, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\ \((105 + 8\ x\^2\ \[Lambda]\ \((\(-105\) + x\^2\ \
\[Lambda]\ \((105 + 2\ x\^2\ \[Lambda]\ \((\(-14\) + x\^2\ \
\[Lambda])\))\))\))\)\)\/\(24\ \@70\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi][9, \[Lambda], 
          x] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \
\[Lambda]\^\(3/4\)\ \((945 + 8\ x\^2\ \[Lambda]\ \((\(-315\) + x\^2\ \
\[Lambda]\ \((189 + 2\ x\^2\ \[Lambda]\ \((\(-18\) + x\^2\ \
\[Lambda])\))\))\))\)\)\/\(72\ \@35\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi][10, \[Lambda], 
          x] = \(1\/\(720\ \@7\ \[Pi]\^\(1/4\)\)\) \
\((\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-945\) + 2\ x\^2\ \[Lambda]\ \((4725 + 
                        4\ x\^2\ \[Lambda]\ \((\(-1575\) + 
                              2\ x\^2\ \[Lambda]\ \((315 + 
                                    x\^2\ \[Lambda]\ \((\(-45\) + 
                                        2\ x\^2\ \[Lambda])\))\))\))\))\))\);\
\)\)}], "Input"],

Cell["Resulting probability densities are:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Psi]\[Psi][0, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\[Lambda]\)\/\
\@\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][1, \[Lambda], 
          x]\  = \(2\ \[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\ \
\[Lambda]\^\(3/2\)\)\/\@\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][2, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\[Lambda]\ \
\((\(-1\) + 2\ x\^2\ \[Lambda])\)\^2\)\/\(2\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][3, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\ \[Lambda]\
\^\(3/2\)\ \((\(-3\) + 2\ x\^2\ \[Lambda])\)\^2\)\/\(3\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][4, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\[Lambda]\ \
\((3 + 4\ x\^2\ \[Lambda]\ \((\(-3\) + x\^2\ \[Lambda])\))\)\^2\)\/\(24\ \@\
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][5, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\ \[Lambda]\
\^\(3/2\)\ \((15 + 4\ x\^2\ \[Lambda]\ \((\(-5\) + x\^2\ \[Lambda])\))\)\^2\)\
\/\(60\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][6, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\[Lambda]\ \
\((\(-15\) + 90\ x\^2\ \[Lambda] - 60\ x\^4\ \[Lambda]\^2 + 8\ x\^6\ \
\[Lambda]\^3)\)\^2\)\/\(720\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][7, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\ \[Lambda]\
\^\(3/2\)\ \((\(-105\) + 210\ x\^2\ \[Lambda] - 84\ x\^4\ \[Lambda]\^2 + 8\ x\
\^6\ \[Lambda]\^3)\)\^2\)\/\(2520\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][8, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\[Lambda]\ \
\((105 + 8\ x\^2\ \[Lambda]\ \((\(-105\) + x\^2\ \[Lambda]\ \((105 + 2\ x\^2\ \
\[Lambda]\ \((\(-14\) + x\^2\ \[Lambda])\))\))\))\)\^2\)\/\(40320\ \@\[Pi]\);\
\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][9, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\ \[Lambda]\
\^\(3/2\)\ \((945 + 8\ x\^2\ \[Lambda]\ \((\(-315\) + x\^2\ \[Lambda]\ \((189 \
+ 2\ x\^2\ \[Lambda]\ \((\(-18\) + x\^2\ \[Lambda])\))\))\))\)\^2\)\/\(181440\
\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][10, \[Lambda], 
          x]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\[Lambda]\ \
\((\(-945\) + 2\ x\^2\ \[Lambda]\ \((4725 + 4\ x\^2\ \[Lambda]\ \((\(-1575\) \
+ 2\ x\^2\ \[Lambda]\ \((315 + x\^2\ \[Lambda]\ \((\(-45\) + 2\ x\^2\ \
\[Lambda])\))\))\))\))\)\^2\)\/\(3628800\ \@\[Pi]\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
5. General expression for normalized wave functions of the one-dimensional \
quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Normalized wave functions of the one-dimensional quantum oscillator can be \
represented in general form [see Ref. 1].\nIn this case we will use \
expressions for constant ",
  Cell[BoxData[
      \(CC[n\_rad, l\_orb, Z]\)],
    FontSlant->"Italic"],
  ":"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(C[n, \[Lambda]] = \@\(\(1\/\(2\^n\ \(n!\)\)\) \
\@\(\[Lambda]\/\[Pi]\)\)\)], "NumberedEquation"],

Cell["Thus we have", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]gen[n, \[Lambda], 
        x] = \(\@\(\(1\/\(2\^n\ \(n!\)\)\) \@\(\[Lambda]\/\[Pi]\)\)\) \
\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ HermiteH[n, 
          x\ \@\[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \@\(\(2\^\(-n\)\ \@\
\[Lambda]\)\/\(n!\)\)\ HermiteH[n, x\ \@\[Lambda]]\)\/\[Pi]\^\(1/4\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "Now we can compare general expressions to ",
  Cell[BoxData[
      StyleBox[\(\[Psi][n, \[Lambda], x]\),
        FontSlant->"Italic"]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi][0, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[0, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 0}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][1, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[1, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 1}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][2, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[2, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 2}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][3, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[3, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 3}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][4, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[4, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 4}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][5, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[5, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 5}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][6, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[6, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 6}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][7, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[7, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 7}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][8, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[8, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 8}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][9, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]gen[0, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], 
            x], {n \[Rule] 9}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi][10, \[Lambda], x]\), "\[IndentingNewLine]", 
    \(\[Psi]gen[10, \[Lambda], x] = 
      FullSimplify[
        ReplaceAll[\[Psi]gen[n, \[Lambda], x], {n \[Rule] 10}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@2\ \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\
\(3/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@2\ \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\
\(3/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-1\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@2\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-1\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@2\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((\(-3\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@3\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((\(-3\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@3\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((3 + 4\ x\^2\ \[Lambda]\ \((\(-3\) + x\^2\ \[Lambda])\))\)\)\/\(2\ \@6\ \
\[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((3 + 4\ x\^2\ \[Lambda]\ \((\(-3\) + x\^2\ \[Lambda])\))\)\)\/\(2\ \@6\ \
\[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((15 + 4\ x\^2\ \[Lambda]\ \((\(-5\) + x\^2\ \[Lambda])\))\)\)\/\(2\ \
\@15\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((15 + 4\ x\^2\ \[Lambda]\ \((\(-5\) + x\^2\ \[Lambda])\))\)\)\/\(2\ \
\@15\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-15\) + 90\ x\^2\ \[Lambda] - 60\ x\^4\ \[Lambda]\^2 + 8\ x\^6\ \
\[Lambda]\^3)\)\)\/\(12\ \@5\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-15\) + 90\ x\^2\ \[Lambda] - 60\ x\^4\ \[Lambda]\^2 + 8\ x\^6\ \
\[Lambda]\^3)\)\)\/\(12\ \@5\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((\(-105\) + 210\ x\^2\ \[Lambda] - 84\ x\^4\ \[Lambda]\^2 + 8\ x\^6\ \
\[Lambda]\^3)\)\)\/\(6\ \@70\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((\(-105\) + 210\ x\^2\ \[Lambda] - 84\ x\^4\ \[Lambda]\^2 + 8\ x\^6\ \
\[Lambda]\^3)\)\)\/\(6\ \@70\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((105 + 8\ x\^2\ \[Lambda]\ \((\(-105\) + x\^2\ \[Lambda]\ \((105 + 2\ x\^2\ \
\[Lambda]\ \((\(-14\) + x\^2\ \[Lambda])\))\))\))\)\)\/\(24\ \@70\ \
\[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((105 + 8\ x\^2\ \[Lambda]\ \((\(-105\) + x\^2\ \[Lambda]\ \((105 + 2\ x\^2\ \
\[Lambda]\ \((\(-14\) + x\^2\ \[Lambda])\))\))\))\)\)\/\(24\ \@70\ \
\[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((945 + 8\ x\^2\ \[Lambda]\ \((\(-315\) + x\^2\ \[Lambda]\ \((189 + 2\ x\
\^2\ \[Lambda]\ \((\(-18\) + x\^2\ \[Lambda])\))\))\))\)\)\/\(72\ \@35\ \[Pi]\
\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\
\)\ \((945 + 8\ x\^2\ \[Lambda]\ \((\(-315\) + x\^2\ \[Lambda]\ \((189 + 2\ x\
\^2\ \[Lambda]\ \((\(-18\) + x\^2\ \[Lambda])\))\))\))\)\)\/\(72\ \@35\ \[Pi]\
\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-945\) + 2\ x\^2\ \[Lambda]\ \((4725 + 4\ x\^2\ \[Lambda]\ \((\(-1575\) \
+ 2\ x\^2\ \[Lambda]\ \((315 + x\^2\ \[Lambda]\ \((\(-45\) + 2\ x\^2\ \
\[Lambda])\))\))\))\))\)\)\/\(720\ \@7\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-945\) + 2\ x\^2\ \[Lambda]\ \((4725 + 4\ x\^2\ \[Lambda]\ \((\(-1575\) \
+ 2\ x\^2\ \[Lambda]\ \((315 + x\^2\ \[Lambda]\ \((\(-45\) + 2\ x\^2\ \
\[Lambda])\))\))\))\))\)\)\/\(720\ \@7\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 655},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[]}, "Classroom1.nb", \
CharacterEncoding -> "WindowsCyrillic"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 190, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2740, 91, 91, 2, 85, "Section"],
Cell[2834, 95, 61, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[2920, 99, 161, 3, 75, "Input"],
Cell[3084, 104, 137, 2, 75, "Output"]
}, Open  ]],
Cell[3236, 109, 126, 6, 56, "Text"],
Cell[3365, 117, 44, 0, 56, "Text"],
Cell[3412, 119, 167, 4, 54, "NumberedEquation"],
Cell[3582, 125, 190, 8, 56, "Text"],

Cell[CellGroupData[{
Cell[3797, 137, 91, 1, 64, "Input"],
Cell[3891, 140, 129, 2, 73, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4069, 148, 114, 3, 85, "Section"],
Cell[4186, 153, 158, 3, 56, "Text"],
Cell[4347, 158, 90, 1, 76, "NumberedEquation"],

Cell[CellGroupData[{
Cell[4462, 163, 173, 4, 95, "Input"],
Cell[4638, 169, 117, 2, 73, "Output"]
}, Open  ]],
Cell[4770, 174, 128, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[4923, 181, 185, 4, 95, "Input"],
Cell[5111, 187, 109, 2, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5269, 195, 167, 5, 85, "Section"],
Cell[5439, 202, 113, 3, 92, "Text"],
Cell[5555, 207, 170, 2, 72, "NumberedEquation"],
Cell[5728, 211, 47, 0, 56, "Text"],
Cell[5778, 213, 171, 2, 77, "NumberedEquation"],
Cell[5952, 217, 179, 6, 56, "Text"],
Cell[6134, 225, 234, 5, 50, "NumberedEquation"],
Cell[6371, 232, 271, 10, 56, "Text"],

Cell[CellGroupData[{
Cell[6667, 246, 107, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[6799, 256, 643, 12, 212, "Input"],
Cell[7445, 270, 88, 1, 73, "Output"],
Cell[7536, 273, 84, 1, 67, "Output"],
Cell[7623, 276, 78, 1, 104, "Output"],
Cell[7704, 279, 197, 5, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7938, 289, 348, 8, 124, "Input"],
Cell[8289, 299, 124, 2, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8462, 307, 107, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[8594, 317, 643, 12, 212, "Input"],
Cell[9240, 331, 107, 2, 73, "Output"],
Cell[9350, 335, 99, 2, 67, "Output"],
Cell[9452, 339, 81, 1, 104, "Output"],
Cell[9536, 342, 215, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9788, 352, 380, 10, 136, "Input"],
Cell[10171, 364, 132, 2, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10352, 372, 108, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[10485, 382, 643, 12, 212, "Input"],
Cell[11131, 396, 125, 2, 73, "Output"],
Cell[11259, 400, 117, 2, 67, "Output"],
Cell[11379, 404, 81, 1, 104, "Output"],
Cell[11463, 407, 221, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11721, 417, 403, 9, 136, "Input"],
Cell[12127, 428, 168, 2, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12344, 436, 109, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[12478, 446, 643, 12, 212, "Input"],
Cell[13124, 460, 135, 2, 73, "Output"],
Cell[13262, 464, 125, 2, 67, "Output"],
Cell[13390, 468, 82, 1, 104, "Output"],
Cell[13475, 471, 221, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13733, 481, 411, 9, 136, "Input"],
Cell[14147, 492, 171, 2, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14367, 500, 109, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[14501, 510, 643, 12, 212, "Input"],
Cell[15147, 524, 139, 2, 73, "Output"],
Cell[15289, 528, 129, 2, 67, "Output"],
Cell[15421, 532, 83, 1, 104, "Output"],
Cell[15507, 535, 221, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15765, 545, 417, 9, 136, "Input"],
Cell[16185, 556, 200, 3, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16434, 565, 109, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[16568, 575, 643, 12, 212, "Input"],
Cell[17214, 589, 148, 2, 73, "Output"],
Cell[17365, 593, 138, 2, 67, "Output"],
Cell[17506, 597, 84, 1, 104, "Output"],
Cell[17593, 600, 225, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17855, 610, 428, 9, 136, "Input"],
Cell[18286, 621, 205, 3, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18540, 630, 108, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[18673, 640, 643, 12, 212, "Input"],
Cell[19319, 654, 162, 2, 73, "Output"],
Cell[19484, 658, 152, 2, 67, "Output"],
Cell[19639, 662, 85, 1, 104, "Output"],
Cell[19727, 665, 223, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19987, 675, 454, 10, 136, "Input"],
Cell[20444, 687, 225, 3, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20718, 696, 108, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[20851, 706, 643, 12, 212, "Input"],
Cell[21497, 720, 182, 3, 73, "Output"],
Cell[21682, 725, 163, 2, 67, "Output"],
Cell[21848, 729, 86, 1, 104, "Output"],
Cell[21937, 732, 225, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22199, 742, 453, 10, 136, "Input"],
Cell[22655, 754, 230, 3, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22934, 763, 108, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[23067, 773, 643, 12, 212, "Input"],
Cell[23713, 787, 189, 3, 73, "Output"],
Cell[23905, 792, 172, 3, 67, "Output"],
Cell[24080, 797, 88, 1, 104, "Output"],
Cell[24171, 800, 227, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24435, 810, 474, 10, 136, "Input"],
Cell[24912, 822, 273, 4, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25234, 832, 109, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[25368, 842, 643, 12, 212, "Input"],
Cell[26014, 856, 199, 3, 73, "Output"],
Cell[26216, 861, 180, 3, 67, "Output"],
Cell[26399, 866, 89, 1, 104, "Output"],
Cell[26491, 869, 229, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26757, 879, 483, 10, 136, "Input"],
Cell[27243, 891, 276, 4, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27568, 901, 110, 6, 89, "Subsection"],

Cell[CellGroupData[{
Cell[27703, 911, 650, 12, 212, "Input"],
Cell[28356, 925, 222, 3, 73, "Output"],
Cell[28581, 930, 203, 3, 67, "Output"],
Cell[28787, 935, 91, 1, 104, "Output"],
Cell[28881, 938, 231, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29149, 948, 523, 11, 161, "Input"],
Cell[29675, 961, 315, 4, 108, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30051, 972, 172, 5, 85, "Section"],
Cell[30226, 979, 103, 2, 56, "Text"],
Cell[30332, 983, 2937, 53, 949, "Input"],
Cell[33272, 1038, 99, 2, 56, "Text"],
Cell[33374, 1042, 2693, 45, 874, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36104, 1092, 169, 5, 85, "Section"],
Cell[36276, 1099, 334, 10, 92, "Text"],
Cell[36613, 1111, 116, 2, 104, "NumberedEquation"],
Cell[36732, 1115, 75, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[36832, 1121, 218, 4, 116, "Input"],
Cell[37053, 1127, 177, 3, 124, "Output"]
}, Open  ]],
Cell[37245, 1133, 173, 6, 56, "Text"],

Cell[CellGroupData[{
Cell[37443, 1143, 2727, 64, 838, "Input"],
Cell[40173, 1209, 124, 2, 98, "Output"],
Cell[40300, 1213, 124, 2, 98, "Output"],
Cell[40427, 1217, 132, 2, 98, "Output"],
Cell[40562, 1221, 132, 2, 98, "Output"],
Cell[40697, 1225, 168, 2, 108, "Output"],
Cell[40868, 1229, 168, 2, 108, "Output"],
Cell[41039, 1233, 171, 2, 108, "Output"],
Cell[41213, 1237, 171, 2, 108, "Output"],
Cell[41387, 1241, 200, 3, 108, "Output"],
Cell[41590, 1246, 200, 3, 108, "Output"],
Cell[41793, 1251, 205, 3, 108, "Output"],
Cell[42001, 1256, 205, 3, 108, "Output"],
Cell[42209, 1261, 225, 3, 108, "Output"],
Cell[42437, 1266, 225, 3, 108, "Output"],
Cell[42665, 1271, 230, 3, 108, "Output"],
Cell[42898, 1276, 230, 3, 108, "Output"],
Cell[43131, 1281, 273, 4, 108, "Output"],
Cell[43407, 1287, 273, 4, 108, "Output"],
Cell[43683, 1293, 276, 4, 108, "Output"],
Cell[43962, 1299, 276, 4, 108, "Output"],
Cell[44241, 1305, 315, 4, 108, "Output"],
Cell[44559, 1311, 315, 4, 108, "Output"]
}, Open  ]],
Cell[44889, 1318, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

