(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    127585,       2445]*)
(*NotebookOutlinePosition[    128314,       2470]*)
(*  CellTagsIndexPosition[    128270,       2466]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.2. One-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.2.6. Comparative visualization of the Wave Functions and Probability \
Densities of the Two-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial wave functions, radial probability densities and \
probability densities of the two-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["In this file we will present visualizations in ",
    FontWeight->"Bold"],
  StyleBox["unified",
    FontWeight->"Bold"],
  StyleBox[" scales for all states defined by given quantum numbers.",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the two-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)]],
  ",\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["Graphics`FilledPlot`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool in this part to give vivid presentation of functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input"],

Cell["\<\
Determine parameter \[Lambda] of the two-dimensional quantum oscillator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\[Lambda] = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
two-dimensional quantum oscillator for given quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \@\[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ r\ \[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[0, 1, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[Lambda]] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\
\^2\ \[Lambda]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 
          2, \[Lambda]] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^2\)\/\@3;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda]] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \@\[Lambda]\ \((1 - r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((1 - \
r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[Lambda]] = \(-\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\
\)\ r\ \[Lambda]\ \((\(-2\) + 
              r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 
          1, \[Lambda]] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((\(-3\) + 
                    r\^2\ \[Lambda])\)\)\/\@3\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda]] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-3\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^3\ \[Lambda]\^2\ \((\(-4\) + 
                    r\^2\ \[Lambda])\)\)\/\(2\ \@3\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda]] = 
        1\/12\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-4\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((2 + r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \
\[Lambda])\))\)\)\/\@2;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda]] = 
        1\/2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((2 + \
r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\)\/\@6;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda]] = 
        1\/6\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^2\ \[Lambda]\^\(3/2\)\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-2\) + r\^2\ \
\[Lambda])\)\)\/\(2\ \@6\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 2, \[Lambda]] = 
        1\/24\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^2\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\
\)\)\/\(2\ \@30\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda]] = 
        1\/120\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\
\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((6 - r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \
\((\(-3\) + r\^2\ \[Lambda])\))\)\)\/\(3\ \@2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda]] = 
        1\/18\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((6 \
- r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \
\[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\ \[Lambda]\ \((\(-24\) + 
                    r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\)\/\
\(6\ \@2\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda]] = 
        1\/72\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[Lambda]] = \@10\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((1 - 
              1\/60\ r\^2\ \[Lambda]\ \((60 + 
                    r\^2\ \[Lambda]\ \((\(-15\) + 
                          r\^2\ \[Lambda])\))\))\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda]] = 
        10\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \[Lambda]\ \((\(-15\) + r\^2\ \
\[Lambda])\))\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[Lambda]] = \(-\(1\/\(12\ \@15\)\)\) \
\((\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^2\ \
\((\(-120\) + r\^2\ \[Lambda]\ \((90 + 
                        r\^2\ \[Lambda]\ \((\(-18\) + 
                              r\^2\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 
          3, \[Lambda]] = \(1\/2160\) \((\[ExponentialE]\^\(\(-r\^2\)\ \
\[Lambda]\)\ r\^7\ \[Lambda]\^4\ \((\(-120\) + r\^2\ \[Lambda]\ \((90 + r\^2\ \
\[Lambda]\ \((\(-18\) + r\^2\ \[Lambda])\))\))\)\^2)\);\)\)}], "Input"],

Cell["\<\
Normalized probability densities of the two-dimensional quantum oscillator \
for given quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\)\/\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\)\/\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\)\/\(2\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\)\/\(6\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((1 - r\^2\ \[Lambda])\)\^2\)\/\[Pi];\)\), "\[IndentingNewLine]", \

    \(\(\[Psi]\[Psi]\_Oscl[1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2\)\/\(2\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\ \((\(-3\) + r\^2\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\ \((\(-4\) + r\^2\ \[Lambda])\)\^2\)\/\(24\ \[Pi]\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((2 + r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(12\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\ \((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\
\)\^2\)\/\(48\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(240\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((6 - r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) \
+ r\^2\ \[Lambda])\))\)\^2\)\/\(36\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\)\^2)\)\^2\)\/\(144\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          2, \[Lambda]] = \(1\/\[Pi]\) \((5\ \[ExponentialE]\^\(\(-r\^2\)\ \
\[Lambda]\)\ r\^5\ \[Lambda]\^3\ \((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \
\[Lambda]\ \((\(-15\) + r\^2\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          3, \[Lambda]] = \(1\/\(4320\ \[Pi]\)\) \
\((\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \((\(-120\) \
+ r\^2\ \[Lambda]\ \((90 + r\^2\ \[Lambda]\ \((\(-18\) + r\^2\ \
\[Lambda])\))\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2. ",
  StyleBox["Visualization ",
    TextAlignment->Left,
    TextJustification->0],
  "of the wave functions and probability densities of the quantum oscillator"
}], "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the two-dimensional \
quantum oscillator.
We will obtain two-dimensional plots for radial  functions and radial \
probability densities and present density and surface (three-dimensional) \
plots for probability densities of the two-dimensional quantum oscillator.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(IS2dHorz = 325;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 325;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dAllHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dAllVert = 600;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(\(VP3 = 1.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(WP2 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(\(WP3 = 3.000;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(AR = 3/4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(x2dMax = 5;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.85\);\)\), "\[IndentingNewLine]", 
    \(\(PR2dMax = 1.775;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(y3dMax = 5;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 0.15;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0, m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=0, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=0, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=0, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=0, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=0, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=0, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=0, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=0, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=0, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=0, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=0, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=0, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=0, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=0, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=0, \!\(m\_azm\)=2\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=0, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=0, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=0, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=0, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=0, \!\(m\_azm\)=3\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6",
  ")",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 1, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7",
  ")",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 1, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=2\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8",
  ")",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 1, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=1, \!\(m\_azm\)=3\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\  = 2, m\_azm\  = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=2, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\  = 2, m\_azm\  = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=2, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11",
  ")",
  " ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for for \!\(n\_rad\)=2, \!\(m\_azm\)=2\>\
\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=2, \!\(m\_azm\)=3\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 0\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=0\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=1\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=2\>\""]\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, m\_azm, \[Lambda]], 
            RR\_Oscl[n\_rad, m\_azm, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial functions \
for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision \
for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Density \
vision for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D vision for \
\!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of wave function for \!\(n\_rad\)=3, \!\(m\_azm\)=3\>\""]\
\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparative visualization of the wave functions and probability densities \
of the two-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations in unified scales for all states defined by \
given quantum numbers.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[0, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[0, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[0, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[0, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[1, 0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[1, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[1, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[1, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[2, 0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[2, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[2, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[2, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[3, 0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[3, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[3, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]{Grph3dDEN\
\[Psi]\[Psi]xy\_Oscl[3, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}}], \[IndentingNewLine]\[IndentingNewLine]Background \
\[Rule] RGBColor[0.2, 0.475, 0.2], \[IndentingNewLine]ImageSize \[Rule] {820, 
          4000}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of wave \
function of the One-dimentional quantum oscillator\>"]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 204, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2754, 91, 209, 5, 119, "Section"],
Cell[2966, 98, 303, 9, 56, "Text"],
Cell[3272, 109, 163, 5, 56, "Text"],
Cell[3438, 116, 145, 6, 72, "NumberedEquation"],
Cell[3586, 124, 293, 9, 57, "Text"],
Cell[3882, 135, 56, 1, 63, "Input"],
Cell[3941, 138, 143, 4, 56, "Text"],
Cell[4087, 144, 61, 1, 63, "Input"],
Cell[4151, 147, 215, 5, 80, "Text"],
Cell[4369, 154, 7007, 138, 2179, "Input"],
Cell[11379, 294, 182, 5, 56, "Text"],
Cell[11564, 301, 3555, 65, 1059, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15156, 371, 245, 8, 85, "Section"],
Cell[15404, 381, 520, 9, 176, "Text"],
Cell[15927, 392, 666, 17, 452, "Text"],
Cell[16596, 411, 1511, 30, 888, "Input"],

Cell[CellGroupData[{
Cell[18132, 445, 93, 4, 89, "Subsection"],
Cell[18228, 451, 6071, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24336, 558, 197, 12, 89, "Subsection"],
Cell[24536, 572, 6066, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30639, 679, 197, 12, 89, "Subsection"],
Cell[30839, 693, 6066, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36942, 800, 185, 10, 89, "Subsection"],
Cell[37130, 812, 6066, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43233, 919, 197, 12, 89, "Subsection"],
Cell[43433, 933, 6070, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49540, 1040, 116, 5, 89, "Subsection"],
Cell[49659, 1047, 6070, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55766, 1154, 116, 5, 89, "Subsection"],
Cell[55885, 1161, 6070, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61992, 1268, 116, 5, 89, "Subsection"],
Cell[62111, 1275, 6070, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68218, 1382, 109, 6, 89, "Subsection"],
Cell[68330, 1390, 6070, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74437, 1497, 110, 6, 89, "Subsection"],
Cell[74550, 1505, 6070, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80657, 1612, 124, 6, 89, "Subsection"],
Cell[80784, 1620, 6090, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86911, 1727, 112, 4, 89, "Subsection"],
Cell[87026, 1733, 6066, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93129, 1840, 112, 4, 89, "Subsection"],
Cell[93244, 1846, 6066, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99347, 1953, 112, 4, 89, "Subsection"],
Cell[99462, 1959, 6066, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105565, 2066, 112, 4, 89, "Subsection"],
Cell[105680, 2072, 6066, 102, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111783, 2179, 112, 4, 89, "Subsection"],
Cell[111898, 2185, 6066, 102, 2048, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[118013, 2293, 194, 5, 119, "Section"],
Cell[118210, 2300, 169, 5, 56, "Text"],
Cell[118382, 2307, 9168, 133, 2563, "Input"],
Cell[127553, 2442, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

