(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     73673,       2051]*)
(*NotebookOutlinePosition[     74402,       2076]*)
(*  CellTagsIndexPosition[     74358,       2072]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.3. Radial probability density and normalization of the radial wave \
functions of Three-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Radial probability density of the three-dimensional quantum oscillator\
\>", "Section"],

Cell["\<\
Consider radial wave function of the three-dimensional quantum oscillator:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, l\_orb, \[Lambda], r] = 
      C[n\_rad, l\_orb] \((r^l\_orb)\)*Exp[\(-\((\[Lambda]*r^2)\)\)/2]*\ 
        Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, 
          r\^2\ \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ C[n\_rad, 
        l\_orb]\ Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, 
        r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb]\)],
    FontSlant->"Italic"],
  "are constants."
}], "Text"],

Cell["\<\
Define radial probability density of the three-dimensional quantum \
oscillator:\
\>", "Text"],

Cell[BoxData[
    \(RR[n\_rad, l\_orb, \[Lambda], 
        r] = \(\(|\)\(R[n\_rad, l\_orb, \[Lambda], 
          r]\)\( | \^2\)\(\ \)\(r\^2\)\)\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(R[n\_rad, l\_orb, \[Lambda], r]\)],
    FontSlant->"Italic"],
  "is real ",
  "function we have"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, l\_orb, \[Lambda], r] = 
      FullSimplify[\((R[n\_rad, l\_orb, \[Lambda], r] r)\)\^2]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^\(2\ \((1 + l\_orb)\)\)\ \
C[n\_rad, l\_orb]\^2\ Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, r\^2\ \
\[Lambda]]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Dimensionless form of the radial wave functions of quantum oscillator\
\>", "Section"],

Cell[TextData[{
  "Transform  radial wave function of ",
  "the three-dimensional quantum oscillator",
  " to the dimensionless form using new dimensionless variable \[Rho] and \
constant ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb, \[Lambda]]\)],
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Rho] = r \@ \[Lambda], r = \[Rho]\/\@\[Lambda]\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, l\_orb, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          R[n\_rad, l\_orb, \[Lambda], 
            r], {r \[Rule] \[Rho]\/\@\[Lambda]}]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\((\[Rho]\/\@\[Lambda])\)\^l\_orb\ C[n\_rad, 
        l\_orb]\ Hypergeometric1F1[\(-n\_rad\), 
        3\/2 + l\_orb, \[Rho]\^2]\)], "Output"]
}, Open  ]],

Cell["\<\
Transform  radial probability density of the three-dimensional quantum \
oscillator to the dimensionless form too:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, l\_orb, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          RR[n\_rad, l\_orb, \[Lambda], 
            r], {r \[Rule] \[Rho]\/\@\[Lambda]}]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Rho]\^2\)\ \((\[Rho]\/\@\[Lambda])\)\^\(2\ \((1 + \
l\_orb)\)\)\ C[n\_rad, l\_orb]\^2\ Hypergeometric1F1[\(-n\_rad\), 3\/2 + \
l\_orb, \[Rho]\^2]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Normalization procedure for the radial wave functions of the \
three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider normalization procedure for radial wave functions. This implies the \
integral condition:\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] RR[n\_rad, l\_orb, \[Lambda], 
            r] \[DifferentialD]r = 1\)], "NumberedEquation"],

Cell["or for dimensionless radial functions:", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] RR1[n\_rad, 
            l\_orb, \[Rho]] \[DifferentialD]r = \(\(1\/\@\[Lambda]\) \(\
\[Integral]\_0\%\[Infinity] RR1[n\_rad, 
                l\_orb, \[Rho]] \[DifferentialD]\[Rho]\) = 
        1\)\)], "NumberedEquation"],

Cell["\<\
Normalize radial wave functions for different values of quantum numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox[\(n\_rad\),
        FontSlant->"Italic"]]],
  " = 0, 1, 2, 3\n",
  Cell[BoxData[
      \(l\_orb\)]],
  " = 0, 1, 2, 3"
}], "NumberedEquation"],

Cell[TextData[{
  "We will obtain values for constants ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb]\)],
    FontSlant->"Italic"],
  " and normalized radial wave functions ",
  Cell[BoxData[
      \(R\_Nrm[0, 0, r]\)],
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[0, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ C[0, 0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^2\ C[0, \
0]\^2\)\/\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\@\[Pi]\ C[0, 0]\^2\)\/\(4\ \[Lambda]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[0, 
            0] \[Rule] \(-\(\(2\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)\)\)}, \
{C[0, 0] \[Rule] \(2\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        0, \[Rho]] = \(\(2\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[0, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 0, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\
\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[0, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ C[0, \
1]\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^4\ C[0, \
1]\^2\)\/\[Lambda]\^2\)], "Output"],

Cell[BoxData[
    \(\(3\ \@\[Pi]\ C[0, 1]\^2\)\/\(8\ \[Lambda]\^\(5/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[0, 
            1] \[Rule] \(-\(\(2\ \@\(2\/3\)\ \
\[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)\)\)}, {C[0, 
            1] \[Rule] \(2\ \@\(2\/3\)\ \
\[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        1, \[Rho]] = \(\(2\ \@\(2\/3\)\ \
\[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\
\)\ \[Rho]\)\/\@\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[0, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 1, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \[Rho]\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \
\[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[0, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ C[0, 2]\)\/\
\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^6\ C[0, \
2]\^2\)\/\[Lambda]\^3\)], "Output"],

Cell[BoxData[
    \(\(15\ \@\[Pi]\ C[0, 2]\^2\)\/\(16\ \[Lambda]\^\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[0, 
            2] \[Rule] \(-\(\(4\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\(1/4\)\
\)\)\)}, {C[0, 
            2] \[Rule] \(4\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        2, \[Rho]] = \(\(4\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\(1/4\)\)\) \
\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\)\/\[Lambda]\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[0, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 2, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\)\ \[Rho]\
\^2\)\/\(\@15\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[0, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ C[0, 3]\)\/\
\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^8\ C[0, \
3]\^2\)\/\[Lambda]\^4\)], "Output"],

Cell[BoxData[
    \(\(105\ \@\[Pi]\ C[0, 3]\^2\)\/\(32\ \[Lambda]\^\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[0, 
            3] \[Rule] \(-\(\(4\ \@\(2\/105\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\)\)}, {C[0, 
            3] \[Rule] \(4\ \@\(2\/105\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        3, \[Rho]] = \(\(4\ \@\(2\/105\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\
\)\ \[Rho]\^3\)\/\[Lambda]\^\(3/2\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[0, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 3, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(4\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \[Rho]\^3\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[1, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - \(2\ \[Rho]\^2\)\/3)\)\ \
C[1, 0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^2\ \((1 - \(2\ \
\[Rho]\^2\)\/3)\)\^2\ C[1, 0]\^2\)\/\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\@\[Pi]\ C[1, 0]\^2\)\/\(6\ \[Lambda]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 
            0] \[Rule] \(-\(\(\@6\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)\)\)}, \
{C[1, 0] \[Rule] \(\@6\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 
        0, \[Rho]] = \(\(\@6\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - \(2\ \[Rho]\^2\)\/3)\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[1, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 0, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@6\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\)\ \((1 \
- \(2\ \[Rho]\^2\)\/3)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@6\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\)\/\[Pi]\^\(1/4\)\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[1, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \(2\ \[Rho]\^2\
\)\/5)\)\ C[1, 1]\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^4\ \((1 - \(2\ \
\[Rho]\^2\)\/5)\)\^2\ C[1, 1]\^2\)\/\[Lambda]\^2\)], "Output"],

Cell[BoxData[
    \(\(3\ \@\[Pi]\ C[1, 1]\^2\)\/\(20\ \[Lambda]\^\(5/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 
            1] \[Rule] \(-\(\(2\ \@5\ \[Lambda]\^\(5/4\)\)\/\(\@3\ \
\[Pi]\^\(1/4\)\)\)\)}, {C[1, 
            1] \[Rule] \(2\ \@5\ \[Lambda]\^\(5/4\)\)\/\(\@3\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 
        1, \[Rho]] = \(\(2\ \@5\ \[Lambda]\^\(5/4\)\)\/\(\@3\ \
\[Pi]\^\(1/4\)\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \
\(2\ \[Rho]\^2\)\/5)\)\)\/\@\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[1, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 1, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \@\(5\/3\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \[Rho]\ \((1 - \(2\ \
\[Rho]\^2\)\/5)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \
\[Lambda]\^\(5/4\)\ \((\(-5\) + 
                2\ r\^2\ \[Lambda])\)\)\/\(\@15\ \[Pi]\^\(1/4\)\)\)\)\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[1, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \(2\ \[Rho]\
\^2\)\/7)\)\ C[1, 2]\)\/\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^6\ \((1 - \(2\ \
\[Rho]\^2\)\/7)\)\^2\ C[1, 2]\^2\)\/\[Lambda]\^3\)], "Output"],

Cell[BoxData[
    \(\(15\ \@\[Pi]\ C[1, 2]\^2\)\/\(56\ \[Lambda]\^\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 
            2] \[Rule] \(-\(\(2\ \@\(14\/15\)\ \
\[Lambda]\^\(7/4\)\)\/\[Pi]\^\(1/4\)\)\)}, {C[1, 
            2] \[Rule] \(2\ \@\(14\/15\)\ \
\[Lambda]\^\(7/4\)\)\/\[Pi]\^\(1/4\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 
        2, \[Rho]] = \(\(2\ \@\(14\/15\)\ \
\[Lambda]\^\(7/4\)\)\/\[Pi]\^\(1/4\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\
\)\ \[Rho]\^2\ \((1 - \(2\ \[Rho]\^2\)\/7)\)\)\/\[Lambda]\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[1, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 2, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \@\(14\/15\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \[Rho]\^2\ \((1 - \(2\ \
\[Rho]\^2\)\/7)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 
                2\ r\^2\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[1, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \(2\ \[Rho]\
\^2\)\/9)\)\ C[1, 3]\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^8\ \((1 - \(2\ \
\[Rho]\^2\)\/9)\)\^2\ C[1, 3]\^2\)\/\[Lambda]\^4\)], "Output"],

Cell[BoxData[
    \(\(35\ \@\[Pi]\ C[1, 3]\^2\)\/\(48\ \[Lambda]\^\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 
            3] \[Rule] \(-\(\(4\ \@\(3\/35\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\)\)}, {C[1, 
            3] \[Rule] \(4\ \@\(3\/35\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 
        3, \[Rho]] = \(\(4\ \@\(3\/35\)\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\
\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \(2\ \[Rho]\^2\
\)\/9)\)\)\/\[Lambda]\^\(3/2\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[1, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 3, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(4\ \@\(3\/35\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \[Rho]\^3\ \((1 - \(2\ \
\[Rho]\^2\)\/9)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \@\(3\/35\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\)\/\[Pi]\^\(1/4\
\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[2, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - \(4\ \[Rho]\^2\)\/3 + \
\(4\ \[Rho]\^4\)\/15)\)\ C[2, 0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^2\ \((1 - \(4\ \
\[Rho]\^2\)\/3 + \(4\ \[Rho]\^4\)\/15)\)\^2\ C[2, 0]\^2\)\/\[Lambda]\)], \
"Output"],

Cell[BoxData[
    \(\(2\ \@\[Pi]\ C[2, 0]\^2\)\/\(15\ \[Lambda]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 
            0] \[Rule] \(\@\(15\/2\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)}, \
{C[2, 0] \[Rule] \(-\(\(\@15\ \[Lambda]\^\(3/4\)\)\/\(\@2\ \[Pi]\^\(1/4\)\)\)\
\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        0, \[Rho]] = \(\(\@\(15\/2\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - \(4\ \[Rho]\^2\)\/3 + \(4\ \
\[Rho]\^4\)\/15)\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 0, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(15\/2\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\
\)\ \((1 - \(4\ \[Rho]\^2\)\/3 + \(4\ \
\[Rho]\^4\)\/15)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \
\((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \[Lambda])\))\)\)\/\(\@30\ \
\[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[2, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \(4\ \[Rho]\^2\
\)\/5 + \(4\ \[Rho]\^4\)\/35)\)\ C[2, 1]\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^4\ \((1 - \(4\ \
\[Rho]\^2\)\/5 + \(4\ \[Rho]\^4\)\/35)\)\^2\ C[2, 1]\^2\)\/\[Lambda]\^2\)], \
"Output"],

Cell[BoxData[
    \(\(3\ \@\[Pi]\ C[2, 1]\^2\)\/\(35\ \[Lambda]\^\(5/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 
            1] \[Rule] \(\@\(35\/3\)\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)}, \
{C[2, 1] \[Rule] \(-\(\(\@35\ \[Lambda]\^\(5/4\)\)\/\(\@3\ \[Pi]\^\(1/4\)\)\)\
\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        1, \[Rho]] = \(\(\@\(35\/3\)\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)\) \
\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \(4\ \[Rho]\^2\)\/5 \
+ \(4\ \[Rho]\^4\)\/35)\)\)\/\@\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 1, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(35\/3\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\
\)\ \[Rho]\ \((1 - \(4\ \[Rho]\^2\)\/5 + \(4\ \
\[Rho]\^4\)\/35)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\
\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \[Lambda])\))\)\)\/\(\@105\ \
\[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[2, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \(4\ \[Rho]\
\^2\)\/7 + \(4\ \[Rho]\^4\)\/63)\)\ C[2, 2]\)\/\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^6\ \((1 - \(4\ \
\[Rho]\^2\)\/7 + \(4\ \[Rho]\^4\)\/63)\)\^2\ C[2, 2]\^2\)\/\[Lambda]\^3\)], \
"Output"],

Cell[BoxData[
    \(\(5\ \@\[Pi]\ C[2, 2]\^2\)\/\(42\ \[Lambda]\^\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 
            2] \[Rule] \(\@\(42\/5\)\ \[Lambda]\^\(7/4\)\)\/\[Pi]\^\(1/4\)}, \
{C[2, 2] \[Rule] \(-\(\(\@42\ \[Lambda]\^\(7/4\)\)\/\(\@5\ \[Pi]\^\(1/4\)\)\)\
\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        2, \[Rho]] = \(\(\@\(42\/5\)\ \[Lambda]\^\(7/4\)\)\/\[Pi]\^\(1/4\)\) \
\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \(4\ \
\[Rho]\^2\)\/7 + \(4\ \[Rho]\^4\)\/63)\)\)\/\[Lambda]\), \
"\[IndentingNewLine]", 
    \(R\_Nrm[2, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 2, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(42\/5\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\
\)\ \[Rho]\^2\ \((1 - \(4\ \[Rho]\^2\)\/7 + \(4\ \
\[Rho]\^4\)\/63)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \
\[Lambda])\))\)\)\/\(3\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[2, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \(4\ \[Rho]\
\^2\)\/9 + \(4\ \[Rho]\^4\)\/99)\)\ C[2, 3]\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^8\ \((1 - \(4\ \
\[Rho]\^2\)\/9 + \(4\ \[Rho]\^4\)\/99)\)\^2\ C[2, 3]\^2\)\/\[Lambda]\^4\)], \
"Output"],

Cell[BoxData[
    \(\(35\ \@\[Pi]\ C[2, 3]\^2\)\/\(132\ \[Lambda]\^\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 
            3] \[Rule] \(-\(\(2\ \@\(33\/35\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\)\)}, {C[2, 
            3] \[Rule] \(2\ \@\(33\/35\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        3, \[Rho]] = \(\(2\ \@\(33\/35\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\
\)\ \[Rho]\^3\ \((1 - \(4\ \[Rho]\^2\)\/9 + \(4\ \[Rho]\^4\)\/99)\)\)\/\
\[Lambda]\^\(3/2\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 3, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \@\(33\/35\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \[Rho]\^3\ \((1 - \(4\ \[Rho]\^2\)\/9 + \(4\ \
\[Rho]\^4\)\/99)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\
\))\)\)\/\(3\ \@1155\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[3, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - 
          2\ \[Rho]\^2 + \(4\ \[Rho]\^4\)\/5 - \(8\ \[Rho]\^6\)\/105)\)\ C[3, 
        0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^2\ \((1 - 2\ \[Rho]\^2 + \(4\
\ \[Rho]\^4\)\/5 - \(8\ \[Rho]\^6\)\/105)\)\^2\ C[3, 0]\^2\)\/\[Lambda]\)], \
"Output"],

Cell[BoxData[
    \(\(4\ \@\[Pi]\ C[3, 0]\^2\)\/\(35\ \[Lambda]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 
            0] \[Rule] \(-\(\(\@35\ \[Lambda]\^\(3/4\)\)\/\(2\ \[Pi]\^\(1/4\)\
\)\)\)}, {C[3, 
            0] \[Rule] \(\@35\ \[Lambda]\^\(3/4\)\)\/\(2\ \
\[Pi]\^\(1/4\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 
        0, \[Rho]] = \(\(\@35\ \[Lambda]\^\(3/4\)\)\/\(2\ \[Pi]\^\(1/4\)\)\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - 
            2\ \[Rho]\^2 + \(4\ \[Rho]\^4\)\/5 - \(8\ \[Rho]\^6\)\/105)\)\), \
"\[IndentingNewLine]", 
    \(R\_Nrm[3, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 0, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@35\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\)\ \
\((1 - 2\ \[Rho]\^2 + \(4\ \[Rho]\^4\)\/5 - \(8\ \[Rho]\^6\)\/105)\)\)\/\(2\ \
\[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\@35\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((1 - 2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\)\/5 \
- \(8\ r\^6\ \[Lambda]\^3\)\/105)\)\)\/\(2\ \[Pi]\^\(1/4\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[3, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \(6\ \[Rho]\^2\
\)\/5 + \(12\ \[Rho]\^4\)\/35 - \(8\ \[Rho]\^6\)\/315)\)\ C[3, 1]\)\/\@\
\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^4\ \((1 - \(6\ \
\[Rho]\^2\)\/5 + \(12\ \[Rho]\^4\)\/35 - \(8\ \[Rho]\^6\)\/315)\)\^2\ C[3, 1]\
\^2\)\/\[Lambda]\^2\)], "Output"],

Cell[BoxData[
    \(\(2\ \@\[Pi]\ C[3, 1]\^2\)\/\(35\ \[Lambda]\^\(5/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 
            1] \[Rule] \(\@\(35\/2\)\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)}, \
{C[3, 1] \[Rule] \(-\(\(\@35\ \[Lambda]\^\(5/4\)\)\/\(\@2\ \[Pi]\^\(1/4\)\)\)\
\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 
        1, \[Rho]] = \(\(\@\(35\/2\)\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\)\) \
\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \(6\ \[Rho]\^2\)\/5 \
+ \(12\ \[Rho]\^4\)\/35 - \(8\ \[Rho]\^6\)\/315)\)\)\/\@\[Lambda]\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[3, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 1, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(35\/2\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\
\)\ \[Rho]\ \((1 - \(6\ \[Rho]\^2\)\/5 + \(12\ \[Rho]\^4\)\/35 - \(8\ \
\[Rho]\^6\)\/315)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\
\(5/4\)\ \((\(-315\) + 
                2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 
                      4\ r\^4\ \[Lambda]\^2)\))\)\)\/\(9\ \@70\ \
\[Pi]\^\(1/4\)\)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[3, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \(6\ \[Rho]\
\^2\)\/7 + \(4\ \[Rho]\^4\)\/21 - \(8\ \[Rho]\^6\)\/693)\)\ C[3, 2]\)\/\
\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^6\ \((1 - \(6\ \
\[Rho]\^2\)\/7 + \(4\ \[Rho]\^4\)\/21 - \(8\ \[Rho]\^6\)\/693)\)\^2\ C[3, \
2]\^2\)\/\[Lambda]\^3\)], "Output"],

Cell[BoxData[
    \(\(5\ \@\[Pi]\ C[3, 2]\^2\)\/\(77\ \[Lambda]\^\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 
            2] \[Rule] \(\@\(77\/5\)\ \[Lambda]\^\(7/4\)\)\/\[Pi]\^\(1/4\)}, \
{C[3, 2] \[Rule] \(-\(\(\@77\ \[Lambda]\^\(7/4\)\)\/\(\@5\ \[Pi]\^\(1/4\)\)\)\
\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 
        2, \[Rho]] = \(\(\@\(77\/5\)\ \[Lambda]\^\(7/4\)\)\/\[Pi]\^\(1/4\)\) \
\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \(6\ \
\[Rho]\^2\)\/7 + \(4\ \[Rho]\^4\)\/21 - \(8\ \[Rho]\^6\)\/693)\)\)\/\[Lambda]\
\), "\[IndentingNewLine]", 
    \(R\_Nrm[3, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 2, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(77\/5\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Lambda]\^\(3/4\
\)\ \[Rho]\^2\ \((1 - \(6\ \[Rho]\^2\)\/7 + \(4\ \[Rho]\^4\)\/21 - \(8\ \
\[Rho]\^6\)\/693)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(77\/5\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[3, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \(2\ \[Rho]\
\^2\)\/3 + \(4\ \[Rho]\^4\)\/33 - \(8\ \[Rho]\^6\)\/1287)\)\ C[3, 3]\)\/\
\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^8\ \((1 - \(2\ \
\[Rho]\^2\)\/3 + \(4\ \[Rho]\^4\)\/33 - \(8\ \[Rho]\^6\)\/1287)\)\^2\ C[3, 3]\
\^2\)\/\[Lambda]\^4\)], "Output"],

Cell[BoxData[
    \(\(35\ \@\[Pi]\ C[3, 3]\^2\)\/\(286\ \[Lambda]\^\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 
            3] \[Rule] \(\@\(286\/35\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)}, {C[3, 
            3] \[Rule] \(-\(\(\@286\ \[Lambda]\^\(9/4\)\)\/\(\@35\ \
\[Pi]\^\(1/4\)\)\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 
        3, \[Rho]] = \(\(\@\(286\/35\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\
\)\ \[Rho]\^3\ \((1 - \(2\ \[Rho]\^2\)\/3 + \(4\ \[Rho]\^4\)\/33 - \(8\ \
\[Rho]\^6\)\/1287)\)\)\/\[Lambda]\^\(3/2\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[3, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 3, \[Rho]], {\[Rho] \[Rule] r\ \@\[Lambda]}]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(286\/35\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \[Rho]\^3\ \((1 - \(2\ \[Rho]\^2\)\/3 + \(4\ \
\[Rho]\^4\)\/33 - \(8\ \[Rho]\^6\)\/1287)\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(286\/35\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\
\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Normalized radial wave functions of the three-dimensional quantum \
oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Radial functions and radial probability densities of the three-dimensional \
quantum rotator are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda]] = 
        R\_Oscl[0, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[Lambda]] = \(2\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 1, \[Lambda]] = 
        R\_Oscl[0, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[Lambda]] = \(4\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ r\^2\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 2, \[Lambda]] = 
        R\_Oscl[0, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[Lambda]] = \(4\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda]] = 
        R\_Oscl[0, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[Lambda]] = \(\@6\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ \[Lambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\)\/\[Pi]\^\(1/4\
\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda]] = 
        R\_Oscl[1, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[Lambda]] = \(-\(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\
\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-5\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 1, \[Lambda]] = 
        R\_Oscl[1, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[Lambda]] = \(-\(\(2\ \@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((\(-7\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda]] = 
        R\_Oscl[1, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[Lambda]] = \(4\ \@\(3\/35\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda]] = 
        R\_Oscl[1, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@30\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda]] = 
        R\_Oscl[2, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\^\(5/4\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@105\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda]] = 
        R\_Oscl[2, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[Lambda]] = \(1\/\(3\ \[Pi]\^\(1/4\)\)\) \((\@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + 
                        r\^2\ \[Lambda])\))\))\);\)\), "\[IndentingNewLine]", \

    \(\(\(RR\_Oscl[2, 2, \[Lambda]] = 
        R\_Oscl[2, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[Lambda]] = \((2\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 
                  4\ r\^2\ \[Lambda]\ \((\(-11\) + 
                        r\^2\ \[Lambda])\))\))\)/\((3\ \@1155\ \
\[Pi]\^\(1/4\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda]] = 
        R\_Oscl[2, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[Lambda]] = \(1\/\(2\ \[Pi]\^\(1/4\)\)\) \((\@35\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \((1 - 
                  2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\)\/5 - \(8\ \
r\^6\ \[Lambda]\^3\)\/105)\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda]] = 
        R\_Oscl[3, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[Lambda]] = \(-\(\(1\/\(9\ \@70\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \
\((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 
                          4\ r\^4\ \[Lambda]\^2)\))\))\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda]] = 
        R\_Oscl[3, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(77\/5\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 
                        4\ r\^4\ \[Lambda]\^2)\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda]] = 
        R\_Oscl[3, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(286\/35\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
\((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\)\)\/1287)\))\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 3, \[Lambda]] = 
        R\_Oscl[3, 3, \[Lambda]]\^2\ r\^2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
5. Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator in the Cartesian rectangular coordinates\
\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
To obtain radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator in the Cartesian rectangular coordinates \
we will use coordinate transformations:\
\>", "Text"],

Cell[BoxData[
    \(\(r = \@\(x^2 + y^2 + z^2\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[R\_Oscl[0, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[0, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[0, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[R\_Oscl[0, 3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[1, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[1, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[1, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[R\_Oscl[1, 3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[2, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[2, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[2, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[R\_Oscl[2, 3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[3, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[3, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[3, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[R\_Oscl[3, 3, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \@\(2\/3\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\
\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \@\(2\/105\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@6\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ \[Lambda]\^\(3/4\)\ \((1 - 2\/3\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\)\/\[Pi]\^\(1/4\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \((\(-5\) + 
                2\ \((x\^2 + y\^2 + 
                      z\^2)\)\ \[Lambda])\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/105\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
                z\^2)\)\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 
                2\ \((x\^2 + y\^2 + 
                      z\^2)\)\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \@\(3\/35\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\)\ \
\((1 - 2\/9\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ \[Lambda]\^\(3/4\)\ \((15 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(\@30\ \[Pi]\^\(1/4\
\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \((35 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\
\(\@105\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(2\/105\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/4\)\ \((63 + 4\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\)\/\(3\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\)\ \((99 + 4\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\)\/\(3\ \@1155\ \[Pi]\^\(1/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(2\ \[Pi]\^\(1/4\)\)\)\((\@35\ \[ExponentialE]\^\(\(-\(1\/2\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\ \((1 + 
            2\/105\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((21 - 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(9\ \@70\ \[Pi]\^\(1/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(5/4\)\ \((315 - 
            2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\[Pi]\^\(1/4\)\)\((\@\(77\/5\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(7/4\)\ \((1 + 
            2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(286\/35\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\)\ \
\((1 + \(2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\)\/1287)\)\)\/\[Pi]\^\(1/4\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[RR\_Oscl[0, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[0, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[0, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[RR\_Oscl[0, 3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[1, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[1, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[1, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[RR\_Oscl[1, 3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[2, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[2, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[2, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[RR\_Oscl[2, 3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[3, 0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[3, 1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[3, 2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR\_Oscl[3, 3, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\)\/\@\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\)\/\(3\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(16\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\)\/\(15\ \@\[Pi]\)\)], \
"Output"],

Cell[BoxData[
    \(\(32\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\)\/\(105\ \@\[Pi]\)\)], \
"Output"],

Cell[BoxData[
    \(\(6\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 - 2\/3\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda])\)\^2\)\/\@\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda])\)\^2\)\/\(15\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda])\)\^2\)\/\(105\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(16\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda])\)\^2\)\/\(945\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(30\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(105\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(945\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\
\)\/\(10395\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(4\ \@\[Pi]\)\)\((35\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(5670\ \@\[Pi]\)\)\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \
\((315 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(5\ \@\[Pi]\)\)\((77\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((1 \
+ 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\
\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(286\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2\)\/\(35\ \
\@\[Pi]\)\)], "Output"]
}, Open  ]],

Cell["\<\
Resulting normalized radial wave functions in the Cartesian rectangular \
coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_\(Oscl, Cart\)[0, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[0, 
          1, \[Lambda]] = \(2\ \@\(2\/3\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[0, 
          2, \[Lambda]] = \(4\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/4\)\)\/\
\(\@15\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(R\_\(Oscl, Cart\)[0, 
          3, \[Lambda]] = \(4\ \@\(2\/105\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[1, 
          0, \[Lambda]] = \(\@6\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\ \((1 - 2\/3\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda])\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[1, 
          1, \[Lambda]] = \(-\(\(2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \
\((\(-5\) + 2\ \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\)\)\/\(\@15\ \[Pi]\^\(1/4\)\)\)\
\);\)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[1, 
          2, \[Lambda]] = \(-\(\(2\ \@\(2\/105\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\
\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 
                    2\ \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_\(Oscl, Cart\)[1, 
          3, \[Lambda]] = \(4\ \@\(3\/35\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
\[Lambda]\^\(9/4\)\ \((1 - 2\/9\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\/\
\[Pi]\^\(1/4\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\ \((15 + 4\ \((x\^2 + y\^2 + z\^2)\
\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\)\/\(\@30\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \((35 + \
4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\)\/\(\@105\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[2, 
          2, \[Lambda]] = \(\@\(2\/105\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/4\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) \
+ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(3\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_\(Oscl, Cart\)[2, 
          3, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
\[Lambda]\^\(9/4\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(3\ \@1155\ \
\[Pi]\^\(1/4\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[3, 
          0, \[Lambda]] = \(\(1\/\(6\ \@35\ \[Pi]\^\(1/4\)\)\)\((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \
\[Lambda]\^\(3/4\)\ \((105 + 
                2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 
                      2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((21 - 
                            2\ \((x\^2 + y\^2 + 
                                  z\^2)\)\ \[Lambda])\))\))\))\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[3, 
          1, \[Lambda]] = \(\(1\/\(9\ \@70\ \[Pi]\^\(1/4\)\)\)\((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \
\@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \((315 - 
                2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + 
                      2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 
                            2\ \((x\^2 + y\^2 + 
                                  z\^2)\)\ \[Lambda])\))\))\))\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[3, 
          2, \[Lambda]] = \(\(1\/\(9\ \@385\ \[Pi]\^\(1/4\)\)\)\((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\
\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/4\)\ \((693 + 
                2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 
                      2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 
                            2\ \((x\^2 + y\^2 + 
                                  z\^2)\)\ \[Lambda])\))\))\))\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_\(Oscl, Cart\)[3, 
          3, \[Lambda]] = \(1\/\(9\ \[Pi]\^\(1/4\)\)\) \((\@\(2\/5005\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\
\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\)\ \((1287 - 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((429 + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\)}], \
"Input"],

Cell[BoxData[{
    \(\(RR\_\(Oscl, Cart\)[0, 
          0, \[Lambda]] = \(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(3/2\)\)\/\@\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[0, 
          1, \[Lambda]] = \(8\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\)\/\(3\ \@\
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[0, 
          2, \[Lambda]] = \(16\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \
\[Lambda]\^\(7/2\)\)\/\(15\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Oscl, Cart\)[0, 
          3, \[Lambda]] = \(32\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \
\[Lambda]\^\(9/2\)\)\/\(105\ \@\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[1, 
          0, \[Lambda]] = \(6\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 - 2\/3\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\@\[Pi];\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[1, 
          1, \[Lambda]] = \(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(15\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[1, 
          2, \[Lambda]] = \(8\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((7 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(105\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_\(Oscl, Cart\)[1, 
          3, \[Lambda]] = \(16\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((9 \
- 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(945\ \@\[Pi]\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\
\))\)\^2\)\/\(30\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\
\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(105\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          2, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(945\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Oscl, Cart\)[2, 
          3, \[Lambda]] = \(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(10395\ \@\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          0, \[Lambda]] = \(\(1\/\(1260\ \@\[Pi]\)\)\((\[ExponentialE]\^\(\(-\
\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
                z\^2)\)\ \[Lambda]\^\(3/2\)\ \((105 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((105 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-21\
\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          1, \[Lambda]] = \(\(1\/\(5670\ \@\[Pi]\)\)\((\[ExponentialE]\^\(\(-\
\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \
\[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + \
2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\))\)\^2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          2, \[Lambda]] = \(\(1\/\(31185\ \
\@\[Pi]\)\)\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((693 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((297 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-33\
\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          3, \[Lambda]] = \(\(1\/\(405405\ \@\[Pi]\)\)\((2\ \[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \
\[Lambda]\^\(9/2\)\ \((1287 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((429 \
+ 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\))\)\^2)\)\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 202, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2754, 91, 100, 2, 85, "Section"],
Cell[2857, 95, 98, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[2980, 101, 223, 4, 112, "Input"],
Cell[3206, 107, 194, 3, 85, "Output"]
}, Open  ]],
Cell[3415, 113, 130, 6, 56, "Text"],
Cell[3548, 121, 104, 3, 56, "Text"],
Cell[3655, 126, 192, 4, 54, "NumberedEquation"],
Cell[3850, 132, 204, 9, 56, "Text"],

Cell[CellGroupData[{
Cell[4079, 145, 131, 2, 64, "Input"],
Cell[4213, 149, 196, 3, 87, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4458, 158, 99, 2, 85, "Section"],
Cell[4560, 162, 291, 9, 80, "Text"],
Cell[4854, 173, 92, 1, 73, "NumberedEquation"],

Cell[CellGroupData[{
Cell[4971, 178, 191, 5, 92, "Input"],
Cell[5165, 185, 204, 4, 103, "Output"]
}, Open  ]],
Cell[5384, 192, 138, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[5547, 199, 193, 5, 92, "Input"],
Cell[5743, 206, 204, 3, 103, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5996, 215, 176, 5, 119, "Section"],
Cell[6175, 222, 122, 3, 56, "Text"],
Cell[6300, 227, 139, 2, 73, "NumberedEquation"],
Cell[6442, 231, 54, 0, 56, "Text"],
Cell[6499, 233, 270, 5, 77, "NumberedEquation"],
Cell[6772, 240, 96, 2, 56, "Text"],
Cell[6871, 244, 189, 8, 74, "NumberedEquation"],
Cell[7063, 254, 261, 10, 56, "Text"],

Cell[CellGroupData[{
Cell[7349, 268, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7559, 282, 623, 13, 212, "Input"],
Cell[8185, 297, 81, 1, 73, "Output"],
Cell[8269, 300, 105, 2, 92, "Output"],
Cell[8377, 304, 84, 1, 94, "Output"],
Cell[8464, 307, 180, 3, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8681, 315, 311, 7, 124, "Input"],
Cell[8995, 324, 117, 2, 99, "Output"],
Cell[9115, 328, 127, 2, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9291, 336, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[9501, 350, 623, 13, 212, "Input"],
Cell[10127, 365, 108, 2, 109, "Output"],
Cell[10238, 369, 108, 2, 92, "Output"],
Cell[10349, 373, 87, 1, 94, "Output"],
Cell[10439, 376, 219, 5, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10695, 386, 350, 8, 176, "Input"],
Cell[11048, 396, 137, 2, 124, "Output"],
Cell[11188, 400, 142, 2, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11379, 408, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[11589, 422, 623, 13, 212, "Input"],
Cell[12215, 437, 109, 2, 99, "Output"],
Cell[12327, 441, 108, 2, 92, "Output"],
Cell[12438, 445, 89, 1, 94, "Output"],
Cell[12530, 448, 215, 5, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12782, 458, 349, 8, 148, "Input"],
Cell[13134, 468, 138, 2, 109, "Output"],
Cell[13275, 472, 143, 2, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13467, 480, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[13677, 494, 623, 13, 212, "Input"],
Cell[14303, 509, 118, 2, 99, "Output"],
Cell[14424, 513, 108, 2, 92, "Output"],
Cell[14535, 517, 90, 1, 94, "Output"],
Cell[14628, 520, 223, 5, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14888, 530, 362, 8, 165, "Input"],
Cell[15253, 540, 142, 2, 124, "Output"],
Cell[15398, 544, 147, 2, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15594, 552, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[15804, 566, 623, 13, 212, "Input"],
Cell[16430, 581, 114, 2, 88, "Output"],
Cell[16547, 585, 139, 2, 104, "Output"],
Cell[16689, 589, 84, 1, 94, "Output"],
Cell[16776, 592, 184, 3, 94, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16997, 600, 346, 8, 131, "Input"],
Cell[17346, 610, 150, 2, 106, "Output"],
Cell[17499, 614, 168, 3, 104, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17716, 623, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[17926, 637, 623, 13, 212, "Input"],
Cell[18552, 652, 139, 2, 116, "Output"],
Cell[18694, 656, 142, 2, 104, "Output"],
Cell[18839, 660, 88, 1, 94, "Output"],
Cell[18930, 663, 223, 5, 104, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19190, 673, 383, 8, 156, "Input"],
Cell[19576, 683, 170, 3, 124, "Output"],
Cell[19749, 688, 203, 4, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20001, 698, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[20211, 712, 623, 13, 212, "Input"],
Cell[20837, 727, 140, 2, 106, "Output"],
Cell[20980, 731, 142, 2, 104, "Output"],
Cell[21125, 735, 89, 1, 94, "Output"],
Cell[21217, 738, 223, 5, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21477, 748, 386, 9, 165, "Input"],
Cell[21866, 759, 175, 3, 124, "Output"],
Cell[22044, 764, 208, 3, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22301, 773, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[22511, 787, 623, 13, 212, "Input"],
Cell[23137, 802, 149, 2, 106, "Output"],
Cell[23289, 806, 142, 2, 104, "Output"],
Cell[23434, 810, 89, 1, 94, "Output"],
Cell[23526, 813, 221, 5, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23784, 823, 392, 8, 165, "Input"],
Cell[24179, 833, 174, 3, 124, "Output"],
Cell[24356, 838, 185, 3, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24590, 847, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[24800, 861, 623, 13, 212, "Input"],
Cell[25426, 876, 137, 2, 88, "Output"],
Cell[25566, 880, 164, 3, 104, "Output"],
Cell[25733, 885, 88, 1, 94, "Output"],
Cell[25824, 888, 204, 4, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26065, 897, 377, 8, 165, "Input"],
Cell[26445, 907, 183, 3, 124, "Output"],
Cell[26631, 912, 199, 3, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26879, 921, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[27090, 935, 623, 13, 212, "Input"],
Cell[27716, 950, 162, 2, 116, "Output"],
Cell[27881, 954, 167, 3, 104, "Output"],
Cell[28051, 959, 88, 1, 94, "Output"],
Cell[28142, 962, 204, 4, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28383, 971, 402, 8, 176, "Input"],
Cell[28788, 981, 191, 3, 124, "Output"],
Cell[28982, 986, 203, 3, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29234, 995, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[29445, 1009, 623, 13, 212, "Input"],
Cell[30071, 1024, 163, 2, 106, "Output"],
Cell[30237, 1028, 167, 3, 104, "Output"],
Cell[30407, 1033, 88, 1, 94, "Output"],
Cell[30498, 1036, 204, 4, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30739, 1045, 405, 9, 165, "Input"],
Cell[31147, 1056, 194, 3, 124, "Output"],
Cell[31344, 1061, 216, 3, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31609, 1070, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[31820, 1084, 623, 13, 212, "Input"],
Cell[32446, 1099, 172, 2, 106, "Output"],
Cell[32621, 1103, 167, 3, 104, "Output"],
Cell[32791, 1108, 90, 1, 94, "Output"],
Cell[32884, 1111, 223, 5, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33144, 1121, 418, 9, 165, "Input"],
Cell[33565, 1132, 198, 3, 124, "Output"],
Cell[33766, 1137, 214, 3, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34029, 1146, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[34240, 1160, 623, 13, 212, "Input"],
Cell[34866, 1175, 171, 3, 88, "Output"],
Cell[35040, 1180, 180, 3, 104, "Output"],
Cell[35223, 1185, 88, 1, 94, "Output"],
Cell[35314, 1188, 215, 5, 94, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35566, 1198, 406, 9, 131, "Input"],
Cell[35975, 1209, 199, 3, 106, "Output"],
Cell[36177, 1214, 233, 3, 104, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36459, 1223, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[36670, 1237, 623, 13, 212, "Input"],
Cell[37296, 1252, 189, 3, 116, "Output"],
Cell[37488, 1257, 192, 3, 104, "Output"],
Cell[37683, 1262, 88, 1, 94, "Output"],
Cell[37774, 1265, 204, 4, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38015, 1274, 429, 9, 176, "Input"],
Cell[38447, 1285, 216, 3, 124, "Output"],
Cell[38666, 1290, 285, 5, 108, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39000, 1301, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[39211, 1315, 623, 13, 212, "Input"],
Cell[39837, 1330, 189, 3, 106, "Output"],
Cell[40029, 1335, 191, 3, 104, "Output"],
Cell[40223, 1340, 88, 1, 94, "Output"],
Cell[40314, 1343, 204, 4, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40555, 1352, 429, 9, 165, "Input"],
Cell[40987, 1363, 218, 3, 124, "Output"],
Cell[41208, 1368, 237, 3, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41494, 1377, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[41705, 1391, 623, 13, 212, "Input"],
Cell[42331, 1406, 199, 3, 106, "Output"],
Cell[42533, 1411, 192, 3, 104, "Output"],
Cell[42728, 1416, 90, 1, 94, "Output"],
Cell[42821, 1419, 221, 5, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43079, 1429, 441, 9, 165, "Input"],
Cell[43523, 1440, 221, 3, 124, "Output"],
Cell[43747, 1445, 244, 3, 124, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44052, 1455, 155, 5, 85, "Section"],
Cell[44210, 1462, 168, 5, 56, "Text"],
Cell[44381, 1469, 6236, 123, 2077, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50654, 1597, 231, 6, 119, "Section"],
Cell[50888, 1605, 217, 4, 80, "Text"],
Cell[51108, 1611, 63, 1, 69, "Input"],

Cell[CellGroupData[{
Cell[51196, 1616, 1261, 19, 513, "Input"],
Cell[52460, 1637, 150, 2, 94, "Output"],
Cell[52613, 1641, 190, 3, 124, "Output"],
Cell[52806, 1646, 188, 3, 104, "Output"],
Cell[52997, 1651, 201, 3, 124, "Output"],
Cell[53201, 1656, 207, 3, 100, "Output"],
Cell[53411, 1661, 292, 5, 105, "Output"],
Cell[53706, 1668, 311, 5, 124, "Output"],
Cell[54020, 1675, 255, 4, 124, "Output"],
Cell[54278, 1681, 264, 4, 104, "Output"],
Cell[54545, 1687, 291, 4, 105, "Output"],
Cell[54839, 1693, 301, 4, 124, "Output"],
Cell[55143, 1699, 308, 4, 104, "Output"],
Cell[55454, 1705, 422, 6, 136, "Output"],
Cell[55879, 1713, 447, 7, 135, "Output"],
Cell[56329, 1722, 461, 7, 177, "Output"],
Cell[56793, 1731, 371, 5, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57201, 1741, 1277, 19, 513, "Input"],
Cell[58481, 1762, 159, 2, 103, "Output"],
Cell[58643, 1766, 169, 2, 103, "Output"],
Cell[58815, 1770, 173, 3, 103, "Output"],
Cell[58991, 1775, 174, 3, 103, "Output"],
Cell[59168, 1780, 217, 3, 109, "Output"],
Cell[59388, 1785, 225, 3, 103, "Output"],
Cell[59616, 1790, 226, 3, 103, "Output"],
Cell[59845, 1795, 227, 3, 103, "Output"],
Cell[60075, 1800, 274, 4, 103, "Output"],
Cell[60352, 1806, 278, 4, 103, "Output"],
Cell[60633, 1812, 281, 4, 103, "Output"],
Cell[60917, 1818, 284, 4, 103, "Output"],
Cell[61204, 1824, 361, 5, 150, "Output"],
Cell[61568, 1831, 349, 5, 129, "Output"],
Cell[61920, 1838, 353, 5, 150, "Output"],
Cell[62276, 1845, 349, 5, 117, "Output"]
}, Open  ]],
Cell[62640, 1853, 161, 5, 56, "Text"],
Cell[62804, 1860, 5752, 99, 1767, "Input"],
Cell[68559, 1961, 5079, 85, 1612, "Input"],
Cell[73641, 2048, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

