(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     77613,       1726]*)
(*NotebookOutlinePosition[     78342,       1751]*)
(*  CellTagsIndexPosition[     78298,       1747]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.4. Visualization of the Radial Wave Functions and Radial Probability \
Densities of the Three-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["In this file we will present visualizations in \
individual scales for states defined by given quantum numbers.",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["Graphics`FilledPlot`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool in this part to give vivid presentation of functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input"],

Cell["\<\
Determine parameter \[Lambda] of the three-dimensional quantum oscillator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\[Lambda] = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
quantum oscillator for quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda]] = 
        R\_Oscl[0, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[Lambda]] = \(2\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 1, \[Lambda]] = 
        R\_Oscl[0, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[Lambda]] = \(4\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ r\^2\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 2, \[Lambda]] = 
        R\_Oscl[0, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[Lambda]] = \(4\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda]] = 
        R\_Oscl[0, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[Lambda]] = \(\@6\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ \[Lambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\)\/\[Pi]\^\(1/4\
\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda]] = 
        R\_Oscl[1, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[Lambda]] = \(-\(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\
\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-5\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 1, \[Lambda]] = 
        R\_Oscl[1, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[Lambda]] = \(-\(\(2\ \@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((\(-7\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda]] = 
        R\_Oscl[1, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[Lambda]] = \(4\ \@\(3\/35\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda]] = 
        R\_Oscl[1, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@30\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda]] = 
        R\_Oscl[2, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\^\(5/4\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@105\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda]] = 
        R\_Oscl[2, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[Lambda]] = \(1\/\(3\ \[Pi]\^\(1/4\)\)\) \((\@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + 
                        r\^2\ \[Lambda])\))\))\);\)\), "\[IndentingNewLine]", \

    \(\(\(RR\_Oscl[2, 2, \[Lambda]] = 
        R\_Oscl[2, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[Lambda]] = \((2\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 
                  4\ r\^2\ \[Lambda]\ \((\(-11\) + 
                        r\^2\ \[Lambda])\))\))\)/\((3\ \@1155\ \
\[Pi]\^\(1/4\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda]] = 
        R\_Oscl[2, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[Lambda]] = \(1\/\(2\ \[Pi]\^\(1/4\)\)\) \((\@35\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \((1 - 
                  2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\)\/5 - \(8\ \
r\^6\ \[Lambda]\^3\)\/105)\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda]] = 
        R\_Oscl[3, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[Lambda]] = \(-\(\(1\/\(9\ \@70\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \
\((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 
                          4\ r\^4\ \[Lambda]\^2)\))\))\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda]] = 
        R\_Oscl[3, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(77\/5\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 
                        4\ r\^4\ \[Lambda]\^2)\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda]] = 
        R\_Oscl[3, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(286\/35\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
\((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\)\)\/1287)\))\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 3, \[Lambda]] = 
        R\_Oscl[3, 3, \[Lambda]]\^2\ r\^2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial wave functions, radial probability densities \
and probability densities of the three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the three-dimensional \
quantum oscillator.
We will obtain three-dimensional plots for radial  functions and radial \
probability densities and present density and surface (three-dimensional) \
plots for probability densities of the three-dimensional quantum oscillator.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(IS2dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(\(ISAll3dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 1.25;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.55;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=0,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=0,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=0,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=0,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.95;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.4\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.9;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.35\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.35\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.15;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.4\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.975;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.345\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.725;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.3\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.55\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.45\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.625;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.35\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.3\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 5.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation  of Radial function for \
\!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 208, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2760, 91, 188, 5, 119, "Section"],
Cell[2951, 98, 216, 4, 56, "Text"],
Cell[3170, 104, 165, 5, 56, "Text"],
Cell[3338, 111, 195, 8, 72, "NumberedEquation"],
Cell[3536, 121, 293, 9, 57, "Text"],
Cell[3832, 132, 56, 1, 63, "Input"],
Cell[3891, 135, 145, 4, 56, "Text"],
Cell[4039, 141, 61, 1, 63, "Input"],
Cell[4103, 144, 193, 5, 56, "Text"],
Cell[4299, 151, 6236, 123, 2077, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10572, 279, 221, 5, 119, "Section"],
Cell[10796, 286, 526, 9, 176, "Text"],
Cell[11325, 297, 666, 17, 452, "Text"],
Cell[11994, 316, 642, 13, 388, "Input"],

Cell[CellGroupData[{
Cell[12661, 333, 185, 10, 89, "Subsection"],
Cell[12849, 345, 3826, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16712, 420, 185, 10, 89, "Subsection"],
Cell[16900, 432, 3837, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20774, 507, 185, 10, 89, "Subsection"],
Cell[20962, 519, 3831, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24830, 594, 185, 10, 89, "Subsection"],
Cell[25018, 606, 3838, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28893, 681, 185, 10, 89, "Subsection"],
Cell[29081, 693, 3834, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32952, 768, 185, 10, 89, "Subsection"],
Cell[33140, 780, 3824, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37001, 855, 185, 10, 89, "Subsection"],
Cell[37189, 867, 3837, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41063, 942, 185, 10, 89, "Subsection"],
Cell[41251, 954, 3837, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45125, 1029, 185, 10, 89, "Subsection"],
Cell[45313, 1041, 3836, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49186, 1116, 186, 10, 89, "Subsection"],
Cell[49375, 1128, 3834, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53246, 1203, 186, 10, 89, "Subsection"],
Cell[53435, 1215, 3837, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57309, 1290, 186, 10, 89, "Subsection"],
Cell[57498, 1302, 3834, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61369, 1377, 186, 10, 89, "Subsection"],
Cell[61558, 1389, 3835, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65430, 1464, 186, 10, 89, "Subsection"],
Cell[65619, 1476, 3836, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69492, 1551, 186, 10, 89, "Subsection"],
Cell[69681, 1563, 3824, 70, 1448, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73542, 1638, 186, 10, 89, "Subsection"],
Cell[73731, 1650, 3835, 70, 1448, "Input"],
Cell[77569, 1722, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

