(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    388822,       6874]*)
(*NotebookOutlinePosition[    389551,       6899]*)
(*  CellTagsIndexPosition[    389507,       6895]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "2.3.7. Visualization of the Wave Functions and Probability Densities of \
the Three-Dimensional Quantum ",
  "Oscillator",
  " (",
  StyleBox["beginning",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Radial and angular probability densities and probability densities of the \
three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ", \n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["In this file we present states for radial quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[Cell[BoxData[
    \(n\_rad = 1, 2\)],
  FontSlant->"Italic"]], "NumberedEquation"],

Cell["and next file presents states for radial quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 3, 4. \)],
    FontSlant->"Italic"],
  " "
}], "NumberedEquation"],

Cell["\<\
Determine parameter \[Lambda] of the three-dimensional quantum oscillator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\[Lambda] = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator for given quantum numbers in the \
Cartesian rectangular coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Radial  probability densities:", "Text"],

Cell[BoxData[{
    \(\(RR\_\(Oscl, Cart\)[0, 
          0, \[Lambda]] = \(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(3/2\)\)\/\@\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[0, 
          1, \[Lambda]] = \(8\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\)\/\(3\ \@\
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[0, 
          2, \[Lambda]] = \(16\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \
\[Lambda]\^\(7/2\)\)\/\(15\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Oscl, Cart\)[0, 
          3, \[Lambda]] = \(32\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \
\[Lambda]\^\(9/2\)\)\/\(105\ \@\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[1, 
          0, \[Lambda]] = \(6\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 - 2\/3\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\@\[Pi];\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[1, 
          1, \[Lambda]] = \(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(15\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[1, 
          2, \[Lambda]] = \(8\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((7 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(105\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_\(Oscl, Cart\)[1, 
          3, \[Lambda]] = \(16\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((9 \
- 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(945\ \@\[Pi]\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\
\))\)\^2\)\/\(30\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\
\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(105\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          2, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(945\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Oscl, Cart\)[2, 
          3, \[Lambda]] = \(4\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(10395\ \@\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          0, \[Lambda]] = \(1\/\(1260\ \@\[Pi]\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((105 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((105 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-21\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          1, \[Lambda]] = \(1\/\(5670\ \@\[Pi]\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          2, \[Lambda]] = \(1\/\(31185\ \@\[Pi]\)\) \((\[ExponentialE]\^\(\(-\
\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \
\[Lambda]\^\(7/2\)\ \((693 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((297 + \
2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-33\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          3, \[Lambda]] = \(1\/\(405405\ \@\[Pi]\)\) \((2\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((1287 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((429 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\)}], "Input"],

Cell["Angular probability densities:", "Text"],

Cell[BoxData[{
    \(\(YY[0, 0] = 1\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[1, 
          0] = \(3\ Cos[\[Theta]]\^2\)\/\(4\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[1, 
          1] = \(3\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          0] = \(5\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(64\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          1] = \(15\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), \
"\[IndentingNewLine]", 
    \(\(YY[2, 
          2] = \(15\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[3, 
          0] = \(7\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(256\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          1] = \(21\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(1024\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          2] = \(105\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(32\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 3] = \(35\ Sin[\[Theta]]\^6\)\/\(64\ \[Pi]\);\)\)}], "Input"],

Cell["Probability densities:", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\)\/\(3\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          1, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\^\(7/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ \
z\^3)\)\^2\ \[Lambda]\^\(9/2\)\)\/\(15\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\)\/\(10\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\)\/\(6\ \[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((3 - 2\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(5\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((5 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(10\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(42\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(7\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(28\ \[Pi]\^\(3/2\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\
\^2\)\/\(135\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(180\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(18\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(108\ \
\[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\
\))\)\^2\)\/\(120\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(140\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((35 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\)\^2\)\/\(280\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          0, \[Lambda]] = \(1\/\(1512\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) \
+ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(252\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(1008\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          0, \[Lambda]] = \(1\/\(5940\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          1, \[Lambda]] = \(1\/\(7920\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          2, \[Lambda]] = \(1\/\(792\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(4752\ \[Pi]\^\(3/2\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 0, 
          0, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((35\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          0, \[Lambda]] = \(1\/\(7560\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          1, \[Lambda]] = \(1\/\(15120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\
\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          0, \[Lambda]] = \(1\/\(64\ \[Pi]\^\(3/2\)\)\) \((77\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^3\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
\[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          1, \[Lambda]] = \(1\/\(8\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          2, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          0, \[Lambda]] = \(1\/\(40\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          1, \[Lambda]] = \(1\/\(160\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          2, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          3, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial probability densities, angular probability \
densities and probability densities of the three-dimensional quantum \
oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the two-dimensional \
quantum oscillator.\nWe will obtain three-dimensional plots for radial and \
angular probability densities (product of these functions gives probability \
density), three-dimensional plots for probability densities (surface and \
density plots) for four cross-sectional profiles (defined by coordinate \
planes ",
  StyleBox["y0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y3",
    FontSlant->"Italic"],
  ") of the three-dimensional quantum oscillator.\nIn this file we will \
present visualizations in individual scales for states defined by given \
quantum numbers."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\n\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 550;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ISProf3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISProf3dVert = 550;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.0\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-1.5\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.0675;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-2.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 2.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-2.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 2.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.0875\), 
                0.0875}, {\(-0.0875\), 0.0875}, {\(-0.0875\), 
                0.0875}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,0,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,0,0], y=0, -0.75, -1.5, -2\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.0\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-1.5\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.195;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,1,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,1,0], y=0, -0.75, -1.5, -2\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.1;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,1,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,1,1], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.3;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,2,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,2,0], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.5\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.125;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.12\), 
                0.12}, {\(-0.12\), 0.12}, {\(-0.12\), 
                0.12}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,2,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-2.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=-2.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=-2.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,2,0], y=0, -1, -2, -2.5\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.75\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.125;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.16\), 
                0.16}, {\(-0.16\), 0.16}, {\(-0.16\), 
                0.16}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,2,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=-2.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=-2.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=-2.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,2,2], y=0, -1, -2, -2.75\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.5;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,0], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.15;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,1], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.125;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.135\), 
                0.135}, {\(-0.135\), 0.135}, {\(-0.135\), 
                0.135}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,2], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.14;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,3], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,3], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.0575;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 3.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.09\), 
                0.09}, {\(-0.09\), 0.09}, {\(-0.09\), 
                0.09}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,0,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,0,0], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.165;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,1,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,1,0], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.085;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,1,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,1,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-1.5\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-2.25\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.27;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=-0.75\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=-1.5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=-1.5\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=-2.25\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,0], y=0, -0.75, -1.5, -2.25\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.1;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.115\), 
                0.115}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.1;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.155\), 
                0.155}, {\(-0.155\), 0.155}, {\(-0.155\), 
                0.155}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,2], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.375;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.15;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.105;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.14\), 
                0.14}, {\(-0.14\), 0.14}, {\(-0.14\), 
                0.14}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,2], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.115;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.183\), 
                0.183}, {\(-0.183\), 0.183}, {\(-0.183\), 
                0.183}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,3], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,3], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 333, 12, 125, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2885, 98, 189, 5, 119, "Section"],
Cell[3077, 105, 165, 5, 56, "Text"],
Cell[3245, 112, 196, 8, 72, "NumberedEquation"],
Cell[3444, 122, 121, 2, 56, "Text"],
Cell[3568, 126, 96, 2, 50, "NumberedEquation"],
Cell[3667, 130, 120, 2, 56, "Text"],
Cell[3790, 134, 115, 5, 52, "NumberedEquation"],
Cell[3908, 141, 145, 4, 56, "Text"],
Cell[4056, 147, 61, 1, 63, "Input"],
Cell[4120, 150, 256, 6, 80, "Text"],
Cell[4379, 158, 46, 0, 56, "Text"],
Cell[4428, 160, 5069, 85, 1712, "Input"],
Cell[9500, 247, 46, 0, 56, "Text"],
Cell[9549, 249, 1079, 26, 588, "Input"],
Cell[10631, 277, 38, 0, 56, "Text"],
Cell[10672, 279, 14541, 234, 3926, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25250, 518, 231, 6, 119, "Section"],
Cell[25484, 526, 848, 22, 200, "Text"],
Cell[26335, 550, 666, 17, 452, "Text"],
Cell[27004, 569, 296, 5, 213, "Input"],

Cell[CellGroupData[{
Cell[27325, 578, 202, 11, 89, "Subsection"],
Cell[27530, 591, 17842, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45409, 891, 202, 11, 89, "Subsection"],
Cell[45614, 904, 17817, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63468, 1204, 214, 13, 89, "Subsection"],
Cell[63685, 1219, 17835, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81557, 1519, 214, 13, 89, "Subsection"],
Cell[81774, 1534, 17843, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99654, 1834, 214, 13, 89, "Subsection"],
Cell[99871, 1849, 17813, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117721, 2149, 214, 13, 89, "Subsection"],
Cell[117938, 2164, 17814, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135789, 2464, 214, 13, 89, "Subsection"],
Cell[136006, 2479, 17844, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153887, 2779, 214, 13, 89, "Subsection"],
Cell[154104, 2794, 17844, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171985, 3094, 214, 13, 89, "Subsection"],
Cell[172202, 3109, 17845, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[190084, 3409, 215, 13, 89, "Subsection"],
Cell[190302, 3424, 17844, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208183, 3724, 215, 13, 89, "Subsection"],
Cell[208401, 3739, 17843, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226281, 4039, 215, 13, 89, "Subsection"],
Cell[226499, 4054, 17813, 294, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[244349, 4353, 215, 13, 89, "Subsection"],
Cell[244567, 4368, 17796, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[262400, 4668, 215, 13, 89, "Subsection"],
Cell[262618, 4683, 17823, 295, 6136, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[280478, 4983, 215, 13, 89, "Subsection"],
Cell[280696, 4998, 17794, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[298527, 5298, 215, 13, 89, "Subsection"],
Cell[298745, 5313, 17806, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[316588, 5613, 215, 13, 89, "Subsection"],
Cell[316806, 5628, 17808, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[334651, 5928, 215, 13, 89, "Subsection"],
Cell[334869, 5943, 17796, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[352702, 6243, 215, 13, 89, "Subsection"],
Cell[352920, 6258, 17791, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[370748, 6558, 215, 13, 89, "Subsection"],
Cell[370966, 6573, 17809, 295, 6111, "Input"],
Cell[388778, 6870, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

