(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    141788,       3125]*)
(*NotebookOutlinePosition[    142517,       3150]*)
(*  CellTagsIndexPosition[    142473,       3146]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.9. Comparative visualization of the Probability Densities of the \
Three-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Probability densities of the three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["\<\
Determine parameter \[Lambda] of the three-dimensional quantum oscillator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\[Lambda] = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Probability densities of the three-dimensional quantum oscillator for given \
quantum numbers in the Cartesian rectangular coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\)\/\(3\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          1, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\^\(7/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ \
z\^3)\)\^2\ \[Lambda]\^\(9/2\)\)\/\(15\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\)\/\(10\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\)\/\(6\ \[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((3 - 2\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(5\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((5 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(10\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(42\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(7\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(28\ \[Pi]\^\(3/2\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\
\^2\)\/\(135\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(180\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(18\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(108\ \
\[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\
\))\)\^2\)\/\(120\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(140\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((35 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\)\^2\)\/\(280\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          0, \[Lambda]] = \(1\/\(1512\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) \
+ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(252\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(1008\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          0, \[Lambda]] = \(1\/\(5940\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          1, \[Lambda]] = \(1\/\(7920\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          2, \[Lambda]] = \(1\/\(792\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(4752\ \[Pi]\^\(3/2\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 0, 
          0, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((35\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          0, \[Lambda]] = \(1\/\(7560\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          1, \[Lambda]] = \(1\/\(15120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\
\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          0, \[Lambda]] = \(1\/\(64\ \[Pi]\^\(3/2\)\)\) \((77\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^3\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
\[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          1, \[Lambda]] = \(1\/\(8\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          2, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          0, \[Lambda]] = \(1\/\(40\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          1, \[Lambda]] = \(1\/\(160\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          2, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          3, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the probability densities of the three-dimensional \
quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the three-dimensional \
quantum oscillator.\nWe will obtain three-dimensional plots probability \
densities (surface and density plots) for four cross-sectional profile \
(defined by coordinate plane ",
  StyleBox["y0",
    FontSlant->"Italic"],
  ") of the three-dimensional quantum oscillator.\nIn this file we will \
present visualizations in individual scales for states defined by given \
quantum numbers."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(IS3dVert = 265;\)\[IndentingNewLine]\), "\n", 
    \(\(ISAll3dHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 300;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ISProf3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISProf3dVert = 550;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(z3dMax = 5;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0675;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,1,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.16;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.14;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,3], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0575;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.165;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.085;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.27;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.375;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.15;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.105;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.115;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,3], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "21",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0525;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "22",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.155;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "23",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.075;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "24",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "25",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "26",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "27",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.345;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "28",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "29",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "30",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.11;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,3], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "31",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,0,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "32",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.145;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "33",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0685;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "34) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.235;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "35) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0875;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "36) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0865;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "37) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.315;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,0], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "38) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.115;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,1], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "39",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "40",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,3], y=0\>"]\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparative visualization of the probability densities of the \
three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations in unified scales for all states defined by \
given quantum numbers.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3d\_Oscl[0, 0, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 0, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 0, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 0, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 1, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 1, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 1, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 1, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 1, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 1, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 1, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 1, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 2, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 2, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 2, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 2, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 2, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 2, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 2, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 2, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 2, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 2, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 2, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 2, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 3, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 3, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 3, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 3, \[Lambda], y0], 
            WFunktion3d\_Oscl[1, 3, 3, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 3, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 3, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {700, 
          1800}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, \
y=0\>"]\)], "Input"],

Cell["", "Text"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[0, 0, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 0, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 0, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 0, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 1, 0, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 1, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 1, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 1, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 1, 1, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 1, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 1, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 1, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 2, 0, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 2, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 2, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 2, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 2, 1, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 2, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 2, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 2, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 2, 2, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 2, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 2, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 2, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 0, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 3, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 1, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 3, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 2, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 3, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 3, \[Lambda], y0], WFunktion3dDen\_Oscl[1, 3, 3, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 3, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 3, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {700, 
          1800}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, \
y=0\>"]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 187, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2739, 91, 142, 4, 85, "Section"],
Cell[2884, 97, 165, 5, 56, "Text"],
Cell[3052, 104, 195, 8, 72, "NumberedEquation"],
Cell[3250, 114, 145, 4, 56, "Text"],
Cell[3398, 120, 61, 1, 63, "Input"],
Cell[3462, 123, 210, 5, 80, "Text"],
Cell[3675, 130, 14541, 234, 3926, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18253, 369, 165, 5, 85, "Section"],
Cell[18421, 376, 562, 11, 176, "Text"],
Cell[18986, 389, 666, 17, 452, "Text"],
Cell[19655, 408, 710, 12, 463, "Input"],

Cell[CellGroupData[{
Cell[20390, 424, 202, 11, 89, "Subsection"],
Cell[20595, 437, 2626, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23258, 487, 202, 11, 89, "Subsection"],
Cell[23463, 500, 2623, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26123, 550, 202, 11, 89, "Subsection"],
Cell[26328, 563, 2623, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28988, 613, 202, 11, 89, "Subsection"],
Cell[29193, 626, 2623, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31853, 676, 202, 11, 89, "Subsection"],
Cell[32058, 689, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34720, 739, 202, 11, 89, "Subsection"],
Cell[34925, 752, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37587, 802, 202, 11, 89, "Subsection"],
Cell[37792, 815, 2623, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40452, 865, 214, 13, 89, "Subsection"],
Cell[40669, 880, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43330, 930, 214, 13, 89, "Subsection"],
Cell[43547, 945, 2627, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46211, 995, 215, 13, 89, "Subsection"],
Cell[46429, 1010, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49090, 1060, 215, 13, 89, "Subsection"],
Cell[49308, 1075, 2626, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51971, 1125, 215, 13, 89, "Subsection"],
Cell[52189, 1140, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54851, 1190, 215, 13, 89, "Subsection"],
Cell[55069, 1205, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57731, 1255, 215, 13, 89, "Subsection"],
Cell[57949, 1270, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60610, 1320, 215, 13, 89, "Subsection"],
Cell[60828, 1335, 2623, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63488, 1385, 215, 13, 89, "Subsection"],
Cell[63706, 1400, 2623, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66366, 1450, 215, 13, 89, "Subsection"],
Cell[66584, 1465, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69246, 1515, 215, 13, 89, "Subsection"],
Cell[69464, 1530, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72125, 1580, 215, 13, 89, "Subsection"],
Cell[72343, 1595, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75005, 1645, 215, 13, 89, "Subsection"],
Cell[75223, 1660, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77885, 1710, 215, 13, 89, "Subsection"],
Cell[78103, 1725, 2626, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80766, 1775, 215, 13, 89, "Subsection"],
Cell[80984, 1790, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83646, 1840, 215, 13, 89, "Subsection"],
Cell[83864, 1855, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86526, 1905, 215, 13, 89, "Subsection"],
Cell[86744, 1920, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89405, 1970, 215, 13, 89, "Subsection"],
Cell[89623, 1985, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[92284, 2035, 215, 13, 89, "Subsection"],
Cell[92502, 2050, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95163, 2100, 215, 13, 89, "Subsection"],
Cell[95381, 2115, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98043, 2165, 215, 13, 89, "Subsection"],
Cell[98261, 2180, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100923, 2230, 215, 13, 89, "Subsection"],
Cell[101141, 2245, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103803, 2295, 215, 13, 89, "Subsection"],
Cell[104021, 2310, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106682, 2360, 215, 13, 89, "Subsection"],
Cell[106900, 2375, 2626, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109563, 2425, 215, 13, 89, "Subsection"],
Cell[109781, 2440, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112443, 2490, 215, 13, 89, "Subsection"],
Cell[112661, 2505, 2626, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115324, 2555, 203, 11, 89, "Subsection"],
Cell[115530, 2568, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118192, 2618, 203, 11, 89, "Subsection"],
Cell[118398, 2631, 2626, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121061, 2681, 203, 11, 89, "Subsection"],
Cell[121267, 2694, 2626, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[123930, 2744, 203, 11, 89, "Subsection"],
Cell[124136, 2757, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126798, 2807, 203, 11, 89, "Subsection"],
Cell[127004, 2820, 2625, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129666, 2870, 215, 13, 89, "Subsection"],
Cell[129884, 2885, 2624, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132545, 2935, 215, 13, 89, "Subsection"],
Cell[132763, 2950, 2623, 45, 966, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[135435, 3001, 177, 5, 85, "Section"],
Cell[135615, 3008, 169, 5, 56, "Text"],
Cell[135787, 3015, 3029, 55, 888, "Input"],
Cell[138819, 3072, 16, 0, 56, "Text"],
Cell[138838, 3074, 2915, 46, 888, "Input"],
Cell[141756, 3122, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

