(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    129721,       2714]*)
(*NotebookOutlinePosition[    130443,       2739]*)
(*  CellTagsIndexPosition[    130399,       2735]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.10. Comparative visualization of the Radial Wave Functions and Radial \
Probability Densities of the Three-Dimensional Quantum Oscillator for \
Different Values of Oscillator Parameter\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator for different values of oscillator \
parameter\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we can compare quantum states of the three-dimensional quantum oscillator \
for different values of oscillator parameter \[Lambda] characterizing \
oscillator frequency and mass:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[Lambda] = \(\(\ \)\(\(m\_0\) \[Omega]\)\)\/\[HBar]\)], \
"NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Determine two ",
  "different values",
  " parameters ",
  StyleBox["\[Lambda]",
    FontSlant->"Italic"],
  " and ",
  StyleBox["\[CapitalLambda]",
    FontSlant->"Italic"],
  " of the three-dimensional quantum oscillator:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Lambda] = 1;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalLambda] = 3/2;\)\ \)}], "Input"],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["<< Graphics`FilledPlot`", "Input"],

Cell[TextData[{
  "Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator for quantum numbers (1) and oscillator \
parameter ",
  StyleBox["\[Lambda]",
    FontSlant->"Italic"],
  " are:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda]] = 
        R\_Oscl[0, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[Lambda]] = \(2\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 1, \[Lambda]] = 
        R\_Oscl[0, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[Lambda]] = \(4\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ r\^2\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 2, \[Lambda]] = 
        R\_Oscl[0, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[Lambda]] = \(4\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda]] = 
        R\_Oscl[0, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[Lambda]] = \(\@6\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ \[Lambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\)\/\[Pi]\^\(1/4\
\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda]] = 
        R\_Oscl[1, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[Lambda]] = \(-\(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\
\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-5\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 1, \[Lambda]] = 
        R\_Oscl[1, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[Lambda]] = \(-\(\(2\ \@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((\(-7\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda]] = 
        R\_Oscl[1, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[Lambda]] = \(4\ \@\(3\/35\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda]] = 
        R\_Oscl[1, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@30\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda]] = 
        R\_Oscl[2, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\^\(5/4\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@105\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda]] = 
        R\_Oscl[2, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[Lambda]] = \(1\/\(3\ \[Pi]\^\(1/4\)\)\) \((\@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + 
                        r\^2\ \[Lambda])\))\))\);\)\), "\[IndentingNewLine]", \

    \(\(\(RR\_Oscl[2, 2, \[Lambda]] = 
        R\_Oscl[2, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[Lambda]] = \((2\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 
                  4\ r\^2\ \[Lambda]\ \((\(-11\) + 
                        r\^2\ \[Lambda])\))\))\)/\((3\ \@1155\ \
\[Pi]\^\(1/4\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda]] = 
        R\_Oscl[2, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[Lambda]] = \(1\/\(2\ \[Pi]\^\(1/4\)\)\) \((\@35\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \((1 - 
                  2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\)\/5 - \(8\ \
r\^6\ \[Lambda]\^3\)\/105)\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda]] = 
        R\_Oscl[3, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[Lambda]] = \(-\(\(1\/\(9\ \@70\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \
\((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 
                          4\ r\^4\ \[Lambda]\^2)\))\))\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda]] = 
        R\_Oscl[3, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(77\/5\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 
                        4\ r\^4\ \[Lambda]\^2)\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda]] = 
        R\_Oscl[3, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(286\/35\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
\((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\)\)\/1287)\))\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 3, \[Lambda]] = 
        R\_Oscl[3, 3, \[Lambda]]\^2\ r\^2;\)\)}], "Input"],

Cell[TextData[{
  "Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator for quantum numbers (1) and oscillator \
parameter ",
  StyleBox["\[CapitalLambda]",
    FontSlant->"Italic"],
  " are:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[CapitalLambda]] = \(2\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[CapitalLambda]\)\/2\)\)\ \[CapitalLambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[CapitalLambda]] = 
        R\_Oscl[0, 0, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[CapitalLambda]] = \(2\ \@\(2\/3\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ r\ \
\[CapitalLambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 1, \[CapitalLambda]] = 
        R\_Oscl[0, 1, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[CapitalLambda]] = \(4\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[CapitalLambda]\)\/2\)\)\ r\^2\ \[CapitalLambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\
\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 2, \[CapitalLambda]] = 
        R\_Oscl[0, 2, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[CapitalLambda]] = \(4\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\
\^2\ \[CapitalLambda]\)\/2\)\)\ r\^3\ \
\[CapitalLambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[CapitalLambda]] = 
        R\_Oscl[0, 3, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[CapitalLambda]] = \(\@6\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[CapitalLambda]\)\/2\)\)\ \[CapitalLambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \
\[CapitalLambda]\)\/3)\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[CapitalLambda]] = 
        R\_Oscl[1, 0, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[CapitalLambda]] = \(-\(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[CapitalLambda]\)\/2\)\)\ r\ \[CapitalLambda]\^\(5/4\)\ \((\(-5\) + 
                    
                    2\ r\^2\ \[CapitalLambda])\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 1, \[CapitalLambda]] = 
        R\_Oscl[1, 1, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[CapitalLambda]] = \(-\(\(2\ \@\(2\/105\)\ \[ExponentialE]\^\(-\
\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ r\^2\ \[CapitalLambda]\^\(7/4\)\ \((\(-7\
\) + 2\ r\^2\ \[CapitalLambda])\)\)\/\[Pi]\^\(1/4\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[CapitalLambda]] = 
        R\_Oscl[1, 2, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[CapitalLambda]] = \(4\ \@\(3\/35\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ r\^3\ \
\[CapitalLambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[CapitalLambda]\)\/9)\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[CapitalLambda]] = 
        R\_Oscl[1, 3, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[CapitalLambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \
\[CapitalLambda]\)\/2\)\)\ \[CapitalLambda]\^\(3/4\)\ \((15 + 4\ r\^2\ \
\[CapitalLambda]\ \((\(-5\) + r\^2\ \[CapitalLambda])\))\)\)\/\(\@30\ \[Pi]\^\
\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[CapitalLambda]] = 
        R\_Oscl[2, 0, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[CapitalLambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \
\[CapitalLambda]\)\/2\)\)\ r\ \[CapitalLambda]\^\(5/4\)\ \((35 + 4\ r\^2\ \
\[CapitalLambda]\ \((\(-7\) + r\^2\ \[CapitalLambda])\))\)\)\/\(\@105\ \
\[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[CapitalLambda]] = 
        R\_Oscl[2, 1, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[CapitalLambda]] = \(1\/\(3\ \[Pi]\^\(1/4\)\)\) \((\@\(2\/105\)\
\ \[ExponentialE]\^\(-\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ r\^2\ \
\[CapitalLambda]\^\(7/4\)\ \((63 + 
                  4\ r\^2\ \[CapitalLambda]\ \((\(-9\) + 
                        r\^2\ \[CapitalLambda])\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 2, \[CapitalLambda]] = 
        R\_Oscl[2, 2, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[CapitalLambda]] = \((2\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[CapitalLambda]\)\/2\)\)\ r\^3\ \[CapitalLambda]\^\(9/4\)\ \((99 + 
                  4\ r\^2\ \[CapitalLambda]\ \((\(-11\) + 
                        r\^2\ \[CapitalLambda])\))\))\)/\((3\ \@1155\ \[Pi]\^\
\(1/4\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[CapitalLambda]] = 
        R\_Oscl[2, 3, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[CapitalLambda]] = \(1\/\(2\ \[Pi]\^\(1/4\)\)\) \((\@35\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ \
\[CapitalLambda]\^\(3/4\)\ \((1 - 
                  2\ r\^2\ \[CapitalLambda] + \(4\ r\^4\ \
\[CapitalLambda]\^2\)\/5 - \(8\ r\^6\ \[CapitalLambda]\^3\)\/105)\))\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[CapitalLambda]] = 
        R\_Oscl[3, 0, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[CapitalLambda]] = \(-\(\(1\/\(9\ \@70\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ r\ \
\[CapitalLambda]\^\(5/4\)\ \((\(-315\) + 
                    2\ r\^2\ \[CapitalLambda]\ \((189 - 
                          54\ r\^2\ \[CapitalLambda] + 
                          4\ r\^4\ \[CapitalLambda]\^2)\))\))\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[CapitalLambda]] = 
        R\_Oscl[3, 1, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[CapitalLambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(77\/5\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ r\^2\ \
\[CapitalLambda]\^\(7/4\)\ \((1 - 
                  2\/693\ r\^2\ \[CapitalLambda]\ \((297 - 
                        66\ r\^2\ \[CapitalLambda] + 
                        4\ r\^4\ \[CapitalLambda]\^2)\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[CapitalLambda]] = 
        R\_Oscl[3, 2, \[CapitalLambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[CapitalLambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(286\/35\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[CapitalLambda]\)\/2\)\)\ r\^3\ \
\[CapitalLambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[CapitalLambda]\ \((429 - 78\ r\
\^2\ \[CapitalLambda] + 4\ r\^4\ \[CapitalLambda]\^2)\)\)\/1287)\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 3, \[CapitalLambda]] = 
        R\_Oscl[3, 3, \[CapitalLambda]]\^2\ r\^2;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Plots of  the radial wave functions and radial probability densities of \
the three-dimensional quantum oscillator two different values of oscillator \
parameters\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the radial wave functions and radial \
probability densities of the three-dimensional quantum oscillator.
We will obtain two-dimensional plots for radial  functions and radial \
probability densities and present surface (three-dimensional) plots for \
probability densities of the three-dimensional quantum oscillator.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(IS2dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(\(ISAll3dVert = 450;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 1.25;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,0,1],\!\(RR\_Oscl\)[0,0,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,0,1.5],\!\(RR\_Oscl\)[0,0,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,0,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,0,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[0,0,1], \
\!\(RR\_Oscl\)[0,0,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,1,1],\!\(RR\_Oscl\)[0,1,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,1,1.5],\!\(RR\_Oscl\)[0,1,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,1,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,1,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[0,1,1], \
\!\(RR\_Oscl\)[0,1,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,2,1],\!\(RR\_Oscl\)[0,2,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,2,1.5],\!\(RR\_Oscl\)[0,2,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,2,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,2,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[0,2,1], \
\!\(RR\_Oscl\)[0,2,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,3,1],\!\(RR\_Oscl\)[0,3,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[0,3,1.5],\!\(RR\_Oscl\)[0,3,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,3,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[0,3,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[0,3,1], \
\!\(RR\_Oscl\)[0,3,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.55;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.9;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,0,1],\!\(RR\_Oscl\)[1,0,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,0,1.5],\!\(RR\_Oscl\)[1,0,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,0,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,0,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[1,0,1], \
\!\(RR\_Oscl\)[1,0,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.55\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,1,1],\!\(RR\_Oscl\)[1,1,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,1,1.5],\!\(RR\_Oscl\)[1,1,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,1,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,1,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[1,1,1], \
\!\(RR\_Oscl\)[1,1,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.9;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,2,1],\!\(RR\_Oscl\)[1,2,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,2,1.5],\!\(RR\_Oscl\)[1,2,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,2,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,2,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[1,2,1], \
\!\(RR\_Oscl\)[1,2,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.4\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,3,1],\!\(RR\_Oscl\)[1,3,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[1,3,1.5],\!\(RR\_Oscl\)[1,3,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,3,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[1,3,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[1,3,1], \
\!\(RR\_Oscl\)[1,3,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.85;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.805;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,0,1],\!\(RR\_Oscl\)[2,0,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,0,1.5],\!\(RR\_Oscl\)[2,0,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,0,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,0,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[2,0,1], \
\!\(RR\_Oscl\)[2,0,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.6\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.35;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.8;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,1,1],\!\(RR\_Oscl\)[2,1,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,1,1.5],\!\(RR\_Oscl\)[2,1,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,1,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,1,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[2,1,1], \
\!\(RR\_Oscl\)[2,1,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.465\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.945;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.765;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,2,1],\!\(RR\_Oscl\)[2,2,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,2,1.5],\!\(RR\_Oscl\)[2,2,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,2,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,2,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[2,2,1], \
\!\(RR\_Oscl\)[2,2,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.4\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.8;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.765;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,3,1],\!\(RR\_Oscl\)[2,3,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[2,3,1.5],\!\(RR\_Oscl\)[2,3,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,3,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[2,3,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[2,3,1], \
\!\(RR\_Oscl\)[2,3,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.8\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.8;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,0,1],\!\(RR\_Oscl\)[3,0,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,0,1.5],\!\(RR\_Oscl\)[3,0,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,0,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,0,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[3,0,1], \
\!\(RR\_Oscl\)[3,0,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.65\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,1,1],\!\(RR\_Oscl\)[3,1,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,1,1.5],\!\(RR\_Oscl\)[3,1,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,1,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,1,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[3,1,1], \
\!\(RR\_Oscl\)[3,1,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 1. ;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,2,1],\!\(RR\_Oscl\)[3,2,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,2,1.5],\!\(RR\_Oscl\)[3,2,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,2,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,2,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[3,2,1], \
\!\(RR\_Oscl\)[3,2,1.5]\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.45\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.86;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5.25;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 5.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.725;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[Lambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[Lambda]]}, \[IndentingNewLine]{r, 
            x2dMin, x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,3,1],\!\(RR\_Oscl\)[3,3,1]\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x2dMin, x2dMax, 
          PR2dMin, PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            RR\_Oscl[n\_rad, l\_orb, \[CapitalLambda]], 
            0}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[1, 1, 0]}, {{2, Axis}, 
                RGBColor[0, 0, 1]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(R\_Oscl\)[3,3,1.5],\!\(RR\_Oscl\)[3,3,1.5]\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]] = 
        If[y < 0, 0, RRxy\_Oscl[n\_rad, l\_orb, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, l\_orb, \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,3,1]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        FullSimplify[
          ReplaceAll[
            RR\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda]] = 
        If[y < 0, 0, 
          RRxy\_Oscl[n\_rad, l\_orb, \[CapitalLambda]]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_Oscl[n\_rad, l\_orb, \[CapitalLambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[RRxy2\_Oscl[n\_rad, 
            l\_orb, \[CapitalLambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(RR\_Oscl\)[3,3,1.5]\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dR\_Oscl[n\_rad, l\_orb, \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph2dRR\_Oscl[n\_rad, l\_orb, \[CapitalLambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_Oscl[n\_rad, 
              l\_orb, \[CapitalLambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<Presentation of \!\(RR\_Oscl\)[3,3,1], \
\!\(RR\_Oscl\)[3,3,1.5]\>\""]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 268, 6, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2820, 92, 235, 6, 119, "Section"],
Cell[3058, 100, 253, 6, 80, "Text"],
Cell[3314, 108, 123, 3, 65, "NumberedEquation"],
Cell[3440, 113, 302, 12, 56, "Text"],
Cell[3745, 127, 116, 2, 88, "Input"],
Cell[3864, 131, 165, 5, 56, "Text"],
Cell[4032, 138, 195, 8, 72, "NumberedEquation"],
Cell[4230, 148, 40, 0, 62, "Input"],
Cell[4273, 150, 303, 9, 80, "Text"],
Cell[4579, 161, 6236, 123, 2077, "Input"],
Cell[10818, 286, 310, 9, 80, "Text"],
Cell[11131, 297, 7089, 135, 2077, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18257, 437, 239, 6, 119, "Section"],
Cell[18499, 445, 487, 8, 176, "Text"],
Cell[18989, 455, 666, 17, 452, "Text"],
Cell[19658, 474, 642, 13, 388, "Input"],

Cell[CellGroupData[{
Cell[20325, 491, 185, 10, 89, "Subsection"],
Cell[20513, 503, 6590, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27140, 628, 197, 12, 89, "Subsection"],
Cell[27340, 642, 6604, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33981, 767, 197, 12, 89, "Subsection"],
Cell[34181, 781, 6598, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40816, 906, 197, 12, 89, "Subsection"],
Cell[41016, 920, 6605, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47658, 1045, 197, 12, 89, "Subsection"],
Cell[47858, 1059, 6601, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54496, 1184, 197, 12, 89, "Subsection"],
Cell[54696, 1198, 6592, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61325, 1323, 197, 12, 89, "Subsection"],
Cell[61525, 1337, 6602, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68164, 1462, 197, 12, 89, "Subsection"],
Cell[68364, 1476, 6603, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75004, 1601, 197, 12, 89, "Subsection"],
Cell[75204, 1615, 6605, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81846, 1740, 198, 12, 89, "Subsection"],
Cell[82047, 1754, 6599, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88683, 1879, 198, 12, 89, "Subsection"],
Cell[88884, 1893, 6605, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95526, 2018, 198, 12, 89, "Subsection"],
Cell[95727, 2032, 6601, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102365, 2157, 198, 12, 89, "Subsection"],
Cell[102566, 2171, 6597, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109200, 2296, 198, 12, 89, "Subsection"],
Cell[109401, 2310, 6601, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116039, 2435, 198, 12, 89, "Subsection"],
Cell[116240, 2449, 6590, 120, 2333, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122867, 2574, 198, 12, 89, "Subsection"],
Cell[123068, 2588, 6606, 120, 2333, "Input"],
Cell[129677, 2710, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

