(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11763,        433]*)
(*NotebookOutlinePosition[     12471,        457]*)
(*  CellTagsIndexPosition[     12427,        453]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "3.1. Schrodinger Equation for the ",
  StyleBox["Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[TextData[{
  "1. ",
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"]
}], "Section"],

Cell["\<\
Hydrogen-like atoms consists of the electron moving in the Coulomb' electric \
field of atomic nucleus. Potential energy of electron in the Hydrogen-like \
atom are:\
\>", "Text"],

Cell[BoxData[
    \(\(\(V[r] = \(-\(Z\/r\)\)\ e\_0\^2\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_0\)],
    FontSlant->"Italic"],
  " is electron mass, ",
  Cell[BoxData[
      \(e\_0\)],
    FontSlant->"Italic"],
  " is electron charge, Z is number of the ",
  "Hydrogen-like atom",
  ".\nThat is potential energy of particle ",
  Cell[BoxData[
      RowBox[{
        StyleBox["V",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  " depends only upon the spherical coordinate ",
  Cell[BoxData[
      StyleBox["r",
        FontSlant->"Italic"]]],
  "."
}], "Text"],

Cell["\<\
Three-dimensional Schrodinger equation in the centrosymmetrical field is\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"\[CapitalDelta]\[Psi]", "[", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "]"}], "+", 
        RowBox[{\(\(2\ m\_0\)\/\[HBar]\^2\), \((E - V[r])\), 
          RowBox[{"\[Psi]", "[", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "]"}]}]}], "=", "0"}]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  " ",
  Cell[BoxData[
      StyleBox["En",
        FontWeight->"Bold"]],
    FontSlant->"Italic"],
  " is total energy of particle, ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Psi]",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  "is wave function of particle."
}], "Text"],

Cell["Thus Schrodinger equation is:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"\[CapitalDelta]\[Psi]", "[", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "]"}], "+", 
        RowBox[{\(\(2\ m\_0\)\/\[HBar]\^2\), \((En + Z\/r\ e\_0\^2)\), 
          RowBox[{"\[Psi]", "[", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "]"}]}]}], "=", "0"}]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Psi]",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  " is function of three spherical coordinates:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Psi]", "[", 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], "]"}], 
      "=", \(\[Psi][r, \[Theta], \[CurlyPhi]]\)}]], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox["\[CapitalDelta]",
        FontSlant->"Italic"]]],
  " is ",
  "the Laplacian in the spherical coordinates",
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta] = \[CapitalDelta]\_r + 
        1\/r\^2\ \[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\)\)], \
"NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(\[CapitalDelta]\_r\)],
    FontSlant->"Italic"],
  " is ",
  "the radial ",
  "operator",
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]\_r = \(1\/r\^2\) \((\[PartialD]\_r\((r\^2\ \
\[PartialD]\_r)\))\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(\[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\)\)],
    FontSlant->"Italic"],
  " is ",
  "the angular operator",
  ":"
}], "Text"],

Cell[BoxData[{
    \(\[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\) = \[CapitalDelta]\_\[Theta] \
+ \(1\/Sin[\[Theta]]\^2\) \[CapitalDelta]\_\[CurlyPhi]\), "\n", 
    \(\[CapitalDelta]\_\[Theta] = \(1\/Sin[\[Theta]]\) \((\[PartialD]\_\
\[Theta]\ \((Sin[\[Theta]]\ \[PartialD]\_\[Theta])\))\), \ \[CapitalDelta]\_\
\[CurlyPhi] = \[PartialD]\_\(\[CurlyPhi], \[CurlyPhi]\)\)}], \
"NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Separation of variables", "Section"],

Cell[TextData[{
  "We will try to solve Schrodinger equation (3) by a value of wave function \
",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[Psi]",
            FontSlant->"Italic"], 
          StyleBox["[",
            FontSlant->"Italic"], 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontSlant->"Italic"]}], 
        StyleBox["=",
          FontSlant->"Italic"], 
        StyleBox[\(\[Psi][r, \[Theta], \[CurlyPhi]]\),
          FontSlant->"Italic"]}]]],
  " which is the product of separate functions of ",
  Cell[BoxData[
      StyleBox[\(r, \[Theta], \[CurlyPhi]\),
        FontSlant->"Italic"]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][r, \[Theta], \[CurlyPhi]] = 
      R[r]\ Y[\[Theta], \[CurlyPhi]]\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox[\(R[r]\),
        FontSlant->"Italic"]]],
  "is the radial wave function and ",
  Cell[BoxData[
      StyleBox[\(Y[\[Theta], \[CurlyPhi]]\),
        FontSlant->"Italic"]]],
  "is the angular wave function."
}], "Text"],

Cell["\<\
Separated equations for the radial and angular wave functions are\
\>", "Text"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta]\_r\) 
          R[r] + \(\(2\ m\_0\)\/\[HBar]\^2\) \((E - 
              V[r] - \[CapitalLambda]\/r\^2)\) R[r] = 
      0\)\(,\)\)\)], "NumberedEquation"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta]\_\(\[Theta], \[CurlyPhi]\)\) 
          Y[\[Theta], \[CurlyPhi]] + \[CapitalLambda]\ Y[\[Theta], \
\[CurlyPhi]] = 0\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(\[CapitalLambda]\)],
    FontSlant->"Italic"],
  " is constant."
}], "Text"],

Cell["\<\
Solutions of the equation (9) for the angular wave function are Spherical \
Harmonics\
\>", "Text"],

Cell[BoxData[
    \(Y[\[Theta], \[CurlyPhi]] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\)], "NumberedEquation"],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(\[CapitalLambda]\)],
    FontSlant->"Italic"],
  " is equal to"
}], "Text"],

Cell[BoxData[
    \(\(\(\[CapitalLambda] = 
      l\_orb\ \((l\_orb + 1)\)\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontSlant->"Italic"]]],
  " is orbital quantum number, ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontSlant->"Italic"]]],
  " is azimuthal quantum number:"
}], "Text"],

Cell[BoxData[{
    \(l\_orb\  = 0, 1, 2, 3,  ... \), "\[IndentingNewLine]", 
    \(m\_azm\  = \(-l\_orb\), \(-\((l\_orb - 1)\)\),  ... , \((l\_orb - 1)\), 
    l\_orb\)}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3. Radial equation for the ",
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"]
}], "Section"],

Cell["Radial equation for three-dimensional quantum oscillator is:", "Text"],

Cell[BoxData[
    \(\(1\/r\^2\) \((\[PartialD]\_r\((r\^2\ \[PartialD]\_r)\))\) 
          R[r] + \(\(2\ m\_0\)\/\[HBar]\^2\) \((E + 
              Z\/r\ e\_0\^2 - \(l\_orb\ \((l\_orb + 1)\)\)\/r\^2)\) R[r] = 
      0\)], "NumberedEquation"],

Cell[TextData[{
  "or in the \"",
  StyleBox["InputForm",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{\(D[R[r], {r, 2}]\), "+", \(\((2/r)\)*D[R[r], r]\), "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"2", "*", 
              SubscriptBox["m", 
                StyleBox["0",
                  "TI"]], "*", \(En/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
        "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"2", " ", 
              SubscriptBox["m", 
                StyleBox["0",
                  "TI"]], "*", "Z", " ", \(e\_0\^2/\((r\ \ \[HBar]^2)\)\)}], 
            ")"}], "*", \(R[r]\)}], 
        "-", \(\((\(l\_orb\) \((l\_orb + 1)\)/r^2)\)*R[r]\)}], "\[Equal]", 
      "0"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(\(R[r]\ l\_orb\ \((1 + l\_orb)\)\)\/r\^2\)\), 
        "+", \(\(2\ En\ R[r]\ m\_0\)\/\[HBar]\^2\), 
        "+", \(\(2\ Z\ R[r]\ e\_0\%2\ m\_0\)\/\(r\ \[HBar]\^2\)\), "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 181, 6, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2665, 91, 97, 4, 85, "Section"],
Cell[2765, 97, 189, 4, 80, "Text"],
Cell[2957, 103, 86, 1, 67, "NumberedEquation"],
Cell[3046, 106, 693, 27, 92, "Text"],
Cell[3742, 135, 96, 2, 56, "Text"],
Cell[3841, 139, 425, 11, 68, "NumberedEquation"],
Cell[4269, 152, 497, 20, 56, "Text"],
Cell[4769, 174, 45, 0, 56, "Text"],
Cell[4817, 176, 435, 11, 68, "NumberedEquation"],
Cell[5255, 189, 376, 14, 56, "Text"],
Cell[5634, 205, 219, 6, 53, "NumberedEquation"],
Cell[5856, 213, 173, 7, 56, "Text"],
Cell[6032, 222, 145, 3, 68, "NumberedEquation"],
Cell[6180, 227, 147, 8, 56, "Text"],
Cell[6330, 237, 125, 2, 68, "NumberedEquation"],
Cell[6458, 241, 166, 7, 56, "Text"],
Cell[6627, 250, 392, 6, 119, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7056, 261, 45, 0, 85, "Section"],
Cell[7104, 263, 729, 24, 80, "Text"],
Cell[7836, 289, 116, 2, 53, "NumberedEquation"],
Cell[7955, 293, 277, 10, 56, "Text"],
Cell[8235, 305, 89, 2, 56, "Text"],
Cell[8327, 309, 196, 4, 68, "NumberedEquation"],
Cell[8526, 315, 190, 3, 53, "NumberedEquation"],
Cell[8719, 320, 128, 6, 56, "Text"],
Cell[8850, 328, 109, 3, 56, "Text"],
Cell[8962, 333, 144, 3, 53, "NumberedEquation"],
Cell[9109, 338, 125, 6, 56, "Text"],
Cell[9237, 346, 107, 2, 53, "NumberedEquation"],
Cell[9347, 350, 245, 9, 56, "Text"],
Cell[9595, 361, 191, 3, 78, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9823, 369, 121, 4, 85, "Section"],
Cell[9947, 375, 76, 0, 56, "Text"],
Cell[10026, 377, 240, 4, 68, "NumberedEquation"],
Cell[10269, 383, 175, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[10469, 394, 672, 18, 88, "Input"],
Cell[11144, 414, 563, 13, 89, "Output"]
}, Open  ]],
Cell[11722, 430, 25, 0, 55, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

