(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29000,        952]*)
(*NotebookOutlinePosition[     29729,        977]*)
(*  CellTagsIndexPosition[     29685,        973]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
3.2. Radial Equation of the Hydrogen-like atoms:
General Solutions, Radial Wave Functions  and Energy Levels\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Radial equation of the Hydrogen-like atoms", "Section"],

Cell[TextData[{
  "Consider radial equation (",
  StyleBox["RadDifEqnHdrLAt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") of the Hydrogen-like atoms"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RadDifEqnHdrLAt", "=", 
      RowBox[{
        RowBox[{\(D[R[r], {r, 2}]\), "+", \(\((2/r)\)*D[R[r], r]\), "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"2", "*", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]], "*", \(En/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
          "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(-2\), "*", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]], "*", \(V[r]/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}],
           "-", \(\((\(l\_orb\) \((l\_orb + 1)\)/r^2)\)*R[r]\)}], "\[Equal]", 
        "0"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(\(R[r]\ l\_orb\ \((1 + l\_orb)\)\)\/r\^2\)\), 
        "+", \(\(2\ En\ R[r]\ m\_0\)\/\[HBar]\^2\), 
        "-", \(\(2\ R[r]\ m\_0\ V[r]\)\/\[HBar]\^2\), "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  StyleBox["V",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is potential energy of ",
  "the Hydrogen-like atoms",
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(V[r] = \(-\(Z\/r\)\)\ e\_0\^2\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_0\)],
    FontSlant->"Italic"],
  " is electron mass, ",
  Cell[BoxData[
      \(e\_0\)],
    FontSlant->"Italic"],
  " is electron charge, ",
  Cell[BoxData[
      \(TraditionalForm\`l\_orb\)]],
  " is orbital quantum number, ",
  StyleBox["En",
    FontSlant->"Italic"],
  " is total energy of electron, ",
  StyleBox["R",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is radial part of wave function."
}], "Text"],

Cell[TextData[{
  "Substitute expression for potential energy ",
  StyleBox["V",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] to radial equation (",
  StyleBox["RadDifEqnHdrLAt",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") and use extra denotations:"
}], "Text"],

Cell[BoxData[
    \(k\^2 = \(-\(\(2\ \(m\_0\) En\)\/\[HBar]\^2\)\), \ 
    a\_0 = \[HBar]\^2\/\(e\_0\%2\ m\_0\)\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(a\_0\)],
    FontSlant->"Italic"],
  " is constant. So we will have"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadDifEqnHdrLAt1 = 
      ReplaceAll[
        RadDifEqnHdrLAt, {V[r] \[Rule] \(-\(Z\/r\)\)\ e\_0\^2, 
          En \[Rule] \(-\(\(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\)\)\), 
          m\_0 \[Rule] \[HBar]\^2\/\(e\_0\%2\ a\_0\)}]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(2\ Z\ R[r]\)\/\(r\ a\_0\)\), 
        "-", \(\(R[r]\ l\_orb\ \((1 + l\_orb)\)\)\/r\^2\), 
        "-", \(\(k\^2\ \[HBar]\^2\ R[r]\)\/\(a\_0\ e\_0\%2\ m\_0\)\), "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadDifEqnHydAt2 = 
      ReplaceAll[
        RadDifEqnHdrLAt1, {m\_0 \[Rule] \[HBar]\^2\/\(e\_0\%2\ a\_0\)}]\)], \
"Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(-k\^2\)\ R[r]\), "+", \(\(2\ Z\ R[r]\)\/\(r\ a\_0\)\), 
        "-", \(\(R[r]\ l\_orb\ \((1 + l\_orb)\)\)\/r\^2\), "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "These transformations give dimensionless form of the radial equation.\nWe \
will seek solution of radial equation with \"",
  StyleBox["DSolve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[DSolve[RadDifEqnHydAt2, R[r], r]]\)], "Input"],

Cell[BoxData[
    \({{R[
            r] \[Rule] \[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ \((C[
                    1]\ HypergeometricU[1 - Z\/\(k\ a\_0\) + l\_orb, 
                    2\ \((1 + l\_orb)\), 2\ k\ r] + 
                C[2]\ LaguerreL[\(-1\) + Z\/\(k\ a\_0\) - l\_orb, 
                    1 + 2\ l\_orb, 2\ k\ r])\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "General solution for ",
  StyleBox["R",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is superposition of two independent fundamental solutions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R1[r] = \[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ \ HypergeometricU[
          1 - Z\/\(k\ a\_0\) + l\_orb, 2\ \((1 + l\_orb)\), 
          2\ k\ r]\), "\[IndentingNewLine]", 
    \(R2[r] = \[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ LaguerreL[\(-1\) + 
            Z\/\(k\ a\_0\) - l\_orb, 1 + 2\ l\_orb, 2\ k\ r]\)}], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ HypergeometricU[
        1 - Z\/\(k\ a\_0\) + l\_orb, 2\ \((1 + l\_orb)\), 
        2\ k\ r]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ LaguerreL[\(-1\) + 
          Z\/\(k\ a\_0\) - l\_orb, 1 + 2\ l\_orb, 2\ k\ r]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where Hypergeometric1F1[...] is the Kummer confluent hypergeometric \
function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Null]\_1\) \(\(F\_1\)(a; b; z)\)\)], 
    "InlineFormula"],
  ", LaguerreL[...] is the ",
  "generalized Laguerre function ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\_n\%a\)(x)\)], "InlineFormula"],
  " and C[2] and C[1] are constants.\nAs a result we have solution of the \
radial equation as superposition of two components:"
}], "Text"],

Cell[BoxData[
    \(R[r] = C[1]\ R1[r] + C[2] R1[2]\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Now we analyze behavior of functions ",
  StyleBox["R2",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] and ",
  StyleBox["R1",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] near zero.\nTake Taylor series of hypergeometric and ",
  "generalized Laguerre",
  " functions near zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["HG",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], 
      "=", \(FullSimplify[
        Series[HypergeometricU[1 - Z\/\(k\ a\_0\) + l\_orb, 
            2\ \((1 + l\_orb)\), 2\ k\ r], {r, \ 0, \ 
            1}]]\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["LG2",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], 
      "=", \(FullSimplify[
        Series[LaguerreL[\(-1\) + Z\/\(k\ a\_0\) - l\_orb, 1 + 2\ l\_orb, 
            2\ k\ r], {r, \ 0, \ 1}]]\)}]}], "Input"],

Cell[BoxData[
    RowBox[{
    "\[Pi]", " ", \(r\^\(\(-1\) - 2\ l\_orb\)\), 
      " ", \(Csc[2\ \[Pi]\ l\_orb]\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              
              RowBox[{\(-\(\(2\^\(\(-1\) - 2\ l\_orb\)\ k\^\(\(-1\) - 2\ \
l\_orb\)\)\/\(Gamma[\(-2\)\ l\_orb]\ Gamma[1 - Z\/\(k\ a\_0\) + l\_orb]\)\)\),
                 "+", 
                InterpretationBox[\(O[r]\^1\),
                  SeriesData[ r, 0, {}, 0, 1, 1]]}],
              SeriesData[ r, 0, {
                Times[ -1, 
                  Power[ 2, 
                    Plus[ -1, 
                      Times[ -2, 
                        Subscript[ l, orb]]]], 
                  Power[ k, 
                    Plus[ -1, 
                      Times[ -2, 
                        Subscript[ l, orb]]]], 
                  Power[ 
                    Gamma[ 
                      Times[ -2, 
                        Subscript[ l, orb]]], -1], 
                  Power[ 
                    Gamma[ 
                      Plus[ 1, 
                        Times[ -1, 
                          Power[ k, -1], Z, 
                          Power[ 
                            Subscript[ a, 0], -1]], 
                        Subscript[ l, orb]]], -1]]}, 0, 1, 1]], ")"}], "+", 
          RowBox[{\(r\^\(2\ l\_orb\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                
                RowBox[{\(r\/\(Gamma[\(-\(Z\/\(k\ a\_0\)\)\) - l\_orb]\ Gamma[
                          2\ \((1 + l\_orb)\)]\)\), 
                  "+", \(\(2\ \((\(-Z\) + 
                            k\ a\_0\ \((1 + 
                                  l\_orb)\))\)\ r\^2\)\/\(Gamma[\(-\(Z\/\(k\ \
a\_0\)\)\) - l\_orb]\ Gamma[3 + 2\ l\_orb]\ a\_0\)\), "+", 
                  InterpretationBox[\(O[r]\^3\),
                    SeriesData[ r, 0, {}, 1, 3, 1]]}],
                SeriesData[ r, 0, {
                  Times[ 
                    Power[ 
                      Gamma[ 
                        Plus[ 
                          Times[ -1, 
                            Power[ k, -1], Z, 
                            Power[ 
                              Subscript[ a, 0], -1]], 
                          Times[ -1, 
                            Subscript[ l, orb]]]], -1], 
                    Power[ 
                      Gamma[ 
                        Times[ 2, 
                          Plus[ 1, 
                            Subscript[ l, orb]]]], -1]], 
                  Times[ 2, 
                    Power[ 
                      Gamma[ 
                        Plus[ 
                          Times[ -1, 
                            Power[ k, -1], Z, 
                            Power[ 
                              Subscript[ a, 0], -1]], 
                          Times[ -1, 
                            Subscript[ l, orb]]]], -1], 
                    Power[ 
                      Gamma[ 
                        Plus[ 3, 
                          Times[ 2, 
                            Subscript[ l, orb]]]], -1], 
                    Power[ 
                      Subscript[ a, 0], -1], 
                    Plus[ 
                      Times[ -1, Z], 
                      Times[ k, 
                        Subscript[ a, 0], 
                        Plus[ 1, 
                          Subscript[ l, orb]]]]]}, 1, 3, 1]], ")"}]}]}], 
        ")"}]}]], "Output"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\(Pochhammer[Z\/\(k\ a\_0\) - l\_orb, 1 + 2\ l\_orb]\/Gamma[
              2\ \((1 + l\_orb)\)]\), 
        "-", \(\(2\ \((k\ Gamma[
                    1 + Z\/\(k\ a\_0\) + l\_orb])\)\ r\)\/\(Gamma[\(-1\) + 
                  Z\/\(k\ a\_0\) - l\_orb]\ Gamma[3 + 2\ l\_orb]\)\), "+", 
        InterpretationBox[\(O[r]\^2\),
          SeriesData[ r, 0, {}, 0, 2, 1]]}],
      SeriesData[ r, 0, {
        Times[ 
          Power[ 
            Gamma[ 
              Times[ 2, 
                Plus[ 1, 
                  Subscript[ l, orb]]]], -1], 
          Pochhammer[ 
            Plus[ 
              Times[ 
                Power[ k, -1], Z, 
                Power[ 
                  Subscript[ a, 0], -1]], 
              Times[ -1, 
                Subscript[ l, orb]]], 
            Plus[ 1, 
              Times[ 2, 
                Subscript[ l, orb]]]]], 
        Times[ -2, k, 
          Power[ 
            Gamma[ 
              Plus[ -1, 
                Times[ 
                  Power[ k, -1], Z, 
                  Power[ 
                    Subscript[ a, 0], -1]], 
                Times[ -1, 
                  Subscript[ l, orb]]]], -1], 
          Gamma[ 
            Plus[ 1, 
              Times[ 
                Power[ k, -1], Z, 
                Power[ 
                  Subscript[ a, 0], -1]], 
              Subscript[ l, orb]]], 
          Power[ 
            Gamma[ 
              Plus[ 3, 
                Times[ 2, 
                  Subscript[ l, orb]]]], -1]]}, 0, 2, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and take Taylor series of radial functions ",
  StyleBox["R2",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] and ",
  StyleBox["R1",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] near zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["R1",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(\[ExponentialE]\^\(\(-k\)\ r\)\), " ", \(r\^l\_orb\), "  ", 
          
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["HG",
                  FontSlant->"Italic"], "Taylor2"}]], "[", 
            StyleBox["r",
              FontSlant->"Italic"], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["R2",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(\[ExponentialE]\^\(\(-k\)\ r\)\), " ", \(r\^l\_orb\), " ", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["LG2",
                  FontSlant->"Italic"], "Taylor2"}]], "[", 
            StyleBox["r",
              FontSlant->"Italic"], "]"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
    RowBox[{\(\[ExponentialE]\^\(\(-k\)\ r\)\), " ", "\[Pi]", 
      " ", \(r\^\(\(-1\) - l\_orb\)\), " ", \(Csc[2\ \[Pi]\ l\_orb]\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"(", 
            InterpretationBox[
              
              RowBox[{\(-\(\(2\^\(\(-1\) - 2\ l\_orb\)\ k\^\(\(-1\) - 2\ \
l\_orb\)\)\/\(Gamma[\(-2\)\ l\_orb]\ Gamma[1 - Z\/\(k\ a\_0\) + l\_orb]\)\)\),
                 "+", 
                InterpretationBox[\(O[r]\^1\),
                  SeriesData[ r, 0, {}, 0, 1, 1]]}],
              SeriesData[ r, 0, {
                Times[ -1, 
                  Power[ 2, 
                    Plus[ -1, 
                      Times[ -2, 
                        Subscript[ l, orb]]]], 
                  Power[ k, 
                    Plus[ -1, 
                      Times[ -2, 
                        Subscript[ l, orb]]]], 
                  Power[ 
                    Gamma[ 
                      Times[ -2, 
                        Subscript[ l, orb]]], -1], 
                  Power[ 
                    Gamma[ 
                      Plus[ 1, 
                        Times[ -1, 
                          Power[ k, -1], Z, 
                          Power[ 
                            Subscript[ a, 0], -1]], 
                        Subscript[ l, orb]]], -1]]}, 0, 1, 1]], ")"}], "+", 
          RowBox[{\(r\^\(2\ l\_orb\)\), " ", 
            RowBox[{"(", 
              InterpretationBox[
                
                RowBox[{\(r\/\(Gamma[\(-\(Z\/\(k\ a\_0\)\)\) - l\_orb]\ Gamma[
                          2\ \((1 + l\_orb)\)]\)\), 
                  "+", \(\(2\ \((\(-Z\) + 
                            k\ a\_0\ \((1 + 
                                  l\_orb)\))\)\ r\^2\)\/\(Gamma[\(-\(Z\/\(k\ \
a\_0\)\)\) - l\_orb]\ Gamma[3 + 2\ l\_orb]\ a\_0\)\), "+", 
                  InterpretationBox[\(O[r]\^3\),
                    SeriesData[ r, 0, {}, 1, 3, 1]]}],
                SeriesData[ r, 0, {
                  Times[ 
                    Power[ 
                      Gamma[ 
                        Plus[ 
                          Times[ -1, 
                            Power[ k, -1], Z, 
                            Power[ 
                              Subscript[ a, 0], -1]], 
                          Times[ -1, 
                            Subscript[ l, orb]]]], -1], 
                    Power[ 
                      Gamma[ 
                        Times[ 2, 
                          Plus[ 1, 
                            Subscript[ l, orb]]]], -1]], 
                  Times[ 2, 
                    Power[ 
                      Gamma[ 
                        Plus[ 
                          Times[ -1, 
                            Power[ k, -1], Z, 
                            Power[ 
                              Subscript[ a, 0], -1]], 
                          Times[ -1, 
                            Subscript[ l, orb]]]], -1], 
                    Power[ 
                      Gamma[ 
                        Plus[ 3, 
                          Times[ 2, 
                            Subscript[ l, orb]]]], -1], 
                    Power[ 
                      Subscript[ a, 0], -1], 
                    Plus[ 
                      Times[ -1, Z], 
                      Times[ k, 
                        Subscript[ a, 0], 
                        Plus[ 1, 
                          Subscript[ l, orb]]]]]}, 1, 3, 1]], ")"}]}]}], 
        ")"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(r\^l\_orb\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          
          RowBox[{\(Pochhammer[Z\/\(k\ a\_0\) - l\_orb, 1 + 2\ l\_orb]\/Gamma[
                  2\ \((1 + l\_orb)\)]\), 
            "+", \(k\ Gamma[
                1 + Z\/\(k\ a\_0\) + 
                  l\_orb]\ \((\(-\(1\/\(Gamma[Z\/\(k\ a\_0\) - l\_orb]\ Gamma[
                            2\ \((1 + l\_orb)\)]\)\)\) - 
                  2\/\(Gamma[\(-1\) + Z\/\(k\ a\_0\) - l\_orb]\ Gamma[3 + 2\ \
l\_orb]\))\)\ r\), "+", 
            InterpretationBox[\(O[r]\^2\),
              SeriesData[ r, 0, {}, 0, 2, 1]]}],
          SeriesData[ r, 0, {
            Times[ 
              Power[ 
                Gamma[ 
                  Times[ 2, 
                    Plus[ 1, 
                      Subscript[ l, orb]]]], -1], 
              Pochhammer[ 
                Plus[ 
                  Times[ 
                    Power[ k, -1], Z, 
                    Power[ 
                      Subscript[ a, 0], -1]], 
                  Times[ -1, 
                    Subscript[ l, orb]]], 
                Plus[ 1, 
                  Times[ 2, 
                    Subscript[ l, orb]]]]], 
            Times[ k, 
              Gamma[ 
                Plus[ 1, 
                  Times[ 
                    Power[ k, -1], Z, 
                    Power[ 
                      Subscript[ a, 0], -1]], 
                  Subscript[ l, orb]]], 
              Plus[ 
                Times[ -1, 
                  Power[ 
                    Gamma[ 
                      Plus[ 
                        Times[ 
                          Power[ k, -1], Z, 
                          Power[ 
                            Subscript[ a, 0], -1]], 
                        Times[ -1, 
                          Subscript[ l, orb]]]], -1], 
                  Power[ 
                    Gamma[ 
                      Times[ 2, 
                        Plus[ 1, 
                          Subscript[ l, orb]]]], -1]], 
                Times[ -2, 
                  Power[ 
                    Gamma[ 
                      Plus[ -1, 
                        Times[ 
                          Power[ k, -1], Z, 
                          Power[ 
                            Subscript[ a, 0], -1]], 
                        Times[ -1, 
                          Subscript[ l, orb]]]], -1], 
                  Power[ 
                    Gamma[ 
                      Plus[ 3, 
                        Times[ 2, 
                          Subscript[ l, orb]]]], -1]]]]}, 0, 2, 1]], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["R1",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is divergent function near zero and ",
  StyleBox["R2",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] tends to zero.\nFiniteness of the wave function results us to \
condition:"
}], "Text"],

Cell[BoxData[
    \(C[1] = 0\)], "NumberedEquation",
  TextAlignment->Center],

Cell["\<\
Therefore radial wave function is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[k, Z, r] = 
      C[2]\ \[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ LaguerreL[\(-1\) + 
            Z\/\(k\ a\_0\) - l\_orb, 1 + 2\ l\_orb, 2\ k\ r]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ C[
        2]\ LaguerreL[\(-1\) + Z\/\(k\ a\_0\) - l\_orb, 1 + 2\ l\_orb, 
        2\ k\ r]\)], "Output"]
}, Open  ]],

Cell["\<\
Finiteness of the wave function give the second condition for radial \
function:\
\>", "Text"],

Cell[BoxData[{
    \(\(-1\) + Z\/\(k\ a\_0\) - l\_orb = n\_rad\), "\[IndentingNewLine]", 
    \(n\_rad = \ 0, 1, 2, 3,  ... \)}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " is the radial ",
  "quantum number."
}], "Text"],

Cell["\<\
This implies that generalized Laguerre function has to be polynomial.
Thus we have:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[k, Z, r] = 
      C[2]\ \[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ LaguerreL[n\_rad, 
          1 + 2\ l\_orb, 2\ k\ r]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ C[2]\ LaguerreL[n\_rad, 
        1 + 2\ l\_orb, 2\ k\ r]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Energy levels of the Hydrogen-like atoms", "Section"],

Cell[TextData[{
  "Condition (6) give us possibility to obtain energy levels of the \
Hydrogen-like atoms.\nTo obtain energy levels we will use expressions (2) and \
\"",
  StyleBox["Solve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" Tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[{\(-1\) + Z\/\(k\ a\_0\) - l\_orb == n\_rad, 
        En \[Equal] \(-\(\(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\)\)\)}, {En, 
        k}]\)], "Input"],

Cell[BoxData[
    \({{En \[Rule] \(-\(\(Z\^2\ \[HBar]\^2\)\/\(2\ a\_0\%2\ m\_0\ \((1 + \
l\_orb + n\_rad)\)\^2\)\)\), 
        k \[Rule] Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As a result we have quantified energy levels depending on quantum numbers \
",
  Cell[BoxData[
      \(n\_r\)],
    FontSlant->"Italic"],
  "and ",
  StyleBox["l",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(En[n\_rad, 
        l\_orb] = \(-\(\(Z\^2\ \[HBar]\^2\)\/\(2\ a\_0\%2\ m\_0\ \((1 + \
l\_orb + n\_rad)\)\^2\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(-\(\(Z\^2\ \[HBar]\^2\)\/\(2\ a\_0\%2\ m\_0\ \((1 + l\_orb + \
n\_rad)\)\^2\)\)\)\)], "Output"]
}, Open  ]],

Cell["or", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(En[n\_rad, l\_orb] = 
      Simplify[ReplaceAll[\(-\(\(Z\^2\ \[HBar]\^2\)\/\(2\ a\_0\%2\ m\_0\ \((1 \
+ l\_orb + n\_rad)\)\^2\)\)\), n\_rad \[Rule] n - l\_orb - 1]]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(Z\^2\ \[HBar]\^2\)\/\(2\ n\^2\ a\_0\%2\ m\_0\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is total quantum number:"
}], "Text"],

Cell[BoxData[{
    \(n = n\_rad + l\_orb + 1\), "\n", 
    \(n = \ 0, 1, 2, 3,  ... \)}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Find expression for ",
  StyleBox["k",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(k = \@\(\(2\ \(m\_0\) En\)\/\[HBar]\^2\);\)\), "\[IndentingNewLine]", \

    \(\(En[n\_rad, 
          l] = \(-\(\(Z\^2\ \[HBar]\^2\)\/\(2\ a\_0\%2\ m\_0\ \((1 + l\_orb + \
n\_rad)\)\^2\)\)\);\)\), "\[IndentingNewLine]", 
    \(k = 
      FullSimplify[\@\(\(\(2\ m\_0\)\/\[HBar]\^2\) \(Z\^2\ \[HBar]\^2\)\/\(2\ \
a\_0\%2\ m\_0\ \((1 + l\_orb + n\_rad)\)\^2\)\)]\)}], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\@\(Z\^2\/\(a\_0\%2\ \((1 + l\_orb + n\_rad)\)\^2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(k = Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)\)], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)\)], "Output"]
}, Open  ]],

Cell["Thus we can write down the radial function in the forms:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_r, l\_orb, Z, r] = 
      Simplify[ReplaceAll[
          C[2]\ \[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ LaguerreL[n\_rad, 
              1 + 2\ l\_orb, 2\ k\ r], 
          k \[Rule] Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)\)\)\
\ r\^l\_orb\ C[2]\ LaguerreL[n\_rad, 
        1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\)], \
"Output"]
}, Open  ]],

Cell["or", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n, l\_orb, Z, r] = 
      Simplify[ReplaceAll[R[n\_r, l\_orb, Z, r], 
          n\_rad \[Rule] n - l\_orb - 1]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(n\ a\_0\)\)\)\ r\^l\_orb\ C[
        2]\ LaguerreL[\(-1\) + n - l\_orb, 
        1 + 2\ l\_orb, \(2\ r\ Z\)\/\(n\ a\_0\)]\)], "Output"]
}, Open  ]],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 188, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2672, 90, 64, 0, 85, "Section"],
Cell[2739, 92, 220, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[2984, 103, 711, 18, 113, "Input"],
Cell[3698, 123, 550, 13, 85, "Output"]
}, Open  ]],
Cell[4263, 139, 196, 10, 56, "Text"],
Cell[4462, 151, 86, 1, 67, "NumberedEquation"],
Cell[4551, 154, 493, 21, 80, "Text"],
Cell[5047, 177, 356, 13, 57, "Text"],
Cell[5406, 192, 160, 3, 76, "NumberedEquation"],
Cell[5569, 197, 132, 6, 56, "Text"],

Cell[CellGroupData[{
Cell[5726, 207, 255, 5, 124, "Input"],
Cell[5984, 214, 555, 13, 93, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6576, 232, 143, 4, 93, "Input"],
Cell[6722, 238, 510, 12, 88, "Output"]
}, Open  ]],
Cell[7247, 253, 285, 8, 93, "Text"],

Cell[CellGroupData[{
Cell[7557, 265, 75, 1, 63, "Input"],
Cell[7635, 268, 349, 6, 141, "Output"]
}, Open  ]],
Cell[7999, 277, 210, 8, 56, "Text"],

Cell[CellGroupData[{
Cell[8234, 289, 396, 7, 141, "Input"],
Cell[8633, 298, 169, 3, 87, "Output"],
Cell[8805, 303, 155, 2, 87, "Output"]
}, Open  ]],
Cell[8975, 308, 490, 12, 116, "Text"],
Cell[9468, 322, 100, 2, 53, "NumberedEquation"],
Cell[9571, 326, 379, 16, 92, "Text"],

Cell[CellGroupData[{
Cell[9975, 346, 780, 23, 220, "Input"],
Cell[10758, 371, 3441, 87, 282, "Output"],
Cell[14202, 460, 1569, 48, 115, "Output"]
}, Open  ]],
Cell[15786, 511, 289, 14, 56, "Text"],

Cell[CellGroupData[{
Cell[16100, 529, 1190, 35, 89, "Input"],
Cell[17293, 566, 3474, 86, 282, "Output"],
Cell[20770, 654, 2600, 72, 283, "Output"]
}, Open  ]],
Cell[23385, 729, 336, 14, 92, "Text"],
Cell[23724, 745, 77, 2, 53, "NumberedEquation"],
Cell[23804, 749, 58, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[23887, 755, 182, 3, 87, "Input"],
Cell[24072, 760, 168, 3, 87, "Output"]
}, Open  ]],
Cell[24255, 766, 104, 3, 56, "Text"],
Cell[24362, 771, 174, 3, 97, "NumberedEquation"],
Cell[24539, 776, 141, 7, 56, "Text"],
Cell[24683, 785, 107, 3, 92, "Text"],

Cell[CellGroupData[{
Cell[24815, 792, 154, 3, 64, "Input"],
Cell[24972, 797, 133, 2, 64, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25154, 805, 62, 0, 85, "Section"],
Cell[25219, 807, 313, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[25557, 820, 167, 3, 91, "Input"],
Cell[25727, 825, 191, 3, 93, "Output"]
}, Open  ]],
Cell[25933, 831, 226, 10, 56, "Text"],

Cell[CellGroupData[{
Cell[26184, 845, 146, 3, 93, "Input"],
Cell[26333, 850, 117, 2, 93, "Output"]
}, Open  ]],
Cell[26465, 855, 18, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[26508, 859, 197, 3, 93, "Input"],
Cell[26708, 864, 91, 1, 93, "Output"]
}, Open  ]],
Cell[26814, 868, 111, 5, 56, "Text"],
Cell[26928, 875, 134, 3, 78, "NumberedEquation"],
Cell[27065, 880, 101, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[27191, 889, 445, 10, 247, "Input"],
Cell[27639, 901, 87, 1, 116, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27763, 907, 122, 3, 87, "Input"],
Cell[27888, 912, 72, 1, 87, "Output"]
}, Open  ]],
Cell[27975, 916, 72, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[28072, 920, 263, 5, 142, "Input"],
Cell[28338, 927, 219, 4, 88, "Output"]
}, Open  ]],
Cell[28572, 934, 18, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[28615, 938, 146, 3, 63, "Input"],
Cell[28764, 943, 189, 3, 88, "Output"]
}, Open  ]],
Cell[28968, 949, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

