(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     71565,       2072]*)
(*NotebookOutlinePosition[     72294,       2097]*)
(*  CellTagsIndexPosition[     72250,       2093]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
3.3. Radial probability density and normalization of the radial wave \
functions of the Hydrogen-like atoms\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Radial probability density of the Hydrogen-like atoms", "Section"],

Cell["Consider radial wave function of the Hydrogen-like atoms:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, l\_orb, Z, 
        r] = \[IndentingNewLine]C[n\_rad, l\_orb, 
          Z]\ \[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ LaguerreL[n\_rad, 
          1 + 2\ l\_orb, 2\ k\ r]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-k\)\ r\)\ r\^l\_orb\ C[n\_rad, l\_orb, 
        Z]\ LaguerreL[n\_rad, 1 + 2\ l\_orb, 2\ k\ r]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb, Z]\)],
    FontSlant->"Italic"],
  "is constant."
}], "Text"],

Cell["Define radial probability density:", "Text"],

Cell[BoxData[
    \(RR[n\_rad, l\_orb, Z, 
        r] = \(\(|\)\(R[n\_rad, l\_orb, Z, 
          r]\)\( | \^2\)\(\ \)\(r\^2\)\)\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(R[n\_rad, l\_orb, Z, r]\)],
    FontSlant->"Italic"],
  "is real ",
  "function we have"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, l\_orb, Z, r] = 
      FullSimplify[\((R[n\_rad, l\_orb, Z, r] r)\)\^2]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-2\)\ k\ r\)\ r\^\(2\ \((1 + l\_orb)\)\)\ \
C[n\_rad, l\_orb, Z]\^2\ LaguerreL[n\_rad, 1 + 2\ l\_orb, 2\ k\ r]\^2\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Dimensionless form of the radial wave functions of the Hydrogen-like atoms\
\
\>", "Section"],

Cell["\<\
Transform  radial wave function of quantum oscillator to the dimensionless \
form using new dimensionless variable \[Rho]:\
\>", "Text"],

Cell[BoxData[
    \(\[Rho] = r2\ k, r = \[Rho]\/\(2\ k\)\)], "NumberedEquation"],

Cell[TextData[{
  " and constant ",
  Cell[BoxData[
      \(CC[n\_rad, l\_orb]\)],
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(CC[n\_rad, l\_orb, Z] = 
      C[n\_rad, l\_orb, Z]\/\((2  k)\)\^l\_orb\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R1[n\_rad, l\_orb, Z, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          R[n\_rad, l\_orb, Z, r], {r \[Rule] \[Rho]\/\(2\ k\)}]]\)], "Input"],

Cell[BoxData[
    \(2\^\(-l\_orb\)\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \
\((\[Rho]\/k)\)\^l\_orb\ C[n\_rad, l\_orb, Z]\ LaguerreL[n\_rad, 
        1 + 2\ l\_orb, \[Rho]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R2[n\_rad, l\_orb, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          R1[n\_rad, l\_orb, 
            Z, \[Rho]], {C[n\_rad, l\_orb, Z] \[Rule] 
              CC[n\_rad, l\_orb, Z]\ \((2  k)\)\^l\_orb}]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ k\^l\_orb\ \((\[Rho]\/k)\)\^l\_orb\ \
CC[n\_rad, l\_orb, Z]\ LaguerreL[n\_rad, 1 + 2\ l\_orb, \[Rho]]\)], "Output"]
}, Open  ]],

Cell["So we have dimensionless form of the radial function:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, 
        l\_orb, \[Rho]] = \ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \
\[Rho]\^l\_orb\ CC[n\_rad, l\_orb, Z]\ LaguerreL[n\_rad, 
          1 + 2\ l\_orb, \[Rho]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^l\_orb\ CC[n\_rad, l\_orb, 
        Z]\ LaguerreL[n\_rad, 1 + 2\ l\_orb, \[Rho]]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Normalization procedure for the radial wave functions of the Hydrogen-like \
atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider normalization procedure for radial wave functions. This implies the \
integral condition:\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] RR[n\_rad, l\_orb, Z, 
            r] \[DifferentialD]r = \(\[Integral]\_0\%\[Infinity]\(\((R[
                      n\_rad, l\_orb, Z, r]\ r)\)\^2\) \[DifferentialD]r = 
        1\)\)], "NumberedEquation"],

Cell["or for dimensionless radial functions:", "Text"],

Cell[BoxData[
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[n\_rad, 
                      l\_orb, \[Rho]]\ \[Rho])\)\^2\) \
\[DifferentialD]\[Rho]\) = 1\)], "NumberedEquation"],

Cell["\<\
Normalize radial wave functions for different values of quantum numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_rad\),
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Italic"], "0"}], ",", "1", ",", "2", ",", "3"}]]],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "We will obtain values for constants ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb]\)],
    FontSlant->"Italic"],
  " and normalized radial wave functions ",
  Cell[BoxData[
      \(R\_Nrm[0, 0, r]\)],
    FontSlant->"Italic"],
  "using the expression"
}], "Text"],

Cell[BoxData[
    \(k = Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                    0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                        0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[0, 0, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ CC[0, 0, Z]\)], "Output"],

Cell[BoxData[
    \(CC[0, 0, Z]\^2\/\(4\ k\^3\)\)], "Output"],

Cell[BoxData[
    \({{CC[0, 0, Z] \[Rule] \(-2\)\ k\^\(3/2\)}, {CC[0, 0, Z] \[Rule] 
          2\ k\^\(3/2\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[0, 0, \[Rho]] = 
        2\ \(k\^\(3/
                2\)\) \[ExponentialE]\^\(\(-\[Rho]\)/2\);\)\), "\
\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[0, 0, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 0, l\_orb \[Rule] 0}]]\)}], "Input"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ \((Z\/a\_0)\)\^\(3/2\)\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                    1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                        1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[0, 1, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\ CC[0, 1, Z]\)], "Output"],

Cell[BoxData[
    \(\(3\ CC[0, 1, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[0, 1, Z] \[Rule] \(-\(k\^\(3/2\)\/\@3\)\)}, {CC[0, 1, Z] \[Rule] 
          k\^\(3/2\)\/\@3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[0, 
          1, \[Rho]] = \(k\^\(3/2\)\/\@3\) \[ExponentialE]\^\(\(-\[Rho]\)/2\)\
\ \[Rho];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[0, 1, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 0, l\_orb \[Rule] 1}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ \
\((Z\/a\_0)\)\^\(5/2\)\)\/\(2\ \@6\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                    2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                        2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[0, 2, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^2\ CC[0, 2, Z]\)], "Output"],

Cell[BoxData[
    \(\(90\ CC[0, 2, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[0, 2, Z] \[Rule] \(-\(k\^\(3/2\)\/\(3\ \@10\)\)\)}, {CC[0, 2, 
            Z] \[Rule] k\^\(3/2\)\/\(3\ \@10\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[0, 
          2, \[Rho]] = \(k\^\(3/2\)\/\(3\ \@10\)\) \[ExponentialE]\^\(\(-\
\[Rho]\)/2\)\ \[Rho]\^2;\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[0, 2, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 0, l\_orb \[Rule] 2}]]\)}], "Input"],

Cell[BoxData[
    \(2\/81\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \
r\^2\ \((Z\/a\_0)\)\^\(7/2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                    3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[0, 
                        3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[0, 3, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^3\ CC[0, 3, Z]\)], "Output"],

Cell[BoxData[
    \(\(5040\ CC[0, 3, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[0, 3, Z] \[Rule] \(-\(k\^\(3/2\)\/\(12\ \@35\)\)\)}, {CC[0, 3, 
            Z] \[Rule] k\^\(3/2\)\/\(12\ \@35\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[0, 
          3, \[Rho]] = \(k\^\(3/2\)\/\(12\ \@35\)\) \[ExponentialE]\^\(\(-\
\[Rho]\)/2\)\ \[Rho]\^3;\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[0, 3, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 0, l\_orb \[Rule] 3}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/\(768\ \@35\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                    0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                        0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[1, 0, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((2 - \[Rho])\)\ CC[1, 0, 
        Z]\)], "Output"],

Cell[BoxData[
    \(CC[1, 0, Z]\^2\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[1, 0, Z] \[Rule] \(-k\^\(3/2\)\)}, {CC[1, 0, Z] \[Rule] 
          k\^\(3/2\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[1, 
          0, \[Rho]] = \(k\^\(3/
                2\)\) \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((2 - \[Rho])\);\)\
\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[1, 0, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 1, l\_orb \[Rule] 0}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ \((2 - \(r\ \
Z\)\/a\_0)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(2\ \@2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                    1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                        1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[1, 1, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((4 - \[Rho])\)\ \[Rho]\ CC[1, 1, 
        Z]\)], "Output"],

Cell[BoxData[
    \(\(18\ CC[1, 1, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[1, 1, Z] \[Rule] \(-\(k\^\(3/2\)\/\(3\ \@2\)\)\)}, {CC[1, 1, 
            Z] \[Rule] k\^\(3/2\)\/\(3\ \@2\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[1, 
          1, \[Rho]] = \(k\^\(3/2\)\/\(3\ \@2\)\) \
\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((4 - \[Rho])\)\ \[Rho];\)\), "\
\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[1, 1, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 1, l\_orb \[Rule] 1}]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(2\/27\)\)\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\
\)\)\ r\ \((\(-2\) + \(r\ Z\)\/\(3\ a\_0\))\)\ \((Z\/a\_0)\)\^\(5/2\)\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                    2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                        2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[1, 2, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((6 - \[Rho])\)\ \[Rho]\^2\ CC[1, 
        2, Z]\)], "Output"],

Cell[BoxData[
    \(\(720\ CC[1, 2, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[1, 2, Z] \[Rule] \(-\(k\^\(3/2\)\/\(12\ \@5\)\)\)}, {CC[1, 2, 
            Z] \[Rule] k\^\(3/2\)\/\(12\ \@5\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[1, 
          2, \[Rho]] = \(k\^\(3/2\)\/\(12\ \@5\)\) \[ExponentialE]\^\(\(-\
\[Rho]\)/2\)\ \((6 - \[Rho])\)\ \[Rho]\^2;\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[1, 2, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 1, l\_orb \[Rule] 2}]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ \((\(-3\) \
+ \(r\ Z\)\/\(4\ a\_0\))\)\ \((Z\/a\_0)\)\^\(7/2\)\)\/\(192\ \@5\)\)\)\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                    3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[1, 
                        3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[1, 3, Z]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((8 - \[Rho])\)\ \[Rho]\^3\ CC[1, 
        3, Z]\)], "Output"],

Cell[BoxData[
    \(\(50400\ CC[1, 3, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[1, 3, Z] \[Rule] \(-\(k\^\(3/2\)\/\(60\ \@14\)\)\)}, {CC[1, 3, 
            Z] \[Rule] k\^\(3/2\)\/\(60\ \@14\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[1, 
          3, \[Rho]] = \(k\^\(3/2\)\/\(60\ \@14\)\) \[ExponentialE]\^\(\(-\
\[Rho]\)/2\)\ \((8 - \[Rho])\)\ \[Rho]\^3;\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[1, 3, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 1, l\_orb \[Rule] 3}]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ \
r\^3\ \((\(-4\) + \(r\ Z\)\/\(5\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/9375\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                    0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                        0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[2, 0, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/2\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((6 - 
          6\ \[Rho] + \[Rho]\^2)\)\ CC[2, 0, Z]\)], "Output"],

Cell[BoxData[
    \(\(9\ CC[2, 0, Z]\^2\)\/\(4\ k\^3\)\)], "Output"],

Cell[BoxData[
    \({{CC[2, 0, Z] \[Rule] \(-\(\(2\ k\^\(3/2\)\)\/3\)\)}, {CC[2, 0, 
            Z] \[Rule] \(2\ k\^\(3/2\)\)\/3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[2, 
          0, \[Rho]] = \(2\ k\^\(3/2\)\)\/3\ 1\/2\ \[ExponentialE]\^\(\(-\
\[Rho]\)/2\)\ \((6 - 6\ \[Rho] + \[Rho]\^2)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[2, 0, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 2, l\_orb \[Rule] 0}]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \((3 + \(2\ r\ Z\ \
\((r\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(9\ \@3\
\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                    1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                        1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[2, 1, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/2\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\ \((20 - 
          10\ \[Rho] + \[Rho]\^2)\)\ CC[2, 1, Z]\)], "Output"],

Cell[BoxData[
    \(\(60\ CC[2, 1, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[2, 1, Z] \[Rule] \(-\(k\^\(3/2\)\/\(2\ \@15\)\)\)}, {CC[2, 1, 
            Z] \[Rule] k\^\(3/2\)\/\(2\ \@15\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[2, 1, \[Rho]] = \(k\^\(3/2\)\/\(2\ \@15\)\) 
          1\/2\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\ \((20 - 
              10\ \[Rho] + \[Rho]\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[2, 1, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 2, l\_orb \[Rule] 1}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ \((5 + \(r\ Z\ \
\((r\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(5/2\)\)\/\(16\ \
\@15\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                    2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                        2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[2, 2, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/2\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^2\ \((42 - 
          14\ \[Rho] + \[Rho]\^2)\)\ CC[2, 2, Z]\)], "Output"],

Cell[BoxData[
    \(\(3150\ CC[2, 2, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[2, 2, Z] \[Rule] \(-\(k\^\(3/2\)\/\(15\ \@14\)\)\)}, {CC[2, 2, 
            Z] \[Rule] k\^\(3/2\)\/\(15\ \@14\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[2, 2, \[Rho]] = \(k\^\(3/2\)\/\(15\ \@14\)\) 
          1\/2\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^2\ \((42 - 
              14\ \[Rho] + \[Rho]\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[2, 2, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 2, l\_orb \[Rule] 2}]]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^2\
\ \((21 + \(2\ r\ Z\ \((r\ Z - 35\ a\_0)\)\)\/\(25\ a\_0\%2\))\)\ \((Z\/a\_0)\
\)\^\(7/2\)\)\/1875\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                    3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[2, 
                        3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[2, 3, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/2\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^3\ \((72 - 
          18\ \[Rho] + \[Rho]\^2)\)\ CC[2, 3, Z]\)], "Output"],

Cell[BoxData[
    \(\(272160\ CC[2, 3, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[2, 3, Z] \[Rule] \(-\(k\^\(3/2\)\/\(36\ \@210\)\)\)}, {CC[2, 3, 
            Z] \[Rule] k\^\(3/2\)\/\(36\ \@210\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[2, 3, \[Rho]] = \(k\^\(3/2\)\/\(36\ \@210\)\) 
          1\/2\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^3\ \((72 - 
              18\ \[Rho] + \[Rho]\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[2, 3, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 2, l\_orb \[Rule] 3}]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^3\ \((\(-6\) + \
\(r\ Z\)\/\(6\ a\_0\))\)\ \((\(-3\) + \(r\ Z\)\/\(6\ a\_0\))\)\ \((Z\/a\_0)\)\
\^\(9/2\)\)\/\(17496\ \@35\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                    0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                        0, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[3, 0, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((24 - 36\ \[Rho] + 
          12\ \[Rho]\^2 - \[Rho]\^3)\)\ CC[3, 0, Z]\)], "Output"],

Cell[BoxData[
    \(\(4\ CC[3, 0, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[3, 0, Z] \[Rule] \(-\(k\^\(3/2\)\/2\)\)}, {CC[3, 0, Z] \[Rule] 
          k\^\(3/2\)\/2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[3, 0, \[Rho]] = \(k\^\(3/2\)\/2\) 
          1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \((24 - 36\ \[Rho] + 
              12\ \[Rho]\^2 - \[Rho]\^3)\);\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[3, 0, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 3, l\_orb \[Rule] 0}]]\)}], "Input"],

Cell[BoxData[
    \(1\/12\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ \((3 - \(r\ Z\ \
\((r\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                    1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                        1, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[3, 1, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\ \((120 - 90\ \[Rho] + 
          18\ \[Rho]\^2 - \[Rho]\^3)\)\ CC[3, 1, Z]\)], "Output"],

Cell[BoxData[
    \(\(150\ CC[3, 1, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[3, 1, Z] \[Rule] \(-\(k\^\(3/2\)\/\(5\ \@6\)\)\)}, {CC[3, 1, 
            Z] \[Rule] k\^\(3/2\)\/\(5\ \@6\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[3, 1, \[Rho]] = \(k\^\(3/2\)\/\(5\ \@6\)\) 
          1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\ \((120 - 
              90\ \[Rho] + 
              18\ \[Rho]\^2 - \[Rho]\^3)\);\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[3, 1, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 3, l\_orb \[Rule] 1}]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(2\/375\)\)\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\
\)\)\)\ r\ \((Z\/a\_0)\)\^\(5/2\)\ \((\(-30\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + 45\
\ a\_0\ \((\(-2\)\ r\ Z + 25\ a\_0)\))\)\)\/\(125\ a\_0\%3\))\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                    2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                        2, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[3, 2, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^2\ \((336 - 
          168\ \[Rho] + 24\ \[Rho]\^2 - \[Rho]\^3)\)\ CC[3, 2, Z]\)], "Output"],

Cell[BoxData[
    \(\(10080\ CC[3, 2, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[3, 2, Z] \[Rule] \(-\(k\^\(3/2\)\/\(12\ \@70\)\)\)}, {CC[3, 2, 
            Z] \[Rule] k\^\(3/2\)\/\(12\ \@70\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[3, 2, \[Rho]] = \(k\^\(3/2\)\/\(12\ \@70\)\) 
          1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^2\ \((336 - 
              168\ \[Rho] + 
              24\ \[Rho]\^2 - \[Rho]\^3)\);\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[3, 2, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 3, l\_orb \[Rule] 2}]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^2\ \
\((Z\/a\_0)\)\^\(7/2\)\ \((\(-42\) + \(r\ Z\ \((r\^2\ Z\^2 + 72\ a\_0\ \
\((\(-r\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\)\/\(972\ \
\@105\)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, \[Rho]], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                    3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\)\), "\
\[IndentingNewLine]", 
    \(Solve[\(1\/\((2\ k)\)\^3\) \(\[Integral]\_0\%\[Infinity]\(\((R[3, 
                        3, \[Rho]]\ \[Rho])\)\^2\) \[DifferentialD]\[Rho]\) \
\[Equal] 1, CC[3, 3, Z]]\)}], "Input"],

Cell[BoxData[
    \(1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^3\ \((720 - 
          270\ \[Rho] + 30\ \[Rho]\^2 - \[Rho]\^3)\)\ CC[3, 3, Z]\)], "Output"],

Cell[BoxData[
    \(\(1058400\ CC[3, 3, Z]\^2\)\/k\^3\)], "Output"],

Cell[BoxData[
    \({{CC[3, 3, Z] \[Rule] \(-\(k\^\(3/2\)\/\(420\ \@6\)\)\)}, {CC[3, 3, 
            Z] \[Rule] k\^\(3/2\)\/\(420\ \@6\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R\_Nrm[3, 3, \[Rho]] = \(k\^\(3/2\)\/\(420\ \@6\)\) 
          1\/6\ \[ExponentialE]\^\(\(-\[Rho]\)/2\)\ \[Rho]\^3\ \((720 - 
              270\ \[Rho] + 
              30\ \[Rho]\^2 - \[Rho]\^3)\);\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ 2\ k}]];\)\), "\[IndentingNewLine]", 
    \(\(FullSimplify[
        ReplaceAll[%, {k \[Rule] 
              Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)}]];\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[3, 3, r] = 
      FullSimplify[
        ReplaceAll[%, {n\_rad \[Rule] 3, l\_orb \[Rule] 3}]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/21\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ \
r\^3\ \((Z\/a\_0)\)\^\(9/2\)\ \((\(-180\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + 105\ a\
\_0\ \((\(-2\)\ r\ Z + 63\ a\_0)\))\)\)\/\(343\ \
a\_0\%3\))\)\)\/756315\)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Normalized radial wave functions of the Hydrogen-like atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Resulting normalized radial wave functions of the Hydrogen-like atoms are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_HydAt[0, 0, Z] = 
        2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ \
\((Z\/a\_0)\)\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[0, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ \
\((Z\/a\_0)\)\^\(5/2\)\)\/\(2\ \@6\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[0, 2, Z] = 
        2\/81\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \
r\^2\ \((Z\/a\_0)\)\^\(7/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[0, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/\(768\ \@35\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ \((2 - \(r\ \
Z\)\/a\_0)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(2\ \@2\);\)\), \
"\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 1, 
          Z] = \(-\(2\/27\)\)\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\ \
Z\)\/\(3\ a\_0\)\)\)\ r\ \((\(-2\) + \(r\ Z\)\/\(3\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(5/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 2, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ \
\((\(-3\) + \(r\ Z\)\/\(4\ a\_0\))\)\ \((Z\/a\_0)\)\^\(7/2\)\)\/\(192\ \
\@5\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 3, 
          Z] = \(-\(\(2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ \
a\_0\)\)\)\ r\^3\ \((\(-4\) + \(r\ Z\)\/\(5\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/9375\)\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \((3 + \
\(2\ r\ Z\ \((r\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\))\)\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\(9\ \@3\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ \((5 + \
\(r\ Z\ \((r\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(5/2\)\)\
\/\(16\ \@15\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 2, 
          Z] = \(1\/1875\) \((2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ \
Z\)\/\(5\ a\_0\)\)\)\ r\^2\ \((21 + \(2\ r\ Z\ \((r\ Z - 35\ a\_0)\)\)\/\(25\ \
a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(7/2\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 3, 
          Z] = \(-\(1\/\(972\ \@105\)\)\) \((\[ExponentialE]\^\(-\(\(r\ Z\)\/\
\(6\ a\_0\)\)\)\ r\^2\ \((Z\/a\_0)\)\^\(7/2\)\ \((\(-42\) + \(r\ Z\ \((r\^2\ \
Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ a\_0)\))\)\)\/\(216\ \
a\_0\%3\))\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 0, Z] = 
        1\/12\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ \((3 - \(r\ Z\
\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\ \
\((Z\/a\_0)\)\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 1, 
          Z] = \(-\(2\/375\)\)\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\
\(5\ a\_0\)\)\)\ r\ \((Z\/a\_0)\)\^\(5/2\)\ \((\(-30\) + \(r\ Z\ \((2\ r\^2\ \
Z\^2 + 45\ a\_0\ \((\(-2\)\ r\ Z + 25\ a\_0)\))\)\)\/\(125\ \
a\_0\%3\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 2, 
          Z] = \(-\(1\/\(972\ \@105\)\)\) \((\[ExponentialE]\^\(-\(\(r\ Z\)\/\
\(6\ a\_0\)\)\)\ r\^2\ \((Z\/a\_0)\)\^\(7/2\)\ \((\(-42\) + \(r\ Z\ \((r\^2\ \
Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ a\_0)\))\)\)\/\(216\ \
a\_0\%3\))\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 3, 
          Z] = \(-\(1\/756315\)\) \((2\ \@\(2\/21\)\ \
\[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ r\^3\ \((Z\/a\_0)\)\^\(9/2\)\
\ \((\(-180\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + 105\ a\_0\ \((\(-2\)\ r\ Z + 63\ a\
\_0)\))\)\)\/\(343\ a\_0\%3\))\))\);\)\)}], "Input"],

Cell["\<\
Resulting radial probability density of the Hydrogen-like atoms are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RR\_HydAt[0, 0, Z] = 
        R\_HydAt[0, 0, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 1, Z] = 
        R\_HydAt[0, 1, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 2, Z] = 
        R\_HydAt[0, 2, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 3, Z] = 
        R\_HydAt[0, 3, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 0, Z] = 
        R\_HydAt[1, 0, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 1, Z] = 
        R\_HydAt[1, 1, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 2, Z] = 
        R\_HydAt[1, 2, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 3, Z] = 
        R\_HydAt[1, 3, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(RR\_HydAt[2, 0, Z] = 
      R\_HydAt[2, 0, Z]\^2\ r\^2\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 1, Z] = 
        R\_HydAt[2, 1, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 2, Z] = 
        R\_HydAt[2, 2, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 3, Z] = 
        R\_HydAt[2, 3, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 0, Z] = 
        R\_HydAt[3, 0, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 1, Z] = 
        R\_HydAt[3, 1, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 2, Z] = 
        R\_HydAt[3, 2, Z]\^2\ r\^2;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 3, Z] = R\_HydAt[3, 3, Z]\^2\ r\^2;\)\)}], "Input"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ Z\^3\ \
\((3 + \(2\ r\ Z\ \((r\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\))\)\^2\)\/\(243\ a\_0\
\%3\)\)], "Output"]
}, Open  ]],

Cell["Thus we have:", "Text"],

Cell[BoxData[{
    \(\(RR\_HydAt[0, 0, 
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\)\
\/a\_0\%3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\)\/\(24\
\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ \
Z\^7\)\/\(98415\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ \
Z\^9\)\/\(20643840\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\ \((2 - \
\(r\ Z\)\/a\_0)\)\^2\)\/\(8\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 1, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ \
Z\^5\ \((\(-2\) + \(r\ Z\)\/\(3\ a\_0\))\)\^2\)\/\(2187\ a\_0\%5\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((\(-3\) + \(r\ Z\)\/\(4\ a\_0\))\)\^2\)\/\(184320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ \
Z\^9\ \((\(-4\) + \(r\ Z\)\/\(5\ a\_0\))\)\^2\)\/\(3076171875\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 0, 
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ \
Z\^3\ \((3 + \(2\ r\ Z\ \((r\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\))\)\^2\)\/\(243\
\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ \
\((5 + \(r\ Z\ \((r\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\^2\)\/\(3840\ a\_0\
\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ \
Z\^7\ \((21 + \(2\ r\ Z\ \((r\ Z - 35\ a\_0)\)\)\/\(25\ \
a\_0\%2\))\)\^2\)\/\(123046875\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((\(-42\) + \(r\ Z\ \((r\^2\ Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ \
a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^2\ Z\^3\ \
\((3 - \(r\ Z\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\^2\)\/\(144\ \
a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 1, 
          Z] = \(1\/\(2109375\ a\_0\%5\)\) \((8\ \[ExponentialE]\^\(-\(\(2\ r\
\ Z\)\/\(5\ a\_0\)\)\)\ r\^4\ Z\^5\ \((\(-30\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + \
45\ a\_0\ \((\(-2\)\ r\ Z + 25\ a\_0)\))\)\)\/\(125\ a\_0\%3\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((\(-42\) + \(r\ Z\ \((r\^2\ Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ \
a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ \
Z\^9\)\/\(12012259963725\ a\_0\%9\)\ \((\(-180\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + \
105\ a\_0\ \((\(-2\)\ r\ Z + 63\ a\_0)\))\)\)\/\(343\ a\_0\%3\))\)\^2;\)\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. General expression for normalized radial wave functions", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Normalized radial wave functions can be represented in general form [see \
Ref. 1].\nIn this case we will use expressions for constant ",
  Cell[BoxData[
      \(CC[n\_rad, l\_orb, Z]\)],
    FontSlant->"Italic"],
  ":"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(CC[n\_rad, l\_orb, 
        Z] = \@\(\(4\ \(n\_rad!\)\)\/\(\(\ \)\(\(\((1 + 2\ l\_orb + \
n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\)\ \((Z\/a\_0)\)\^\(3/2\)\), "\
\[IndentingNewLine]", 
    \(or\), "\[IndentingNewLine]", 
    \(CC[n, l\_orb, 
        Z] = \@\(\(4\ \(\((n - l\_orb - 1)\)!\)\)\/\(\(\ \)\(\(\((n + l\_orb)\
\)!\)\ n\)\)\)\ \((Z\/a\_0)\)\^\(3/2\)\)}], "NumberedEquation"],

Cell["Thus we have", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rgen\_HydAt[n\_rad, l\_orb, 
        Z] = \(\(\((Z\/\(\((1 + l\_orb + n\_rad)\) a\_0\))\)\^\(3/
              2\)\)\(\ \ \)\(\@\(\(4\ \(n\_rad!\)\)\/\(\(\ \)\(\(\((1 + 
                        2\ l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + 
                      n\_rad)\)\)\)\)\)\(\ \)\(\[ExponentialE]\^\(-\(\(r\ Z\)\
\/\(a\_0\ \((1 + l\_orb + 
                        n\_rad)\)\)\)\)\)\(\ \)\(\((\(2\ r\ Z\)\/\(\((1 + \
l\_orb + n\_rad)\) a\_0\))\)\^l\_orb\)\(\ \)\(LaguerreL[n\_rad, 
          1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
        1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
\@\(\(n\_rad!\)\/\(\(\((1 + 2\ l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\
\)\)\)\ \((Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ \
Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\))\)\^l\_orb\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rgen\_HydAt[n, l\_orb, 
        Z] = \(\(\((Z\/\(n\ a\_0\))\)\^\(3/
              2\)\)\(\ \)\(\@\(\(4\ \(\((n - l\_orb - 
                        1)\)!\)\)\/\(\(\ \)\(\(\((n + 
                        l\_orb)\)!\)\ n\)\)\)\)\(\ \)\(\[ExponentialE]\^\(-\(\
\(r\ Z\)\/\(a\_0\ n\)\)\)\)\(\ \)\(\((\(2  Z\ r\)\/\(n\ a\_0\))\)\^l\_orb\) \
\(LaguerreL[n - l\_orb - 1, 
          1 + 2\ l\_orb, \(2\ r\ Z\)\/\(n\ a\_0\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(n\ a\_0\)\)\)\ \
\@\(\(\((\(-1\) + n - l\_orb)\)!\)\/\(n\ \(\((n + l\_orb)\)!\)\)\)\ \
LaguerreL[\(-1\) + n - l\_orb, 
        1 + 2\ l\_orb, \(2\ r\ Z\)\/\(n\ a\_0\)]\ \((Z\/\(n\ a\_0\))\)\^\(3/2\
\)\ \((\(r\ Z\)\/\(n\ a\_0\))\)\^l\_orb\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we can compare general expressions to ",
  Cell[BoxData[
      StyleBox[\(R\_HydAt[n, l\_orb, Z]\),
        FontSlant->"Italic"]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_HydAt[0, 0, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[0, 0, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[0, 1, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[0, 1, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[0, 2, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[0, 2, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[0, 3, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[0, 3, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 0, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[1, 0, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[1, 0, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[1, 1, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[1, 1, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[1, 2, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[1, 2, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[1, 3, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[1, 3, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 1, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[2, 0, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[2, 0, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[2, 1, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[2, 1, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[2, 2, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[2, 2, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[2, 3, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[2, 3, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 2, 
          l\_orb \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[3, 0, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[3, 0, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[3, 1, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[3, 1, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[3, 2, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[3, 2, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(R\_HydAt[3, 3, Z]\), "\[IndentingNewLine]", 
    \(Rgen\_HydAt[3, 3, Z] = 
      ReplaceAll[
        Rgen\_HydAt[n\_rad, l\_orb, Z], {n\_rad \[Rule] 3, 
          l\_orb \[Rule] 3}]\)}], "Input"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ \((Z\/a\_0)\)\^\(3/2\)\)], \
"Output"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ \((Z\/a\_0)\)\^\(3/2\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ \
\((Z\/a\_0)\)\^\(5/2\)\)\/\(2\ \@6\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ Z\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\(2\ \@6\ a\_0\)\)], "Output"],

Cell[BoxData[
    \(2\/81\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \
r\^2\ \((Z\/a\_0)\)\^\(7/2\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\
\ Z\^2\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(81\ a\_0\%2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/\(768\ \@35\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ Z\^3\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\(768\ \@35\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ \((2 - \(r\ \
Z\)\/a\_0)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(2\ \@2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ \((2 - \(r\ \
Z\)\/a\_0)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(2\ \@2\)\)], "Output"],

Cell[BoxData[
    \(\(-\(2\/27\)\)\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\
\)\)\ r\ \((\(-2\) + \(r\ Z\)\/\(3\ a\_0\))\)\ \((Z\/a\_0)\)\^\(5/2\)\)], \
"Output"],

Cell[BoxData[
    \(\(\@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\ Z\ \
\((4 - \(2\ r\ Z\)\/\(3\ a\_0\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(27\ \
a\_0\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ \((\(-3\) \
+ \(r\ Z\)\/\(4\ a\_0\))\)\ \((Z\/a\_0)\)\^\(7/2\)\)\/\(192\ \@5\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ Z\^2\ \((6 - \
\(r\ Z\)\/\(2\ a\_0\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(384\ \@5\ a\_0\%2\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ \
r\^3\ \((\(-4\) + \(r\ Z\)\/\(5\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/9375\)\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^3\ Z\
\^3\ \((8 - \(2\ r\ Z\)\/\(5\ a\_0\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(9375\ \
a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \((3 + \(2\ r\ Z\ \
\((r\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(9\ \@3\
\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \
\((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^2\ Z\^2 - 18\ r\ Z\ a\_0 + 27\ \
a\_0\%2)\)\)\/\(81\ \@3\ a\_0\%2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ \((5 + \(r\ Z\ \
\((r\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(5/2\)\)\/\(16\ \
\@15\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ Z\ \
\((Z\/a\_0)\)\^\(3/2\)\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ \
a\_0\%2)\)\)\/\(256\ \@15\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^2\
\ \((21 + \(2\ r\ Z\ \((r\ Z - 35\ a\_0)\)\)\/\(25\ a\_0\%2\))\)\ \((Z\/a\_0)\
\)\^\(7/2\)\)\/1875\)], "Output"],

Cell[BoxData[
    \(\(2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^2\
\ Z\^2\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ a\_0\
\%2)\)\)\/\(46875\ a\_0\%4\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^2\ \
\((Z\/a\_0)\)\^\(7/2\)\ \((\(-42\) + \(r\ Z\ \((r\^2\ Z\^2 + 72\ a\_0\ \
\((\(-r\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\)\/\(972\ \
\@105\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^3\ Z\^3\ \
\((Z\/a\_0)\)\^\(3/2\)\ \((r\^2\ Z\^2 - 54\ r\ Z\ a\_0 + 648\ \
a\_0\%2)\)\)\/\(629856\ \@35\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(1\/12\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ \((3 - \(r\ Z\ \
\((r\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ \((Z\/a\_0)\)\^\(3/2\
\)\ \((\(-r\^3\)\ Z\^3 + 24\ r\^2\ Z\^2\ a\_0 - 144\ r\ Z\ a\_0\%2 + 192\ \
a\_0\%3)\)\)\/\(768\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(-\(2\/375\)\)\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\
\)\)\)\ r\ \((Z\/a\_0)\)\^\(5/2\)\ \((\(-30\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + 45\
\ a\_0\ \((\(-2\)\ r\ Z + 25\ a\_0)\))\)\)\/\(125\ a\_0\%3\))\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ \
r\ Z\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^3\ Z\^3 - 90\ r\^2\ Z\^2\ a\_0 + 
                1125\ r\ Z\ a\_0\%2 - 
                3750\ a\_0\%3)\)\)\/\(46875\ a\_0\%4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^2\ \
\((Z\/a\_0)\)\^\(7/2\)\ \((\(-42\) + \(r\ Z\ \((r\^2\ Z\^2 + 72\ a\_0\ \
\((\(-r\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\)\/\(972\ \
\@105\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^2\ Z\^2\ \
\((Z\/a\_0)\)\^\(3/2\)\ \((\(-r\^3\)\ Z\^3 + 72\ r\^2\ Z\^2\ a\_0 - 1512\ r\ \
Z\ a\_0\%2 + 9072\ a\_0\%3)\)\)\/\(209952\ \@105\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/21\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ \
r\^3\ \((Z\/a\_0)\)\^\(9/2\)\ \((\(-180\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + 105\ a\
\_0\ \((\(-2\)\ r\ Z + 63\ a\_0)\))\)\)\/\(343\ \
a\_0\%3\))\)\)\/756315\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(2\ \@\(2\/21\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ \
r\^3\ Z\^3\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^3\ Z\^3 - 
                210\ r\^2\ Z\^2\ a\_0 + 6615\ r\ Z\ a\_0\%2 - 
                61740\ a\_0\%3)\)\)\/\(259416045\ a\_0\%6\)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6. Normalized radial probability densities of the Hydrogen-like atoms in the \
Cartesian rectangular coordinates\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
To obtain radial wave functions and radial probability densities of the \
Hydrogen-like atoms in the Cartesian rectangular coordinates we will use \
coordinate transformations:\
\>", "Text"],

Cell[BoxData[
    \(\(r = \@\(x^2 + y^2 + z^2\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(RR\_HydAt[0, 0, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[0, 1, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[0, 2, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[0, 3, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[1, 0, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[1, 1, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[1, 2, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[1, 3, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[2, 0, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[2, 1, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[2, 2, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[2, 3, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[3, 0, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[3, 1, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[3, 2, Z]\), "\[IndentingNewLine]", 
    \(RR\_HydAt[3, 3, Z]\)}], "Input"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/a\_0\%3\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\ \((x\
\^2 + y\^2 + z\^2)\)\^2\ Z\^5\)\/\(24\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\)\/\(98415\ a\_0\%7\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\)\/\(20643840\ a\_0\%9\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\ \((x\
\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2 - \(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0)\)\^2\)\/\(8\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((\(-2\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\)\/\(3\ a\_0\))\)\^2\)\/\(2187\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-3\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\)\/\(4\ a\_0\))\)\^2\)\/\(184320\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\ \((\(-4\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\)\/\(5\ a\_0\))\)\^2\)\/\(3076171875\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(4\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((3 + \(2\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 9\ a\_0)\)\)\/\(9\ \
a\_0\%2\))\)\^2\)\/\(243\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((5 + \(\@\(x\^2 + y\^2 + \
z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\
\^2\)\/\(3840\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((21 + \(2\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 35\ a\_0)\)\)\/\(25\ a\_0\%2\))\)\
\^2\)\/\(123046875\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-42\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 72\ a\_0\ \((\(-\@\(x\^2 + y\
\^2 + z\^2\)\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\
\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((3 - \(\@\(x\^2 + y\^2 + z\^2\)\
\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\^2\
\)\/\(144\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((\(-30\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 45\ a\_0\ \((\(-2\)\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z + 25\ a\_0)\))\)\)\/\(125\ \
a\_0\%3\))\)\^2\)\/\(2109375\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-42\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 72\ a\_0\ \((\(-\@\(x\^2 + y\
\^2 + z\^2\)\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\
\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\ \((\(-180\) + \(\@\(x\^2 + \
y\^2 + z\^2\)\ Z\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 105\ a\_0\ \((\(-2\)\
\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 63\ a\_0)\))\)\)\/\(343\ \
a\_0\%3\))\)\^2\)\/\(12012259963725\ a\_0\%9\)\)], "Output"]
}, Open  ]],

Cell["\<\
Resulting radial probability densities of the Hydrogen-like atoms in the \
Cartesian rectangular coordinates:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_\(HydAt, Cart\)[0, 0, 
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/a\_0\%3;\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[0, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\)\/\(24\ a\_0\%5\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[0, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\)\/\(98415\ \
a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[0, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\)\/\(20643840\ a\_0\%9\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2 - \(\@\(x\^2 + y\^2 + \
z\^2\)\ Z\)\/a\_0)\)\^2\)\/\(8\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 1, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((\(-2\) + \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\))\)\^2\)\/\(2187\ a\_0\%5\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-3\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\)\/\(4\ a\_0\))\)\^2\)\/\(184320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\ \((\(-4\) + \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\))\)\^2\)\/\(3076171875\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 0, 
          
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((3 + \(2\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\
\))\)\^2\)\/\(243\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((5 + \(\@\(x\^2 + y\^2 + \
z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\
\^2\)\/\(3840\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((21 + \(2\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 35\ a\_0)\)\)\/\
\(25\ a\_0\%2\))\)\^2\)\/\(123046875\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-42\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 72\ a\_0\ \((\(-\@\(x\^2 + y\
\^2 + z\^2\)\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\
\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((3 - \(\@\(x\^2 + y\^2 + z\^2\)\
\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\^2\
\)\/\(144\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 1, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((\(-30\) + \(\@\(x\
\^2 + y\^2 + z\^2\)\ Z\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 45\ a\_0\ \
\((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 25\ a\_0)\))\)\)\/\(125\ \
a\_0\%3\))\)\^2\)\/\(2109375\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-42\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 72\ a\_0\ \((\(-\@\(x\^2 + y\
\^2 + z\^2\)\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\
\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(7\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\ \((\(-180\) + \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 105\ \
a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 63\ a\_0)\))\)\)\/\(343\ \
a\_0\%3\))\)\^2\)\/\(12012259963725\ a\_0\%9\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 187, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2671, 90, 75, 0, 85, "Section"],
Cell[2749, 92, 73, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[2847, 96, 215, 4, 88, "Input"],
Cell[3065, 102, 149, 2, 64, "Output"]
}, Open  ]],
Cell[3229, 107, 131, 6, 56, "Text"],
Cell[3363, 115, 50, 0, 56, "Text"],
Cell[3416, 117, 176, 4, 54, "NumberedEquation"],
Cell[3595, 123, 196, 9, 56, "Text"],

Cell[CellGroupData[{
Cell[3816, 136, 115, 2, 64, "Input"],
Cell[3934, 140, 170, 3, 64, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4153, 149, 106, 3, 85, "Section"],
Cell[4262, 154, 146, 3, 56, "Text"],
Cell[4411, 159, 80, 1, 65, "NumberedEquation"],
Cell[4494, 162, 119, 5, 56, "Text"],
Cell[4616, 169, 115, 2, 71, "NumberedEquation"],

Cell[CellGroupData[{
Cell[4756, 175, 171, 4, 82, "Input"],
Cell[4930, 181, 184, 3, 84, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5151, 189, 246, 6, 113, "Input"],
Cell[5400, 197, 171, 2, 84, "Output"]
}, Open  ]],
Cell[5586, 202, 69, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[5680, 206, 200, 4, 64, "Input"],
Cell[5883, 212, 158, 2, 64, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6090, 220, 159, 5, 85, "Section"],
Cell[6252, 227, 122, 3, 56, "Text"],
Cell[6377, 232, 254, 4, 73, "NumberedEquation"],
Cell[6634, 238, 54, 0, 56, "Text"],
Cell[6691, 240, 194, 3, 73, "NumberedEquation"],
Cell[6888, 245, 96, 2, 56, "Text"],
Cell[6987, 249, 309, 11, 72, "NumberedEquation"],
Cell[7299, 262, 280, 10, 56, "Text"],
Cell[7582, 274, 86, 1, 70, "NumberedEquation"],

Cell[CellGroupData[{
Cell[7693, 279, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7903, 293, 526, 10, 170, "Input"],
Cell[8432, 305, 81, 1, 64, "Output"],
Cell[8516, 308, 61, 1, 88, "Output"],
Cell[8580, 311, 124, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8741, 318, 579, 16, 168, "Input"],
Cell[9323, 336, 103, 2, 89, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9475, 344, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[9685, 358, 526, 10, 170, "Input"],
Cell[10214, 370, 89, 1, 64, "Output"],
Cell[10306, 373, 61, 1, 88, "Output"],
Cell[10370, 376, 132, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10539, 383, 574, 15, 206, "Input"],
Cell[11116, 400, 126, 2, 116, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11291, 408, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[11501, 422, 526, 10, 170, "Input"],
Cell[12030, 434, 92, 1, 64, "Output"],
Cell[12125, 437, 62, 1, 88, "Output"],
Cell[12190, 440, 150, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12377, 447, 585, 15, 206, "Input"],
Cell[12965, 464, 133, 2, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13147, 472, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[13357, 486, 526, 10, 170, "Input"],
Cell[13886, 498, 92, 1, 64, "Output"],
Cell[13981, 501, 64, 1, 88, "Output"],
Cell[14048, 504, 152, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14237, 511, 586, 15, 206, "Input"],
Cell[14826, 528, 132, 2, 116, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15007, 536, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[15217, 550, 526, 10, 170, "Input"],
Cell[15746, 562, 108, 2, 64, "Output"],
Cell[15857, 566, 54, 1, 88, "Output"],
Cell[15914, 569, 118, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16069, 576, 596, 16, 168, "Input"],
Cell[16668, 594, 149, 2, 116, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[16866, 602, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[17076, 616, 526, 10, 170, "Input"],
Cell[17605, 628, 116, 2, 64, "Output"],
Cell[17724, 632, 62, 1, 88, "Output"],
Cell[17789, 635, 148, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17974, 642, 601, 16, 206, "Input"],
Cell[18578, 660, 178, 3, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18805, 669, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[19015, 683, 526, 10, 170, "Input"],
Cell[19544, 695, 119, 2, 64, "Output"],
Cell[19666, 699, 63, 1, 88, "Output"],
Cell[19732, 702, 150, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19919, 709, 603, 15, 206, "Input"],
Cell[20525, 726, 180, 3, 116, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20754, 735, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[20964, 749, 526, 10, 170, "Input"],
Cell[21493, 761, 119, 2, 64, "Output"],
Cell[21615, 765, 65, 1, 88, "Output"],
Cell[21683, 768, 152, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21872, 775, 604, 15, 206, "Input"],
Cell[22479, 792, 188, 3, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22716, 801, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[22926, 815, 526, 10, 170, "Input"],
Cell[23455, 827, 131, 2, 85, "Output"],
Cell[23589, 831, 68, 1, 88, "Output"],
Cell[23660, 834, 144, 2, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23841, 841, 609, 15, 195, "Input"],
Cell[24453, 858, 189, 3, 118, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24691, 867, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[24902, 881, 526, 10, 170, "Input"],
Cell[25431, 893, 141, 2, 85, "Output"],
Cell[25575, 897, 62, 1, 88, "Output"],
Cell[25640, 900, 150, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25827, 907, 636, 15, 206, "Input"],
Cell[26466, 924, 190, 3, 118, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26705, 933, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[26916, 947, 526, 10, 170, "Input"],
Cell[27445, 959, 144, 2, 85, "Output"],
Cell[27592, 963, 64, 1, 88, "Output"],
Cell[27659, 966, 152, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27848, 973, 640, 15, 206, "Input"],
Cell[28491, 990, 205, 3, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28745, 999, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[28956, 1013, 526, 10, 170, "Input"],
Cell[29485, 1025, 144, 2, 85, "Output"],
Cell[29632, 1029, 66, 1, 88, "Output"],
Cell[29701, 1032, 154, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29892, 1039, 641, 15, 206, "Input"],
Cell[30536, 1056, 212, 3, 116, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30797, 1065, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[31008, 1079, 526, 10, 170, "Input"],
Cell[31537, 1091, 149, 2, 85, "Output"],
Cell[31689, 1095, 61, 1, 88, "Output"],
Cell[31753, 1098, 128, 2, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31918, 1105, 634, 15, 195, "Input"],
Cell[32555, 1122, 179, 3, 93, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32783, 1131, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[32994, 1145, 526, 10, 170, "Input"],
Cell[33523, 1157, 158, 2, 85, "Output"],
Cell[33684, 1161, 63, 1, 88, "Output"],
Cell[33750, 1164, 148, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33935, 1171, 667, 16, 206, "Input"],
Cell[34605, 1189, 249, 3, 100, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34903, 1198, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[35114, 1212, 526, 10, 170, "Input"],
Cell[35643, 1224, 162, 2, 85, "Output"],
Cell[35808, 1228, 65, 1, 88, "Output"],
Cell[35876, 1231, 152, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36065, 1238, 673, 16, 206, "Input"],
Cell[36741, 1256, 247, 4, 119, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37037, 1266, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[37248, 1280, 526, 10, 170, "Input"],
Cell[37777, 1292, 162, 2, 85, "Output"],
Cell[37942, 1296, 67, 1, 88, "Output"],
Cell[38012, 1299, 152, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38201, 1306, 673, 16, 206, "Input"],
Cell[38877, 1324, 263, 4, 124, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39201, 1335, 136, 4, 85, "Section"],
Cell[39340, 1341, 145, 4, 56, "Text"],
Cell[39488, 1347, 3553, 64, 1380, "Input"],
Cell[43044, 1413, 139, 4, 56, "Text"],

Cell[CellGroupData[{
Cell[43208, 1421, 1505, 31, 439, "Input"],
Cell[44716, 1454, 189, 3, 113, "Output"]
}, Open  ]],
Cell[44920, 1460, 29, 0, 56, "Text"],
Cell[44952, 1462, 3410, 63, 1352, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48399, 1530, 124, 2, 85, "Section"],
Cell[48526, 1534, 297, 9, 92, "Text"],
Cell[48826, 1545, 409, 8, 176, "NumberedEquation"],
Cell[49238, 1555, 75, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[49338, 1561, 602, 10, 157, "Input"],
Cell[49943, 1573, 426, 6, 154, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50406, 1584, 457, 8, 154, "Input"],
Cell[50866, 1594, 324, 5, 156, "Output"]
}, Open  ]],
Cell[51205, 1602, 172, 6, 56, "Text"],

Cell[CellGroupData[{
Cell[51402, 1612, 3441, 80, 854, "Input"],
Cell[54846, 1694, 103, 2, 89, "Output"],
Cell[54952, 1698, 103, 2, 89, "Output"],
Cell[55058, 1702, 126, 2, 116, "Output"],
Cell[55187, 1706, 135, 2, 117, "Output"],
Cell[55325, 1710, 133, 2, 98, "Output"],
Cell[55461, 1714, 156, 2, 129, "Output"],
Cell[55620, 1718, 132, 2, 116, "Output"],
Cell[55755, 1722, 147, 2, 117, "Output"],
Cell[55905, 1726, 149, 2, 116, "Output"],
Cell[56057, 1730, 149, 2, 116, "Output"],
Cell[56209, 1734, 178, 3, 98, "Output"],
Cell[56390, 1739, 181, 3, 127, "Output"],
Cell[56574, 1744, 180, 3, 116, "Output"],
Cell[56757, 1749, 181, 3, 117, "Output"],
Cell[56941, 1754, 188, 3, 124, "Output"],
Cell[57132, 1759, 193, 3, 129, "Output"],
Cell[57328, 1764, 189, 3, 118, "Output"],
Cell[57520, 1769, 190, 3, 117, "Output"],
Cell[57713, 1774, 190, 3, 118, "Output"],
Cell[57906, 1779, 192, 3, 117, "Output"],
Cell[58101, 1784, 205, 3, 124, "Output"],
Cell[58309, 1789, 214, 3, 129, "Output"],
Cell[58526, 1794, 247, 4, 119, "Output"],
Cell[58776, 1800, 202, 3, 117, "Output"],
Cell[58981, 1805, 179, 3, 93, "Output"],
Cell[59163, 1810, 213, 3, 111, "Output"],
Cell[59379, 1815, 249, 3, 100, "Output"],
Cell[59631, 1820, 278, 4, 129, "Output"],
Cell[59912, 1826, 247, 4, 119, "Output"],
Cell[60162, 1832, 237, 3, 117, "Output"],
Cell[60402, 1837, 263, 4, 124, "Output"],
Cell[60668, 1843, 290, 4, 129, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[61007, 1853, 186, 5, 119, "Section"],
Cell[61196, 1860, 200, 4, 80, "Text"],
Cell[61399, 1866, 63, 1, 69, "Input"],

Cell[CellGroupData[{
Cell[61487, 1871, 833, 16, 438, "Input"],
Cell[62323, 1889, 150, 2, 113, "Output"],
Cell[62476, 1893, 155, 2, 113, "Output"],
Cell[62634, 1897, 173, 3, 113, "Output"],
Cell[62810, 1902, 170, 3, 113, "Output"],
Cell[62983, 1907, 205, 3, 122, "Output"],
Cell[63191, 1912, 236, 3, 122, "Output"],
Cell[63430, 1917, 232, 3, 122, "Output"],
Cell[63665, 1922, 242, 3, 122, "Output"],
Cell[63910, 1927, 280, 4, 132, "Output"],
Cell[64193, 1933, 277, 4, 132, "Output"],
Cell[64473, 1939, 292, 4, 132, "Output"],
Cell[64768, 1945, 344, 5, 132, "Output"],
Cell[65115, 1952, 276, 4, 132, "Output"],
Cell[65394, 1958, 355, 5, 132, "Output"],
Cell[65752, 1965, 344, 5, 132, "Output"],
Cell[66099, 1972, 364, 5, 132, "Output"]
}, Open  ]],
Cell[66478, 1980, 180, 5, 56, "Text"],
Cell[66661, 1987, 4869, 80, 1755, "Input"],
Cell[71533, 2069, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

