(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    363961,       6796]*)
(*NotebookOutlinePosition[    364690,       6821]*)
(*  CellTagsIndexPosition[    364646,       6817]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "3.7. Visualization of the Wave Functions and Probability Densities of the \
",
  StyleBox["Hydrogen-Like Atoms",
    FontWeight->"Bold"],
  " (",
  StyleBox["beginning",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[TextData[{
  "1. ",
  "Radial and angular probability densities and probability densities of \
the",
  " ",
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"]
}], "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the Hydrogen-like atoms defined by quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ", \n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["In this file we present states for radial quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[Cell[BoxData[
    \(n\_rad = 0, 1\)],
  FontSlant->"Italic"]], "NumberedEquation"],

Cell["and next file presents states for radial quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 2, 3. \)],
    FontSlant->"Italic"],
  " "
}], "NumberedEquation"],

Cell["\<\
Determine parameter Z of the Hydrogen-like atoms and the first Borh's radius \
(in special dimensionless units):\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(Z = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(a\_0 = 1;\)\)}], "Input"],

Cell["\<\
Radial and angular probability densities and probability densities of the \
Hydrogen-like atoms for quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["Radial  probability densities:", "Text"],

Cell[BoxData[{
    \(\(RR\_\(HydAt, Cart\)[0, 0, 
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/a\_0\%3;\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[0, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\)\/\(24\ a\_0\%5\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[0, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\)\/\(98415\ \
a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[0, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\)\/\(20643840\ a\_0\%9\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2 - \(\@\(x\^2 + y\^2 + \
z\^2\)\ Z\)\/a\_0)\)\^2\)\/\(8\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 1, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((\(-2\) + \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\))\)\^2\)\/\(2187\ a\_0\%5\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-3\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\)\/\(4\ a\_0\))\)\^2\)\/\(184320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[1, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\ \((\(-4\) + \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\))\)\^2\)\/\(3076171875\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 0, 
          
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((3 + \(2\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\
\))\)\^2\)\/\(243\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((5 + \(\@\(x\^2 + y\^2 + \
z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\
\^2\)\/\(3840\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((21 + \(2\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 35\ a\_0)\)\)\/\
\(25\ a\_0\%2\))\)\^2\)\/\(123046875\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[2, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-42\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 72\ a\_0\ \((\(-\@\(x\^2 + y\
\^2 + z\^2\)\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\
\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((3 - \(\@\(x\^2 + y\^2 + z\^2\)\
\ Z\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\^2\
\)\/\(144\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 1, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^2\ Z\^5\ \((\(-30\) + \(\@\(x\
\^2 + y\^2 + z\^2\)\ Z\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 45\ a\_0\ \
\((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 25\ a\_0)\))\)\)\/\(125\ \
a\_0\%3\))\)\^2\)\/\(2109375\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ Z\^7\ \((\(-42\) + \(\@\(x\^2 + y\^2 \
+ z\^2\)\ Z\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 72\ a\_0\ \((\(-\@\(x\^2 + y\
\^2 + z\^2\)\)\ Z + 21\ a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\
\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(HydAt, Cart\)[3, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(7\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ Z\^9\ \((\(-180\) + \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 105\ \
a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 63\ a\_0)\))\)\)\/\(343\ \
a\_0\%3\))\)\^2\)\/\(12012259963725\ a\_0\%9\);\)\)}], "Input"],

Cell["Angular functions:", "Text"],

Cell[BoxData[{
    \(\(YY[0, 0] = 1\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[1, 
          0] = \(3\ Cos[\[Theta]]\^2\)\/\(4\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[1, 
          1] = \(3\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          0] = \(5\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(64\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          1] = \(15\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), \
"\[IndentingNewLine]", 
    \(\(YY[2, 
          2] = \(15\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[3, 
          0] = \(7\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(256\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          1] = \(21\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(1024\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          2] = \(105\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(32\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 3] = \(35\ Sin[\[Theta]]\^6\)\/\(64\ \[Pi]\);\)\)}], "Input"],

Cell["Probability densities:", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/\(\[Pi]\ a\_0\%3\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(32\ \[Pi]\ \
a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(64\ \
\[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^7\)\/\(39366\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\
\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^7\)\/\(26244\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\
\^2\ Z\^9\)\/\(47185920\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 \
+ z\^2)\)\ Z\^9\)\/\(62914560\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(37748736\ \[Pi]\ a\_0\%9\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z \
- 2\ a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\
\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(9437184\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\
\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ a\_0\%9\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ \
a\_0)\)\^2\)\/\(21972656250\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\
\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\
\/\(29296875000\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \[Pi]\ \
a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ a\_0\
\%11\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^2 + 9\ a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 3\ a\_0)\))\
\)\^2\)\/\(19683\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\^2 + z\^2)\)\
\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(1310720\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\
\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(2621440\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 0, 
          Z] = \(1\/\(30761718750\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 1, 
          Z] = \(1\/\(5126953125\ \[Pi]\ a\_0\%11\)\) \((\[ExponentialE]\^\(-\
\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 2, 
          Z] = \(1\/\(20507812500\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 0, 
          Z] = \(1\/\(31737486458880\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 1, 
          Z] = \(1\/\(42316648611840\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 2, 
          Z] = \(1\/\(4231664861184\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 3, 
          Z] = \(1\/\(25389989167104\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 0, 0, 
          Z] = \(1\/\(2359296\ \[Pi]\ a\_0\%9\)\) \((\[ExponentialE]\^\(-\(\(\
\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^3\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
24\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 6\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 8\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
          Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2\ a\_0 \
+ 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 1, 
          Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2\ a\_0 \
+ 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 0, 
          Z] = \(1\/\(14810827014144\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 1, 
          Z] = \(1\/\(2468471169024\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((z\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 72\ z\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 2, 
          Z] = \(1\/\(9873884676096\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 0, 
          Z] = \(1\/\(403780106420652150\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 1, 
          Z] = \(1\/\(538373475227536200\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 2, 
          Z] = \(1\/\(53837347522753620\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 3, 
          Z] = \(1\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2. Visualization of the radial probability densities, angular probability \
densities and probability densities of the ",
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"]
}], "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the Hydrogen-like atoms.\n\
We will obtain three-dimensional plots for radial and angular probability \
densities (product of these functions gives probability density), \
three-dimensional plots for probability densities (surface and density plots) \
for four cross-sectional profiles (defined by coordinate planes ",
  StyleBox["y0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y3",
    FontSlant->"Italic"],
  ") of the Hydrogen-like atoms.\nIn this file we will present visualizations \
in individual scales for states defined by given quantum numbers."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\n\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 550;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ISProf3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISProf3dVert = 550;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\n", 
    \(\(x3dMax = 4.25;\)\), "\n", 
    \(\(z3dMin = \(-4.25\);\)\), "\n", 
    \(\(\(z3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.575;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.046;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.0875\), 
                0.0875}, {\(-0.0875\), 0.0875}, {\(-0.0875\), 
                0.0875}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,0,0], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,0,0], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-11\);\)\), "\n", 
    \(\(x3dMax = 11;\)\), "\n", 
    \(\(z3dMin = \(-11\);\)\), "\n", 
    \(\(\(z3dMax = 11;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.215;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.046;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, Z], {y -> y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel -> "\<Surface of radial \
density RR[0,1]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel -> "\<Surface profile of \
\[Psi]\[Psi][0,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][0,1,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel -> "\<Profile of \
\[Psi]\[Psi][0,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][0,1,0], y=y0\
\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<Set of functions composing \
wave function \[Psi]\[Psi][0,1,0], y=y0\>"]\)\(\n\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][0,1,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.45] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][0,1,0], y=y1\
\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][0,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][0,1,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.6] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][0,1,0], y=y1\
\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][0,1,0], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n\
", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][0,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.75] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][0,1,0], y=y3\
\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][0,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize -> {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel -> "\<Set of profiles of wave function \[Psi]\[Psi][0,1,0], \
y=0,y1,y2,y3\>", Background -> RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-11\);\)\), "\n", 
    \(\(x3dMax = 11;\)\), "\n", 
    \(\(z3dMin = \(-11\);\)\), "\n", 
    \(\(\(z3dMax = 11;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.215;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.025;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\), "\n", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[
          RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,1]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,1,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,1,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,1,1], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,1,1], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-22\);\)\), "\n", 
    \(\(x3dMax = 22;\)\), "\n", 
    \(\(z3dMin = \(-22\);\)\), "\n", 
    \(\(\(z3dMax = 22;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.125;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.045;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,2,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,2,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,2,0], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,2,0], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-20\);\)\), "\n", 
    \(\(x3dMax = 20;\)\), "\n", 
    \(\(z3dMin = \(-20\);\)\), "\n", 
    \(\(\(z3dMax = 20;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.125;\)\(\n\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\n\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.15\), 
                0.15}, {\(-0.15\), 0.15}, {\(-0.15\), 
                0.15}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,2]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,2,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,2,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,2,1], y=y0\>"]\)\(\n\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y1\>"];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,1], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,2,1], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-20\);\)\), "\n", 
    \(\(x3dMax = 20;\)\), "\n", 
    \(\(z3dMin = \(-20\);\)\), "\n", 
    \(\(\(z3dMax = 20;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.125;\)\(\n\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\n\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.16\), 
                0.16}, {\(-0.16\), 0.16}, {\(-0.16\), 
                0.16}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\), "\n", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,2]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,2,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,2,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,2,2], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y1\>"];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,2,2], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-36\);\)\), "\n", 
    \(\(x3dMax = 36;\)\), "\n", 
    \(\(z3dMin = \(-36\);\)\), "\n", 
    \(\(\(z3dMax = 36;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.075;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.041;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,0], y=y0\>"]\)\(\n\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y1\>"];\)\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,0], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.075;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0145;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints -> {40, 
              40}, \[IndentingNewLine]PlotRange -> {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel -> "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,1], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,1], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.075;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0115;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.135\), 
                0.135}, {\(-0.135\), 0.135}, {\(-0.135\), 
                0.135}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,2], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,2], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.075;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[0,3]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][0,3,3], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][0,3,3], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,3,3], y=y0\>"]\)\(\n\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y1\>"];\)\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][0,3,3], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-14\);\)\), "\n", 
    \(\(x3dMax = 14;\)\), "\n", 
    \(\(z3dMin = \(-14\);\)\), "\n", 
    \(\(\(z3dMax = 14;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.2;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0165;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.09\), 
                0.09}, {\(-0.09\), 0.09}, {\(-0.09\), 
                0.09}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,0,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,0,0], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y1\>"];\)\[IndentingNewLine]\n\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,0,0], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-24\);\)\), "\n", 
    \(\(x3dMax = 24;\)\), "\n", 
    \(\(z3dMin = \(-24\);\)\), "\n", 
    \(\(\(z3dMax = 24;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.12;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0255;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,1]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,1,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,1,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,1,0], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,1,0], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-24\);\)\), "\n", 
    \(\(x3dMax = 24;\)\), "\n", 
    \(\(z3dMin = \(-24\);\)\), "\n", 
    \(\(\(z3dMax = 24;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.12;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints -> {30, 
              30}, \[IndentingNewLine]PlotRange -> {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel -> "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,1]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,1,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,1,1], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y1\>"];\)\[IndentingNewLine]\n\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,1,1], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-40\);\)\), "\n", 
    \(\(x3dMax = 40;\)\), "\n", 
    \(\(z3dMin = \(-40\);\)\), "\n", 
    \(\(\(z3dMax = 40;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.07;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0275;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,0], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,0], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-36\);\)\), "\n", 
    \(\(x3dMax = 36;\)\), "\n", 
    \(\(z3dMin = \(-36\);\)\), "\n", 
    \(\(\(z3dMax = 36;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.07;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.01025;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.115\), 
                0.115}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,2,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,1], y=y0\>"]\)\(\n\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y1\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y1\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=y1\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y1\>"];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y3\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y3\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,1], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-38\);\)\), "\n", 
    \(\(x3dMax = 38;\)\), "\n", 
    \(\(z3dMin = \(-38\);\)\), "\n", 
    \(\(\(z3dMax = 38;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.07;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.01025;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints -> {40, 
              40}, \[IndentingNewLine]PlotRange -> {{\(-0.155\), 
                0.155}, {\(-0.155\), 0.155}, {\(-0.155\), 
                0.155}}, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel -> "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,2,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,2,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,2,2], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,2,2], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-56\);\)\), "\n", 
    \(\(x3dMax = 56;\)\), "\n", 
    \(\(z3dMin = \(-56\);\)\), "\n", 
    \(\(\(z3dMax = 56;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.05;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0275;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints -> {36, 
              36}, \[IndentingNewLine]PlotRange -> {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel -> "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\)\
, "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,0], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y1\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,0], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-52\);\)\), "\n", 
    \(\(x3dMax = 52;\)\), "\n", 
    \(\(z3dMin = \(-52\);\)\), "\n", 
    \(\(\(z3dMax = 52;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.05;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,1], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,1], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y1\>"];\)\[IndentingNewLine]\n\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,1], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-52\);\)\), "\n", 
    \(\(x3dMax = 52;\)\), "\n", 
    \(\(z3dMin = \(-52\);\)\), "\n", 
    \(\(\(z3dMax = 52;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.05;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.14\), 
                0.14}, {\(-0.14\), 0.14}, {\(-0.14\), 
                0.14}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,2], y=y0\>"]\)\(\n\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y1\>"];\)\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,2], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-54\);\)\), "\n", 
    \(\(x3dMax = 54;\)\), "\n", 
    \(\(z3dMin = \(-54\);\)\), "\n", 
    \(\(\(z3dMax = 54;\)\(\n\)
    \)\), "\n", 
    \(\(y0 = 0;\)\), "\n", 
    \(\(y1 = x3dMin\ 1\/4;\)\), "\n", 
    \(\(y2 = x3dMin\ 2\/4;\)\), "\n", 
    \(\(\(y3 = x3dMin\ 3\/4;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\n", 
    \(\(\(PR2dMax = 0.05;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(\(IS3dVert = 265;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, Z] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.183\), 
                0.183}, {\(-0.183\), 0.183}, {\(-0.183\), 
                0.183}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        ReplaceAll[
          RR\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, y0] = 
        If[z < 0, 0, 
          RRy\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Radial3dhf\_HydAt[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(HydAt, Cart\)[n\_rad, l\_orb, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[1,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][1,3,3], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            Anglar3dPlot[l\_orb, m\_azm, Z], 
            Radial3dhf\_HydAt[n\_rad, l\_orb, y0]}, {WFunktion3d\_HydAt[
              n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dVW\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][1,3,3], \
y=y0\>"]\)\(\[IndentingNewLine]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y1] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y1], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y1\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=y1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y2] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2]];\)\), "\n", 
    \(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y2], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y1\>"];\)\[IndentingNewLine]\n\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y3}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=y3\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y3] = 
        If[x < 0, 
          0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3]];\)\), "\n", 
    \(\(\(WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y3], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}, {WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y1], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, y2], 
            WFunktion3dhf\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][1,3,3], y=0,y1,y2,y3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 348, 13, 125, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2832, 98, 232, 9, 85, "Section"],
Cell[3067, 109, 146, 4, 56, "Text"],
Cell[3216, 115, 196, 8, 72, "NumberedEquation"],
Cell[3415, 125, 121, 2, 56, "Text"],
Cell[3539, 129, 96, 2, 50, "NumberedEquation"],
Cell[3638, 133, 120, 2, 56, "Text"],
Cell[3761, 137, 115, 5, 52, "NumberedEquation"],
Cell[3879, 144, 183, 5, 56, "Text"],
Cell[4065, 151, 94, 2, 88, "Input"],
Cell[4162, 155, 195, 5, 56, "Text"],
Cell[4360, 162, 46, 0, 56, "Text"],
Cell[4409, 164, 4869, 80, 1755, "Input"],
Cell[9281, 246, 34, 0, 56, "Text"],
Cell[9318, 248, 1079, 26, 588, "Input"],
Cell[10400, 276, 38, 0, 56, "Text"],
Cell[10441, 278, 14249, 229, 6244, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24727, 512, 260, 7, 119, "Section"],
Cell[24990, 521, 812, 20, 200, "Text"],
Cell[25805, 543, 666, 17, 452, "Text"],
Cell[26474, 562, 296, 5, 213, "Input"],

Cell[CellGroupData[{
Cell[26795, 571, 202, 11, 89, "Subsection"],
Cell[27000, 584, 17228, 295, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44265, 884, 214, 13, 89, "Subsection"],
Cell[44482, 899, 16173, 293, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60692, 1197, 202, 11, 89, "Subsection"],
Cell[60897, 1210, 16613, 294, 6139, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77547, 1509, 202, 11, 89, "Subsection"],
Cell[77752, 1522, 16606, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94395, 1819, 202, 11, 89, "Subsection"],
Cell[94600, 1832, 16543, 294, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111180, 2131, 202, 11, 89, "Subsection"],
Cell[111385, 2144, 16511, 293, 6139, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127933, 2442, 202, 11, 89, "Subsection"],
Cell[128138, 2455, 16610, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144785, 2752, 202, 11, 89, "Subsection"],
Cell[144990, 2765, 16622, 294, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161649, 3064, 202, 11, 89, "Subsection"],
Cell[161854, 3077, 16652, 294, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178543, 3376, 203, 11, 89, "Subsection"],
Cell[178749, 3389, 16669, 294, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[195455, 3688, 203, 11, 89, "Subsection"],
Cell[195661, 3701, 16620, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212318, 3998, 203, 11, 89, "Subsection"],
Cell[212524, 4011, 16621, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[229182, 4308, 203, 11, 89, "Subsection"],
Cell[229388, 4321, 16597, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246022, 4618, 203, 11, 89, "Subsection"],
Cell[246228, 4631, 16615, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[262880, 4928, 203, 11, 89, "Subsection"],
Cell[263086, 4941, 16463, 293, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[279586, 5239, 203, 11, 89, "Subsection"],
Cell[279792, 5252, 16622, 294, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[296451, 5551, 203, 11, 89, "Subsection"],
Cell[296657, 5564, 16629, 294, 6189, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[313323, 5863, 203, 11, 89, "Subsection"],
Cell[313529, 5876, 16627, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[330193, 6173, 203, 11, 89, "Subsection"],
Cell[330399, 6186, 16621, 292, 6164, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347057, 6483, 203, 11, 89, "Subsection"],
Cell[347263, 6496, 16651, 294, 6164, "Input"],
Cell[363917, 6792, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

