(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    134204,       3150]*)
(*NotebookOutlinePosition[    134933,       3175]*)
(*  CellTagsIndexPosition[    134889,       3171]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
3.9. Comparative visualization of the Probability Densities of the \
Hydrogen-Like Atoms\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Probability densities of the Hydrogen-like atoms", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the Hydrogen-like atoms defined by quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["\<\
Determine parameter Z of the Hydrogen-like atoms and the first Borh's radius \
(in special dimensionless units):\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(Z = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(a\_0 = 1;\)\)}], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
Hydrogen-like atoms for quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Wave functions and probability densities of the Hydrogen-like atoms for given \
quantum numbers in the Cartesian rectangular coordinates are\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/\(\[Pi]\ a\_0\%3\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(32\ \[Pi]\ \
a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(64\ \
\[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^7\)\/\(39366\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\
\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^7\)\/\(26244\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\
\^2\ Z\^9\)\/\(47185920\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 \
+ z\^2)\)\ Z\^9\)\/\(62914560\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(37748736\ \[Pi]\ a\_0\%9\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z \
- 2\ a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\
\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(9437184\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\
\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ a\_0\%9\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ \
a\_0)\)\^2\)\/\(21972656250\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\
\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\
\/\(29296875000\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \[Pi]\ \
a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ a\_0\
\%11\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^2 + 9\ a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 3\ a\_0)\))\
\)\^2\)\/\(19683\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\^2 + z\^2)\)\
\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(1310720\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\
\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(2621440\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 0, 
          Z] = \(1\/\(30761718750\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 1, 
          Z] = \(1\/\(5126953125\ \[Pi]\ a\_0\%11\)\) \((\[ExponentialE]\^\(-\
\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 2, 
          Z] = \(1\/\(20507812500\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 0, 
          Z] = \(1\/\(31737486458880\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 1, 
          Z] = \(1\/\(42316648611840\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 2, 
          Z] = \(1\/\(4231664861184\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 3, 
          Z] = \(1\/\(25389989167104\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 0, 0, 
          Z] = \(1\/\(2359296\ \[Pi]\ a\_0\%9\)\) \((\[ExponentialE]\^\(-\(\(\
\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^3\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
24\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 6\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 8\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
          Z] = \[IndentingNewLine]\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
            Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \((\[ExponentialE]\^\
\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((x\^2 + 
                    y\^2 + z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^2\ a\_0 + 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 1, 
          Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2\ a\_0 \
+ 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 0, 
          Z] = \(1\/\(14810827014144\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 1, 
          Z] = \(1\/\(2468471169024\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((z\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 72\ z\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 2, 
          Z] = \(1\/\(9873884676096\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 0, 
          Z] = \(1\/\(403780106420652150\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 1, 
          Z] = \(1\/\(538373475227536200\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 2, 
          Z] = \(1\/\(53837347522753620\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 3, 
          Z] = \(1\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the probability densities of the Hydrogen-like atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the Hydrogen-like atoms.\n\
We will obtain three-dimensional plots probability densities (surface and \
density plots) for four cross-sectional profile (defined by coordinate plane \
",
  StyleBox["y0",
    FontSlant->"Italic"],
  ") of the Hydrogen-like atoms.\nIn this file we will present visualizations \
in individual scales for states defined by given quantum numbers."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(IS3dVert = 265;\)\[IndentingNewLine]\), "\n", 
    \(\(ISAll3dHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 300;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ISProf3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISProf3dVert = 550;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\)}], "Input"],

Cell[BoxData[{
    \(\(x3dMin = \(-24\);\)\), "\n", 
    \(\(x3dMax = 24;\)\), "\n", 
    \(\(z3dMin = \(-24\);\)\), "\n", 
    \(\(\(z3dMax = 24;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin1 = \(-46\);\)\), "\n", 
    \(\(x3dMax1 = 46;\)\), "\n", 
    \(\(z3dMin1 = \(-46\);\)\), "\n", 
    \(\(\(z3dMax1 = 46;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin2 = \(-75\);\)\), "\n", 
    \(\(x3dMax2 = 75;\)\), "\n", 
    \(\(z3dMin2 = \(-75\);\)\), "\n", 
    \(\(\(z3dMax2 = 75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin3 = \(-95\);\)\), "\n", 
    \(\(x3dMax3 = 95;\)\), "\n", 
    \(\(z3dMin3 = \(-95\);\)\), "\n", 
    \(\(z3dMax3 = 95;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.046;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,0,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,0,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.046;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,0], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,0], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][0,1,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.025;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,1,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,1,1], y=y0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,1,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.045;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.045;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,2,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,2,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.041;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0145;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0115;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][0,3,3], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][0,3,3], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,3], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0165;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,0,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,0,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,0,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0255;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,1,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,1,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0275;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.01025;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.01025;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,2,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,2,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0275;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][1,3,3], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin1, x3dMax1}, {z, z3dMin1, 
            z3dMax1}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,3], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,3], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "21",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0085;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,0,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,0,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "22",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0165;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "23",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.008;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "24",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.02;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "25",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0075;\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "26",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "27",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.019;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "28",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0075;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "29",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "30",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin2, x3dMax2}, {z, z3dMin2, 
            z3dMax2}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,3], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,3], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "31",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,0,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,0,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "32",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "33",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "34",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0135;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "35",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][3,2,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][3,2,1], y=y0\
\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<Wave function \
\[Psi]\[Psi][3,2,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "36",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][3,2,2], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][3,2,2], y=y0\
\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<Wave function \
\[Psi]\[Psi][3,2,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "37",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0155;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][3,3,0], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][3,3,0], y=y0\
\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<Wave function \
\[Psi]\[Psi][3,3,0], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "38",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][3,3,1], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][3,3,1], y=y0\
\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<Wave function \
\[Psi]\[Psi][3,3,1], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "39",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.00423;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][3,3,2], y=y0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][3,3,2], y=y0\
\>"];\)\n\n\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<Wave function \
\[Psi]\[Psi][3,3,2], y=y0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "40",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0045;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<Surface of \
\[Psi]\[Psi][3,3,3], y=y0\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin3, x3dMax3}, {z, z3dMin3, 
            z3dMax3}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<Density of \[Psi]\[Psi][3,3,3], y=y0\
\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<Wave function \
\[Psi]\[Psi][3,3,3], y=y0\>"]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparative visualization of the probability densities of theHydrogen-like \
atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations in unified scales for all states defined by \
given quantum numbers.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3d\_HydAt[0, 0, 0, Z, y0], 
            WFunktion3d\_HydAt[1, 0, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 0, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 0, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 1, 0, Z, y0], WFunktion3d\_HydAt[1, 1, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 1, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 1, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 1, 1, Z, y0], WFunktion3d\_HydAt[1, 1, 1, Z, y0], 
            WFunktion3d\_HydAt[2, 1, 1, Z, y0], 
            WFunktion3d\_HydAt[3, 1, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 2, 0, Z, y0], WFunktion3d\_HydAt[1, 2, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 2, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 2, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 2, 1, Z, y0], WFunktion3d\_HydAt[1, 2, 1, Z, y0], 
            WFunktion3d\_HydAt[2, 2, 1, Z, y0], 
            WFunktion3d\_HydAt[3, 2, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 2, 2, Z, y0], WFunktion3d\_HydAt[1, 2, 2, Z, y0], 
            WFunktion3d\_HydAt[2, 2, 2, Z, y0], 
            WFunktion3d\_HydAt[3, 2, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 3, 0, Z, y0], WFunktion3d\_HydAt[1, 3, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 3, 1, Z, y0], WFunktion3d\_HydAt[1, 3, 1, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 1, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 3, 2, Z, y0], WFunktion3d\_HydAt[1, 3, 2, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 2, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_HydAt[
              0, 3, 3, Z, y0], WFunktion3d\_HydAt[1, 3, 3, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 3, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 3, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {800, 
          2000}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, \
y=0\>"]\)], "Input"],

Cell["", "Text"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[0, 0, 0, Z, y0], 
            WFunktion3dDen\_HydAt[1, 0, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 0, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 0, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 1, 0, Z, y0], WFunktion3dDen\_HydAt[1, 1, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 1, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 1, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 1, 1, Z, y0], WFunktion3dDen\_HydAt[1, 1, 1, Z, y0], 
            WFunktion3dDen\_HydAt[2, 1, 1, Z, y0], 
            WFunktion3dDen\_HydAt[3, 1, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 2, 0, Z, y0], WFunktion3dDen\_HydAt[1, 2, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 2, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 2, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 2, 1, Z, y0], WFunktion3dDen\_HydAt[1, 2, 1, Z, y0], 
            WFunktion3dDen\_HydAt[2, 2, 1, Z, y0], 
            WFunktion3dDen\_HydAt[3, 2, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 2, 2, Z, y0], WFunktion3dDen\_HydAt[1, 2, 2, Z, y0], 
            WFunktion3dDen\_HydAt[2, 2, 2, Z, y0], 
            WFunktion3dDen\_HydAt[3, 2, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 3, 0, Z, y0], WFunktion3dDen\_HydAt[1, 3, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 3, 1, Z, y0], WFunktion3dDen\_HydAt[1, 3, 1, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 1, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 3, 2, Z, y0], WFunktion3dDen\_HydAt[1, 3, 2, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 2, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
HydAt[0, 3, 3, Z, y0], WFunktion3dDen\_HydAt[1, 3, 3, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 3, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 3, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {800, 
          2000}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, \
y=0\>"]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 168, 5, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2652, 90, 117, 2, 85, "Section"],
Cell[2772, 94, 146, 4, 56, "Text"],
Cell[2921, 100, 195, 8, 72, "NumberedEquation"],
Cell[3119, 110, 183, 5, 56, "Text"],
Cell[3305, 117, 94, 2, 88, "Input"],
Cell[3402, 121, 194, 5, 56, "Text"],
Cell[3599, 128, 164, 3, 80, "Text"],
Cell[3766, 133, 14367, 231, 6295, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18170, 369, 146, 4, 85, "Section"],
Cell[18319, 375, 526, 10, 176, "Text"],
Cell[18848, 387, 666, 17, 452, "Text"],
Cell[19517, 406, 468, 8, 338, "Input"],
Cell[19988, 416, 745, 19, 513, "Input"],

Cell[CellGroupData[{
Cell[20758, 439, 202, 11, 89, "Subsection"],
Cell[20963, 452, 2580, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23580, 502, 214, 13, 89, "Subsection"],
Cell[23797, 517, 2529, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26363, 567, 214, 13, 89, "Subsection"],
Cell[26580, 582, 2502, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29119, 632, 214, 13, 89, "Subsection"],
Cell[29336, 647, 2451, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31824, 697, 214, 13, 89, "Subsection"],
Cell[32041, 712, 2451, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34529, 762, 214, 13, 89, "Subsection"],
Cell[34746, 777, 2451, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37234, 827, 214, 13, 89, "Subsection"],
Cell[37451, 842, 2451, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39939, 892, 202, 11, 89, "Subsection"],
Cell[40144, 905, 2452, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42633, 955, 202, 11, 89, "Subsection"],
Cell[42838, 968, 2452, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45327, 1018, 215, 13, 89, "Subsection"],
Cell[45545, 1033, 2452, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48034, 1083, 215, 13, 89, "Subsection"],
Cell[48252, 1098, 2443, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50732, 1148, 215, 13, 89, "Subsection"],
Cell[50950, 1163, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53447, 1213, 215, 13, 89, "Subsection"],
Cell[53665, 1228, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56162, 1278, 215, 13, 89, "Subsection"],
Cell[56380, 1293, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58877, 1343, 215, 13, 89, "Subsection"],
Cell[59095, 1358, 2461, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61593, 1408, 215, 13, 89, "Subsection"],
Cell[61811, 1423, 2461, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64309, 1473, 215, 13, 89, "Subsection"],
Cell[64527, 1488, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67024, 1538, 215, 13, 89, "Subsection"],
Cell[67242, 1553, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69739, 1603, 215, 13, 89, "Subsection"],
Cell[69957, 1618, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72454, 1668, 215, 13, 89, "Subsection"],
Cell[72672, 1683, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75169, 1733, 215, 13, 89, "Subsection"],
Cell[75387, 1748, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77884, 1798, 215, 13, 89, "Subsection"],
Cell[78102, 1813, 2460, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80599, 1863, 215, 13, 89, "Subsection"],
Cell[80817, 1878, 2459, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83313, 1928, 215, 13, 89, "Subsection"],
Cell[83531, 1943, 2441, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86009, 1993, 215, 13, 89, "Subsection"],
Cell[86227, 2008, 2409, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88673, 2058, 215, 13, 89, "Subsection"],
Cell[88891, 2073, 2408, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91336, 2123, 215, 13, 89, "Subsection"],
Cell[91554, 2138, 2442, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94033, 2188, 215, 13, 89, "Subsection"],
Cell[94251, 2203, 2443, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96731, 2253, 215, 13, 89, "Subsection"],
Cell[96949, 2268, 2426, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99412, 2318, 215, 13, 89, "Subsection"],
Cell[99630, 2333, 2443, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102110, 2383, 215, 13, 89, "Subsection"],
Cell[102328, 2398, 2443, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104808, 2448, 215, 13, 89, "Subsection"],
Cell[105026, 2463, 2443, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107506, 2513, 215, 13, 89, "Subsection"],
Cell[107724, 2528, 2443, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110204, 2578, 215, 13, 89, "Subsection"],
Cell[110422, 2593, 2426, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112885, 2643, 215, 13, 89, "Subsection"],
Cell[113103, 2658, 2346, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115486, 2708, 215, 13, 89, "Subsection"],
Cell[115704, 2723, 2346, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118087, 2773, 215, 13, 89, "Subsection"],
Cell[118305, 2788, 2363, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120705, 2838, 215, 13, 89, "Subsection"],
Cell[120923, 2853, 2346, 45, 966, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[123306, 2903, 215, 13, 89, "Subsection"],
Cell[123524, 2918, 2353, 44, 991, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125914, 2967, 215, 13, 89, "Subsection"],
Cell[126132, 2982, 2346, 45, 966, "Input"],
Cell[128481, 3029, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[128546, 3035, 159, 5, 85, "Section"],
Cell[128708, 3042, 169, 5, 56, "Text"],
Cell[128880, 3049, 2632, 46, 888, "Input"],
Cell[131515, 3097, 16, 0, 56, "Text"],
Cell[131534, 3099, 2635, 46, 888, "Input"],
Cell[134172, 3147, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

