(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    277328,       5514]*)
(*NotebookOutlinePosition[    278057,       5539]*)
(*  CellTagsIndexPosition[    278013,       5535]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
3.10. Comparative visualization of the Radial Wave Functions and Radial \
Probability Densities of the Hydrogen-Like Atoms for Different Atoms\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Probability densities of the Hydrogen-like atoms for different atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the Hydrogen-like atoms defined by quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["\<\
Determine parameter Z and Z2 of the three-dimensional quantum oscillator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(Z = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Z2 = 2;\)\ \), "\[IndentingNewLine]", 
    \(\(a\_0 = 1;\)\)}], "Input"],

Cell["\<\
Probability densities of the Hydrogen-like atom (number Z) for quantum \
numbers (1) are:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/\(\[Pi]\ a\_0\%3\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(32\ \[Pi]\ \
a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(64\ \
\[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^7\)\/\(39366\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\
\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^7\)\/\(26244\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\
\^2\ Z\^9\)\/\(47185920\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 \
+ z\^2)\)\ Z\^9\)\/\(62914560\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(37748736\ \[Pi]\ a\_0\%9\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z \
- 2\ a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\
\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(9437184\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\
\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ a\_0\%9\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ \
a\_0)\)\^2\)\/\(21972656250\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\
\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\
\/\(29296875000\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \[Pi]\ \
a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ a\_0\
\%11\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^2 + 9\ a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 3\ a\_0)\))\
\)\^2\)\/\(19683\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\^2 + z\^2)\)\
\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(1310720\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\
\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(2621440\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 0, 
          Z] = \(1\/\(30761718750\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 1, 
          Z] = \(1\/\(5126953125\ \[Pi]\ a\_0\%11\)\) \((\[ExponentialE]\^\(-\
\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 2, 
          Z] = \(1\/\(20507812500\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 0, 
          Z] = \(1\/\(31737486458880\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 1, 
          Z] = \(1\/\(42316648611840\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 2, 
          Z] = \(1\/\(4231664861184\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 3, 
          Z] = \(1\/\(25389989167104\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 0, 0, 
          Z] = \(1\/\(2359296\ \[Pi]\ a\_0\%9\)\) \((\[ExponentialE]\^\(-\(\(\
\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^3\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
24\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 6\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 8\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
          Z] = \[IndentingNewLine]\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
            Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \((\[ExponentialE]\^\
\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((x\^2 + 
                    y\^2 + z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^2\ a\_0 + 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 1, 
          Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2\ a\_0 \
+ 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 0, 
          Z] = \(1\/\(14810827014144\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 1, 
          Z] = \(1\/\(2468471169024\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((z\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 72\ z\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 2, 
          Z] = \(1\/\(9873884676096\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 0, 
          Z] = \(1\/\(403780106420652150\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 1, 
          Z] = \(1\/\(538373475227536200\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 2, 
          Z] = \(1\/\(53837347522753620\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 3, 
          Z] = \(1\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\)}], "Input"],

Cell["\<\
Probability densities of the Hydrogen-like atom (number Z2) for quantum \
numbers (1) are:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 0, 0, 
          Z2] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^3\)\/\(\[Pi]\ a\_0\%3\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 1, 0, 
          Z2] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/a\_0\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^5\)\/\(32\ \[Pi]\ a\_0\%5\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 1, 1, 
          Z2] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/a\_0\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^5\)\/\(64\ \
\[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 2, 0, 
          Z2] = \(1\/\(39366\ \[Pi]\ a\_0\%7\)\) \((\[ExponentialE]\^\(-\(\(2\
\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ \
z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^7)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 2, 1, 
          Z2] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\
\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^7\)\/\
\(6561\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 2, 2, 
          Z2] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\
\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z2\^7\)\/\(26244\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 3, 0, 
          Z2] = \((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ Z2\^9)\
\)/\((47185920\ \[Pi]\ a\_0\%9)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 3, 1, 
          Z2] = \((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(2\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9)\)/\((62914560\ \[Pi]\ a\_0\%9)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 3, 2, 
          Z2] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(2\
\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^9\)\/\
\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[0, 3, 3, 
          Z2] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(2\
\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \
Z2\^9\)\/\(37748736\ \[Pi]\ a\_0\%9\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 0, 0, 
          Z2] = \(1\/\(32\ \[Pi]\ a\_0\%5\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/a\_0\)\)\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z2\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 2\ \
a\_0)\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 1, 0, 
          Z2] = \(1\/\(6561\ \[Pi]\ a\_0\%7\)\) \((2\ \
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ z\
\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^5\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 6\ \
a\_0)\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 1, 1, 
          Z2] = \(1\/\(6561\ \[Pi]\ a\_0\%7\)\) \((\[ExponentialE]\^\(-\(\(2\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ Z2\^5\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 6\ \
a\_0)\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 2, 0, 
          Z2] = \((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 12\ a\_0)\
\)\^2)\)/\((9437184\ \[Pi]\ a\_0\%9)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 2, 1, 
          Z2] = \((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 12\ a\_0)\
\)\^2)\)/\((1572864\ \[Pi]\ a\_0\%9)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 2, 2, 
          Z2] = \((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 12\ a\_0)\
\)\^2)\)/\((6291456\ \[Pi]\ a\_0\%9)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 3, 0, 
          Z2] = \((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(5\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 20\ a\_0)\)\^2)\)/\
\((21972656250\ \[Pi]\ a\_0\%11)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 3, 1, 
          Z2] = \((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(5\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 20\ a\_0)\
\)\^2)\)/\((29296875000\ \[Pi]\ a\_0\%11)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 3, 2, 
          Z2] = \((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 20\ a\_0)\
\)\^2)\)/\((2929687500\ \[Pi]\ a\_0\%11)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[1, 3, 3, 
          Z2] = \((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  
                  z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 20\ a\_0)\
\)\^2)\)/\((17578125000\ \[Pi]\ a\_0\%11)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 0, 0, 
          Z2] = \(1\/\(19683\ \[Pi]\ a\_0\%7\)\) \((\[ExponentialE]\^\(-\(\(2\
\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^3\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 + 9\ \
a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z2 + 3\ a\_0)\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 1, 0, 
          Z2] = \((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(2\ a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^5\ \((\((x\^2 + y\^2 + z\^2)\)\ Z2\^2 - 20\ \@\
\(x\^2 + y\^2 + z\^2\)\ Z2\ a\_0 + 80\ a\_0\%2)\)\^2)\)/\((1310720\ \[Pi]\ \
a\_0\%9)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 1, 1, 
          Z2] = \((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z2\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^5\ \((\((x\^2 + y\^2 + z\^2)\)\ Z2\^2 - 20\ \@\
\(x\^2 + y\^2 + z\^2\)\ Z2\ a\_0 + 80\ a\_0\%2)\)\^2)\)/\((2621440\ \[Pi]\ \
a\_0\%9)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 2, 0, 
          Z2] = \(1\/\(30761718750\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(5\ a\_0\)\)\)\
\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z2\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 2, 1, 
          Z2] = \(1\/\(5126953125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(5\ a\_0\)\)\)\
\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z2\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 2, 2, 
          Z2] = \(1\/\(20507812500\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(5\ a\_0\)\)\)\
\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z2\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 3, 0, 
          Z2] = \(1\/\(31737486458880\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\
\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 \
+ y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 36\ a\_0)\
\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 3, 1, 
          Z2] = \(1\/\(42316648611840\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\
\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 36\ a\_0)\
\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 3, 2, 
          Z2] = \(1\/\(4231664861184\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 36\ a\_0)\
\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[2, 3, 3, 
          Z2] = \(1\/\(25389989167104\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\
\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \((x\^2 + \
y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  
                  z\^2)\)\ Z2\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 36\ a\_0)\
\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z2 - 18\ a\_0)\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 0, 0, 
          Z2] = \(1\/\(2359296\ \[Pi]\ a\_0\%9\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(2\ a\_0\)\)\)\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^3\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\^3 \
+ 24\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z2\^2 + 6\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z2\ a\_0 - 8\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 1, 0, 
          Z2] = \[IndentingNewLine]\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, \
Cart\)[3, 1, 0, 
            Z2] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(5\ a\_0\)\)\)\
\ z\^2\ \((x\^2 + y\^2 + 
                    z\^2)\)\ Z2\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2\ a\
\_0 + 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z2\^3 + 1125\ Z2\ a\_0\%2)\))\)\^2)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 1, 1, 
          Z2] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(5\ a\_0\)\)\)\
\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2\ \
a\_0 + 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\
\)\ Z2\^3 + 1125\ Z2\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 2, 0, 
          Z2] = \(1\/\(14810827014144\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\
\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ \
z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\^3 \
+ 72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z2\^2 + 21\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ Z2 - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 2, 1, 
          Z2] = \(1\/\(2468471169024\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((z\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\
\^3 + 72\ z\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z2\^2 + 21\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z2 - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 2, 2, 
          Z2] = \(1\/\(9873884676096\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\^3 \
+ 72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z2\^2 + 21\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ Z2 - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 3, 0, 
          Z2] = \(1\/\(403780106420652150\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(7\ a\_0\)\)\)\ z\
\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\
\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z2\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 3, 1, 
          Z2] = \(1\/\(538373475227536200\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\
\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z2\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 3, 2, 
          Z2] = \(1\/\(53837347522753620\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\
\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z2\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[3, 3, 3, 
          Z2] = \(1\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z2\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z2\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z2\
\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z2\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z2\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the probability densities of the Hydrogen-like atoms for \
different atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the probability densities of the \
Hydrogen-like atoms.
We will obtain density and surface (three-dimensional) plots for probability \
densities of the Hydrogen-like atoms for different atoms.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\n", 
    \(\(IS3dVert = 265;\)\[IndentingNewLine]\), "\n", 
    \(\(ISAll3dHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 600;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ISProf3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISProf3dVert = 550;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\n", 
    \(\(x3dMax = 4;\)\), "\n", 
    \(\(z3dMin = \(-4\);\)\), "\n", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0946;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 
          0];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,0,0,Z], \[CapitalPsi]\[CapitalPsi][0,0,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,0,0,Z], \[CapitalPsi]\[CapitalPsi][0,0,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,0,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,0,0,Z2], y=0\>"];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,0,0,Z], \[CapitalPsi]\[CapitalPsi][0,0,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-11\);\)\), "\n", 
    \(\(x3dMax = 11;\)\), "\n", 
    \(\(z3dMin = \(-11\);\)\), "\n", 
    \(\(\(z3dMax = 11;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0946;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 
          0];\)\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0,Z], \[CapitalPsi]\[CapitalPsi][0,1,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0,Z], \[CapitalPsi]\[CapitalPsi][0,1,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,1,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,1,0,Z2], y=0\>"];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\n", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,1,0,Z], \[CapitalPsi]\[CapitalPsi][0,1,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-11\);\)\), "\n", 
    \(\(x3dMax = 11;\)\), "\n", 
    \(\(z3dMin = \(-11\);\)\), "\n", 
    \(\(\(z3dMax = 11;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,1,Z], \[CapitalPsi]\[CapitalPsi][0,1,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,1,Z], \[CapitalPsi]\[CapitalPsi][0,1,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][0,1,1,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][0,1,1,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,1,1,Z], \[CapitalPsi]\[CapitalPsi][0,1,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-22\);\)\), "\n", 
    \(\(x3dMax = 22;\)\), "\n", 
    \(\(z3dMin = \(-22\);\)\), "\n", 
    \(\(\(z3dMax = 22;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,0,Z], \[CapitalPsi]\[CapitalPsi][0,2,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,0,Z], \[CapitalPsi]\[CapitalPsi][0,2,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,2,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,2,0,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,0,Z], \[CapitalPsi]\[CapitalPsi][0,2,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-20\);\)\), "\n", 
    \(\(x3dMax = 20;\)\), "\n", 
    \(\(z3dMin = \(-20\);\)\), "\n", 
    \(\(\(z3dMax = 20;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.035;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,1,Z], \[CapitalPsi]\[CapitalPsi][0,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,1,Z], \[CapitalPsi]\[CapitalPsi][0,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][0,2,1,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][0,2,1,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,1,Z], \[CapitalPsi]\[CapitalPsi][0,2,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-20\);\)\), "\n", 
    \(\(x3dMax = 20;\)\), "\n", 
    \(\(z3dMin = \(-20\);\)\), "\n", 
    \(\(\(z3dMax = 20;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.034;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,2,Z], \[CapitalPsi]\[CapitalPsi][0,2,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,2,Z], \[CapitalPsi]\[CapitalPsi][0,2,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][0,2,2,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][0,2,2,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,2,Z], \[CapitalPsi]\[CapitalPsi][0,2,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-36\);\)\), "\n", 
    \(\(x3dMax = 36;\)\), "\n", 
    \(\(z3dMin = \(-36\);\)\), "\n", 
    \(\(\(z3dMax = 36;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.082;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,0,Z], \[CapitalPsi]\[CapitalPsi][0,3,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,0,Z], \[CapitalPsi]\[CapitalPsi][0,3,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,0,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,0,Z], \[CapitalPsi]\[CapitalPsi][0,3,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.03;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,1,Z], \[CapitalPsi]\[CapitalPsi][0,3,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,1,Z], \[CapitalPsi]\[CapitalPsi][0,3,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,1,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,1,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,1,Z], \[CapitalPsi]\[CapitalPsi][0,3,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.022;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,2,Z], \[CapitalPsi]\[CapitalPsi][0,3,2,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,2,Z], \[CapitalPsi]\[CapitalPsi][0,3,2,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,2,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,2,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,2,Z], \[CapitalPsi]\[CapitalPsi][0,3,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.025;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,3,Z], \[CapitalPsi]\[CapitalPsi][0,3,3,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,3,Z], \[CapitalPsi]\[CapitalPsi][0,3,3,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,3,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][0,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][0,3,3,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,3,Z], \[CapitalPsi]\[CapitalPsi][0,3,3,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-14\);\)\), "\n", 
    \(\(x3dMax = 14;\)\), "\n", 
    \(\(z3dMin = \(-14\);\)\), "\n", 
    \(\(\(z3dMax = 14;\)\(\n\)
    \)\), "\n", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0375;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0,Z], \[CapitalPsi]\[CapitalPsi][1,0,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0,Z], \[CapitalPsi]\[CapitalPsi][1,0,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,0,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,0,0,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,0,0,Z], \[CapitalPsi]\[CapitalPsi][1,0,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-24\);\)\), "\n", 
    \(\(x3dMax = 24;\)\), "\n", 
    \(\(z3dMin = \(-24\);\)\), "\n", 
    \(\(\(z3dMax = 24;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.055;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0,Z], \[CapitalPsi]\[CapitalPsi][1,1,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0,Z], \[CapitalPsi]\[CapitalPsi][1,1,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,1,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,1,0,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,0,Z], \[CapitalPsi]\[CapitalPsi][1,1,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-24\);\)\), "\n", 
    \(\(x3dMax = 24;\)\), "\n", 
    \(\(z3dMin = \(-24\);\)\), "\n", 
    \(\(\(z3dMax = 24;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1,Z], \[CapitalPsi]\[CapitalPsi][1,1,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1,Z], \[CapitalPsi]\[CapitalPsi][1,1,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][1,1,1,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][1,1,1,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,1,Z], \[CapitalPsi]\[CapitalPsi][1,1,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-40\);\)\), "\n", 
    \(\(x3dMax = 40;\)\), "\n", 
    \(\(z3dMin = \(-40\);\)\), "\n", 
    \(\(\(z3dMax = 40;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.057;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0,Z], \[CapitalPsi]\[CapitalPsi][1,2,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0,Z], \[CapitalPsi]\[CapitalPsi][1,2,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,2,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,2,0,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,0,Z], \[CapitalPsi]\[CapitalPsi][1,2,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-36\);\)\), "\n", 
    \(\(x3dMax = 36;\)\), "\n", 
    \(\(z3dMin = \(-36\);\)\), "\n", 
    \(\(\(z3dMax = 36;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0225;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1,Z], \[CapitalPsi]\[CapitalPsi][1,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1,Z], \[CapitalPsi]\[CapitalPsi][1,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][1,2,1,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][1,2,1,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,1,Z], \[CapitalPsi]\[CapitalPsi][1,2,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-38\);\)\), "\n", 
    \(\(x3dMax = 38;\)\), "\n", 
    \(\(z3dMin = \(-38\);\)\), "\n", 
    \(\(\(z3dMax = 38;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0225;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2,Z], \[CapitalPsi]\[CapitalPsi][1,2,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2,Z], \[CapitalPsi]\[CapitalPsi][1,2,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][1,2,2,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][1,2,2,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,2,Z], \[CapitalPsi]\[CapitalPsi][1,2,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-56\);\)\), "\n", 
    \(\(x3dMax = 56;\)\), "\n", 
    \(\(z3dMin = \(-56\);\)\), "\n", 
    \(\(\(z3dMax = 56;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.056;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0,Z], \[CapitalPsi]\[CapitalPsi][1,3,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0,Z], \[CapitalPsi]\[CapitalPsi][1,3,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,0,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,0,Z], \[CapitalPsi]\[CapitalPsi][1,3,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-52\);\)\), "\n", 
    \(\(x3dMax = 52;\)\), "\n", 
    \(\(z3dMin = \(-52\);\)\), "\n", 
    \(\(\(z3dMax = 52;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0215;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0,Z], \[CapitalPsi]\[CapitalPsi][0,1,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1,Z], \[CapitalPsi]\[CapitalPsi][1,3,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,1,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,1,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,1,Z], \[CapitalPsi]\[CapitalPsi][1,3,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-52\);\)\), "\n", 
    \(\(x3dMax = 52;\)\), "\n", 
    \(\(z3dMin = \(-52\);\)\), "\n", 
    \(\(\(z3dMax = 52;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.02;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2,Z], \[CapitalPsi]\[CapitalPsi][1,3,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2,Z], \[CapitalPsi]\[CapitalPsi][1,3,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,2,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,2,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,2,Z], \[CapitalPsi]\[CapitalPsi][1,3,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-54\);\)\), "\n", 
    \(\(x3dMax = 54;\)\), "\n", 
    \(\(z3dMin = \(-54\);\)\), "\n", 
    \(\(\(z3dMax = 54;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.02;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3,Z], \[CapitalPsi]\[CapitalPsi][1,3,3,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3,Z], \[CapitalPsi]\[CapitalPsi][1,3,3,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,3,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][1,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][1,3,3,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,3,Z], \[CapitalPsi]\[CapitalPsi][1,3,3,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "21) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-25\);\)\), "\n", 
    \(\(x3dMax = 25;\)\), "\n", 
    \(\(z3dMin = \(-25\);\)\), "\n", 
    \(\(\(z3dMax = 25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0,Z], \[CapitalPsi]\[CapitalPsi][2,0,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0,Z], \[CapitalPsi]\[CapitalPsi][2,0,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,0,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,0,0,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,0,0,Z], \[CapitalPsi]\[CapitalPsi][2,0,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "22) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-40\);\)\), "\n", 
    \(\(x3dMax = 40;\)\), "\n", 
    \(\(z3dMin = \(-40\);\)\), "\n", 
    \(\(\(z3dMax = 40;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.033;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0,Z], \[CapitalPsi]\[CapitalPsi][2,1,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0,Z], \[CapitalPsi]\[CapitalPsi][2,1,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,1,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,1,0,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,0,Z], \[CapitalPsi]\[CapitalPsi][2,1,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "23) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-45\);\)\), "\n", 
    \(\(x3dMax = 45;\)\), "\n", 
    \(\(z3dMin = \(-45\);\)\), "\n", 
    \(\(\(z3dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1,Z], \[CapitalPsi]\[CapitalPsi][2,1,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1,Z], \[CapitalPsi]\[CapitalPsi][2,1,1,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][2,1,1,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][2,1,1,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,1,Z], \[CapitalPsi]\[CapitalPsi][2,1,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "24) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-60\);\)\), "\n", 
    \(\(x3dMax = 60;\)\), "\n", 
    \(\(z3dMin = \(-60\);\)\), "\n", 
    \(\(\(z3dMax = 60;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.04;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0,Z], \[CapitalPsi]\[CapitalPsi][2,2,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0,Z], \[CapitalPsi]\[CapitalPsi][2,2,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,2,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,2,0,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,0,Z], \[CapitalPsi]\[CapitalPsi][2,2,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "25) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-54\);\)\), "\n", 
    \(\(x3dMax = 54;\)\), "\n", 
    \(\(z3dMin = \(-54\);\)\), "\n", 
    \(\(\(z3dMax = 54;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.02;\)\(\n\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1,Z], \[CapitalPsi]\[CapitalPsi][2,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1,Z], \[CapitalPsi]\[CapitalPsi][2,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][2,2,1,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][2,2,1,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,1,Z], \[CapitalPsi]\[CapitalPsi][2,2,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "26) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(x3dMin = \(-58\);\)\), "\n", 
    \(\(x3dMax = 58;\)\), "\n", 
    \(\(z3dMin = \(-58\);\)\), "\n", 
    \(\(\(z3dMax = 58;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0175;\)\(\n\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2,Z], \[CapitalPsi]\[CapitalPsi][2,2,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2,Z], \[CapitalPsi]\[CapitalPsi][2,2,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][2,2,2,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][2,2,2,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,2,Z], \[CapitalPsi]\[CapitalPsi][2,2,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "27) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-84\);\)\), "\n", 
    \(\(x3dMax = 84;\)\), "\n", 
    \(\(z3dMin = \(-84\);\)\), "\n", 
    \(\(\(z3dMax = 84;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.04;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0,Z], \[CapitalPsi]\[CapitalPsi][2,3,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0,Z], \[CapitalPsi]\[CapitalPsi][2,3,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,0,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,0,Z], \[CapitalPsi]\[CapitalPsi][2,3,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "28) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-84\);\)\), "\n", 
    \(\(x3dMax = 84;\)\), "\n", 
    \(\(z3dMin = \(-84\);\)\), "\n", 
    \(\(\(z3dMax = 84;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.015;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1,Z], \[CapitalPsi]\[CapitalPsi][2,3,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1,Z], \[CapitalPsi]\[CapitalPsi][2,3,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,1,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,1,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,1,Z], \[CapitalPsi]\[CapitalPsi][2,3,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "29) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-80\);\)\), "\n", 
    \(\(x3dMax = 80;\)\), "\n", 
    \(\(z3dMin = \(-80\);\)\), "\n", 
    \(\(\(z3dMax = 80;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.012;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2,Z], \[CapitalPsi]\[CapitalPsi][2,3,2,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2,Z], \[CapitalPsi]\[CapitalPsi][2,3,2,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,2,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,2,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,2,Z], \[CapitalPsi]\[CapitalPsi][2,3,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "30) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-88\);\)\), "\n", 
    \(\(x3dMax = 88;\)\), "\n", 
    \(\(z3dMin = \(-88\);\)\), "\n", 
    \(\(\(z3dMax = 88;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.015;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3,Z], \[CapitalPsi]\[CapitalPsi][2,3,3,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3,Z], \[CapitalPsi]\[CapitalPsi][2,3,3,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,3,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][2,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][2,3,3,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,3,Z], \[CapitalPsi]\[CapitalPsi][2,3,3,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "31) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-44\);\)\), "\n", 
    \(\(x3dMax = 44;\)\), "\n", 
    \(\(z3dMin = \(-44\);\)\), "\n", 
    \(\(\(z3dMax = 44;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.012;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0,Z], \[CapitalPsi]\[CapitalPsi][3,0,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0,Z], \[CapitalPsi]\[CapitalPsi][3,0,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,0,0,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,0,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,0,0,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,0,0,Z], \[CapitalPsi]\[CapitalPsi][3,0,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "32) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-62\);\)\), "\n", 
    \(\(x3dMax = 62;\)\), "\n", 
    \(\(z3dMin = \(-62\);\)\), "\n", 
    \(\(\(z3dMax = 62;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0111;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0,Z], \[CapitalPsi]\[CapitalPsi][3,1,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0,Z], \[CapitalPsi]\[CapitalPsi][3,1,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,1,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,1,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,1,0,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,0,Z], \[CapitalPsi]\[CapitalPsi][3,1,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "33) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-66\);\)\), "\n", 
    \(\(x3dMax = 66;\)\), "\n", 
    \(\(z3dMin = \(-66\);\)\), "\n", 
    \(\(\(z3dMax = 66;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.011;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1,Z], \[CapitalPsi]\[CapitalPsi][3,1,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1,Z], \[CapitalPsi]\[CapitalPsi][3,1,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][3,1,1,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,1,1,Z], \
\[CapitalPsi]\[CapitalPsi][3,1,1,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,1,Z], \[CapitalPsi]\[CapitalPsi][3,1,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "34) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-88\);\)\), "\n", 
    \(\(x3dMax = 88;\)\), "\n", 
    \(\(z3dMin = \(-88\);\)\), "\n", 
    \(\(\(z3dMax = 88;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.027;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0,Z], \[CapitalPsi]\[CapitalPsi][3,2,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0,Z], \[CapitalPsi]\[CapitalPsi][3,2,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,2,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,2,0,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,0,Z], \[CapitalPsi]\[CapitalPsi][3,2,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "35) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-80\);\)\), "\n", 
    \(\(x3dMax = 80;\)\), "\n", 
    \(\(z3dMin = \(-80\);\)\), "\n", 
    \(\(\(z3dMax = 80;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.011;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,1,Z], \[CapitalPsi]\[CapitalPsi][3,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,1,Z], \[CapitalPsi]\[CapitalPsi][3,2,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][3,2,1,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,1,Z], \
\[CapitalPsi]\[CapitalPsi][3,2,1,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,1,Z], \[CapitalPsi]\[CapitalPsi][3,2,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "36) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-84\);\)\), "\n", 
    \(\(x3dMax = 84;\)\), "\n", 
    \(\(z3dMin = \(-84\);\)\), "\n", 
    \(\(\(z3dMax = 84;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.011;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,2,Z], \[CapitalPsi]\[CapitalPsi][3,2,2,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,2,Z], \[CapitalPsi]\[CapitalPsi][3,2,2,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][3,2,2,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,2,Z], \
\[CapitalPsi]\[CapitalPsi][3,2,2,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,2,Z], \[CapitalPsi]\[CapitalPsi][3,2,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "37) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0315;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\[IndentingNewLine]\n\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,0,Z], \[CapitalPsi]\[CapitalPsi][3,3,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,0,Z], \[CapitalPsi]\[CapitalPsi][3,3,0,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,0,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,0,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,0,Z2], y=0\>"];\)\n\[IndentingNewLine]\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,0,Z], \[CapitalPsi]\[CapitalPsi][3,3,0,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "38) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.011;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\[IndentingNewLine]\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,1,Z], \[CapitalPsi]\[CapitalPsi][3,3,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,1,Z], \[CapitalPsi]\[CapitalPsi][3,3,1,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,1,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,1,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,1,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,1,Z], \[CapitalPsi]\[CapitalPsi][3,3,1,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "39) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.00875;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0,Z], \[CapitalPsi]\[CapitalPsi][0,1,0,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,2,Z], \[CapitalPsi]\[CapitalPsi][3,3,2,Z2], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,2,Z2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,2,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,2,Z2], y=0\>"];\)\n\n\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,2,Z], \[CapitalPsi]\[CapitalPsi][3,3,2,Z2], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "40) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.009;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, y0] = 
        If[x > 0, \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], 0];\)\(\n\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          y0] = If[
          x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], 0];\)\n\n\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
          Z2, y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, 
            l\_orb, m\_azm, Z2], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z2, y0], \[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, Z, y0]];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,3,Z], \[CapitalPsi]\[CapitalPsi][3,3,3,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(HydAt, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,3,Z], \[CapitalPsi]\[CapitalPsi][3,3,3,Z2], y=0\>"];\)\(\n\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,3,Z2], y=0\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]hf\_\(HydAt, Cart\)[n\_rad, l\_orb, 
            m\_azm, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.9], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint \[Rule] {\(-3\), \(-2\), 
              3}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,3,Z], \
\[CapitalPsi]\[CapitalPsi][3,3,3,Z2], y=0\>"];\)\[IndentingNewLine]\n\), "\n\
", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}, {WFunktion3dZ\_HydAt[n\_rad, l\_orb, m\_azm, y0], 
            WFunktion3dZ2\_HydAt[n\_rad, l\_orb, m\_azm, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,3,Z], \[CapitalPsi]\[CapitalPsi][3,3,3,Z2], y=0\>"]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 222, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2706, 90, 145, 4, 85, "Section"],
Cell[2854, 96, 146, 4, 56, "Text"],
Cell[3003, 102, 277, 12, 92, "NumberedEquation"],
Cell[3283, 116, 144, 4, 56, "Text"],
Cell[3430, 122, 141, 3, 113, "Input"],
Cell[3574, 127, 113, 3, 56, "Text"],
Cell[3690, 132, 14367, 231, 6321, "Input"],
Cell[18060, 365, 114, 3, 56, "Text"],
Cell[18177, 370, 15476, 244, 6645, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33690, 619, 168, 5, 85, "Section"],
Cell[33861, 626, 361, 7, 152, "Text"],
Cell[34225, 635, 666, 17, 452, "Text"],
Cell[34894, 654, 468, 8, 338, "Input"],

Cell[CellGroupData[{
Cell[35387, 666, 202, 11, 89, "Subsection"],
Cell[35592, 679, 5987, 105, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41616, 789, 202, 11, 89, "Subsection"],
Cell[41821, 802, 5819, 104, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47677, 911, 202, 11, 89, "Subsection"],
Cell[47882, 924, 5806, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53725, 1032, 202, 11, 89, "Subsection"],
Cell[53930, 1045, 5806, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59773, 1153, 202, 11, 89, "Subsection"],
Cell[59978, 1166, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65822, 1274, 202, 11, 89, "Subsection"],
Cell[66027, 1287, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71871, 1395, 202, 11, 89, "Subsection"],
Cell[72076, 1408, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77920, 1516, 202, 11, 89, "Subsection"],
Cell[78125, 1529, 5806, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83968, 1637, 202, 11, 89, "Subsection"],
Cell[84173, 1650, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90017, 1758, 203, 11, 89, "Subsection"],
Cell[90223, 1771, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96067, 1879, 203, 11, 89, "Subsection"],
Cell[96273, 1892, 5774, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102084, 2000, 203, 11, 89, "Subsection"],
Cell[102290, 2013, 6013, 107, 2146, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108340, 2125, 203, 11, 89, "Subsection"],
Cell[108546, 2138, 5808, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114391, 2246, 203, 11, 89, "Subsection"],
Cell[114597, 2259, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120441, 2367, 203, 11, 89, "Subsection"],
Cell[120647, 2380, 5808, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[126492, 2488, 203, 11, 89, "Subsection"],
Cell[126698, 2501, 5808, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132543, 2609, 203, 11, 89, "Subsection"],
Cell[132749, 2622, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138593, 2730, 203, 11, 89, "Subsection"],
Cell[138799, 2743, 5808, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144644, 2851, 203, 11, 89, "Subsection"],
Cell[144850, 2864, 5806, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150693, 2972, 203, 11, 89, "Subsection"],
Cell[150899, 2985, 5806, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156742, 3093, 203, 11, 89, "Subsection"],
Cell[156948, 3106, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162792, 3214, 203, 11, 89, "Subsection"],
Cell[162998, 3227, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168842, 3335, 203, 11, 89, "Subsection"],
Cell[169048, 3348, 5807, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174892, 3456, 203, 11, 89, "Subsection"],
Cell[175098, 3469, 5789, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180924, 3577, 203, 11, 89, "Subsection"],
Cell[181130, 3590, 5772, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[186939, 3698, 203, 11, 89, "Subsection"],
Cell[187145, 3711, 5757, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192939, 3819, 203, 11, 89, "Subsection"],
Cell[193145, 3832, 5789, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198971, 3940, 203, 11, 89, "Subsection"],
Cell[199177, 3953, 5790, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[205004, 4061, 203, 11, 89, "Subsection"],
Cell[205210, 4074, 5773, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[211020, 4182, 203, 11, 89, "Subsection"],
Cell[211226, 4195, 5790, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217053, 4303, 203, 11, 89, "Subsection"],
Cell[217259, 4316, 5790, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223086, 4424, 203, 11, 89, "Subsection"],
Cell[223292, 4437, 5791, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[229120, 4545, 203, 11, 89, "Subsection"],
Cell[229326, 4558, 5790, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235153, 4666, 203, 11, 89, "Subsection"],
Cell[235359, 4679, 5773, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241169, 4787, 203, 11, 89, "Subsection"],
Cell[241375, 4800, 5773, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247185, 4908, 203, 11, 89, "Subsection"],
Cell[247391, 4921, 5790, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[253218, 5029, 203, 11, 89, "Subsection"],
Cell[253424, 5042, 5795, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259256, 5150, 203, 11, 89, "Subsection"],
Cell[259462, 5163, 5777, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[265276, 5271, 203, 11, 89, "Subsection"],
Cell[265482, 5284, 5779, 103, 2095, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271298, 5392, 203, 11, 89, "Subsection"],
Cell[271504, 5405, 5777, 103, 2095, "Input"],
Cell[277284, 5510, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

