(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    504671,      11150]*)
(*NotebookOutlinePosition[    505400,      11175]*)
(*  CellTagsIndexPosition[    505356,      11171]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["Part 4. Comparison of Quantum States of the Bound \
Isotropic Systems",
  FontWeight->"Bold"]], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "4.2. Comparison of Quantum States of the Three-Dimensional Isotropic \
Quantum Rotator and Oscillator and ",
  StyleBox["Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell[TextData[{
  "1. Probability densities of the three-dimensional quantum rotator and \
oscillator and ",
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"]
}], "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider states of the three-dimensional quantum rotator defined by quantum \
numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 1, 2, 3, 4\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["\<\
and states (corresponding to given states of rotator) of the \
three-dimensional quantum oscillator and Hydrogen-like atoms defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell[TextData[{
  "Determine parameters ",
  StyleBox["r0",
    FontSlant->"Italic"],
  " of the three-dimensional quantum rotator, \[Lambda] of the \
three-dimensional quantum oscillator and Z and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  " of Hydrogen-like atoms:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(r0 = 1;\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\[Lambda] = 1;\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Z = 1;\)\ \), "\n", 
    \(\(a\_0 = 1;\)\)}], "Input"],

Cell["\<\
Probability densities of the three-dimensional quantum rotator in the \
Cartesian rectangular coordinates:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.5630360474111934`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(3.1415926535897913`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((9.441825313230899`\ z\^2\ \
\((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((4.720912656615449`\ \((x\^2 + 
                  y\^2)\)\ \((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((4.509770315871688`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((27.05862189523013`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((6.764655473807532`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\
\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 0, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((7.180738041514811`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 1, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((5.385553531136108`\ \
\((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
6.987932000503647`\ \@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) \
+ 0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 2, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((53.85553531136109`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 3, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((8.975922551893515`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\
\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4963228357196234`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(6.283185307179585`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((16.962502900061462`\ z\^2\ \
\((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((8.481251450030731`\ \((x\^2 + 
                  y\^2)\)\ \((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((7.850515282898902`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.00959518174141225`\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((47.10309169739341`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 2, 
          
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.775772924348352`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\
\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((11.995847465449176`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + \
0.24721012729596964`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((8.996885599086882`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + \
0.14238685650074237`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((89.96885599086882`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((14.994809331811469`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4856662084790068`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(9.424777960902889`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((24.231131639907577`\ z\^2\ \
\((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((12.115565819953789`\ \((x\^2 + 
                  y\^2)\)\ \((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.023293658715744`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((66.13976195229446`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((16.534940488073616`\ \((x\^2 + y\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((16.58802556637349`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + \
0.215581313417243`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\
\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0012581391733403658`\)\ r0\^2 + \
0.09442879939898956`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((12.441019174780115`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((124.41019174780115`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((20.73503195796686`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4820436953208706`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(12.566370614390479`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((31.4119931862564`\ z\^2\ \
\((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((15.7059965931282`\ \((x\^2 + 
                  y\^2)\)\ \((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((14.112846556690327`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((84.67707934014196`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((21.16926983503549`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\
\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((21.037307069172908`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + \
0.19395162042753517`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0006002121422403276`\)\ r0\^2 + \
0.06876245355250067`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((15.777980301879683`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((157.77980301879683`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((26.29663383646614`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\)}], "Input"],

Cell["\<\
Probability densities of the three-dimensional quantum oscillator in the \
Cartesian rectangular coordinates:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\)\/\(3\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          1, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\^\(7/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ \
z\^3)\)\^2\ \[Lambda]\^\(9/2\)\)\/\(15\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\)\/\(10\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\)\/\(6\ \[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((3 - 2\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(5\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((5 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(10\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(42\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(7\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(28\ \[Pi]\^\(3/2\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\
\^2\)\/\(135\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(180\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(18\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(108\ \
\[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\
\))\)\^2\)\/\(120\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(140\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((35 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\)\^2\)\/\(280\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          0, \[Lambda]] = \(1\/\(1512\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) \
+ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(252\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(1008\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          0, \[Lambda]] = \(1\/\(5940\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          1, \[Lambda]] = \(1\/\(7920\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          2, \[Lambda]] = \(1\/\(792\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(4752\ \[Pi]\^\(3/2\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 0, 
          0, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((35\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          0, \[Lambda]] = \(1\/\(7560\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          1, \[Lambda]] = \(1\/\(15120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\
\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          0, \[Lambda]] = \(1\/\(64\ \[Pi]\^\(3/2\)\)\) \((77\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^3\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
\[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          1, \[Lambda]] = \(1\/\(8\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          2, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          0, \[Lambda]] = \(1\/\(40\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          1, \[Lambda]] = \(1\/\(160\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          2, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          3, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\)}], \
"Input"],

Cell["\<\
Probability densities of the Hydrogen-like atom in the Cartesian rectangular \
coordinates:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/\(\[Pi]\ a\_0\%3\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(32\ \[Pi]\ \
a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(64\ \
\[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^7\)\/\(39366\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\
\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^7\)\/\(26244\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\
\^2\ Z\^9\)\/\(47185920\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 \
+ z\^2)\)\ Z\^9\)\/\(62914560\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(37748736\ \[Pi]\ a\_0\%9\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z \
- 2\ a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\
\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(9437184\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\
\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ a\_0\%9\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ \
a\_0)\)\^2\)\/\(21972656250\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\
\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\
\/\(29296875000\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \[Pi]\ \
a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ a\_0\
\%11\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^2 + 9\ a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 3\ a\_0)\))\
\)\^2\)\/\(19683\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\^2 + z\^2)\)\
\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(1310720\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\
\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(2621440\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 0, 
          Z] = \(1\/\(30761718750\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 1, 
          Z] = \(1\/\(5126953125\ \[Pi]\ a\_0\%11\)\) \((\[ExponentialE]\^\(-\
\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 2, 
          Z] = \(1\/\(20507812500\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 0, 
          Z] = \(1\/\(31737486458880\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 1, 
          Z] = \(1\/\(42316648611840\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 2, 
          Z] = \(1\/\(4231664861184\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 3, 
          Z] = \(1\/\(25389989167104\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\
\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 0, 0, 
          Z] = \(1\/\(2359296\ \[Pi]\ a\_0\%9\)\) \((\[ExponentialE]\^\(-\(\(\
\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ a\_0\)\)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^3\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
24\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 6\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 8\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
          Z] = \[IndentingNewLine]\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
            Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \((\[ExponentialE]\^\
\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((x\^2 + 
                    y\^2 + z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^2\ a\_0 + 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 1, 
          Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2\ a\_0 \
+ 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 0, 
          Z] = \(1\/\(14810827014144\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 1, 
          Z] = \(1\/\(2468471169024\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((z\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 72\ z\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 2, 
          Z] = \(1\/\(9873884676096\ \[Pi]\ a\_0\%13\)\) \((\[ExponentialE]\^\
\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 0, 
          Z] = \(1\/\(403780106420652150\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 1, 
          Z] = \(1\/\(538373475227536200\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 2, 
          Z] = \(1\/\(53837347522753620\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 3, 
          Z] = \(1\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2. Visualization of quantum states of the three-dimensional quantum \
rotator and oscillator and ",
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"]
}], "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the probability densities of the \
three-dimensional quantum rotator and oscillator and Hydrogen-Like Atoms.
We will obtain two-dimensional plots for radial  functions and radial \
probability densities and present density and surface (three-dimensional) \
plots for probability densities of the three-dimensional quantum rotator and \
oscillator and Hydrogen-Like Atoms.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-r0\) - 0.1;\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = r0 + 0.1;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-r0\) - 0.1;\)\), "\[IndentingNewLine]", 
    \(\(z3dMax = r0 + 0.1;\)\n\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 300;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(IS3dVert = 265;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VP1 = 0;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = 0;\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 3;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n1) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.65], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], Rotator\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              
              0.7], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], Rotator\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,0,0], \
Rotator\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n2) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.65], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], Rotator\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              
              0.7], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], \
Rotator\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,1,0], \
Rotator\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n3) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.35;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.65], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], Rotator\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              
              0.7], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], \
Rotator\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,1,0], \
Rotator\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n4) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 1.2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.65], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], Rotator\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.7], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], \
Rotator\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\< \[Psi]\[Psi][1,2,0], \
Rotator\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n5) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.65], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], Rotator\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.7], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], \
Rotator\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,2,1], \
Rotator\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n6) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        Plot3D[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.65], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], Rotator\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0] = 
        DensityPlot[\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0, y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.7], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], \
Rotator\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,2,2], \
Rotator\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n7) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1.85;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n8) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n9) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.6;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n10) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.6;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n11) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.35;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n12) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n13) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n14) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1.725;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n15) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR2dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR2dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.7;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n16) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.61;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n17) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        2.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n18) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.9;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n19) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n20) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.7;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n21) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n22) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n23) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n24) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n25) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n26) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.65;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n27) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        2.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(Show[
      GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0], 
          WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][3,3,0], \
\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n28) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n29) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n30) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.85;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n31) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,0,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n32) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1.15;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,1,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n33) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.65;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,1,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n34)  ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1.95;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,2,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n35) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,2,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n36) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,2,2], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n37) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        2.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,3,0], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n38) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1.05;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,3,1], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n39) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,3,2], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum rotator\n40) ",
  Cell[BoxData[
      \(n\_rad = 4\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        1.05;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
          l\_orb, m\_azm, r0, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
            r0], {y \[Rule] 
              y0}];\), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]2\_\(Rotat, \
Cart\)[n\_rad, l\_orb, m\_azm, r0, y0] = 
        If[\@\(x\^2 + z\^2\) < r0, \[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, 
            l\_orb, m\_azm, r0, y0], 0];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), "=",
           
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.65]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]\), 
          "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]2\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, 
                r0, y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.7]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][4,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
            "]"}]}], ";"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3dDen\_Rotat[n\_rad, l\_orb, m\_azm, 
              r0, y0], 
            WFunktion3dVW\_Rotat[n\_rad, l\_orb, m\_azm, r0, y0]}]\), ",", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][4,3,3], \!\(InputForm\`Rotator\)\>\""}]}], 
      "]"}]}], "Input"],

Cell["", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-2.75\);\), "\n", \(x3dMax = 
        2.75;\), "\n", \(z3dMin = \(-2.75\);\), "\n", \(\(z3dMax = 
        2.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.0675;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,0,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n2) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3\);\), "\n", \(x3dMax = 
        3;\), "\n", \(z3dMin = \(-3\);\), "\n", \(\(z3dMax = 
        3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,1,0], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,1,0], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,1,0], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n3) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3\);\), "\n", \(x3dMax = 
        3;\), "\n", \(z3dMin = \(-3\);\), "\n", \(\(z3dMax = 
        3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,1,1], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,1,1], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,1,1], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n4 ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.25\);\), "\n", \(x3dMax = 
        3.25;\), "\n", \(z3dMin = \(-3.25\);\), "\n", \(\(z3dMax = 
        3.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 0;\), "\[IndentingNewLine]", 
    RowBox[{\(PR3dMax = 0.35;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
              m\_azm, \[Lambda]], {y \[Rule] y0}];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,2,0], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,2,0], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,2,0], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n5) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.25\);\), "\n", \(x3dMax = 
        3.25;\), "\n", \(z3dMin = \(-3.25\);\), "\n", \(\(z3dMax = 
        3.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.125;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,2,1], \!\(InputForm\`Oscllator\)\>\""}]}],
             "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,2,1], \
\!\(InputForm\`\(InputForm\`Oscillator\)\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,2,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n6) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.5\);\), "\n", \(x3dMax = 
        3.5;\), "\n", \(z3dMin = \(-3.5\);\), "\n", \(\(z3dMax = 
        3.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.125;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,2,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n7) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.75\);\), "\n", \(x3dMax = 
        3.75;\), "\n", \(z3dMin = \(-3.75\);\), "\n", \(\(z3dMax = 
        3.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,3,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n8) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.5\);\), "\n", \(x3dMax = 
        3.5;\), "\n", \(z3dMin = \(-3.5\);\), "\n", \(\(z3dMax = 
        3.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.16;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,3,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n9) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.5\);\), "\n", \(x3dMax = 
        3.5;\), "\n", \(z3dMin = \(-3.5\);\), "\n", \(z3dMax = 
        3.5;\), "\[IndentingNewLine]", \(IS3dHorz = 
        250;\), "\[IndentingNewLine]", \(\(IS3dVert = 
        265;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,3,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n10) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 0;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.5\);\), "\n", \(x3dMax = 
        3.5;\), "\n", \(z3dMin = \(-3.5\);\), "\n", \(z3dMax = 
        3.5;\), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.14;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][0,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][0,3,3], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n11) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-3.75\);\), "\n", \(x3dMax = 
        3.75;\), "\n", \(z3dMin = \(-3.75\);\), "\n", \(\(z3dMax = 
        3.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.0575;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,0,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n12) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4\);\), "\n", \(x3dMax = 
        4;\), "\n", \(z3dMin = \(-4\);\), "\n", \(\(z3dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.165;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,1,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,1,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,1,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n13) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4\);\), "\n", \(x3dMax = 
        4;\), "\n", \(z3dMin = \(-4\);\), "\n", \(\(z3dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.085;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,1,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,1,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,1,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n14) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4\);\), "\n", \(x3dMax = 
        4;\), "\n", \(z3dMin = \(-4\);\), "\n", \(\(z3dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.27;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,2,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,2,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,2,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n15) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4\);\), "\n", \(x3dMax = 
        4;\), "\n", \(z3dMin = \(-4\);\), "\n", \(\(z3dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,2,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,2,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,2,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n16) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.25\);\), "\n", \(x3dMax = 
        4.25;\), "\n", \(z3dMin = \(-4.25\);\), "\n", \(\(z3dMax = 
        4.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,2,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n17) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.25\);\), "\n", \(x3dMax = 
        4.25;\), "\n", \(z3dMin = \(-4.25\);\), "\n", \(\(z3dMax = 
        4.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.375;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
          DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
              x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
              False, \[IndentingNewLine]PlotPoints \[Rule] 
              N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
                IS3dVert}, \[IndentingNewLine]Background \[Rule] 
              GrayLevel[
                0.8], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][1,3,0], y=0\>"];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n18) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4\);\), "\n", \(x3dMax = 
        4;\), "\n", \(z3dMin = \(-4\);\), "\n", \(\(z3dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.15;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n19) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4\);\), "\n", \(x3dMax = 
        4;\), "\n", \(z3dMin = \(-4\);\), "\n", \(\(z3dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.105;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n20) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.25\);\), "\n", \(x3dMax = 
        4.25;\), "\n", \(z3dMin = \(-4.25\);\), "\n", \(\(z3dMax = 
        4.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.115;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][1,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][1,3,3], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n21) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4\);\), "\n", \(x3dMax = 
        4;\), "\n", \(z3dMin = \(-4\);\), "\n", \(\(z3dMax = 
        4;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.0525;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,0,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n22) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.25\);\), "\n", \(x3dMax = 
        4.25;\), "\n", \(z3dMin = \(-4.25\);\), "\n", \(\(z3dMax = 
        4.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.155;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,1,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n23) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.25\);\), "\n", \(x3dMax = 
        4.25;\), "\n", \(z3dMin = \(-4.25\);\), "\n", \(\(z3dMax = 
        4.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.075;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,1,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,1,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n24) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.5\);\), "\n", \(x3dMax = 
        4.5;\), "\n", \(z3dMin = \(-4.5\);\), "\n", \(\(z3dMax = 
        4.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<S\[Psi]\[Psi][2,2,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,2,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n25) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.5\);\), "\n", \(x3dMax = 
        4.5;\), "\n", \(z3dMin = \(-4.5\);\), "\n", \(\(z3dMax = 
        4.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.09;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,2,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n26) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.5\);\), "\n", \(x3dMax = 
        4.5;\), "\n", \(z3dMin = \(-4.5\);\), "\n", \(\(z3dMax = 
        4.5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.09;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,2,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n27) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.75\);\), "\n", \(x3dMax = 
        4.75;\), "\n", \(z3dMin = \(-4.75\);\), "\n", \(\(z3dMax = 
        4.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.345;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n28) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.75\);\), "\n", \(x3dMax = 
        4.75;\), "\n", \(z3dMin = \(-4.75\);\), "\n", \(\(z3dMax = 
        4.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.125;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n29) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.75\);\), "\n", \(x3dMax = 
        4.75;\), "\n", \(z3dMin = \(-4.75\);\), "\n", 
    RowBox[{\(z3dMax = 4.75;\), "\[IndentingNewLine]", 
      "\[IndentingNewLine]"}], "\n", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.095;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n30) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.75\);\), "\n", \(x3dMax = 
        4.75;\), "\n", \(z3dMin = \(-4.75\);\), "\n", \(\(z3dMax = 
        4.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.11;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][2,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][2,3,3], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n31) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.75\);\), "\n", \(x3dMax = 
        4.75;\), "\n", \(z3dMin = \(-4.75\);\), "\n", \(\(z3dMax = 
        4.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.0475;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,0,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,0,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n32) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-4.75\);\), "\n", \(x3dMax = 
        4.75;\), "\n", \(z3dMin = \(-4.75\);\), "\n", \(\(z3dMax = 
        4.75;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.145;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,1,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n33) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5\);\), "\n", \(x3dMax = 
        5;\), "\n", \(z3dMin = \(-5\);\), "\n", \(\(z3dMax = 
        5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.0685;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,1,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,1,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n34) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5\);\), "\n", \(x3dMax = 
        5;\), "\n", \(z3dMin = \(-5\);\), "\n", \(\(z3dMax = 
        5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.235;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,2,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n35) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5\);\), "\n", \(x3dMax = 
        5;\), "\n", \(z3dMin = \(-5\);\), "\n", \(\(z3dMax = 
        5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.0875;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,2,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n36) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5.25\);\), "\n", \(x3dMax = 
        5.25;\), "\n", \(z3dMin = \(-5.25\);\), "\n", \(\(z3dMax = 
        5.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.0865;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,2,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,2,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n37) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5.25\);\), "\n", \(x3dMax = 
        5.25;\), "\n", \(z3dMin = \(-5.25\);\), "\n", \(\(z3dMax = 
        5.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.315;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,0], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,3,0], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n38) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5\);\), "\n", \(x3dMax = 
        5;\), "\n", \(z3dMin = \(-5\);\), "\n", \(\(z3dMax = 
        5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.115;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,1], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,3,1], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n39) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5\);\), "\n", \(x3dMax = 
        5;\), "\n", \(z3dMin = \(-5\);\), "\n", \(\(z3dMax = 
        5;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.09;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,2], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,3,2], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Three-dimensional quantum oscillator\n40) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", \(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(x3dMin = \(-5.25\);\), "\n", \(x3dMax = 
        5.25;\), "\n", \(z3dMin = \(-5.25\);\), "\n", \(\(z3dMax = 
        5.25;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(PR3dMin = 
        0;\), "\[IndentingNewLine]", \(\(PR3dMax = 
        0.1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]\), 
          "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.5, 0. , 0.35]\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Boxed \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {0.000, \ 0.000, 4}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]\), "=", 
          RowBox[{"DensityPlot", "[", 
            RowBox[{\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
                m\_azm, \[Lambda], y0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({z, z3dMin, z3dMax}\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.8]\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\)\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\[Psi]\[Psi][3,3,3], \
\!\(InputForm\`Oscillator\)\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{WFunktion3d\_Oscl[n\_rad, l\_orb, 
              m\_azm, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0]}]\), 
        ",", "\[IndentingNewLine]", \(ImageSize \[Rule] {ISAll3dHorz, 
            ISAll3dVert}\), ",", 
        "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.0, 0.75, 0.0]\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\[Psi]\[Psi][3,3,3], \!\(InputForm\`Oscillator\)\>\""}]}], 
      "]"}]}], "Input"],

Cell["", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\n", 
    \(\(x3dMax = 4.25;\)\), "\n", 
    \(\(z3dMin = \(-4.25\);\)\), "\n", 
    \(\(\(z3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.046;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,0,0], Hydrogen-like Atom\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,0,0], Hydrogen-like Atom\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,0,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n2) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-11\);\)\), "\n", 
    \(\(x3dMax = 11;\)\), "\n", 
    \(\(z3dMin = \(-11\);\)\), "\n", 
    \(\(\(z3dMax = 11;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.046;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0], Hydrogen-like Atom\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,1,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n3) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-11\);\)\), "\n", 
    \(\(x3dMax = 11;\)\), "\n", 
    \(\(z3dMin = \(-11\);\)\), "\n", 
    \(\(\(z3dMax = 11;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.025;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,1,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n4)  ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-22\);\)\), "\n", 
    \(\(x3dMax = 22;\)\), "\n", 
    \(\(z3dMin = \(-22\);\)\), "\n", 
    \(\(\(z3dMax = 22;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.045;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,2,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n5)  ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-20\);\)\), "\n", 
    \(\(x3dMax = 20;\)\), "\n", 
    \(\(z3dMin = \(-20\);\)\), "\n", 
    \(\(\(z3dMax = 20;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.045;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,2,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n6) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-20\);\)\), "\n", 
    \(\(x3dMax = 20;\)\), "\n", 
    \(\(z3dMin = \(-20\);\)\), "\n", 
    \(\(\(z3dMax = 20;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,2,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n7) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-36\);\)\), "\n", 
    \(\(x3dMax = 36;\)\), "\n", 
    \(\(z3dMin = \(-36\);\)\), "\n", 
    \(\(\(z3dMax = 36;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.041;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,3,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n8) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0145;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,3,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n9) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0115;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,3,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n10) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-33\);\)\), "\n", 
    \(\(x3dMax = 33;\)\), "\n", 
    \(\(z3dMin = \(-33\);\)\), "\n", 
    \(\(\(z3dMax = 33;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,3], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,3], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][0,3,3], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n11) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-14\);\)\), "\n", 
    \(\(x3dMax = 14;\)\), "\n", 
    \(\(z3dMin = \(-14\);\)\), "\n", 
    \(\(\(z3dMax = 14;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0165;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,0,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n12) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-24\);\)\), "\n", 
    \(\(x3dMax = 24;\)\), "\n", 
    \(\(z3dMin = \(-24\);\)\), "\n", 
    \(\(\(z3dMax = 24;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0255;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,1,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n13) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-24\);\)\), "\n", 
    \(\(x3dMax = 24;\)\), "\n", 
    \(\(z3dMin = \(-24\);\)\), "\n", 
    \(\(\(z3dMax = 24;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,1,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n14) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-40\);\)\), "\n", 
    \(\(x3dMax = 40;\)\), "\n", 
    \(\(z3dMin = \(-40\);\)\), "\n", 
    \(\(\(z3dMax = 40;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0275;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,2,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n15) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-36\);\)\), "\n", 
    \(\(x3dMax = 36;\)\), "\n", 
    \(\(z3dMin = \(-36\);\)\), "\n", 
    \(\(\(z3dMax = 36;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-40\);\)\), "\n", 
    \(\(x3dMax = 40;\)\), "\n", 
    \(\(z3dMin = \(-40\);\)\), "\n", 
    \(\(\(z3dMax = 40;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.01025;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,2,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n16) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-38\);\)\), "\n", 
    \(\(x3dMax = 38;\)\), "\n", 
    \(\(z3dMin = \(-38\);\)\), "\n", 
    \(\(\(z3dMax = 38;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.01025;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,2,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n17) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-56\);\)\), "\n", 
    \(\(x3dMax = 56;\)\), "\n", 
    \(\(z3dMin = \(-56\);\)\), "\n", 
    \(\(\(z3dMax = 56;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0275;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,3,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n18) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-52\);\)\), "\n", 
    \(\(x3dMax = 52;\)\), "\n", 
    \(\(z3dMin = \(-52\);\)\), "\n", 
    \(\(\(z3dMax = 52;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,3,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n19) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-52\);\)\), "\n", 
    \(\(x3dMax = 52;\)\), "\n", 
    \(\(z3dMin = \(-52\);\)\), "\n", 
    \(\(\(z3dMax = 52;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,3,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n20) ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-54\);\)\), "\n", 
    \(\(x3dMax = 54;\)\), "\n", 
    \(\(z3dMin = \(-54\);\)\), "\n", 
    \(\(\(z3dMax = 54;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][1,3,3], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n21) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-25\);\)\), "\n", 
    \(\(x3dMax = 25;\)\), "\n", 
    \(\(z3dMin = \(-25\);\)\), "\n", 
    \(\(\(z3dMax = 25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0085;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,0,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n22) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-40\);\)\), "\n", 
    \(\(x3dMax = 40;\)\), "\n", 
    \(\(z3dMin = \(-40\);\)\), "\n", 
    \(\(\(z3dMax = 40;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0165;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,2,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n23) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-45\);\)\), "\n", 
    \(\(x3dMax = 45;\)\), "\n", 
    \(\(z3dMin = \(-45\);\)\), "\n", 
    \(\(\(z3dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.008;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,1,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n24) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-60\);\)\), "\n", 
    \(\(x3dMax = 60;\)\), "\n", 
    \(\(z3dMin = \(-60\);\)\), "\n", 
    \(\(\(z3dMax = 60;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.02;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,2,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n25) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-54\);\)\), "\n", 
    \(\(x3dMax = 54;\)\), "\n", 
    \(\(z3dMin = \(-54\);\)\), "\n", 
    \(\(\(z3dMax = 54;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0075;\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,2,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n26) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-58\);\)\), "\n", 
    \(\(x3dMax = 58;\)\), "\n", 
    \(\(z3dMin = \(-58\);\)\), "\n", 
    \(\(\(z3dMax = 58;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.017;\)\(\n\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,2,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n27) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-84\);\)\), "\n", 
    \(\(x3dMax = 84;\)\), "\n", 
    \(\(z3dMin = \(-84\);\)\), "\n", 
    \(\(\(z3dMax = 84;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.019;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,3,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n28) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-84\);\)\), "\n", 
    \(\(x3dMax = 84;\)\), "\n", 
    \(\(z3dMin = \(-84\);\)\), "\n", 
    \(\(\(z3dMax = 84;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0075;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,3,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n29) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-80\);\)\), "\n", 
    \(\(x3dMax = 80;\)\), "\n", 
    \(\(z3dMin = \(-80\);\)\), "\n", 
    \(\(\(z3dMax = 80;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,3,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n30) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-88\);\)\), "\n", 
    \(\(x3dMax = 88;\)\), "\n", 
    \(\(z3dMin = \(-88\);\)\), "\n", 
    \(\(\(z3dMax = 88;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0125;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][2,3,3], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n31)  ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-44\);\)\), "\n", 
    \(\(x3dMax = 44;\)\), "\n", 
    \(\(z3dMin = \(-44\);\)\), "\n", 
    \(\(\(z3dMax = 44;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][3,0,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n32) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-62\);\)\), "\n", 
    \(\(x3dMax = 62;\)\), "\n", 
    \(\(z3dMin = \(-62\);\)\), "\n", 
    \(\(\(z3dMax = 62;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][3,1,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n33) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-66\);\)\), "\n", 
    \(\(x3dMax = 66;\)\), "\n", 
    \(\(z3dMin = \(-66\);\)\), "\n", 
    \(\(\(z3dMax = 66;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][3,1,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n34) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-88\);\)\), "\n", 
    \(\(x3dMax = 88;\)\), "\n", 
    \(\(z3dMin = \(-88\);\)\), "\n", 
    \(\(\(z3dMax = 88;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0135;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y \[Rule] y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0], Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<\[Psi]\[Psi][3,2,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n35) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-80\);\)\), "\n", 
    \(\(x3dMax = 80;\)\), "\n", 
    \(\(z3dMin = \(-80\);\)\), "\n", 
    \(\(\(z3dMax = 80;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,1], \
Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,1], Hydrogen-like \
Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n36) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-84\);\)\), "\n", 
    \(\(x3dMax = 84;\)\), "\n", 
    \(\(z3dMin = \(-84\);\)\), "\n", 
    \(\(\(z3dMax = 84;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,2], \
Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,2], Hydrogen-like \
Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,2,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n37) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0155;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,0], \
Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,0], Hydrogen-like \
Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,0], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n38) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0055;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,1], \
Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,1], Hydrogen-like \
Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,1], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n39) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.00423;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,2], \
Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,2], Hydrogen-like \
Atom\>"];\)\n\n\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,2], \
Hydrogen-like Atom\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Hydrogen-like atoms",
    FontWeight->"Bold"],
  "\n40) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-110\);\)\), "\n", 
    \(\(x3dMax = 110;\)\), "\n", 
    \(\(z3dMin = \(-110\);\)\), "\n", 
    \(\(\(z3dMax = 110;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(\(PR3dMax = 0.0045;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, 
            Z], {y -> y0}];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        Plot3D[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange -> {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.65, 0. , 0.35], \[IndentingNewLine]Axes -> 
            False, \[IndentingNewLine]Boxed -> 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,3], \
Hydrogen-like Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(\(\(WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(HydAt, Cart\)[n\_rad, l\_orb, m\_azm, Z, 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints -> 
            N3d, \[IndentingNewLine]ImageSize -> {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background -> 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction -> \((GrayLevel[#^0.3] \
&)\), \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,3], Hydrogen-like \
Atom\>"];\)\(\n\)
    \)\), "\n", 
    \(Show[
      GraphicsArray[{WFunktion3d\_HydAt[n\_rad, l\_orb, m\_azm, Z, y0], 
          WFunktion3dDen\_HydAt[n\_rad, l\_orb, m\_azm, Z, 
            y0]}], \[IndentingNewLine]ImageSize -> {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background -> 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel -> "\<\[Psi]\[Psi][3,3,3], \
Hydrogen-like Atom\>"]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparison of quantum states of the three-dimensional quantum rotator, \
oscillator and Hydrogen-like atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we can compare quantum states of the three-dimensional quantum rotator \
and oscillator and Hydrogen-like atoms for given quantum numbers.
We will present quantum states of rotator, oscillator and atoms in individual \
scales in order to compare geometrical properties corresponding quantum \
states.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3dVW\_Rotat[1, 0, 0, r0, y0], 
            WFunktion3dVW\_Rotat[2, 0, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 0, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 0, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 0, 0, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 0, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 0, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 0, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 0, 0, Z, y0], 
            WFunktion3d\_HydAt[1, 0, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 0, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 0, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 1, 0, r0, y0], WFunktion3dVW\_Rotat[2, 1, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 1, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 1, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 1, 0, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 1, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 1, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 1, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 1, 0, Z, y0], 
            WFunktion3d\_HydAt[1, 1, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 1, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 1, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 1, 1, r0, y0], WFunktion3dVW\_Rotat[2, 1, 1, r0, y0], 
            WFunktion3dVW\_Rotat[3, 1, 1, r0, y0], 
            WFunktion3dVW\_Rotat[4, 1, 1, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 1, 1, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 1, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 1, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 1, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 1, 1, Z, y0], 
            WFunktion3d\_HydAt[1, 1, 1, Z, y0], 
            WFunktion3d\_HydAt[2, 1, 1, Z, y0], 
            WFunktion3d\_HydAt[3, 1, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 2, 0, r0, y0], WFunktion3dVW\_Rotat[2, 2, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 2, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 2, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 2, 0, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 2, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 2, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 2, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 2, 0, Z, y0], 
            WFunktion3d\_HydAt[1, 2, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 2, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 2, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 2, 1, r0, y0], WFunktion3dVW\_Rotat[2, 2, 1, r0, y0], 
            WFunktion3dVW\_Rotat[3, 2, 1, r0, y0], 
            WFunktion3dVW\_Rotat[4, 2, 1, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 2, 1, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 2, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 2, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 2, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 2, 1, Z, y0], 
            WFunktion3d\_HydAt[1, 2, 1, Z, y0], 
            WFunktion3d\_HydAt[2, 2, 1, Z, y0], 
            WFunktion3d\_HydAt[3, 2, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 2, 2, r0, y0], WFunktion3dVW\_Rotat[2, 2, 2, r0, y0], 
            WFunktion3dVW\_Rotat[3, 2, 2, r0, y0], 
            WFunktion3dVW\_Rotat[4, 2, 2, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 2, 2, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 2, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 2, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 2, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 2, 2, Z, y0], 
            WFunktion3d\_HydAt[1, 2, 2, Z, y0], 
            WFunktion3d\_HydAt[2, 2, 2, Z, y0], 
            WFunktion3d\_HydAt[3, 2, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 0, r0, y0], WFunktion3dVW\_Rotat[2, 3, 0, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 0, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 3, 0, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 3, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 0, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 3, 0, Z, y0], 
            WFunktion3d\_HydAt[1, 3, 0, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 0, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 1, r0, y0], WFunktion3dVW\_Rotat[2, 3, 1, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 1, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 1, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 3, 1, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 3, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 1, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 3, 1, Z, y0], 
            WFunktion3d\_HydAt[1, 3, 1, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 1, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 2, r0, y0], WFunktion3dVW\_Rotat[2, 3, 2, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 2, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 2, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 3, 2, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 3, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 2, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 3, 2, Z, y0], 
            WFunktion3d\_HydAt[1, 3, 2, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 2, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dVW\_\
Rotat[1, 3, 3, r0, y0], WFunktion3dVW\_Rotat[2, 3, 3, r0, y0], 
            WFunktion3dVW\_Rotat[3, 3, 3, r0, y0], 
            WFunktion3dVW\_Rotat[4, 3, 3, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3d\_Oscl[0, 3, 3, \[Lambda], 
              y0], WFunktion3d\_Oscl[1, 3, 3, \[Lambda], y0], 
            WFunktion3d\_Oscl[2, 3, 3, \[Lambda], y0], 
            WFunktion3d\_Oscl[3, 3, 3, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3d\_HydAt[0, 3, 3, Z, y0], 
            WFunktion3d\_HydAt[1, 3, 3, Z, y0], 
            WFunktion3d\_HydAt[2, 3, 3, Z, y0], 
            WFunktion3d\_HydAt[3, 3, 3, Z, 
              y0]}}], \[IndentingNewLine]\[IndentingNewLine]ImageSize \[Rule] \
{1000, 6000}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave \
functions\>"]\)], "Input"],

Cell["", "Text"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Rotat[1, 0, 0, r0, y0], 
            WFunktion3dDen\_Rotat[2, 0, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 0, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 0, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 0, 
              0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 0, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 0, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 0, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 0, 0, Z, 
              y0], WFunktion3dDen\_HydAt[1, 0, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 0, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 0, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 1, 0, r0, y0], WFunktion3dDen\_Rotat[2, 1, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 1, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 1, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 1, 
              0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 1, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 1, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 1, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 1, 0, Z, 
              y0], WFunktion3dDen\_HydAt[1, 1, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 1, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 1, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 1, 1, r0, y0], WFunktion3dDen\_Rotat[2, 1, 1, r0, y0], 
            WFunktion3dDen\_Rotat[3, 1, 1, r0, y0], 
            WFunktion3dDen\_Rotat[4, 1, 1, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 1, 
              1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 1, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 1, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 1, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 1, 1, Z, 
              y0], WFunktion3dDen\_HydAt[1, 1, 1, Z, y0], 
            WFunktion3dDen\_HydAt[2, 1, 1, Z, y0], 
            WFunktion3dDen\_HydAt[3, 1, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 2, 0, r0, y0], WFunktion3dDen\_Rotat[2, 2, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 2, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 2, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 2, 
              0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 2, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 2, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 2, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 2, 0, Z, 
              y0], WFunktion3dDen\_HydAt[1, 2, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 2, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 2, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 2, 1, r0, y0], WFunktion3dDen\_Rotat[2, 2, 1, r0, y0], 
            WFunktion3dDen\_Rotat[3, 2, 1, r0, y0], 
            WFunktion3dDen\_Rotat[4, 2, 1, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 2, 
              1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 2, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 2, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 2, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 2, 1, Z, 
              y0], WFunktion3dDen\_HydAt[1, 2, 1, Z, y0], 
            WFunktion3dDen\_HydAt[2, 2, 1, Z, y0], 
            WFunktion3dDen\_HydAt[3, 2, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 2, 2, r0, y0], WFunktion3dDen\_Rotat[2, 2, 2, r0, y0], 
            WFunktion3dDen\_Rotat[3, 2, 2, r0, y0], 
            WFunktion3dDen\_Rotat[4, 2, 2, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 2, 
              2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 2, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 2, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 2, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 2, 2, Z, 
              y0], WFunktion3dDen\_HydAt[1, 2, 2, Z, y0], 
            WFunktion3dDen\_HydAt[2, 2, 2, Z, y0], 
            WFunktion3dDen\_HydAt[3, 2, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 0, r0, y0], WFunktion3dDen\_Rotat[2, 3, 0, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 0, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 0, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 3, 
              0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 3, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 0, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 0, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 3, 0, Z, 
              y0], WFunktion3dDen\_HydAt[1, 3, 0, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 0, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 0, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 1, r0, y0], WFunktion3dDen\_Rotat[2, 3, 1, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 1, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 1, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 3, 
              1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 3, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 1, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 1, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 3, 1, Z, 
              y0], WFunktion3dDen\_HydAt[1, 3, 1, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 1, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 1, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 2, r0, y0], WFunktion3dDen\_Rotat[2, 3, 2, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 2, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 2, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 3, 
              2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 3, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 2, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 2, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 3, 2, Z, 
              y0], WFunktion3dDen\_HydAt[1, 3, 2, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 2, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 2, Z, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Rotat[1, 3, 3, r0, y0], WFunktion3dDen\_Rotat[2, 3, 3, r0, y0], 
            WFunktion3dDen\_Rotat[3, 3, 3, r0, y0], 
            WFunktion3dDen\_Rotat[4, 3, 3, r0, 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_Oscl[0, 3, 
              3, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[1, 3, 3, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[2, 3, 3, \[Lambda], y0], 
            WFunktion3dDen\_Oscl[3, 3, 3, \[Lambda], 
              y0]}, \[IndentingNewLine]{WFunktion3dDen\_HydAt[0, 3, 3, Z, 
              y0], WFunktion3dDen\_HydAt[1, 3, 3, Z, y0], 
            WFunktion3dDen\_HydAt[2, 3, 3, Z, y0], 
            WFunktion3dDen\_HydAt[3, 3, 3, Z, 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {1000, 
          6000}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave \
functions\>"]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 180, 4, 56, "Subtitle"],
Cell[2453, 78, 253, 7, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2731, 89, 228, 7, 119, "Section"],
Cell[2962, 98, 157, 5, 56, "Text"],
Cell[3122, 105, 277, 12, 92, "NumberedEquation"],
Cell[3402, 119, 224, 6, 80, "Text"],
Cell[3629, 127, 277, 12, 92, "NumberedEquation"],
Cell[3909, 141, 339, 11, 80, "Text"],
Cell[4251, 154, 216, 4, 188, "Input"],
Cell[4470, 160, 130, 3, 56, "Text"],
Cell[4603, 165, 22740, 356, 15083, "Input"],
Cell[27346, 523, 133, 3, 56, "Text"],
Cell[27482, 528, 14541, 234, 3926, "Input"],
Cell[42026, 764, 115, 3, 56, "Text"],
Cell[42144, 769, 14367, 231, 6295, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56548, 1005, 238, 7, 119, "Section"],
Cell[56789, 1014, 540, 9, 176, "Text"],
Cell[57332, 1025, 666, 17, 452, "Text"],
Cell[58001, 1044, 762, 13, 488, "Input"],

Cell[CellGroupData[{
Cell[58788, 1061, 237, 11, 123, "Subsection"],
Cell[59028, 1074, 2786, 49, 1053, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61851, 1128, 237, 11, 123, "Subsection"],
Cell[62091, 1141, 2797, 50, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64925, 1196, 237, 11, 123, "Subsection"],
Cell[65165, 1209, 2797, 50, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67999, 1264, 237, 11, 123, "Subsection"],
Cell[68239, 1277, 2782, 49, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71058, 1331, 237, 11, 123, "Subsection"],
Cell[71298, 1344, 2781, 49, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74116, 1398, 237, 11, 123, "Subsection"],
Cell[74356, 1411, 2781, 49, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77174, 1465, 237, 11, 123, "Subsection"],
Cell[77414, 1478, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81166, 1554, 237, 11, 123, "Subsection"],
Cell[81406, 1567, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85158, 1643, 237, 11, 123, "Subsection"],
Cell[85398, 1656, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89149, 1732, 238, 11, 123, "Subsection"],
Cell[89390, 1745, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93141, 1821, 238, 11, 123, "Subsection"],
Cell[93382, 1834, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97134, 1910, 238, 11, 123, "Subsection"],
Cell[97375, 1923, 3712, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101124, 1999, 238, 11, 123, "Subsection"],
Cell[101365, 2012, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105116, 2088, 238, 11, 123, "Subsection"],
Cell[105357, 2101, 3716, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109110, 2177, 238, 11, 123, "Subsection"],
Cell[109351, 2190, 3859, 75, 1153, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113247, 2270, 238, 11, 123, "Subsection"],
Cell[113488, 2283, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117240, 2359, 238, 11, 123, "Subsection"],
Cell[117481, 2372, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121232, 2448, 238, 11, 123, "Subsection"],
Cell[121473, 2461, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125224, 2537, 238, 11, 123, "Subsection"],
Cell[125465, 2550, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129217, 2626, 238, 11, 123, "Subsection"],
Cell[129458, 2639, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133209, 2715, 238, 11, 123, "Subsection"],
Cell[133450, 2728, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137201, 2804, 238, 11, 123, "Subsection"],
Cell[137442, 2817, 3712, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141191, 2893, 238, 11, 123, "Subsection"],
Cell[141432, 2906, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145183, 2982, 238, 11, 123, "Subsection"],
Cell[145424, 2995, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149176, 3071, 238, 11, 123, "Subsection"],
Cell[149417, 3084, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153169, 3160, 238, 11, 123, "Subsection"],
Cell[153410, 3173, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157162, 3249, 238, 11, 123, "Subsection"],
Cell[157403, 3262, 3549, 66, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160989, 3333, 238, 11, 123, "Subsection"],
Cell[161230, 3346, 3712, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164979, 3422, 238, 11, 123, "Subsection"],
Cell[165220, 3435, 3712, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168969, 3511, 238, 11, 123, "Subsection"],
Cell[169210, 3524, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172962, 3600, 238, 11, 123, "Subsection"],
Cell[173203, 3613, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176954, 3689, 238, 11, 123, "Subsection"],
Cell[177195, 3702, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180947, 3778, 238, 11, 123, "Subsection"],
Cell[181188, 3791, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184940, 3867, 239, 11, 123, "Subsection"],
Cell[185182, 3880, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188934, 3956, 238, 11, 123, "Subsection"],
Cell[189175, 3969, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192927, 4045, 238, 11, 123, "Subsection"],
Cell[193168, 4058, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196920, 4134, 238, 11, 123, "Subsection"],
Cell[197161, 4147, 3714, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200912, 4223, 238, 11, 123, "Subsection"],
Cell[201153, 4236, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204905, 4312, 238, 11, 123, "Subsection"],
Cell[205146, 4325, 3715, 71, 1078, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208898, 4401, 238, 11, 123, "Subsection"],
Cell[209139, 4414, 3715, 71, 1078, "Input"],
Cell[212857, 4487, 16, 0, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212910, 4492, 240, 11, 123, "Subsection"],
Cell[213153, 4505, 3687, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216877, 4581, 240, 11, 123, "Subsection"],
Cell[217120, 4594, 3712, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220869, 4670, 240, 11, 123, "Subsection"],
Cell[221112, 4683, 3712, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[224861, 4759, 239, 11, 123, "Subsection"],
Cell[225103, 4772, 3728, 70, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228868, 4847, 240, 11, 123, "Subsection"],
Cell[229111, 4860, 3704, 70, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[232852, 4935, 240, 11, 123, "Subsection"],
Cell[233095, 4948, 3682, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236814, 5024, 240, 11, 123, "Subsection"],
Cell[237057, 5037, 3684, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240778, 5113, 240, 11, 123, "Subsection"],
Cell[241021, 5126, 3681, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[244739, 5202, 240, 11, 123, "Subsection"],
Cell[244982, 5215, 3665, 71, 1066, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[248684, 5291, 241, 11, 123, "Subsection"],
Cell[248928, 5304, 3662, 71, 1066, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252627, 5380, 241, 11, 123, "Subsection"],
Cell[252871, 5393, 3687, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256595, 5469, 241, 11, 123, "Subsection"],
Cell[256839, 5482, 3687, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260563, 5559, 241, 11, 123, "Subsection"],
Cell[260807, 5572, 3687, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264531, 5649, 241, 11, 123, "Subsection"],
Cell[264775, 5662, 3686, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268498, 5739, 241, 11, 123, "Subsection"],
Cell[268742, 5752, 3685, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272464, 5829, 241, 11, 123, "Subsection"],
Cell[272708, 5842, 3684, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[276429, 5918, 241, 11, 123, "Subsection"],
Cell[276673, 5931, 3372, 62, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[280082, 5998, 241, 11, 123, "Subsection"],
Cell[280326, 6011, 3686, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[284049, 6088, 241, 11, 123, "Subsection"],
Cell[284293, 6101, 3687, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[288017, 6178, 241, 11, 123, "Subsection"],
Cell[288261, 6191, 3686, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[291984, 6267, 241, 11, 123, "Subsection"],
Cell[292228, 6280, 3688, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[295953, 6357, 241, 11, 123, "Subsection"],
Cell[296197, 6370, 3686, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[299920, 6446, 241, 11, 123, "Subsection"],
Cell[300164, 6459, 3686, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[303887, 6535, 241, 11, 123, "Subsection"],
Cell[304131, 6548, 3682, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[307850, 6624, 241, 11, 123, "Subsection"],
Cell[308094, 6637, 3681, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[311812, 6713, 241, 11, 123, "Subsection"],
Cell[312056, 6726, 3681, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[315774, 6802, 241, 11, 123, "Subsection"],
Cell[316018, 6815, 3686, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[319741, 6891, 241, 11, 123, "Subsection"],
Cell[319985, 6904, 3686, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323708, 6980, 241, 11, 123, "Subsection"],
Cell[323952, 6993, 3696, 71, 1116, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[327685, 7069, 241, 11, 123, "Subsection"],
Cell[327929, 7082, 3685, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[331651, 7158, 241, 11, 123, "Subsection"],
Cell[331895, 7171, 3687, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[335619, 7247, 241, 11, 123, "Subsection"],
Cell[335863, 7260, 3686, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[339586, 7336, 241, 11, 123, "Subsection"],
Cell[339830, 7349, 3688, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[343555, 7426, 241, 11, 123, "Subsection"],
Cell[343799, 7439, 3687, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347523, 7516, 241, 11, 123, "Subsection"],
Cell[347767, 7529, 3688, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[351492, 7606, 241, 11, 123, "Subsection"],
Cell[351736, 7619, 3687, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[355460, 7695, 241, 11, 123, "Subsection"],
Cell[355704, 7708, 3686, 71, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[359427, 7784, 241, 11, 123, "Subsection"],
Cell[359671, 7797, 3687, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[363395, 7874, 241, 11, 123, "Subsection"],
Cell[363639, 7887, 3686, 72, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[367362, 7964, 241, 11, 123, "Subsection"],
Cell[367606, 7977, 3684, 71, 1091, "Input"],
Cell[371293, 8050, 16, 0, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[371346, 8055, 263, 13, 123, "Subsection"],
Cell[371612, 8070, 2759, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[374408, 8125, 263, 13, 123, "Subsection"],
Cell[374674, 8140, 2700, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377411, 8195, 263, 13, 123, "Subsection"],
Cell[377677, 8210, 2700, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[380414, 8265, 264, 13, 123, "Subsection"],
Cell[380681, 8280, 2649, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[383367, 8335, 264, 13, 123, "Subsection"],
Cell[383634, 8350, 2649, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[386320, 8405, 263, 13, 123, "Subsection"],
Cell[386586, 8420, 2649, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389272, 8475, 263, 13, 123, "Subsection"],
Cell[389538, 8490, 2649, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[392224, 8545, 263, 13, 123, "Subsection"],
Cell[392490, 8560, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[395177, 8615, 263, 13, 123, "Subsection"],
Cell[395443, 8630, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[398130, 8685, 264, 13, 123, "Subsection"],
Cell[398397, 8700, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[401084, 8755, 264, 13, 123, "Subsection"],
Cell[401351, 8770, 2633, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[404021, 8825, 264, 13, 123, "Subsection"],
Cell[404288, 8840, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[406975, 8895, 264, 13, 123, "Subsection"],
Cell[407242, 8910, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[409929, 8965, 264, 13, 123, "Subsection"],
Cell[410196, 8980, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[412883, 9035, 264, 13, 123, "Subsection"],
Cell[413150, 9050, 2842, 55, 1216, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[416029, 9110, 264, 13, 123, "Subsection"],
Cell[416296, 9125, 2651, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[418984, 9180, 264, 13, 123, "Subsection"],
Cell[419251, 9195, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[421938, 9250, 264, 13, 123, "Subsection"],
Cell[422205, 9265, 2633, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[424875, 9320, 264, 13, 123, "Subsection"],
Cell[425142, 9335, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[427829, 9390, 264, 13, 123, "Subsection"],
Cell[428096, 9405, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[430783, 9460, 264, 13, 123, "Subsection"],
Cell[431050, 9475, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[433737, 9530, 264, 13, 123, "Subsection"],
Cell[434004, 9545, 2650, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[436691, 9600, 264, 13, 123, "Subsection"],
Cell[436958, 9615, 2649, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[439644, 9670, 264, 13, 123, "Subsection"],
Cell[439911, 9685, 2631, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[442579, 9740, 264, 13, 123, "Subsection"],
Cell[442846, 9755, 2599, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[445482, 9810, 264, 13, 123, "Subsection"],
Cell[445749, 9825, 2598, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[448384, 9880, 264, 13, 123, "Subsection"],
Cell[448651, 9895, 2632, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[451320, 9950, 264, 13, 123, "Subsection"],
Cell[451587, 9965, 2633, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454257, 10020, 264, 13, 123, "Subsection"],
Cell[454524, 10035, 2616, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[457177, 10090, 264, 13, 123, "Subsection"],
Cell[457444, 10105, 2633, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[460114, 10160, 265, 13, 123, "Subsection"],
Cell[460382, 10175, 2633, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[463052, 10230, 264, 13, 123, "Subsection"],
Cell[463319, 10245, 2633, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[465989, 10300, 264, 13, 123, "Subsection"],
Cell[466256, 10315, 2633, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468926, 10370, 264, 13, 123, "Subsection"],
Cell[469193, 10385, 2616, 50, 1091, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[471846, 10440, 264, 13, 123, "Subsection"],
Cell[472113, 10455, 2541, 50, 1117, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474691, 10510, 264, 13, 123, "Subsection"],
Cell[474958, 10525, 2541, 50, 1117, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[477536, 10580, 264, 13, 123, "Subsection"],
Cell[477803, 10595, 2562, 50, 1117, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[480402, 10650, 264, 13, 123, "Subsection"],
Cell[480669, 10665, 2545, 50, 1117, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[483251, 10720, 264, 13, 123, "Subsection"],
Cell[483518, 10735, 2552, 49, 1142, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[486107, 10789, 264, 13, 123, "Subsection"],
Cell[486374, 10804, 2545, 50, 1117, "Input"],
Cell[488922, 10856, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[488987, 10862, 184, 5, 119, "Section"],
Cell[489174, 10869, 375, 8, 140, "Text"],
Cell[489552, 10879, 7321, 126, 1913, "Input"],
Cell[496876, 11007, 16, 0, 56, "Text"],
Cell[496895, 11009, 7741, 136, 1888, "Input"],
Cell[504639, 11147, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

