(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     39021,       1058]*)
(*NotebookOutlinePosition[     39750,       1083]*)
(*  CellTagsIndexPosition[     39706,       1079]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["5. Spherical Harmonics and Angular Probability Densities",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "5.1. ",
  StyleBox["Spherical Harmonics in the Spherical and ",
    FontWeight->"Bold"],
  StyleBox["Cartesian rectangular coordinates",
    FontWeight->"Bold"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Spherical Harmonics in context of the quantum mechanics", "Section"],

Cell[TextData[{
  "Spherical harmonics ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_l\%m\)(\[Theta], \[CurlyPhi])\)], 
    "InlineFormula"],
  " are ",
  "orthogonal functions",
  " with respect to integration over the surface of the unit sphere.\nWe will \
use \"",
  StyleBox["SphericalHarmonicY",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" and \"",
  StyleBox["Graphics",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tools to consider basic properties and plots of these functions."
}], "Text"],

Cell["\<\
These special functions are characterized by two integer numbers.
In context of the quantum mechanics these numbers are:\
\>", "Text"],

Cell[BoxData[{
    \(l\_orb\  - \ orbital\ quantum\ number\), "\[IndentingNewLine]", 
    \(m\_azm\  - \ azimuthal\ quantum\ number\)}], "NumberedEquation"],

Cell["where", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(l\_orb\  = 0, 1, 2, 3,  ... \), "\[IndentingNewLine]", 
    \(m\_azm\  = \(-l\_orb\), \(-\((l\_orb - 1)\)\),  ... , \((l\_orb - 1)\), 
    l\_orb\)}], "NumberedEquation"],

Cell["\<\
Consider some special values of spherical harmonics defined by quantum \
numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Spherical Harmonics and angular probability densities", "Section"],

Cell["Define angular probability density by the formula", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  "=",
  Cell[BoxData[
      \(\(\(|\)\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)\( | \^2\)\)\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "\n\t\t\t- spherical harmonics with given values of ",
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(\(|\)\(Y[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\)\( | \^2\)\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "\n\t\t\t- angular density with given values of ",
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"Consider", " ", "spherical", "  ", "harmonic", " ", 
        StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
          FontFamily->"Courier New",
          FontSize->14,
          FontWeight->"Bold",
          FontSlant->"Italic",
          FontColor->RGBColor[0.996109, 0.996109, 0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "and", " ", "angular", " ", "densities", 
        " ", 
        StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
          FontFamily->"Courier New",
          FontSize->14,
          FontWeight->"Bold",
          FontSlant->"Italic",
          FontColor->RGBColor[0.996109, 0.996109, 0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "in", " ", "the", " ", "spherical", 
        " ", \(\(coordinates\)\(:\)\)}], TextForm]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
        Conjugate[
          SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]]\)}], "Input"],

Cell[BoxData[
    \(SphericalHarmonicY[l\_orb, m\_azm, ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)], 
      ArcCos[x\/\@\(x\^2 + y\^2\)]]\)], "Output"],

Cell[BoxData[
    \(Conjugate[
        SphericalHarmonicY[l\_orb, m\_azm, 
          ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)], 
          ArcCos[x\/\@\(x\^2 + y\^2\)]]]\ SphericalHarmonicY[l\_orb, m\_azm, 
        ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)], 
        ArcCos[x\/\@\(x\^2 + y\^2\)]]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Calculation of the spherical harmonics and angular densities in the \
spherical coordinates\
\>", "Section"],

Cell["\<\
Now we calculate spherical harmonics and angular densities in the spherical \
coordinates.\
\>", "Text"],

Cell[TextData[{
  "Note. Positive values of ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " suffice for our purposes."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(Y[0, 0] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[0, 0] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(1\/\(2\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(1\/\(4\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(Y[1, 0] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[1, 0] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(3\/\[Pi]\)\ z\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\)\)], "Output"],

Cell[BoxData[
    \(\(3\ z\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(Y[1, 1] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[1, 1] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\
\^2\)]\)\ \@\(3\/\(2\ \[Pi]\)\)\ \@\(1 - z\^2\/\(x\^2 + y\^2 + z\^2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(3\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[1\/2\ Arg[1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(8\ \[Pi]\ Abs[\(\[ImaginaryI]\ x\)\/\@\
\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) + \(3\ \@\((1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[1\/2\ Arg[1 - z\^2\/\(x\^2 + y\^2 + z\
\^2\)]]\^2\)\/\(8\ \[Pi]\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 \
- x\^2\/\(x\^2 + y\^2\)\)]\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(Y[2, 0] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[2, 0] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(5\/\[Pi]\)\ \((\(-x\^2\) - y\^2 + 2\ z\^2)\)\)\/\(4\ \((x\^2 + \
y\^2 + z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(5\ x\^4\)\/\(16\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\) + \(5\ x\^2\ \
y\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\) + \(5\ y\^4\)\/\(16\ \[Pi]\ \
\((x\^2 + y\^2 + z\^2)\)\^2\) - \(5\ x\^2\ z\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 \
+ z\^2)\)\^2\) - \(5\ y\^2\ z\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\) \
+ \(5\ z\^4\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(Y[2, 1] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[2, 1] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\
\ \@\(15\/\(2\ \[Pi]\)\)\ z\ \@\(1 - z\^2\/\(x\^2 + y\^2 + z\^2\)\)\)\/\(2\ \
\@\(x\^2 + y\^2 + z\^2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(15\ z\^2\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[1\/2\ \
Arg[1 - z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + \
y\^2\)\)]\^2\) + \(15\ z\^2\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
Sin[1\/2\ Arg[1 - z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(8\ \[Pi]\ \((x\^2 + \
y\^2 + z\^2)\)\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - \
x\^2\/\(x\^2 + y\^2\)\)]\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(Y[2, 2] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[2, 2] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\@\(15\/\(2\ \[Pi]\)\)\ \((x\^2 + y\^2)\)\)\/\(4\ \((x\^2 + y\^2 + \
z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(15\ x\^4\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^4\) \
+ \(15\ x\^2\ y\^2\)\/\(16\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^4\) \
+ \(15\ y\^4\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\[ImaginaryI]\
\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^4\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(Y[3, 0] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[3, 0] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(7\/\[Pi]\)\ \((\(-3\)\ x\^2\ z - 3\ y\^2\ z + 2\ z\^3)\)\)\/\(4\ \
\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(63\ x\^4\ z\^2\)\/\(16\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\) + \(63\ \
x\^2\ y\^2\ z\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\) + \(63\ y\^4\ z\
\^2\)\/\(16\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\) - \(21\ x\^2\ z\^4\)\/\(4\ \
\[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\) - \(21\ y\^2\ z\^4\)\/\(4\ \[Pi]\ \
\((x\^2 + y\^2 + z\^2)\)\^3\) + \(7\ z\^6\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^3\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(Y[3, 1] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[3, 1] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\@\(21\/\[Pi]\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\ \@\(1 - z\^2\/\(x\^2 + y\^2 + z\
\^2\)\)\)\/\(8\ \((x\^2 + y\^2 + z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(21\ x\^4\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[1\/2\ \
Arg[1 - z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - \
x\^2\/\(x\^2 + y\^2\)\)]\^2\) + \(21\ x\^2\ y\^2\ \@\((1 - z\^2\/\(x\^2 + \
y\^2 + z\^2\))\)\^2\ Cos[1\/2\ Arg[1 - z\^2\/\(x\^2 + y\^2 + \
z\^2\)]]\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\[ImaginaryI]\ \
x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) + \(21\ y\^4\ \
\@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[1\/2\ Arg[1 - z\^2\/\(x\^2 + \
y\^2 + z\^2\)]]\^2\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) \
- \(21\ x\^2\ z\^2\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[1\/2\ \
Arg[1 - z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - \
x\^2\/\(x\^2 + y\^2\)\)]\^2\) - \(21\ y\^2\ z\^2\ \@\((1 - z\^2\/\(x\^2 + \
y\^2 + z\^2\))\)\^2\ Cos[1\/2\ Arg[1 - z\^2\/\(x\^2 + y\^2 + \
z\^2\)]]\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\[ImaginaryI]\ \
x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) + \(21\ z\^4\ \
\@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[1\/2\ Arg[1 - z\^2\/\(x\^2 + \
y\^2 + z\^2\)]]\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) \
+ \(21\ x\^4\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[1\/2\ Arg[1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\
\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\
\)]\^2\) + \(21\ x\^2\ y\^2\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
Sin[1\/2\ Arg[1 - z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(32\ \[Pi]\ \((x\^2 + \
y\^2 + z\^2)\)\^2\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\
\/\(x\^2 + y\^2\)\)]\^2\) + \(21\ y\^4\ \@\((1 - z\^2\/\(x\^2 + y\^2 + \
z\^2\))\)\^2\ Sin[1\/2\ Arg[1 - z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(64\ \
\[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\
\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) - \(21\ x\^2\ z\^2\ \@\((1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[1\/2\ Arg[1 - z\^2\/\(x\^2 + y\^2 + z\
\^2\)]]\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\[ImaginaryI]\ x\
\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) - \(21\ y\^2\ z\
\^2\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[1\/2\ Arg[1 - z\^2\/\(x\
\^2 + y\^2 + z\^2\)]]\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^2\) \
+ \(21\ z\^4\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[1\/2\ Arg[1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ \
Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + \
y\^2\)\)]\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(Y[3, 2] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[3, 2] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\@\(105\/\(2\ \[Pi]\)\)\ \((x\^2 + y\^2)\)\ z\)\/\(4\ \((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(105\ x\^4\ z\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^4\) \
+ \(105\ x\^2\ y\^2\ z\^2\)\/\(16\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^4\) \
+ \(105\ y\^4\ z\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^4\)\
\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(Y[3, 3] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[3, 3] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(1\/8\)\)\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 \
+ y\^2\)]\)\ \@\(35\/\[Pi]\)\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^\(3/2\)\
\)], "Output"],

Cell[BoxData[
    \(\(35\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[3\/2\ Arg[1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(64\ \[Pi]\ Abs[\(\[ImaginaryI]\ \
x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^6\) + \(35\ z\^4\ \
\@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[3\/2\ Arg[1 - z\^2\/\(x\^2 + \
y\^2 + z\^2\)]]\^2\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^6\) \
- \(35\ z\^2\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Cos[3\/2\ Arg[1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\ \
Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + \
y\^2\)\)]\^6\) + \(35\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[3\/2\ \
Arg[1 - z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(64\ \[Pi]\ Abs[\(\[ImaginaryI]\
\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^6\) + \(35\ z\^4\
\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[3\/2\ Arg[1 - z\^2\/\(x\^2 \
+ y\^2 + z\^2\)]]\^2\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^2\ Abs[\(\
\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + y\^2\)\)]\^6\) \
- \(35\ z\^2\ \@\((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\ Sin[3\/2\ Arg[1 - \
z\^2\/\(x\^2 + y\^2 + z\^2\)]]\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\ \
Abs[\(\[ImaginaryI]\ x\)\/\@\(x\^2 + y\^2\) + \@\(1 - x\^2\/\(x\^2 + \
y\^2\)\)]\^6\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus we have expressions for the spherical harmonics ",
  Cell[BoxData[
      \(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  " and angular densities ",
  Cell[BoxData[
      \(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  " in the spherical coordinates:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Y[0, 0] = 1\/\(2\ \@\[Pi]\)\), "\[IndentingNewLine]", 
    \(\(\(YY[0, 0] = 1\/\(4\ \[Pi]\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[1, 0] = 
      1\/2\ \@\(3\/\[Pi]\)\ Cos[\[Theta]]\), "\[IndentingNewLine]", 
    \(\(\(YY[1, 
        0] = \(3\ Cos[\[Theta]]\^2\)\/\(4\ \[Pi]\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[1, 
        1] = \(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
\@\(3\/\(2\ \[Pi]\)\)\ Sin[\[Theta]]\), "\[IndentingNewLine]", 
    \(\(\(YY[1, 
        1] = \(3\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[2, 0] = 
      1\/4\ \@\(5\/\[Pi]\)\ \((\(-1\) + 
            3\ Cos[\[Theta]]\^2)\)\), "\[IndentingNewLine]", 
    \(\(\(YY[2, 
        0] = \(5\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(64\ \[Pi]\)\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[2, 
        1] = \(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
\@\(15\/\(2\ \[Pi]\)\)\ Cos[\[Theta]]\ Sin[\[Theta]]\), \
"\[IndentingNewLine]", 
    \(\(\(YY[2, 
        1] = \(15\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\)\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[2, 2] = 
      1\/4\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi]\)\ \@\(15\/\(2\ \
\[Pi]\)\)\ Sin[\[Theta]]\^2\), "\[IndentingNewLine]", 
    \(\(\(YY[2, 
        2] = \(15\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[3, 0] = 
      1\/4\ \@\(7\/\[Pi]\)\ \((\(-3\)\ Cos[\[Theta]] + 
            5\ Cos[\[Theta]]\^3)\)\), "\[IndentingNewLine]", 
    \(\(\(YY[3, 
        0] = \(7\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(256\ \
\[Pi]\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[3, 
        1] = \(-\(1\/8\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
\@\(21\/\[Pi]\)\ \((\(-1\) + 
            5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\), "\[IndentingNewLine]", 
    \(\(\(YY[3, 
        1] = \(21\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(1024\ \
\[Pi]\)\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[3, 2] = 
      1\/4\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi]\)\ \@\(105\/\(2\ \
\[Pi]\)\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\), "\[IndentingNewLine]", 
    \(\(\(YY[3, 
        2] = \(105\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\)\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Y[3, 
        3] = \(-\(1\/8\)\)\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \
\[CurlyPhi]\)\ \@\(35\/\[Pi]\)\ Sin[\[Theta]]\^3\), "\[IndentingNewLine]", 
    \(YY[3, 3] = \(35\ Sin[\[Theta]]\^6\)\/\(64\ \[Pi]\)\)}], "Input"],

Cell[BoxData[
    \(1\/\(2\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(1\/\(4\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(3\/\[Pi]\)\ z\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\)\)], "Output"],

Cell[BoxData[
    \(\(3\ z\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\
\^2\)]\)\ \@\(3\/\(2\ \[Pi]\)\)\ \@\(1 - z\^2\/\(x\^2 + y\^2 + z\^2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(3\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\)\/\(8\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(1\/4\ \@\(5\/\[Pi]\)\ \((\(-1\) + \(3\ z\^2\)\/\(x\^2 + y\^2 + \
z\^2\))\)\)], "Output"],

Cell[BoxData[
    \(\(5\ \((1 + 3\ Cos[2\ ArcCos[z\/\@\(x\^2 + y\^2 + \
z\^2\)]])\)\^2\)\/\(64\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\
\ \@\(15\/\(2\ \[Pi]\)\)\ z\ \@\(1 - z\^2\/\(x\^2 + y\^2 + z\^2\)\)\)\/\(2\ \
\@\(x\^2 + y\^2 + z\^2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(15\ z\^2\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\)\/\(8\ \[Pi]\ \
\((x\^2 + y\^2 + z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(1\/4\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\
\)\ \@\(15\/\(2\ \[Pi]\)\)\ \((1 - 
          z\^2\/\(x\^2 + y\^2 + z\^2\))\)\)], "Output"],

Cell[BoxData[
    \(\(15\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\)\/\(32\ \[Pi]\)\)], \
"Output"],

Cell[BoxData[
    \(1\/4\ \@\(7\/\[Pi]\)\ \((\(5\ z\^3\)\/\((x\^2 + y\^2 + z\^2)\)\^\(3/2\) \
- \(3\ z\)\/\@\(x\^2 + y\^2 + z\^2\))\)\)], "Output"],

Cell[BoxData[
    \(\(7\ \((\(3\ z\)\/\@\(x\^2 + y\^2 + z\^2\) + 5\ Cos[3\ \
ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)]])\)\^2\)\/\(256\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(-\(1\/8\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\
\^2\)]\)\ \@\(21\/\[Pi]\)\ \@\(1 - z\^2\/\(x\^2 + y\^2 + z\^2\)\)\ \((\(-1\) \
+ \(5\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\)], "Output"],

Cell[BoxData[
    \(\(21\ \((\@\(1 - z\^2\/\(x\^2 + y\^2 + z\^2\)\) + 5\ Sin[3\ \
ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)]])\)\^2\)\/\(1024\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\@\(105\/\(2\ \[Pi]\)\)\ z\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\)\/\(4\ \@\
\(x\^2 + y\^2 + z\^2\)\)\)], "Output"],

Cell[BoxData[
    \(\(105\ z\^2\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^2\)\/\(32\ \[Pi]\ \
\((x\^2 + y\^2 + z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(1\/8\)\)\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 \
+ y\^2\)]\)\ \@\(35\/\[Pi]\)\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^\(3/2\)\
\)], "Output"],

Cell[BoxData[
    \(\(35\ \((1 - z\^2\/\(x\^2 + y\^2 + z\^2\))\)\^3\)\/\(64\ \[Pi]\)\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Spherical harmonics and angular densities in the Cartesian rectangular \
coordinates\
\>", "Section"],

Cell[TextData[{
  "To obtain spherical  harmonic ",
  Cell[BoxData[
      \(Y\_Cart[l\_orb, m\_azm]\)],
    FontSlant->"Italic"],
  " and angular densities ",
  Cell[BoxData[
      \(YY\_Cart[l\_orb, m\_azm]\)],
    FontSlant->"Italic"],
  " in the Cartesian rectangular coordinates we will use coordinate \
transformations:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Theta] = ArcCos[z/\@\(x^2 + y^2 + z^2\)]\), "\[IndentingNewLine]", 
    \(\[CurlyPhi] = ArcCos[x/\@\(x^2 + y^2\)]\)}], "Input"],

Cell[BoxData[
    \(ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)]\)], "Output"],

Cell[BoxData[
    \(ArcCos[x\/\@\(x\^2 + y\^2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(l\_orb =. \), "\[IndentingNewLine]", 
    \(m\_azm =. \), "\[IndentingNewLine]", 
    \(Y\_Cart[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY\_Cart[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(SphericalHarmonicY[l\_orb, m\_azm, ArcCos[z\/\@\(x\^2 + y\^2 + z\^2\)], 
      ArcCos[x\/\@\(x\^2 + y\^2\)]]\)], "Output"],

Cell[BoxData[
    \(Im[SphericalHarmonicY[l\_orb, m\_azm, ArcCos[z\/\@\(x\^2 + y\^2 + \
z\^2\)], ArcCos[x\/\@\(x\^2 + y\^2\)]]]\^2 + 
      Re[SphericalHarmonicY[l\_orb, m\_azm, ArcCos[z\/\@\(x\^2 + y\^2 + \
z\^2\)], ArcCos[x\/\@\(x\^2 + y\^2\)]]]\^2\)], "Output"]
}, Open  ]],

Cell["\<\
Now we calculate spherical harmonics and angular densities in the Cartesian \
rectangular coordinates:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[Y[0, 0]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[0, 0]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[1, 0]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[1, 0]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[1, 1]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[1, 1]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[2, 0]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[2, 0]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[2, 1]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[2, 1]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[2, 2]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[2, 2]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[3, 0]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[3, 0]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[3, 1]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[3, 1]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[3, 2]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[YY[3, 2]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[Y[3, 3]]\), "\[IndentingNewLine]", 
    \(FullSimplify[YY[3, 3]]\)}], "Input"],

Cell[BoxData[
    \(1\/\(2\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(1\/\(4\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(3\/\[Pi]\)\ z\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\)\)], "Output"],

Cell[BoxData[
    \(\(3\ z\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\
\^2\)]\)\ \@\(3\/\(2\ \[Pi]\)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + \
z\^2\)\)\)], "Output"],

Cell[BoxData[
    \(\(3\ \((x\^2 + y\^2)\)\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\)\)], \
"Output"],

Cell[BoxData[
    \(1\/4\ \@\(5\/\[Pi]\)\ \((\(-1\) + \(3\ z\^2\)\/\(x\^2 + y\^2 + \
z\^2\))\)\)], "Output"],

Cell[BoxData[
    \(\(5\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\)\/\(64\ \
\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\
\ \@\(15\/\(2\ \[Pi]\)\)\ z\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + \
z\^2\)\)\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(15\ \((x\^2 + y\^2)\)\ z\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\@\(15\/\(2\ \[Pi]\)\)\ \((x\^2 + y\^2)\)\)\/\(4\ \((x\^2 + y\^2 + \
z\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(15\ \((x\^2 + y\^2)\)\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(7\/\[Pi]\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 2\ z\^2)\)\)\/\(4\ \
\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(7\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\)\/\(16\ \[Pi]\ \((x\^2 \
+ y\^2 + z\^2)\)\^3\)\)], "Output"],

Cell[BoxData[
    \(1\/8\ \[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\@\(21\/\[Pi]\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \((1 - \(5\ z\
\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\)], "Output"],

Cell[BoxData[
    \(\(21\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\)\/\(64\ \[Pi]\ \
\((x\^2 + y\^2 + z\^2)\)\^3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\@\(105\/\(2\ \[Pi]\)\)\ \((x\^2 + y\^2)\)\ z\)\/\(4\ \((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(105\ \((x\^2 + y\^2)\)\^2\ z\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^3\)\)], "Output"],

Cell[BoxData[
    \(\(-\(1\/8\)\)\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 \
+ y\^2\)]\)\ \@\(35\/\[Pi]\)\ \((\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^\
\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(35\ \((x\^2 + y\^2)\)\^3\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^3\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus we have expressions for the spherical harmonics ",
  Cell[BoxData[
      \(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  " and angular densities ",
  Cell[BoxData[
      \(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  " in the Cartesian rectangular coordinates:"
}], "Text"],

Cell[BoxData[{
    \(\(Y\_Cart[0, 0] = 1\/\(2\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[0, 0] = 1\/\(4\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[1, 0] = \(\@\(3\/\[Pi]\)\) 
          z\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[1, 
          0] = \(3\ z\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[1, 
          1] = \(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \
ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\(3\/\(2\ \[Pi]\)\)\ \@\(\(x\^2 + \
y\^2\)\/\(x\^2 + y\^2 + z\^2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[1, 
          1] = \(3\ \((x\^2 + y\^2)\)\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\
\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[2, 0] = 
        1\/4\ \@\(5\/\[Pi]\)\ \((\(-1\) + \(3\ z\^2\)\/\(x\^2 + y\^2 + \
z\^2\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[2, 
          0] = \(5\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\)\/\(16\ \[Pi]\ \((x\^2 + \
y\^2 + z\^2)\)\^2\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[2, 
          1] = \(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)]\)\ \@\(15\/\(2\ \[Pi]\)\)\ z\ \@\(1 - z\^2\/\(x\^2 + y\^2 + \
z\^2\)\)\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[2, 
          1] = \(15\ \((x\^2 + y\^2)\)\ z\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[2, 
          2] = \(\@\(15\/\(2\ \[Pi]\)\)\) \(\[ExponentialE]\^\(2\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2)\)\)\/\(4\ \((x\
\^2 + y\^2 + z\^2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[2, 
          2] = \(15\ \((x\^2 + y\^2)\)\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[3, 
          0] = \(\@\(7\/\[Pi]\)\) \(\(\ \)\(z\ \((\(-3\)\ \((x\^2 + y\^2)\) + \
2\ z\^2)\)\)\)\/\(4\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(YY\_Cart[3, 
          0] = \(7\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\)\/\(16\ \[Pi]\
\ \((x\^2 + y\^2 + z\^2)\)\^3\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[3, 1] = 
        1\/8\ \@\(21\/\[Pi]\)\ \[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\
\(x\^2 + y\^2\)]\)\ \ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \((1 - \
\(5\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[3, 
          1] = \(21\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ \
z\^2)\)\^2\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[3, 
          2] = \(\@\(105\/\(2\ \[Pi]\)\)\) \(\[ExponentialE]\^\(2\ \
\[ImaginaryI]\ ArcCos[
                  x\/\@\(x\^2 + y\^2\)]\)\) \(\((x\^2 + y\^2)\)\ z\)\/\(4\ \
\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(YY\_Cart[3, 
          2] = \(105\ \((x\^2 + y\^2)\)\^2\ z\^2\)\/\(32\ \[Pi]\ \((x\^2 + \
y\^2 + z\^2)\)\^3\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Y\_Cart[3, 
          3] = \(-\(1\/8\)\) \@\(35\/\[Pi]\)\ \[ExponentialE]\^\(3\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \ \ \((\(x\^2 + y\^2\)\/\(x\^2 \
+ y\^2 + z\^2\))\)\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[3, 
          3] = \(35\ \((x\^2 + y\^2)\)\^3\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^3\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1014, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 220, 7, 56, "Subtitle"],
Cell[2493, 81, 247, 8, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2765, 93, 77, 0, 85, "Section"],
Cell[2845, 95, 621, 19, 93, "Text"],
Cell[3469, 116, 144, 3, 92, "Text"],
Cell[3616, 121, 156, 2, 78, "NumberedEquation"],
Cell[3775, 125, 68, 2, 56, "Text"],
Cell[3846, 129, 191, 3, 78, "NumberedEquation"],
Cell[4040, 134, 152, 5, 56, "Text"],
Cell[4195, 141, 194, 8, 70, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4426, 154, 75, 0, 85, "Section"],
Cell[4504, 156, 65, 0, 56, "Text"],
Cell[4572, 158, 259, 8, 52, "NumberedEquation"],
Cell[4834, 168, 2166, 68, 156, "Text"],
Cell[7003, 238, 898, 20, 55, "Text"],

Cell[CellGroupData[{
Cell[7926, 262, 349, 8, 113, "Input"],
Cell[8278, 272, 142, 2, 94, "Output"],
Cell[8423, 276, 298, 6, 156, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8770, 288, 121, 3, 85, "Section"],
Cell[8894, 293, 114, 3, 56, "Text"],
Cell[9011, 298, 150, 6, 56, "Text"],

Cell[CellGroupData[{
Cell[9186, 308, 457, 11, 188, "Input"],
Cell[9646, 321, 51, 1, 95, "Output"],
Cell[9700, 324, 49, 1, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9786, 330, 457, 11, 188, "Input"],
Cell[10246, 343, 88, 1, 136, "Output"],
Cell[10337, 346, 85, 1, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10459, 352, 457, 11, 188, "Input"],
Cell[10919, 365, 180, 3, 98, "Output"],
Cell[11102, 370, 447, 6, 322, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11586, 381, 457, 11, 188, "Input"],
Cell[12046, 394, 121, 2, 127, "Output"],
Cell[12170, 398, 401, 5, 155, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12608, 408, 457, 11, 188, "Input"],
Cell[13068, 421, 215, 3, 137, "Output"],
Cell[13286, 426, 515, 7, 322, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13838, 438, 457, 11, 188, "Input"],
Cell[14298, 451, 185, 3, 127, "Output"],
Cell[14486, 456, 473, 6, 351, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14996, 467, 457, 11, 188, "Input"],
Cell[15456, 480, 142, 2, 129, "Output"],
Cell[15601, 484, 426, 6, 155, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16064, 495, 457, 11, 188, "Input"],
Cell[16524, 508, 225, 3, 128, "Output"],
Cell[16752, 513, 3019, 40, 1872, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19808, 558, 457, 11, 188, "Input"],
Cell[20268, 571, 198, 3, 129, "Output"],
Cell[20469, 576, 496, 7, 351, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21002, 588, 457, 11, 188, "Input"],
Cell[21462, 601, 186, 3, 98, "Output"],
Cell[21651, 606, 1431, 19, 942, "Output"]
}, Open  ]],
Cell[23097, 628, 341, 10, 80, "Text"],

Cell[CellGroupData[{
Cell[23463, 642, 2732, 61, 1479, "Input"],
Cell[26198, 705, 51, 1, 95, "Output"],
Cell[26252, 708, 49, 1, 85, "Output"],
Cell[26304, 711, 88, 1, 136, "Output"],
Cell[26395, 714, 85, 1, 91, "Output"],
Cell[26483, 717, 180, 3, 98, "Output"],
Cell[26666, 722, 93, 1, 102, "Output"],
Cell[26762, 725, 108, 2, 98, "Output"],
Cell[26873, 729, 117, 2, 107, "Output"],
Cell[26993, 733, 215, 3, 137, "Output"],
Cell[27211, 738, 128, 2, 105, "Output"],
Cell[27342, 742, 184, 3, 98, "Output"],
Cell[27529, 747, 100, 2, 104, "Output"],
Cell[27632, 751, 147, 2, 107, "Output"],
Cell[27782, 755, 151, 2, 107, "Output"],
Cell[27936, 759, 226, 3, 98, "Output"],
Cell[28165, 764, 157, 2, 131, "Output"],
Cell[28325, 768, 210, 3, 136, "Output"],
Cell[28538, 773, 133, 2, 107, "Output"],
Cell[28674, 777, 186, 3, 98, "Output"],
Cell[28863, 782, 100, 2, 104, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29012, 790, 114, 3, 85, "Section"],
Cell[29129, 795, 337, 11, 80, "Text"],

Cell[CellGroupData[{
Cell[29491, 810, 150, 2, 106, "Input"],
Cell[29644, 814, 69, 1, 94, "Output"],
Cell[29716, 817, 62, 1, 94, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29815, 823, 479, 11, 188, "Input"],
Cell[30297, 836, 142, 2, 94, "Output"],
Cell[30442, 840, 264, 4, 160, "Output"]
}, Open  ]],
Cell[30721, 847, 126, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[30872, 854, 1435, 29, 763, "Input"],
Cell[32310, 885, 51, 1, 95, "Output"],
Cell[32364, 888, 49, 1, 85, "Output"],
Cell[32416, 891, 88, 1, 136, "Output"],
Cell[32507, 894, 85, 1, 91, "Output"],
Cell[32595, 897, 187, 3, 98, "Output"],
Cell[32785, 902, 100, 2, 91, "Output"],
Cell[32888, 906, 108, 2, 98, "Output"],
Cell[32999, 910, 106, 2, 104, "Output"],
Cell[33108, 914, 222, 3, 137, "Output"],
Cell[33333, 919, 110, 2, 93, "Output"],
Cell[33446, 923, 185, 3, 127, "Output"],
Cell[33634, 928, 108, 2, 95, "Output"],
Cell[33745, 932, 142, 2, 129, "Output"],
Cell[33890, 936, 129, 2, 95, "Output"],
Cell[34022, 940, 219, 3, 98, "Output"],
Cell[34244, 945, 137, 2, 95, "Output"],
Cell[34384, 949, 198, 3, 129, "Output"],
Cell[34585, 954, 115, 2, 95, "Output"],
Cell[34703, 958, 193, 3, 98, "Output"],
Cell[34899, 963, 108, 2, 95, "Output"]
}, Open  ]],
Cell[35022, 968, 353, 10, 80, "Text"],
Cell[35378, 980, 3608, 73, 1626, "Input"],
Cell[38989, 1055, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

